/**
 * @file {@link http://xotic750.github.io/astrodate/ AstroDate}. Javascript Date object with Astronomy in mind..
 * @version 0.6.4
 * @author Graham Fairweather <xotic750@gmail.com>
 * @copyright Copyright (c) 2013 Graham Fairweather
 * @license {@link <http://www.gnu.org/licenses/gpl-3.0.html> GPL3}
 * @module astrodate
 */

/*
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

(function (globalThis, privateUndefined) {
    /* jshint -W034 */
    'use strict';

    var UWORD32 = Math.pow(2, 32),
        MAX_UINT32 = UWORD32 - 1,
        baseObject = {},
        /**
         * For hasOwnProperty bug.
         * @private
         * @readonly
         * @type {array.<string>}
         */
        defaultProperties = [
            'toString',
            'toLocaleString',
            'valueOf',
            'hasOwnProperty',
            'isPrototypeOf',
            'propertyIsEnumerable',
            'constructor'
        ],
        baseArray = [],
        baseString = '',
        toObjectString,
        baseNumber = 0,
        baseBoolean = true,
        protoName = '__proto__',
        toObject,
        extend,
        arrayIndexOf,
        objectDefineProperty,
        objectDefineProperties,
        objectFreeze,
        objectIsFrozen,
        hasProperty,
        objectHasOwnProperty,
        objectGetOwnPropertyDescriptor,
        arrayIsArray,
        objectInstanceOf,
        objectGetPrototypeOf,
        isPlainObject,
        objectKeys,
        stringTrim,
        stringRepeat,
        stringSplit,
        //stringStartsWith,
        //stringEndsWith,
        stringContains,
        toObjectFixIndexedAccess,
        //arrayUnshift,
        arrayForEach,
        arraySome,
        arrayMap,
        //arrayFilter,
        arrayReduce,
        objectIs,
        numberToInteger,
        numberIsNaN,
        numberIsFinite,
        mathSign,
        Definition,
        j2000 = {
            jdtt: '2451545.0',
            tt: '2000-01-01T12:00:00.000Z',
            tai: '2000-01-01T11:59:27.816Z',
            utc: '2000-01-01T11:58:55.816Z'
        },
        // Safari 2.x NFE bug fix
        // http://kangax.github.io/nfe/
        tempSafariNFE;

    /**
     * Returns the primitive value undefined.
     * @ignore
     * @private
     * @function
     * @return {undefined}
     */
    /*
function noop() {
    return;
}
*/

    /**
     * Coerces an input to a number.
     * @private
     * @function
     * @param {*} inputArg
     * @return {number}
     */
    function toNumber(inputArg) {
        return +inputArg;
    }

    /**
     * Returns true if the operands are strictly equal with no type conversion.
     * @private
     * @function
     * @param {*} a
     * @param {*} b
     * @return {boolean}
     */
    function strictEqual(a, b) {
        return a === b;
    }

    /**
     * Returns true if the operand number is less than limit.
     * @private
     * @param {number} number
     * @param {number} limit
     * @return {boolean}
     */
    function lt(number, limit) {
        return number < limit;
    }

    /**
     * Returns true if the operand number is less than or equal to limit.
     * @private
     * @function
     * @param {number} number
     * @param {number} limit
     * @return {boolean}
     */
    function lte(number, limit) {
        return number <= limit;
    }

    /**
     * Returns true if the operand number is greater than limit.
     * @private
     * @function
     * @param {number} number
     * @param {number} limit
     * @return {boolean}
     */
    function gt(number, limit) {
        return number > limit;
    }

    /**
     * Returns true if the operand number is greater than or equal to limit.
     * @private
     * @function
     * @param {number} number
     * @param {number} limit
     * @return {boolean}
     */
    function gte(number, limit) {
        return number >= limit;
    }

    /**
     * The mod/remainder operator returns the first operand modulo of the second operand, that is, number1 modulo number2, in the preceding statement,
     * where number1 and number2 are numbers. The modulo function is the integer remainder of dividing number1 by number2.
     * For example, 12 % 5 returns 2. The result will have the same sign as number1; that is, -1 % 2 returns -1.
     * @private
     * @function
     * @param {number} number1
     * @param {number} number2
     * @return {number}
     */
    function mod(number1, number2) {
        return number1 % number2;
    }

    /**
     * Returns a number clamped to the range set by min and max.
     * @private
     * @function
     * @param {number} number
     * @param {number} min
     * @param {number} max
     * @return {number}
     */
    function clamp(number, min, max) {
        return Math.min(Math.max(number, min), max);
    }

    /**
     * Returns true if the operand number is greater than or equal to min or if number is less than or equal to max.
     * @private
     * @function
     * @param {number} number
     * @param {number} min
     * @param {number} max
     * @return {boolean}
     */
    function inRange(number, min, max) {
        return gte(number, min) && lte(number, max);
    }

    /**
     * Returns true if the operand inputArg is undefined.
     * @private
     * @function
     * @param {*} inputArg
     * @return {boolean}
     */
    function isUndefined(inputArg) {
        return strictEqual(typeof inputArg, 'undefined');
    }

    /**
     * Returns true if the operand inputArg is null.
     * @private
     * @function
     * @param {*} inputArg
     * @return {boolean}
     */
    function isNull(inputArg) {
        return strictEqual(inputArg, null);
    }

    /**
     * Returns true if the operand inputArg is a boolean.
     * @private
     * @function
     * @param {*} inputArg
     * @return {boolean}
     */
    function isBoolean(inputArg) {
        return strictEqual(inputArg, true) || strictEqual(inputArg, false);
    }

    /**
     * Returns true if the operand inputArg is a number.
     * @private
     * @function
     * @param {*} inputArg
     * @return {boolean}
     */
    function isNumber(inputArg) {
        return strictEqual(typeof inputArg, 'number');
    }

    /**
     * Returns true if the operand inputArg is the number 0.
     * @private
     * @function
     * @param {*} inputArg
     * @return {boolean}
     */
    function isZero(inputArg) {
        return strictEqual(inputArg, 0);
    }

    /**
     * Returns true if the operand inputArg is a string.
     * @private
     * @function
     * @param {*} inputArg
     * @return {boolean}
     */
    function isString(inputArg) {
        return strictEqual(typeof inputArg, 'string');
    }

    /**
     * Returns true if the operand inputArg is an empty string.
     * @private
     * @function
     * @param {*} inputArg
     * @return {boolean}
     */
    function isEmptyString(inputArg) {
        return strictEqual(inputArg, '');
    }

    /**
     * Returns true if the operand inputArg is deemed numeric.
     * @ignore
     * @private
     * @function
     * @param {*} inputArg
     * @return {boolean}
     */
    /*
function isNumeric(inputArg) {
    var val = false,
        string;

    if (isNumber(inputArg) || isString(inputArg)) {
        string = inputArg.toString().replace(/^[+\-]?/, "");
        if (!isNaN(parseFloat(string)) && isFinite(string)) {
            val = true;
        }
    }

    return val;
}
*/

    /**
     * The abstract operation throws an error if its argument is a value that cannot be
     * converted to an Object using toObject, otherwise returns the argument.
     * @private
     * @function
     * @param {*} inputArg
     * @return {boolean}
     */
    function checkObjectCoercible(inputArg) {
        if (isUndefined(inputArg) || isNull(inputArg)) {
            throw new TypeError('Cannot convert "' + inputArg + '" to object');
        }

        return inputArg;
    }

    /**
     * The abstract operation converts its argument to a value of type Object
     * @private
     * @function
     * @param {*} inputArg
     * @return {object}
     */
    toObject = (function () {
        // Unused variable for JScript NFE bug
        // http://kangax.github.io/nfe/
        var CtrBoolean = baseBoolean.constructor,
            CtrNumber = baseNumber.constructor,
            CtrString = baseString.constructor,
            nfeToObject;

        tempSafariNFE = function nfeToObject(inputArg) {
            var object = checkObjectCoercible(inputArg);

            if (isBoolean(object)) {
                object = new CtrBoolean(object);
            } else if (isNumber(object)) {
                object = new CtrNumber(object);
            } else if (isString(object)) {
                object = new CtrString(object);
            }

            return object;
        };

        nfeToObject = null;

        return tempSafariNFE;
    }());

    /**
     * The abstract operation converts its argument to a value of type String
     * @private
     * @function
     * @param {*} inputArg
     * @return {string}
     */
    // named anyToString instead of toString because of SpiderMonkey and Blackberry bug
    function anyToString(inputArg) {
        var val;

        if (isString(inputArg)) {
            val = inputArg;
        } else if (isUndefined(inputArg)) {
            val = 'undefined';
        } else {
            val = String(inputArg);
        }

        return val;
    }

    /**
     * Return the String value that is the result of concatenating the three Strings "[object ", class, and "]".
     * @private
     * @function
     * @param {*} object
     * @return {string}
     */
    toObjectString = (function () {
        // Unused variable for JScript NFE bug
        // http://kangax.github.io/nfe/
        var toStringFN = baseObject.toString,
            nfeToObjectString;

        try {
            if (strictEqual(toStringFN.call(), '[object Undefined]') && strictEqual(toStringFN.call(null), '[object Null]')) {
                tempSafariNFE = function nfeToObjectString(object) {
                    return toStringFN.call(object);
                };
            }
        } catch (exception) {
            tempSafariNFE = null;
        }

        if (isNull(tempSafariNFE)) {
            tempSafariNFE = function nfeToObjectString(object) {
                var val;

                if (isUndefined(object)) {
                    val = '[object Undefined]';
                } else if (isNull(object)) {
                    val = '[object Null]';
                } else {
                    val = toStringFN.call(object);
                }

                return val;
            };
        }

        nfeToObjectString = null;

        return tempSafariNFE;
    }());

    /**
     * Returns true if the operand inputArg is a RegExp.
     * @private
     * @function
     * @param {*} inputArg
     * @return {boolean}
     */
    function isRegExp(inputArg) {
        return strictEqual(toObjectString(inputArg), '[object RegExp]');
    }

    /**
     * Returns true if the operand inputArg is an Object.
     * @private
     * @function
     * @param {*} inputArg
     * @return {boolean}
     */
    function isObject(inputArg) {
        return strictEqual(toObjectString(inputArg), '[object Object]');
    }

    /**
     * Returns true if the operand inputArg is a Function.
     * @private
     * @function
     * @param {*} inputArg
     * @return {boolean}
     */
    function isFunction(inputArg) {
        return strictEqual(toObjectString(inputArg), '[object Function]');
    }

    /**
     * Returns true if the operand inputArg is an argumenta object.
     * @ignore
     * @private
     * @function
     * @param {*} inputArg
     * @return {boolean}
     */
    /*
function isArguments(inputArg) {
    return strictEqual(toObjectString(inputArg), '[object Arguments]');
}
*/

    /**
     * Returns true if the operand inputArg is of type Object.
     * @private
     * @function
     * @param {*} inputArg
     * @return {boolean}
     */
    function isTypeOfObject(inputArg) {
        return strictEqual(typeof inputArg, 'object') || isRegExp(inputArg);
    }

    /**
     * Returns true if the operand inputArg is of type Object but not if null.
     * @private
     * @function
     * @param {*} inputArg
     * @return {boolean}
     */
    function isTypeObject(inputArg) {
        return !isNull(inputArg) && isTypeOfObject(inputArg);
    }

    /**
     * The function takes one argument inputArg, and returns the Boolean value true if the argument is an object
     * whose class internal property is "Array"; otherwise it returns false.
     * @private
     * @function
     * @param {*} inputArg
     * @return {boolean}
     */
    // named arrayIsArray instead of isArray because of SpiderMonkey and Blackberry bug
    arrayIsArray = (function () {
        // Unused variable for JScript NFE bug
        // http://kangax.github.io/nfe/
        var isArrayFN = baseArray.isArray,
            nfeIsArray;

        if (isFunction(isArrayFN)) {
            tempSafariNFE = isArrayFN;
        } else {
            tempSafariNFE = function nfeIsArray(inputArg) {
                return strictEqual(toObjectString(inputArg), '[object Array]');
            };
        }

        nfeIsArray = null;

        return tempSafariNFE;
    }());

    /**
     * The function takes one argument inputArg, if the argument is an object whose class internal property is "Array"
     * or is an Object but not a Function and has a length property; returns true if length is zero otherwise it returns false.
     * Otherwise returns null if the argument does not match the rquirements.
     * @private
     * @function
     * @param {array} inputArg
     * @return {(boolean|null)}
     */
    function isEmptyArray(inputArg) {
        var val;

        if (arrayIsArray(inputArg) || (isTypeObject(inputArg) && !isFunction(inputArg) && hasProperty(inputArg, 'length'))) {
            val = isZero(inputArg.length);
        } else {
            val = null;
        }

        return val;
    }

    /**
     * Returns the first element of an array; otherwise returns undefined.
     * @private
     * @function
     * @param {array} inputArg
     * @return {(*|undefined)}
     */
    function arrayFirst(inputArg) {
        var val;

        if (!isEmptyArray(inputArg)) {
            val = inputArg[0];
        }

        return val;
    }

    /**
     * Returns the last element of an array; otherwise returns undefined.
     * @private
     * @function
     * @param {array} inputArg
     * @return {(*|undefined)}
     */
    function arrayLast(inputArg) {
        var val;

        if (!isEmptyArray(inputArg)) {
            val = inputArg[inputArg.length - 1];
        }

        return val;
    }

    /**
     * Returns true if the operand inputArg is a Date object.
     * @private
     * @function
     * @param {*} inputArg
     * @return {boolean}
     */
    function isDate(inputArg) {
        return strictEqual(toObjectString(inputArg), '[object Date]');
    }

    /**
     * Determines whether two values are the same value.
     * @private
     * @function
     * @param {*} x
     * @param {*} y
     * @return {boolean}
     */
    // named objectIs instead of objectIs because of SpiderMonkey and Blackberry bug
    objectIs = (function () {
        // Unused variable for JScript NFE bug
        // http://kangax.github.io/nfe/
        var isIsFn = baseObject.constructor.is,
            nfeIs;

        if (isFunction(isIsFn)) {
            tempSafariNFE = isIsFn;
        } else {
            tempSafariNFE = function nfeIs(x, y) {
                var val;

                if (strictEqual(x, y)) {
                    if (isZero(x)) {
                        val = strictEqual(1 / x, 1 / y);
                    } else {
                        val = true;
                    }
                } else {
                    val = !strictEqual(x, x) && !strictEqual(y, y);
                }

                return val;
            };
        }

        nfeIs = null;

        return tempSafariNFE;
    }());

    /**
     * The function determines whether the passed value is NaN. More robust version of the original global isNaN.
     * @private
     * @function
     * @param {*} number
     * @return {boolean}
     */
    // named numberIsNaN instead of isNaN because of SpiderMonkey and Blackberry bug
    numberIsNaN = (function () {
        // Unused variable for JScript NFE bug
        // http://kangax.github.io/nfe/
        var isNaNFN = baseNumber.constructor.isNaN,
            nfeIsNaN;

        if (isFunction(isNaNFN)) {
            tempSafariNFE = isNaNFN;
        } else {
            tempSafariNFE = function nfeIsNaN(number) {
                return objectIs(number, NaN);
            };
        }

        nfeIsNaN = null;

        return tempSafariNFE;
    }());

    /**
     * The function determines whether the passed value is finite. More robust version of the original global isFinite.
     * @private
     * @function
     * @param {*} number
     * @return {boolean}
     */
    // named numberIsFinite instead of isFinite because of SpiderMonkey and Blackberry bug
    numberIsFinite = (function () {
        // Unused variable for JScript NFE bug
        // http://kangax.github.io/nfe/
        var isFiniteFN = baseNumber.constructor.isFinite,
            nfeIsFinite;

        if (isFunction(isFiniteFN)) {
            tempSafariNFE = isFiniteFN;
        } else {
            tempSafariNFE = function nfeIsFinite(number) {
                return isNumber(number) && isFinite(number);
            };
        }

        nfeIsFinite = null;

        return tempSafariNFE;
    }());

    /**
     * The function returns the sign of a number, indicating whether the number is positive, negative or zero.
     * This function has 5 kinds of return values, 1, -1, 0, -0, NaN, which represent "positive number",
     * "negative number", "positive zero",  "negative zero" and NaN respectively
     * @private
     * @function
     * @param {*} value
     * @return {number}
     */
    // named mathSign instead of sign because of SpiderMonkey and Blackberry bug
    mathSign = (function () {
        // Unused variable for JScript NFE bug
        // http://kangax.github.io/nfe/
        var signFN = Math.sign,
            nfeSign;

        if (isFunction(signFN)) {
            tempSafariNFE = signFN;
        } else {
            tempSafariNFE = function nfeSign(value) {
                var number = toNumber(value),
                    val;

                if (isZero(number) || numberIsNaN(number)) {
                    val = number;
                } else if (lt(number, 0)) {
                    val = -1;
                } else {
                    val = 1;
                }

                return val;
            };
        }

        nfeSign = null;

        return tempSafariNFE;
    }());

    /**
     * The function evaluates the passed value and converts it to an integer.
     * @private
     * @function
     * @param {*} inputArg
     * @return {number}
     */
    // named numberToInteger instead of toInteger because of SpiderMonkey and Blackberry bug
    numberToInteger = (function () {
        // Unused variable for JScript NFE bug
        // http://kangax.github.io/nfe/
        var toIntegerFN = Number.toInteger,
            nfeToInteger;

        if (isFunction(toIntegerFN)) {
            tempSafariNFE = toIntegerFN;
        } else {
            tempSafariNFE = function nfeToInteger(inputArg) {
                var number = toNumber(inputArg),
                    val;

                if (numberIsNaN(number)) {
                    val = +0;
                } else if (isZero(number) || !numberIsFinite(number)) {
                    val = number;
                } else {
                    val = mathSign(number) * Math.floor(Math.abs(number));
                }

                return val;
            };
        }

        nfeToInteger = null;

        return tempSafariNFE;
    }());

    /**
     * The abstract operation converts its argument to one of 2^32 integer values in the range -2^31 through 2^31-1, inclusive.
     * @ignore
     * @private
     * @function
     * @param {*} inputArg
     * @return {number}
     */
    /*
function toInt32(inputArg) {
    var number = toNumber(inputArg),
        int32bit,
        val;

    if (isZero(number) || !numberIsFinite(number)) {
        val = +0;
    } else {
        int32bit = mod(mathSign(number) * Math.floor(Math.abs(number)), UWORD32);
        if (gt(int32bit, UWORD32)) {
            val = int32bit - UWORD32;
        } else {
            val = int32bit;
        }
    }

    return val;
}
*/

    /**
     * The abstract operation converts its argument to one of 2^32 integer values in the range 0 through 2^32-1,inclusive.
     * @private
     * @function
     * @param {*} inputArg
     * @return {number}
     */
    function toUint32(inputArg) {
        var number = toNumber(inputArg),
            val;

        if (isZero(number) || !numberIsFinite(number)) {
            val = +0;
        } else {
            val = mod(mathSign(number) * Math.floor(Math.abs(number)), UWORD32);
        }

        return val;
    }

    /**
     * Splits a String object into an array of strings by separating the string into substrings.
     * @private
     * @function
     * @param {string} str
     * @param {string} [separator]
     * @param {number} [limit]
     * @return {array.<string>}
     */
    // named stringSplit instead of split because of SpiderMonkey and Blackberry bug
    stringSplit = (function () {
        // Unused variable for JScript NFE bug
        // http://kangax.github.io/nfe/
        var splitFN = baseString.split,
            compliantExecNpcg = isUndefined(/()??/.exec('')[1]),
            nfeSplit;

        function replacer(separator, match, args) {
            var length = args.length - 2,
                index;

            arrayFirst(match).replace(separator, function () {
                for (index = 1; lt(index, length); index += 1) {
                    if (isUndefined(arguments[index])) {
                        match[index] = privateUndefined;
                    }
                }
            });
        }

        tempSafariNFE = function nfeSplit(str, separator, limit) {
            var string = anyToString(checkObjectCoercible(str)),
                output,
                flags,
                lastLastIndex,
                separator2,
                match,
                lastIndex,
                lastLength,
                val;

            if (isRegExp(separator)) {
                flags = 'g';
                if (separator.ignoreCase) {
                    flags += 'i';
                }

                if (separator.multiline) {
                    flags += 'm';
                }

                if (separator.extended) {
                    flags += 'x';
                }

                if (separator.sticky) {
                    flags += 'y';
                }

                separator = new RegExp(separator.source, flags);
                if (!compliantExecNpcg) {
                    separator2 = new RegExp('^' + separator.source + '$(?!\\s)', flags);
                }

                if (isUndefined(limit)) {
                    limit = MAX_UINT32;
                } else {
                    limit = toUint32(limit);
                }

                output = [];
                flags = 'g';
                lastLastIndex = 0;
                match = separator.exec(string);
                while (match) {
                    lastIndex = match.index + arrayFirst(match).length;
                    if (lastIndex > lastLastIndex) {
                        output.push(string.slice(lastLastIndex, match.index));
                        if (!compliantExecNpcg && gt(match.length, 1)) {
                            replacer(separator2, match, arguments);
                        }

                        if (gt(match.length, 1) && lt(match.index, string.length)) {
                            output = output.concat(match.slice(1));
                        }

                        lastLength = arrayFirst(match).length;
                        lastLastIndex = lastIndex;
                        if (gte(output.length, limit)) {
                            break;
                        }
                    }

                    if (strictEqual(separator.lastIndex, match.index)) {
                        separator.lastIndex += 1;
                    }

                    match = separator.exec(string);
                }

                if (strictEqual(lastLastIndex, string.length)) {
                    if (lastLength || !separator.test('')) {
                        output.push('');
                    }
                } else {
                    output.push(string.slice(lastLastIndex));
                }

                if (gt(output.length, limit)) {
                    return output.slice(0, limit);
                }

                val = output;
            } else {
                val = splitFN.call(str, separator, limit);
            }

            return val;
        };

        nfeSplit = null;

        return tempSafariNFE;
    }());

    /**
     * Coerces its argument to a string and returns the first character of that string.
     * If the argument is an empty string, returns an empty string.
     * Throws an error if the argument can not be coerced, i.e. null or undefined.
     * @private
     * @function
     * @param {string} inputArg
     * @return {string}
     */
    function firstChar(inputArg) {
        return anyToString(checkObjectCoercible(inputArg)).charAt(0);
    }

    /**
     * Coerces inputArg to a string and compares the first character to the argument character.
     * Throws an error if the arguments can not be coerced, i.e. null or undefined.
     * @private
     * @function
     * @param {string} inputArg
     * @param {string} character
     * @return {boolean}
     */
    function firstCharIs(inputArg, character) {
        return strictEqual(firstChar(inputArg), firstChar(character));
    }

    /**
     * Coerces its argument to a string and returns the last character of that string.
     * If the argument is an empty string, returns an empty string.
     * Throws an error if the argument can not be coerced, i.e. null or undefined.
     * @private
     * @function
     * @param {string} inputArg
     * @return {string}
     */
    function lastChar(inputArg) {
        var thisStr = anyToString(checkObjectCoercible(inputArg));

        return thisStr.charAt(thisStr.length - 1);
    }

    /**
     * Coerces inputArg to a string and compares the last character to the argument character.
     * Throws an error if the arguments can not be coerced, i.e. null or undefined.
     * @private
     * @function
     * @param {string} inputArg
     * @param {string} character
     * @return {boolean}
     */
    function lastCharIs(inputArg, character) {
        return strictEqual(lastChar(inputArg), firstChar(character));
    }

    /**
     * Coerces inputArg to a string and counts the occurences of the argument character.
     * Throws an error if the arguments can not be coerced, i.e. null or undefined.
     * @private
     * @function
     * @param {string} inputArg
     * @param {string} character
     * @return {number}
     */
    function countCharacter(inputArg, character) {
        return clamp(stringSplit(anyToString(checkObjectCoercible(inputArg)), firstChar(character)).length - 1, 0, Number.POSITIVE_INFINITY);
    }

    /**
     * Coerces inputArg to a string and repeatedly adds the argument character to the beginning until
     * the string is greater than or equal to the specified length.
     * Throws an error if the arguments can not be coerced, i.e. null or undefined.
     * @private
     * @function
     * @param {string} inputArg
     * @param {string} character
     * @param {number} size
     * @return {string}
     */
    function padLeadingChar(inputArg, character, size) {
        var string = anyToString(checkObjectCoercible(inputArg)),
            singleChar = firstChar(character),
            count = numberToInteger(size) - string.length;

        if (lt(count, 0) || strictEqual(count, Infinity)) {
            count = 0;
        }

        return stringRepeat(singleChar, count) + string;
    }

    /**
     * Repeat the current string several times, return the new string.
     * @private
     * @function
     * @param {string} string
     * @param {number} times
     * @return {string}
     */
    // named stringRepeat instead of repeat because of SpiderMonkey and Blackberry bug
    stringRepeat = (function () {
        // Unused variable for JScript NFE bug
        // http://kangax.github.io/nfe
        var repeatFN = baseString.constructor.repeat,
            nfeRepeat;

        function rep(s, times) {
            var half,
                val;

            if (lt(times, 1)) {
                val = '';
            } else if (mod(times, 2)) {
                val = rep(s, times - 1) + s;
            } else {
                half = rep(s, times / 2);
                val = half + half;
            }

            return val;
        }

        if (isFunction(repeatFN)) {
            tempSafariNFE = function nfeRepeat(string, times) {
                return repeatFN.call(string, times);
            };
        } else {
            tempSafariNFE = function nfeRepeat(string, count) {
                var thisString = anyToString(checkObjectCoercible(string)),
                    times = numberToInteger(count);

                if (lt(times, 0) || strictEqual(times, Infinity)) {
                    throw new RangeError();
                }

                return rep(thisString, times);
            };
        }

        nfeRepeat = null;

        return tempSafariNFE;
    }());

    /**
     * Determines whether a string begins with the characters of another string, returning true or false as appropriate.
     * @ignore
     * @private
     * @function
     * @param {string} string
     * @param {string} searchString
     * @param {number} [position]
     * @return {boolean}
     */
    /*
// named stringStartsWith instead of startsWith because of SpiderMonkey and Blackberry bug
stringStartsWith = (function () {
    // Unused variable for JScript NFE bug
    // http://kangax.github.io/nfe
    var startsWithFN = baseString.constructor.startsWith,
        nfeStartsWith;

    if (isFunction(startsWithFN)) {
        tempSafariNFE = function nfeStartsWith(string, searchString, position) {
            return startsWithFN.call(string, searchString, position);
        };
    } else {
        tempSafariNFE = function nfeStartsWith(string, searchString, position) {
            var thisStr = anyToString(checkObjectCoercible(string)),
                searchStr = anyToString(searchString),
                thisLen = thisStr.length,
                start = clamp(toInteger(position), 0, thisLen);

            return strictEqual(thisStr.slice(start, start + thisLen), searchStr);
        };
    }

    nfeStartsWith = null;

    return tempSafariNFE;
}());
*/

    /**
     * Determines whether a string ends with the characters of another string, returning true or false as appropriate.
     * @ignore
     * @private
     * @function
     * @param {string} string
     * @param {string} searchString
     * @param {number} [position]
     * @return {boolean}
     */
    /*
// named stringEndsWith instead of endsWith because of SpiderMonkey and Blackberry bug
stringEndsWith = (function () {
    // Unused variable for JScript NFE bug
    // http://kangax.github.io/nfe
    var endsWithFN = baseString.constructor.endsWith,
        nfeEndsWith;

    if (isFunction(endsWithFN)) {
        tempSafariNFE = function nfeEndsWith(string, searchString, position) {
            return endsWithFN.call(string, searchString, position);
        };
    } else {
        tempSafariNFE = function nfeEndsWith(string, searchString, position) {
            var thisStr = anyToString(checkObjectCoercible(string)),
                searchStr = anyToString(searchString),
                thisLen = thisStr.length,
                end,
                start;

            if (isUndefined(position)) {
                position = thisLen;
            } else {
                position = toInteger(position);
            }

            end = clamp(position, 0, thisLen);
            start = end - searchStr.length;

            return gte(start, 0) && strictEqual(thisStr.slice(start, end), searchStr);
        };
    }

    nfeEndsWith = null;

    return tempSafariNFE;
}());
*/

    /**
     * Determines whether a string contains the characters of another string, returning true or false as appropriate.
     * @private
     * @function
     * @param {string} string
     * @param {string} searchString
     * @param {number} [position]
     * @return {boolean}
     */
    // named stringContains instead of contains because of SpiderMonkey and Blackberry bug
    stringContains = (function () {
        // Unused variable for JScript NFE bug
        // http://kangax.github.io/nfe
        var containsFN = baseString.constructor.contains,
            nfeContains;

        if (isFunction(containsFN)) {
            tempSafariNFE = function nfeContains(string, searchString, position) {
                return containsFN.call(string, searchString, position);
            };
        } else {
            tempSafariNFE = function nfeContains(string, searchString, position) {
                var thisStr = anyToString(checkObjectCoercible(string)),
                    searchStr = anyToString(searchString),
                    thisLen = thisStr.length;

                if (isUndefined(position)) {
                    position = 0;
                } else {
                    position = numberToInteger(position);
                }

                return !strictEqual(baseString.indexOf.call(thisStr, searchStr, clamp(position, 0, thisLen)), -1);
            };
        }

        nfeContains = null;

        return tempSafariNFE;
    }());

    /**
     * Return the value of the [[Prototype]] internal property of object.
     * @private
     * @function
     * @param {object} object
     * @return {Prototype}
     */
    // named objectGetPrototypeOf instead of getPrototypeOf because of SpiderMonkey and Blackberry bug
    objectGetPrototypeOf = (function () {
        // Unused variable for JScript NFE bug
        // http://kangax.github.io/nfe
        var getPrototypeOfFN = baseObject.constructor.getPrototypeOf,
            nfeGetPrototypeOf,
            bocProto;

        if (isFunction(getPrototypeOfFN)) {
            tempSafariNFE = getPrototypeOfFN;
        } else if (isNull(baseObject.constructor.prototype[protoName])) {
            tempSafariNFE = function nfeGetPrototypeOf(object) {
                return object[protoName];
            };
        } else {
            bocProto = baseObject.constructor.prototype;
            tempSafariNFE = function nfeGetPrototypeOf(object) {
                if (strictEqual(object, bocProto)) {
                    return null;
                }

                var ctrProto = object.constructor.prototype;

                if (strictEqual(object, ctrProto)) {
                    return bocProto;
                }

                return ctrProto;
            };
        }

        nfeGetPrototypeOf = null;

        return tempSafariNFE;
    }());

    /**
     * Returns true if the specified property is in the specified object.
     * @private
     * @function
     * @param {object} object
     * @param {string} property
     * @return {boolean}
     */
    hasProperty = (function () {
        // Unused variable for JScript NFE bug
        // http://kangax.github.io/nfe
        var nfeHasProperty;

        tempSafariNFE = function nfehasProperty(object, property) {
            return property in object;
        };

        nfeHasProperty = null;

        return tempSafariNFE;
    }());

    /**
     * Returns true if the specified searchElement is in the specified array.
     * Using strict equality (the same method used by the === comparison operator).
     * @private
     * @function
     * @param {array} array
     * @param {*} searchElement
     * @return {boolean}
     */
    function arrayContains(array, searchElement) {
        return !strictEqual(arrayIndexOf(array, searchElement), -1);
    }

    /**
     * Returns a boolean indicating whether the object has the specified property.
     * This function can be used to determine whether an object has the specified property as a direct property of that object;
     * unlike the hasProperty function, this method does not check down the object's prototype chain.
     * @private
     * @function
     * @param {object} object
     * @param {string} property
     * @return {boolean}
     */
    // http://ecma-international.org/ecma-262/5.1/#sec-15.2.4.5
    // Create our own local "hasOwnProperty" function: native -> shim -> sham
    // named objectHasOwnProperty instead of hasOwnProperty because of SpiderMonkey and Blackberry bug
    objectHasOwnProperty = (function () {
        // Unused variable for JScript NFE bug
        // http://kangax.github.io/nfe
        var hasOwnPropertyFN = baseObject.hasOwnProperty, // to combat old IE8- issues, min support IE6
            propertyIsEnumerableFN = baseObject.propertyIsEnumerable,
            hasDontEnumBug = true,
            testObject = {
                toString: null
            },
            nfeHasOwnProperty;

        // use nfeHasOwnProperty to save a var
        for (nfeHasOwnProperty in testObject) {
            if (strictEqual(nfeHasOwnProperty, 'toString') && isNull(testObject[nfeHasOwnProperty])) {
                hasDontEnumBug = false;
            }
        }

        function checkDontEnums(object, property) {
            return hasDontEnumBug && arrayContains(defaultProperties, property) && hasProperty(object, property) && !strictEqual(object[property], objectGetPrototypeOf(object)[property]);
        }

        if (isFunction(hasOwnPropertyFN)) {
            tempSafariNFE = function nfeHasOwnProperty(object, property) {
                return hasOwnPropertyFN.call(object, property) || checkDontEnums(object, property);
            };
        } else if (isFunction(propertyIsEnumerableFN)) {
            tempSafariNFE = function nfeHasOwnProperty(object, property) {
                return propertyIsEnumerableFN.call(object, property) || checkDontEnums(object, property);
            };
        } else {
            tempSafariNFE = function nfeHasOwnProperty(object, property) {
                return hasProperty(object, property) && isUndefined(objectGetPrototypeOf(object)[property]);
            };
        }

        nfeHasOwnProperty = null;

        return tempSafariNFE;
    }());

    /**
     * The abstract operation converts its argument to a value of type Object but fixes some environment bugs.
     * @private
     * @function
     * @param {*} inputArg
     * @return {object}
     */
    toObjectFixIndexedAccess = (function () {
        // Unused variable for JScript NFE bug
        // http://kangax.github.io/nfe
        var boxedString = baseObject.constructor('a'),
            splitString = !strictEqual(boxedString[0], 'a') || !hasProperty(boxedString, 0),
            nfeToObjectFixIndexedAccess;

        if (splitString) {
            tempSafariNFE = function nfeToObjectFixIndexedAccess(inputArg) {
                var object;

                if (isString(inputArg)) {
                    object = stringSplit(inputArg, '');
                } else {
                    object = toObject(inputArg);
                }

                return object;
            };
        } else {
            tempSafariNFE = toObject;
        }

        nfeToObjectFixIndexedAccess = null;

        return tempSafariNFE;
    }());

    /**
     * Executes a provided function once per array element.
     * @private
     * @function
     * @param {array} array
     * @param {function} fn
     * @param {object} [thisArg]
     */
    // named arrayForEach instead of forEach because of SpiderMonkey and Blackberry bug
    arrayForEach = (function () {
        // Unused variable for JScript NFE bug
        // http://kangax.github.io/nfe
        var forEachFN = baseArray.forEach,
            nfeForEach;

        if (isFunction(forEachFN)) {
            tempSafariNFE = function nfeForEach(array, fn, thisArg) {
                return forEachFN.call(array, fn, thisArg);
            };
        } else {
            tempSafariNFE = function nfeForEach(array, fn, thisArg) {
                var object = toObjectFixIndexedAccess(array),
                    length,
                    index;

                if (!isFunction(fn)) {
                    throw new TypeError(fn + ' is not a function');
                }

                for (index = 0, length = toUint32(object.length); lt(index, length); index += 1) {
                    if (hasProperty(object, index)) {
                        fn.call(thisArg, object[index], index, object);
                    }
                }
            };
        }

        nfeForEach = null;

        return tempSafariNFE;
    }());

    /**
     * Tests whether some element in the array passes the test implemented by the provided function.
     * @private
     * @function
     * @param {array} array
     * @param {function} fn
     * @param {object} [thisArg]
     * @return {boolean}
     */
    // named arraySome instead of some because of SpiderMonkey and Blackberry bug
    arraySome = (function () {
        // Unused variable for JScript NFE bug
        // http://kangax.github.io/nfe
        var someFN = baseArray.some,
            nfeSome;

        if (isFunction(someFN)) {
            tempSafariNFE = function nfeSome(array, fn, thisArg) {
                return someFN.call(array, fn, thisArg);
            };
        } else {
            tempSafariNFE = function nfeSome(array, fn, thisArg) {
                var object = toObjectFixIndexedAccess(array),
                    length,
                    index,
                    val;

                if (!isFunction(fn)) {
                    throw new TypeError(fn + ' is not a function');
                }

                for (index = 0, length = toUint32(object.length), val = false; lt(index, length); index += 1) {
                    if (hasProperty(object, index) && fn.call(thisArg, object[index], index, object)) {
                        val = true;
                        break;
                    }
                }

                return val;
            };
        }

        nfeSome = null;

        return tempSafariNFE;
    }());

    /**
     * Creates a new array with the results of calling a provided function on every element in this array.
     * @private
     * @function
     * @param {array} array
     * @param {function} fn
     * @param {object} [thisArg]
     * @return {array}
     */
    // named arrayMap instead of map because of SpiderMonkey and Blackberry bug
    arrayMap = (function () {
        // Unused variable for JScript NFE bug
        // http://kangax.github.io/nfe
        var mapFN = baseArray.map,
            nfeMap;

        if (isFunction(mapFN)) {
            tempSafariNFE = function nfeMap(array, fn, thisArg) {
                return mapFN.call(array, fn, thisArg);
            };
        } else {
            tempSafariNFE = function nfeMap(array, fn, thisArg) {
                var object = toObjectFixIndexedAccess(array),
                    length,
                    index,
                    arr;

                if (!isFunction(fn)) {
                    throw new TypeError(fn + ' is not a function');
                }

                for (index = 0, length = toUint32(object.length), arr = []; lt(index, length); index += 1) {
                    arr[index] = fn.call(thisArg, object[index], index, object);
                }

                return arr;
            };
        }

        nfeMap = null;

        return tempSafariNFE;
    }());

    /*
function argumentsSlice(args, start, end) {
    var val;

    if (isArguments(args)) {
        val = baseArray.slice.call(args, start, end);
    }

    return val;
}
*/

    // named arrayUnshift instead of unshift because of SpiderMonkey and Blackberry bug
    /*
arrayUnshift = (function () {
    // Unused variable for JScript NFE bug
    // http://kangax.github.io/nfe
    var unshiftFN = baseArray.unshift,
        nfeUnshift;

    if (strictEqual(unshiftFN.call([], 0), 1)) {
        tempSafariNFE = function nfeUnshift(array) {
            return unshiftFN.apply(array, argumentsSlice(arguments, 1));
        };
    } else {
        tempSafariNFE = function nfeUnshift(array) {
            unshiftFN.apply(array, argumentsSlice(arguments, 1));

            return array.length;
        };
    }

    nfeUnshift = null;

    return tempSafariNFE;
}());
*/

    /**
     * Creates a new array with all elements that pass the test implemented by the provided function.
     * @ignore
     * @private
     * @function
     * @param {array} array
     * @param {function} fn
     * @param {object} [thisArg]
     * @return {array}
     */
    // named arrayFilter instead of filter because of SpiderMonkey and Blackberry bug
    /*
arrayFilter = (function () {
    // Unused variable for JScript NFE bug
    // http://kangax.github.io/nfe
    var filterFN = baseArray.filter,
        nfeFilter;

    if (isFunction(filterFN)) {
        tempSafariNFE = function nfeFilter(array, fn, thisArg) {
            return filterFN.call(array, fn, thisArg);
        };
    } else {
        tempSafariNFE = function nfeFilter(array, fn, thisArg) {
            var object = toObjectFixIndexedAccess(array),
                length,
                arr,
                index,
                element;

            if (!isFunction(fn)) {
                throw new TypeError(fn + ' is not a function');
            }

            for (index = 0, length = toUint32(object.length), arr = []; lt(index, length); index += 1) {
                element = object[index];
                if (fn.call(thisArg, element, index, object)) {
                    arr[index] = element;
                }
            }

            return arr;
        };
    }

    nfeFilter = null;

    return tempSafariNFE;
}());
*/

    /**
     * Apply a function against an accumulator and each value of the array (from left-to-right) as to reduce it to a single value.
     * @private
     * @function
     * @param {array} array
     * @param {function} fn
     * @param {*} [initialValue]
     * @return {*}
     */
    // named arrayReduce instead of reduce because of SpiderMonkey and Blackberry bug
    arrayReduce = (function () {
        // Unused variable for JScript NFE bug
        // http://kangax.github.io/nfe
        var reduceFN = baseArray.reduce,
            errString = 'Reduce of empty array with no initial value',
            nfeReduce;

        if (isFunction(reduceFN)) {
            tempSafariNFE = function nfeReduce(array, fn, initialValue) {
                return reduceFN.call(array, fn, initialValue);
            };
        } else {
            tempSafariNFE = function nfeReduce(array, fn, initialValue) {
                var object = toObjectFixIndexedAccess(array),
                    length,
                    k,
                    index,
                    accumulator,
                    kPresent;

                if (!isFunction(fn)) {
                    throw new TypeError(fn + ' is not a function');
                }

                if (isZero(length) && lt(arguments.length, 3)) {
                    throw new TypeError(errString);
                }

                k = 0;
                if (gt(arguments.length, 2)) {
                    accumulator = initialValue;
                } else {
                    for (k = 0, length = toUint32(object.length), kPresent = false; !kPresent && lt(k, length); k += 1) {
                        kPresent = hasProperty(object, k);
                        if (kPresent) {
                            accumulator = object[k];
                        }
                    }

                    if (!kPresent) {
                        throw new TypeError(errString);
                    }
                }

                for (index = k; lt(index, length); index += 1) {
                    if (hasProperty(object, index)) {
                        accumulator = fn.call(privateUndefined, accumulator, object[index], index, object);
                    }
                }

                return accumulator;
            };
        }

        nfeReduce = null;

        return tempSafariNFE;
    }());

    /**
     * Removes whitespace from both ends of the string.
     * @private
     * @function
     * @param {string} inputArg
     * @return {string}
     */
    // named stringTrim instead of trim because of SpiderMonkey and Blackberry bug
    stringTrim = (function () {
        // Unused variable for JScript NFE bug
        // http://kangax.github.io/nfe/
        var trimFN = baseString.trim,
            whiteSpacesList = [
                0x0009, // Tab
                0x000a, // Line Feed
                0x000b, // Vertical Tab
                0x000c, // Form Feed
                0x000d, // Carriage Return
                0x0020, // Space
                0x0085, // Next line
                0x00a0, // No-break space
                0x1680, // Ogham space mark
                0x180e, // Mongolian vowel separator
                0x2000, // En quad
                0x2001, // Em quad
                0x2002, // En space
                0x2003, // Em space
                0x2004, // Three-per-em space
                0x2005, // Four-per-em space
                0x2006, // Six-per-em space
                0x2007, // Figure space
                0x2008, // Punctuation space
                0x2009, // Thin space
                0x200a, // Hair space
                0x200b, // Zero width space
                0x2028, // Line separator
                0x2029, // Paragraph separator
                0x202f, // Narrow no-break space
                0x205f, // Medium mathematical space
                0x3000, // Ideographic space
                0xfeff // Byte Order Mark
            ],
            testString,
            whiteSpacesString,
            wsTrimRX,
            nfeTrim,
            nfeBuildTestString,
            nfeBuildWhiteSpaceString;

        tempSafariNFE = function nfeBuildTestString(previous, element) {
            return previous + String.fromCharCode(element);
        };

        testString = arrayReduce(whiteSpacesList, tempSafariNFE, '');
        if (isFunction(trimFN) && isZero(trimFN.call(testString).length)) {
            tempSafariNFE = function nfeTrim(inputArg) {
                return trimFN.call(inputArg);
            };
        } else {
            tempSafariNFE = function nfeBuildWhiteSpaceString(previous, element) {
                return previous + '\\u' + padLeadingChar(element.toString(16), '0', 4);
            };

            whiteSpacesString = arrayReduce(whiteSpacesList, tempSafariNFE, '');
            wsTrimRX = new RegExp('^[' + whiteSpacesString + ']+|[' + whiteSpacesString + ']+$', 'g');
            tempSafariNFE = function nfeTrim(inputArg) {
                return anyToString(checkObjectCoercible(inputArg)).replace(wsTrimRX, '');
            };
        }

        nfeTrim = null;
        nfeBuildTestString = null;
        nfeBuildWhiteSpaceString = null;

        return tempSafariNFE;
    }());

    /**
     * Returns the first index at which a given element can be found in the array, or -1 if it is not present.
     * @private
     * @function
     * @param {array} array
     * @param {object} searchElement
     * @param {number} [fromIndex]
     * @return {number}
     */
    // http://ecma-international.org/ecma-262/5.1/#sec-15.4.4.14
    // Create our own local "indexOf" function: native -> polyfill
    // named arrayIndexOf instead of indexOf because of SpiderMonkey and Blackberry bug
    arrayIndexOf = (function () {
        // Unused variable for JScript NFE bug
        // http://kangax.github.io/nfe
        var indexOfFN = baseArray.indexOf,
            nfeIndexOf;

        if (isFunction(indexOfFN) && strictEqual(indexOfFN.call([0, 1], 1, 2), 1)) {
            tempSafariNFE = function nfeIndexOf(array, searchElement, fromIndex) {
                return indexOfFN.call(array, searchElement, fromIndex);
            };
        } else {
            tempSafariNFE = function nfeIndexOf(array, searchElement, fromIndex) {
                var object = toObjectFixIndexedAccess(array),
                    length = toUint32(object.length),
                    index,
                    start,
                    val;

                if (isZero(length)) {
                    val = -1;
                } else {
                    if (gt(arguments.length, 2)) {
                        fromIndex = numberToInteger(fromIndex);
                    } else {
                        fromIndex = 0;
                    }

                    if (gte(fromIndex, length)) {
                        val = -1;
                    } else {
                        if (gte(fromIndex, 0)) {
                            start = fromIndex;
                        } else {
                            start = length - Math.abs(fromIndex);
                        }

                        if (lt(start, 0)) {
                            start = 0;
                        }

                        for (index = start, val = -1; lt(index, length); index += 1) {
                            if (hasProperty(object, index) && strictEqual(searchElement, object[index])) {
                                val = index;
                                break;
                            }
                        }
                    }
                }

                return val;
            };
        }

        nfeIndexOf = null;

        return tempSafariNFE;
    }());

    /**
     * Returns an array of a given object's own enumerable properties, in the same order as that provided by a for-in loop
     * (the difference being that a for-in loop enumerates properties in the prototype chain as well).
     * @private
     * @function
     * @param {object} object
     * @return {array}
     */
    // named objectKeys instead of keys because of SpiderMonkey and Blackberry bug
    objectKeys = (function () {
        // Unused variable for JScript NFE bug
        // http://kangax.github.io/nfe
        var keysFN = baseObject.keys,
            nfeKeys;

        if (isFunction(keysFN)) {
            tempSafariNFE = keysFN;
        } else {
            tempSafariNFE = function nfeKeys(object) {
                if (!isTypeObject(object) && !isFunction(object)) {
                    throw new TypeError('Object.keys called on a non-object');
                }

                var props = [],
                    prop;

                for (prop in object) {
                    if (objectHasOwnProperty(object, prop)) {
                        props.push(prop);
                    }
                }

                return props;
            };
        }

        nfeKeys = null;

        return tempSafariNFE;
    }());

    /**
     * Defines a new property directly on an object, or modifies an existing property on an object, and returns the object.
     * @private
     * @function
     * @param {object} object
     * @param {string} property
     * @param {object} descriptor
     * @return {object}
     */
    // http://ecma-international.org/ecma-262/5.1/#sec-15.4.4.14
    // Create our own local "defineProperty" function: native -> sham
    // named objectDefineProperty instead of defineProperty because of SpiderMonkey and Blackberry bug
    objectDefineProperty = (function () {
        // Unused variable for JScript NFE bug
        // http://kangax.github.io/nfe
        var definePropertyFN = baseObject.constructor.defineProperty,
            defineGetter = '__defineGetter__',
            defineSetter = '__defineSetter__',
            defineGetterFN,
            defineSetterFN,
            testObject,
            nfeDefineProperty;

        if (isFunction(definePropertyFN)) {
            try {
                testObject = definePropertyFN({}, 'sentinel', {
                    value: null
                });

                if (!isNull(testObject.sentinel)) {
                    definePropertyFN = null;
                }
            } catch (exception) {
                definePropertyFN = null;
            }
        }

        if (isFunction(definePropertyFN)) {
            tempSafariNFE = definePropertyFN;
        } else {
            defineGetterFN = baseObject[defineGetter];
            defineSetterFN = baseObject[defineSetter];
            tempSafariNFE = function nfeDefineProperty(object, property, descriptor) {
                var prototype;

                if (!isTypeObject(object) && !isFunction(object)) {
                    throw new TypeError('Object.defineProperty called on non-object');
                }

                if (!isTypeObject(descriptor) && !isFunction(descriptor)) {
                    throw new TypeError('Property description must be an object');
                }

                if (objectHasOwnProperty(descriptor, 'value')) {
                    if (isNull(objectGetPrototypeOf(baseObject)[protoName])) {
                        prototype = object[protoName];
                        object[protoName] = objectGetPrototypeOf(baseObject);
                        delete object[property];
                        object[property] = descriptor.value;
                        object[protoName] = prototype;
                    } else {
                        object[property] = descriptor.value;
                    }
                } else {
                    if (!isFunction(defineGetterFN) || !isFunction(defineSetterFN)) {
                        throw new TypeError('getters & setters can not be defined on this javascript engine');
                    }

                    if (isFunction(descriptor.get)) {
                        defineGetterFN.call(object, property, descriptor.get);
                    }

                    if (isFunction(descriptor.set)) {
                        defineSetterFN.call(object, property, descriptor.set);
                    }
                }

                return object;
            };
        }

        nfeDefineProperty = null;

        return tempSafariNFE;
    }());

    /**
     * Defines new or modifies existing properties directly on an object, returning the object.
     * @private
     * @function
     * @param {object} object
     * @param {string} props
     * @return {object}
     */
    // Create our own local "defineProperties" function: native -> sham
    // named objectDefineProperties instead of defineProperties because of SpiderMonkey and Blackberry bug
    objectDefineProperties = (function () {
        // Unused variable for JScript NFE bug
        // http://kangax.github.io/nfe
        var definePropertiesFN = baseObject.constructor.defineProperties,
            nfeDefineProperties;

        if (isFunction(definePropertiesFN)) {
            tempSafariNFE = definePropertiesFN;
        } else {
            tempSafariNFE = function nfeDefineProperties(object, props) {
                if (!isTypeObject(object) && !isFunction(object)) {
                    throw new TypeError('Object.defineProperties called on non-object');
                }

                if (!isTypeObject(props) && !isFunction(props)) {
                    throw new TypeError('Property description must be an object');
                }

                arrayForEach(objectKeys(props), function (key) {
                    objectDefineProperty(object, key, props[key]);
                });

                return object;
            };
        }

        nfeDefineProperties = null;

        return tempSafariNFE;
    }());

    /**
     * Returns a property descriptor for an own property (that is, one directly present on an object,
     * not present by dint of being along an object's prototype chain) of a given object.
     * @private
     * @function
     * @param {object} object
     * @param {string} property
     * @return {object}
     */
    // Create our own local "getOwnPropertyDescriptor" function: native -> sham
    // named objectGetOwnPropertyDescriptor instead of getOwnPropertyDescriptor because of SpiderMonkey and Blackberry bug
    objectGetOwnPropertyDescriptor = (function () {
        // Unused variable for JScript NFE bug
        // http://kangax.github.io/nfe
        var getOwnPropertyDescriptorFN = baseObject.constructor.getOwnPropertyDescriptor,
            lookupGetter = '__lookupGetter__',
            lookupSetter = '__lookupSetter__',
            lookupGetterFN,
            lookupSetterFN,
            testObject,
            nfeGetOwnPropertyDescriptor;

        if (isFunction(getOwnPropertyDescriptorFN)) {
            try {
                testObject = {
                    sentinel: null
                };

                if (!isNull(getOwnPropertyDescriptorFN(testObject, 'sentinel').value)) {
                    getOwnPropertyDescriptorFN = null;
                }
            } catch (exception) {
                getOwnPropertyDescriptorFN = null;
            }
        }

        if (isFunction(getOwnPropertyDescriptorFN)) {
            tempSafariNFE = getOwnPropertyDescriptorFN;
        } else {
            lookupGetterFN = baseObject[lookupGetter];
            lookupSetterFN = baseObject[lookupSetter];
            tempSafariNFE = function nfeGetOwnPropertyDescriptor(object, property) {
                var descriptor,
                    prototype,
                    getter,
                    setter;

                if (!isTypeObject(object) && !isFunction(object)) {
                    throw new TypeError('Object.getOwnPropertyDescriptor called on a non-object');
                }

                if (objectHasOwnProperty(object, property)) {
                    descriptor = {
                        enumerable: true,
                        configurable: true
                    };

                    if (isFunction(lookupGetterFN) && isFunction(lookupSetterFN)) {
                        prototype = object[protoName];
                        object[protoName] = objectGetPrototypeOf(baseObject);
                        getter = lookupGetterFN.call(object, property);
                        setter = lookupSetterFN.call(object, property);
                        object[protoName] = prototype;
                        if (isFunction(getter) || isFunction(setter)) {
                            if (isFunction(getter)) {
                                descriptor.get = getter;
                            }

                            if (isFunction(setter)) {
                                descriptor.set = setter;
                            }
                        }
                    } else {
                        descriptor.value = object[property];
                        descriptor.writable = true;
                    }
                }

                return descriptor;
            };
        }

        nfeGetOwnPropertyDescriptor = null;

        return getOwnPropertyDescriptorFN;
    }());

    /**
     * Freezes an object: that is, prevents new properties from being added to it; prevents existing properties from being removed;
     * and prevents existing properties, or their enumerability, configurability, or writability, from being changed.
     * In essence the object is made effectively immutable. Returns the object being frozen.
     * @private
     * @function
     * @param {object} object
     * @return {object}
     */
    // Create our own local "freeze" function: native -> sham
    // named objectFreeze instead of freeze because of SpiderMonkey and Blackberry bug
    objectFreeze = (function () {
        // Unused variable for JScript NFE bug
        // http://kangax.github.io/nfe
        var freezeFN = baseObject.constructor.freeze,
            nfeFreeze;

        if (isFunction(freezeFN)) {
            tempSafariNFE = freezeFN;
        } else {
            tempSafariNFE = function nfeFreeze(object) {
                if (!isTypeObject(object) && !isFunction(object)) {
                    throw new TypeError('Object.freeze called on non-object');
                }

                return object;
            };
        }

        nfeFreeze = null;

        return tempSafariNFE;
    }());

    // detect a Rhino bug and patch it
    try {
        objectFreeze(function () {
            return;
        });
    } catch (exception) {
        objectFreeze = (function (freezeObject) {
            var nfeFreeze;

            tempSafariNFE = function nfeFreeze(object) {
                var val;

                if (isFunction(object)) {
                    val = object;
                } else {
                    val = freezeObject(object);
                }

                return val;
            };

            nfeFreeze = null;

            return tempSafariNFE;
        }(objectFreeze));
    }

    /**
     * Determine if an object is frozen.
     * @private
     * @function
     * @param {object} object
     * @return {boolean}
     */
    // Create our own local "isFrozen" function: native -> sham
    // named objectIsFrozen instead of isFrozen because of SpiderMonkey and Blackberry bug
    objectIsFrozen = (function () {
        // Unused variable for JScript NFE bug
        // http://kangax.github.io/nfe
        var isFrozenFN = baseObject.constructor.isFrozen,
            nfeIsFrozen;

        if (isFunction(isFrozenFN)) {
            tempSafariNFE = isFrozenFN;
        } else {
            tempSafariNFE = function nfeIsFrozen(object) {
                if (!isTypeObject(object) && !isFunction(object)) {
                    throw new TypeError('Object.isFrozen called on non-object');
                }

                return false;
            };
        }

        nfeIsFrozen = null;

        return tempSafariNFE;
    }());

    /**
     * To make object fully immutable, freeze each object in object.
     * @private
     * @function
     * @param {object} object
     * @return {object}
     */
    function deepFreeze(object) {
        objectFreeze(object);
        arrayForEach(objectKeys(object), function (propKey) {
            var prop = object[propKey];

            if ((isTypeObject(prop) || isFunction(prop)) && !objectIsFrozen(prop)) {
                deepFreeze(prop);
            }
        });

        return object;
    }

    /**
     * The function tests whether an object has in its prototype chain the prototype property of a constructor.
     * @private
     * @function
     * @param {object} object
     * @param {function} ctr
     * @return {boolean}
     */
    // named objectInstanceOf instead of instanceOf because of SpiderMonkey and Blackberry bug
    objectInstanceOf = (function () {
        // Unused variable for JScript NFE bug
        // http://kangax.github.io/nfe
        var isPrototypeOfFN = baseObject.constructor.prototype.isPrototypeOf,
            nfeInstanceOf;

        if (isFunction(isPrototypeOfFN)) {
            tempSafariNFE = function nfeInstanceOf(object, ctr) {
                if (!isFunction(ctr)) {
                    throw new TypeError('Expecting a function in instanceOf check');
                }

                return isPrototypeOfFN.call(ctr.prototype, object);
            };
        } else if (isFunction(objectGetPrototypeOf)) {
            tempSafariNFE = function nfeInstanceOf(object, ctr) {
                if (!isFunction(ctr)) {
                    throw new TypeError('Expecting a function in instanceOf check');
                }

                var val = false;

                while (object) {
                    if (strictEqual(object, ctr.prototype)) {
                        val = true;
                        break;
                    }

                    object = objectGetPrototypeOf(object);
                }

                return val;
            };
        }

        nfeInstanceOf = null;

        return tempSafariNFE;
    }());

    /**
     * Check to see if an object is a plain object (created using "{}" or "new Object").
     * @private
     * @function
     * @param {object} object
     * @return {boolean}
     */
    isPlainObject = (function () {
        // Unused variable for JScript NFE bug
        // http://kangax.github.io/nfe
        var baseObjectPrototype = objectGetPrototypeOf(baseObject),
            nfeIsPlainObject;

        tempSafariNFE = function nfeIsPlainObject(object) {
            return isObject(object) && strictEqual(objectGetPrototypeOf(object), baseObjectPrototype);
        };

        nfeIsPlainObject = null;

        return tempSafariNFE;
    }());

    /**
     * Merge the contents of source object together into the target object.
     * @private
     * @function
     * @param {object} target
     * @param {object} source
     * @return {object}
     */
    extend = (function () {
        // Unused variable for JScript NFE bug
        // http://kangax.github.io/nfe
        var nfeExtend;

        tempSafariNFE = function nfeExtend(target, source) {
            if (!isTypeObject(target) && !isFunction(target)) {
                throw new TypeError('extend called on a non-object');
            }

            arrayForEach(objectKeys(source), function (key) {
                objectDefineProperty(target, key, objectGetOwnPropertyDescriptor(source, key));
            });

            return target;
        };

        nfeExtend = null;

        return tempSafariNFE;
    }());

    /**
     * Returns true if the operand inputArg is a Date object and is valid.
     * @private
     * @function
     * @param {*} dateObject
     * @return {boolean}
     */
    function isDateValid(dateObject) {
        return isDate(dateObject) && !numberIsNaN(dateObject.getTime());
    }

    /**
     * Returns true if the operand inputArg is a String and only contains numerical digits.
     * @private
     * @function
     * @param {*} string
     * @return {boolean}
     */
    function isDigits(string) {
        return isString(string) && (/^\d+$/).test(string);
    }

    /**
     * Takes string and puts a backslash in front of every character that is part of the regular expression syntax.
     * This is useful if you have a run-time string that you need to match in some text and the string may contain special regex characters.
     * @private
     * @function
     * @param {string} string
     * @return {string}
     */
    function escapeRegex(string) {
        return string.replace(/[\[\](){}?*+\^$\\.|]/g, '\\$&');
    }

    /**
     * Wraps a string within the string character.
     * @private
     * @function
     * @param {string} string
     * @param {string} character
     * @return {string}
     */
    function wrapInChar(string, character) {
        return character + string + character;
    }

    /**
     * Replace all occurences of a string pattern within a string with the string characters.
     * @private
     * @function
     * @param {string} string
     * @param {string} pattern
     * @param {string} characters
     * @return {string}
     */
    function replaceAll(string, pattern, characters) {
        return string.replace(new RegExp(escapeRegex(pattern), 'g'), characters);
    }

    deepFreeze(defaultProperties);

    /**
     * Variables and utility functions used by the AstroDate class and requiring the BigNumber library.
     * @private
     * @function
     * @param {class} BigNumber
     * @return {class} AsroDate
     */
    function defineAstroDate(BigNumber) {
        BigNumber.config({
            DECIMAL_PLACES: 9,
            ROUNDING_MODE: 0,
            EXPONENTIAL_AT: [-7, 20],
            RANGE: [-1000000000, 1000000000],
            ERRORS: true
        });

        /**
         * The BigNumber library namespace.
         * @ignore
         * @external BigNumber
         * @see {@link http://mikemcl.github.io/bignumber.js/}
         */
        objectDefineProperties(BigNumber.prototype, {
            /**
             * @memberOf external:BigNumber.prototype
             * @function
             * @this BigNumber
             * @return {BigNumber}
             */
            trunc: {
                value: function () {
                    return this.round(0, 1);
                }
            },

            /**
             * @memberOf external:BigNumber.prototype
             * @function
             * @this BigNumber
             * @return {boolean}
             */
            inRange: {
                value: function (min, max) {
                    return this.gte(min) && this.lte(max);
                }
            },

            /**
             * @memberOf external:BigNumber.prototype
             * @function
             * @this BigNumber
             * @return {BigNumber}
             */
            modf: {
                value: function () {
                    var bn = this;

                    if (bn.isFinite()) {
                        bn = bn.mod(bn.trunc());
                    } else {
                        bn = new BigNumber(NaN);
                    }

                    return bn;
                }
            },

            /**
             * @memberOf external:BigNumber.prototype
             * @function
             * @this BigNumber
             * @return {BigNumber}
             */
            difference: {
                value: function (value) {
                    var diff;

                    if (this.gt(value)) {
                        diff = this.minus(value);
                    } else {
                        diff = this.neg().plus(value);
                    }

                    return diff;
                }
            },

            /**
             * @memberOf external:BigNumber.prototype
             * @function
             * @this BigNumber
             * @return {string}
             */
            padLeadingZero: {
                value: function (size) {
                    return padLeadingChar(this.toString(), '0', size);
                }
            }
        });

        objectDefineProperties(BigNumber, {
            /**
             * @memberOf external:BigNumber
             * @function
             * @param {*} inputArg
             * @return {boolean}
             */
            isBigNumber: {
                value: function (inputArg) {
                    return isObject(inputArg) && objectInstanceOf(inputArg, BigNumber);
                }
            },

            /**
             * @memberOf external:BigNumber
             * @function
             * @param {(number|string)} inputArg
             * @return {BigNumber}
             */
            trunc: {
                value: function (number) {
                    return new BigNumber(number).trunc();
                }
            },

            /**
             * @memberOf external:BigNumber
             * @function
             * @param {(number|string)} inputArg
             * @return {BigNumber}
             */
            modf: {
                value: function (number) {
                    return new BigNumber(number).modf();
                }
            },

            /**
             * @memberOf external:BigNumber
             * @function
             * @param {(number|string)} number1
             * @param {(number|string)} number2
             * @return {BigNumber}
             *
             */
            difference: {
                value: function (number1, number2) {
                    return new BigNumber(number1).difference(number2);
                }
            },

            /**
             * @memberOf external:BigNumber
             * @function
             * @return {BigNumber}
             */
            zero: {
                value: function () {
                    return new BigNumber(0);
                }
            },

            /**
             * @memberOf external:BigNumber
             * @function
             * @return {BigNumber}
             */
            one: {
                value: function () {
                    return new BigNumber(1);
                }
            }
        });

        arrayForEach([BigNumber, BigNumber.prototype], function (element) {
            arrayForEach(objectKeys(element), function (key) {
                objectDefineProperty(element, key, {
                    enumerable: false,
                    configurable: false,
                    writeable: false
                });
            });
        });

        var VERSION = '0.6.4',
            /**
             * For normalising user input and looking up Date object methods.
             * @private
             * @readonly
             * @type {array.<object>}
             */
            fullKeys = [{
                full: 'year',
                alias: 'y',
                local: 'getFullYear'
            }, {
                full: 'month',
                alias: 'M',
                local: 'getMonth'
            }, {
                full: 'day',
                alias: 'd',
                local: 'getDate'
            }, {
                full: 'hour',
                alias: 'h',
                local: 'getHours'
            }, {
                full: 'minute',
                alias: 'm',
                local: 'getMinutes'
            }, {
                full: 'second',
                alias: 's',
                local: 'getSeconds'
            }, {
                full: 'millisecond',
                alias: 'ms',
                local: 'getMilliseconds'
            }, {
                full: 'offset',
                alias: 'z',
                local: 'getTimezoneOffset'
            }],
            /**
             * For looking up CLDR day translations.
             * @private
             * @readonly
             * @type {array.<string>}
             */
            dayKeys = ['sun', 'mon', 'tue', 'wed', 'thu', 'fri', 'sat'],
            /**
             * For looking up CLDR month translations.
             * @private
             * @readonly
             * @type {array.<string>}
             */
            monthKeys = ['1', '2', '3', '4', '5', '6', '7', '8', '9', '10', '11', '12'],
            /**
             * For looking up CLDR format translations.
             * @private
             * @readonly
             * @type {array.<string>}
             */
            nameTypes = ['format', 'stand-alone'],
            /**
             * For looking up CLDR width translations.
             * @private
             * @readonly
             * @type {array.<string>}
             */
            widthTypes = ['wide', 'abbreviated', 'narrow'],
            /**
             * For looking up CLDR date and time patterns.
             * @private
             * @readonly
             * @type {array.<string>}
             */
            formatTypes = ['full', 'long', 'medium', 'short'],
            invalidISOCharsRx = new RegExp('[^\\d\\-+WT Z:,\\.]'),
            replaceTokenRX = new RegExp('([^\\\']+)|(\\\'[^\\\']+\\\')', 'g'),
            unmatchedTokenRx = new RegExp('[^a-z]', 'gi'),
            //j2000 = [2000, 1, 1, 11, 58, 55, 816],
            /**
             * For holding CLDR language specific data.
             * @private
             * @type {object}
             */
            languages = {},
            /**
             * For parsing CLDR date patterns.
             * @private
             * @readonly
             * @type {array.<string>}
             */
            datePatterns,
            /**
             * For parsing CLDR time patterns
             * @private
             * @readonly
             * @type {array.<string>}
             */
            timePatterns,
            /**
             * The current default language of the AstroDate constructor.
             * @private
             * @type {string}
             */
            defaultLanguage,
            /**
             * The current default locale of the AstroDate constructor.
             * @private
             * @type {string}
             */
            defaultLocale,
            //calendarTypes,
            leapSeconds,
            /**
             * For holding CLDR supplemental data.
             * @private
             * @type {object}
             */
            supplemental;

        deepFreeze(fullKeys);
        deepFreeze(monthKeys);
        deepFreeze(dayKeys);
        deepFreeze(nameTypes);
        deepFreeze(widthTypes);
        deepFreeze(formatTypes);

        /*
        function InvalidError(message) {
            //this.name = "InvalidError";
            this.message = message || "";
        }

        InvalidError.prototype = new Error();

        function NotImplimentedError(message) {
            //this.name = "NotImplementedError";
            this.message = message || "";
        }

        NotImplimentedError.prototype = new Error();
        */

        function isGregorianLeapYear(struct) {
            return struct.year.mod(400).isZero() || (!struct.year.mod(100).isZero() && struct.year.mod(4).isZero());
        }

        function isJulianLeapYear(struct) {
            return struct.year.mod(4).equals(0);
        }

        function daysInGregorianMonth(struct) {
            var days;

            if (struct.month.eq(2)) {
                days = new BigNumber(28);
                if (isGregorianLeapYear(struct)) {
                    days = days.plus(1);
                }
            } else {
                days = struct.month.minus(1).mod(7).mod(2).neg().plus(31);
            }

            return days;
        }

        function daysInJulianMonth(struct) {
            var days = new BigNumber(28);

            if (struct.month.eq(2) && isJulianLeapYear(struct)) {
                days = days.plus(1);
            }

            return days;
        }

        function daysInGregorianYear(struct) {
            var days = new BigNumber(365);

            if (isGregorianLeapYear(struct)) {
                days = days.plus(1);
            }

            return days;
        }

        function daysInJulianYear(struct) {
            var days = new BigNumber(365);

            if (isJulianLeapYear(struct)) {
                days = days.plus(1);
            }

            return days;
        }

        function inYearRange(year) {
            return year.isFinite();
        }

        function inMonthRange(month) {
            return month.inRange(1, 12);
        }

        function inDayRange(day, dim) {
            return day.inRange(1, dim);
        }

        function inHourRange(hour) {
            return hour.inRange(0, 24);
        }

        function inMinuteRange(minute, hour) {
            return (hour.equals(24) && minute.isZero()) || (!hour.equals(24) && minute.gte(0) && minute.lt(60));
        }

        function inSecondRange(second, struct) {
            var maxSecond = 60,
                leapSecond;

            if (struct.year.gte(1961) && struct.hour.equals(23) && struct.minute.equals(59)) {
                if (!isPlainObject(leapSeconds)) {
                    throw new Error('No leap second table!');
                }

                leapSecond = leapSeconds[struct.year.toString()];
                if (isPlainObject(leapSecond)) {
                    leapSecond = leapSecond[struct.month.toString()];
                    if (isPlainObject(leapSecond)) {
                        leapSecond = toNumber(leapSecond[struct.day.toString()]);
                        if (numberIsFinite(leapSecond)) {
                            maxSecond += leapSecond;
                        }
                    }
                }
            }

            return (struct.hour.equals(24) && second.isZero()) || (!struct.hour.equals(24) && second.gte(0) && second.lt(maxSecond));
        }

        function inMillisecondRange(millisecond, hour) {
            return (hour.equals(24) && millisecond.isZero()) || (!hour.equals(24) && millisecond.gte(0) && millisecond.lt(1000));
        }

        function inOffsetRange(offset) {
            return offset.inRange(-1440, 1440);
        }

        /*
        function inWeekRange(week, year) {
            return offset.inRange(1, 53);
        }

        function inWeekDayRange(weekDay) {
            return weekDay.inRange(1, 7);
        }
        */

        function isValid(struct, julian) {
            var valid = false;

            if (isPlainObject(struct)) {
                valid = !arraySome(fullKeys, function (element) {
                    var bn = struct[element.full],
                        dim;

                    if (!BigNumber.isBigNumber(bn)) {
                        return true;
                    }

                    switch (element.full) {
                    case 'year':
                        if (!inYearRange(bn)) {
                            return true;
                        }

                        break;
                    case 'month':
                        if (!inMonthRange(bn)) {
                            return true;
                        }

                        break;
                    case 'day':
                        if (strictEqual(julian, true)) {
                            dim = daysInJulianMonth(struct);
                        } else {
                            dim = daysInGregorianMonth(struct);
                        }

                        if (!inDayRange(bn, dim)) {
                            return true;
                        }

                        break;
                    case 'hour':
                        if (!inHourRange(bn)) {
                            return true;
                        }

                        break;
                    case 'minute':
                        if (!inMinuteRange(bn, struct.hour)) {
                            return true;
                        }

                        break;
                    case 'second':
                        if (!inSecondRange(bn, struct)) {
                            return true;
                        }

                        break;
                    case 'millisecond':
                        if (!inMillisecondRange(bn, struct.hour)) {
                            return true;
                        }

                        break;
                    case 'offset':
                        if (!inOffsetRange(bn)) {
                            return true;
                        }

                        break;
                        /*
                    case 'week':
                        if (!inWeekRange(bn)) {
                            return true;
                        }

                        break;
                    case 'weekDay':
                        if (!inWeekDayRange(bn)) {
                            return true;
                        }

                        break;
                    */
                    default:
                        throw new Error(element.full);
                    }

                    return false;
                });
            }

            return valid;
        }

        function dayOfGregorianYear(struct) {
            var k;

            if (isGregorianLeapYear(struct)) {
                k = 1;
            } else {
                k = 2;
            }

            return struct.month.times(275).div(9).floor().minus(struct.month.plus(9).div(12).floor().times(k)).plus(struct.day).minus(30);
        }

        function dayOfJulianYear(struct) {
            var dayOfYear = struct.month.times(28).plus(struct.day);

            if (struct.month.gte(2) && isJulianLeapYear(struct)) {
                dayOfYear = dayOfYear.plus(1);
            }

            return dayOfYear;
        }

        function normaliseUnits(unitString) {
            var unit;

            if (isString(unitString)) {
                unitString = stringTrim(unitString).toLowerCase();
                if (gt(unitString.length, 2) && lastCharIs(unitString, 's')) {
                    unitString = unitString.slice(0, -1);
                }

                arraySome(fullKeys, function (element) {
                    var val;

                    if (strictEqual(unitString, element.alias) || strictEqual(unitString, element.full)) {
                        unit = element.full;
                        val = true;
                    } else {
                        val = false;
                    }

                    return val;
                });
            }

            return unit;
        }

        function timeTo(struct, unit) {
            var value;

            switch (normaliseUnits(unit)) {
            case 'day':
                value = struct.hour.div(24).plus(struct.minute.div(1440)).plus(struct.second.div(86400)).plus(struct.millisecond.div(86400000));
                break;
            case 'hour':
                value = struct.hour.plus(struct.minute.div(60)).plus(struct.second.div(3600)).plus(struct.millisecond.div(3600000));
                break;
            case 'minute':
                value = struct.hour.times(60).plus(struct.minute).plus(struct.second.div(60)).plus(struct.millisecond.div(60000));
                break;
            case 'second':
                value = struct.hour.times(3600).plus(struct.minute.times(60)).plus(struct.second).plus(struct.millisecond.div(1000));
                break;
            case 'millisecond':
                value = struct.hour.times(3600000).plus(struct.minute.times(60000)).plus(struct.second.times(1000)).plus(struct.millisecond);
                break;
            default:
                throw new Error(unit);
            }

            return value;
        }

        function gregorianToJd(struct) {
            var b = struct.year.minus(1),
                c = b.times(365),
                d = b.div(4).floor(),
                e = b.div(100).floor().neg(),
                f = b.div(400).floor(),
                g = struct.month.times(367).minus(362).div(12).floor(),
                h;

            if (struct.month.gt(2)) {
                if (isGregorianLeapYear(struct)) {
                    h = -1;
                } else {
                    h = -2;
                }
            } else {
                h = 0;
            }

            return new BigNumber(1721424.5).plus(c).plus(d).plus(e).plus(f).plus(g.plus(h).plus(struct.day).floor()).plus(timeTo(struct, 'day'));
        }

        function gregorianToJdn(struct) {
            return gregorianToJd(struct).round(1, 1);
        }

        /*
        function objectValues(inputArg) {
            return arrayMap(objectKeys(inputArg), function (key) {
                return inputArg[key];
            });
        }
        */

        function dayOfWeekNumber(struct) {
            var day = gregorianToJd(struct).plus(1.5).mod(7).floor();

            if (day.lt(0)) {
                day = day.plus(7);
            }

            return day;
        }

        function weekDayNumber(struct) {
            var bnWeekDay = dayOfWeekNumber(struct);

            if (bnWeekDay.isZero()) {
                bnWeekDay = new BigNumber(7);
            }

            return bnWeekDay;
        }

        function cldrDayKey(struct) {
            return dayKeys[toNumber(dayOfWeekNumber(struct))];
        }

        function fractionToTime(fraction, fractionIn, struct, julian) {
            var time = {},
                totalMs,
                days;

            fraction = new BigNumber(fraction);
            switch (fractionIn) {
            case 'year':
                if (strictEqual(julian, true)) {
                    days = daysInJulianYear(struct);
                } else {
                    days = daysInGregorianYear(struct);
                }

                totalMs = fraction.times(days.times(86400000));
                break;
            case 'month':
                if (strictEqual(julian, true)) {
                    days = daysInJulianMonth(struct);
                } else {
                    days = daysInGregorianMonth(struct);
                }

                totalMs = fraction.times(days.times(86400000));
                break;
            case 'day':
                totalMs = fraction.times(86400000);
                break;
            case 'hour':
                totalMs = fraction.times(3600000);
                break;
            case 'minute':
                totalMs = fraction.times(60000);
                break;
            case 'second':
                totalMs = fraction.times(1000);
                break;
            case 'millisecond':
                totalMs = fraction;
                break;
            default:
                throw new Error(fractionIn);
            }

            time.hour = totalMs.div(3600000).floor();
            time.minute = totalMs.minus(time.hour.times(3600000)).div(60000).floor();
            time.second = totalMs.minus(time.hour.times(3600000)).minus(time.minute.times(60000)).div(1000).floor();
            time.millisecond = totalMs.minus(time.hour.times(3600000)).minus(time.minute.times(60000)).minus(time.second.times(1000)).floor();

            return time;
        }

        function getTime(struct) {
            return gregorianToJd(struct).minus(2440587.5).times(86400000).floor();
        }

        // DeltaT
        //http://eclipse.gsfc.nasa.gov/SEhelp/deltatpoly2004.html
        function deltaTime(struct, canonCorrection) {
            var y = struct.year.plus(struct.month.minus(0.5).div(12)),
                u,
                t,
                r;

            if (struct.year.inRange(-500, 2150)) {
                if (struct.year.lt(500)) {
                    u = y.div(100);
                    r = new BigNumber(10583.6).minus(u.times(1014.41)).plus(u.pow(2).times(33.78311)).minus(u.pow(3).times(5.952053)).minus(u.pow(4).times(0.1798452)).plus(u.pow(5).times(0.022174192)).plus(u.pow(6).times(0.0090316521));
                } else if (struct.year.lt(1600)) {
                    u = y.minus(1000).div(100);
                    r = new BigNumber(1574.2).minus(u.times(556.01)).plus(u.pow(2).times(71.23472)).plus(u.pow(3).times(0.319781)).minus(u.pow(4).times(0.8503463)).minus(u.pow(5).times(0.005050998)).plus(u.pow(6).times(0.0083572073));
                } else if (struct.year.lt(1700)) {
                    t = y.minus(1600);
                    r = new BigNumber(120).minus(t.times(0.9808)).minus(t.pow(2).times(0.01532)).plus(t.pow(3).div(7129));
                } else if (struct.year.lt(1800)) {
                    t = y.minus(1700);
                    r = new BigNumber(8.83).plus(t.times(0.1603)).minus(t.pow(2).times(0.0059285)).plus(t.pow(3).times(0.00013336)).minus(t.pow(4).div(1174000));
                } else if (struct.year.lt(1860)) {
                    t = y.minus(1800);
                    r = new BigNumber(13.72).minus(t.times(0.332447)).plus(t.pow(2).times(0.0068612)).plus(t.pow(3).times(0.0041116)).minus(t.pow(4).times(0.00037436)).plus(t.pow(5).times(0.0000121272)).minus(t.pow(6).times(0.0000001699)).plus(t.pow(7).times(0.000000000875));
                } else if (struct.year.lt(1900)) {
                    t = y.minus(1860);
                    r = new BigNumber(7.62).plus(t.times(0.5737)).minus(t.pow(2).times(0.251754)).plus(t.pow(3).times(0.01680668)).minus(t.pow(4).times(0.0004473624)).plus(t.pow(5).div(233174));
                } else if (struct.year.lt(1920)) {
                    t = y.minus(1900);
                    r = new BigNumber(-2.79).plus(t.times(1.494119)).minus(t.pow(2).times(0.0598939)).plus(t.pow(3).times(0.0061966)).minus(t.pow(4).times(0.000197));
                } else if (struct.year.lt(1941)) {
                    t = y.minus(1920);
                    r = new BigNumber(21.20).plus(t.times(0.84493)).minus(t.pow(2).times(0.076100)).plus(t.pow(3).times(0.0020936));
                } else if (struct.year.lt(1961)) {
                    t = y.minus(1950);
                    r = new BigNumber(29.07).plus(t.times(0.407)).minus(t.pow(2).div(233)).plus(t.pow(3).div(2547));
                } else if (struct.year.lt(1986)) {
                    t = y.minus(1975);
                    r = new BigNumber(45.45).plus(t.times(1.067)).minus(t.pow(2).div(260)).minus(t.pow(3).div(718));
                } else if (struct.year.lt(2005)) {
                    t = y.minus(2000);
                    r = new BigNumber(63.86).plus(t.times(0.3345)).minus(t.pow(2).times(0.060374)).plus(t.pow(3).times(0.0017275)).plus(t.pow(4).times(0.000651814)).plus(t.pow(5).times(0.00002373599));
                } else if (struct.year.lt(2050)) {
                    t = y.minus(2000);
                    r = new BigNumber(62.92).plus(t.times(0.32217)).plus(t.pow(2).times(0.005589));
                } else {
                    r = new BigNumber(-20).plus(y.minus(1820).div(100).pow(2).times(32)).minus(y.neg().plus(2150).times(0.5628));
                }
            } else {
                u = y.minus(1820).div(100);
                r = u.pow(2).times(32).plus(-20);
            }

            if (canonCorrection && !struct.year.inRange(1955, 2004)) {
                r.plus(y.minus(1955).pow(2).times(-0.000012932));
            }

            return r.times(1000).trunc();
        }

        function arrayToStruct(arr, julian) {
            var struct = {};

            if (arrayIsArray(arr)) {
                arraySome(fullKeys, function (element, index) {
                    var value = arr[index],
                        bn,
                        dim;

                    if (isNumber(value) || isString(value) || (value && value instanceof BigNumber)) {
                        bn = new BigNumber(value);
                    } else {
                        bn = new BigNumber(NaN);
                    }

                    switch (element.full) {
                    case 'year':
                        if (!inYearRange(bn)) {
                            struct = {};
                            return true;
                        }

                        break;
                    case 'month':
                        if (isUndefined(value)) {
                            bn = BigNumber.one();
                        }

                        if (!inMonthRange(bn)) {
                            struct = {};
                            return true;
                        }

                        break;
                    case 'day':
                        if (strictEqual(julian, true)) {
                            dim = daysInJulianMonth(struct);
                        } else {
                            dim = daysInGregorianMonth(struct);
                        }

                        if (isUndefined(value)) {
                            bn = BigNumber.one();
                        }

                        if (!inDayRange(bn, dim)) {
                            struct = {};
                            return true;
                        }

                        break;
                    case 'hour':
                        if (isUndefined(value)) {
                            bn = BigNumber.zero();
                        }

                        if (!inHourRange(bn)) {
                            struct = {};
                            return true;
                        }

                        break;
                    case 'minute':
                        if (isUndefined(value)) {
                            bn = BigNumber.zero();
                        }

                        if (!inMinuteRange(bn, struct.hour)) {
                            struct = {};
                            return true;
                        }

                        break;
                    case 'second':
                        if (isUndefined(value)) {
                            bn = BigNumber.zero();
                        }

                        if (!inSecondRange(bn, struct)) {
                            struct = {};
                            return true;
                        }

                        break;
                    case 'millisecond':
                        if (isUndefined(value)) {
                            bn = BigNumber.zero();
                        }

                        if (!inMillisecondRange(bn, struct.hour)) {
                            struct = {};
                            return true;
                        }

                        break;
                    case 'offset':
                        if (isUndefined(value)) {
                            bn = BigNumber.zero();
                        }

                        if (!inOffsetRange(bn)) {
                            struct = {};
                            return true;
                        }

                        break;
                    default:
                        throw new Error(element);
                    }

                    struct[element.full] = bn;

                    return false;
                });
            }

            return struct;
        }

        function structToArray(struct) {
            var arr;

            if (isValid(struct)) {
                arr = arrayMap(fullKeys, function (element) {
                    return struct[element.full];
                });
            } else {
                arr = [];
            }

            return arr;
        }

        function returnElementToString(element) {
            return element.toString();
        }

        function structToArrayOfString(struct) {
            return arrayMap(structToArray(struct), returnElementToString);
        }

        function objectToStruct(object, julian) {
            var struct = {};

            if (isPlainObject(object)) {
                arraySome(fullKeys, function (element) {
                    var value = object[element.alias] || object[element.full] || object[element.full + 's'],
                        bn,
                        dim;

                    if (isNumber(value) || isString(value) || (value && value instanceof BigNumber)) {
                        bn = new BigNumber(value);
                    } else {
                        bn = new BigNumber(NaN);
                    }

                    switch (element.full) {
                    case 'year':
                        if (!inYearRange(bn)) {
                            struct = {};
                            return true;
                        }

                        break;
                    case 'month':
                        if (isUndefined(value)) {
                            bn = BigNumber.one();
                        }

                        if (!inMonthRange(bn)) {
                            struct = {};
                            return true;
                        }

                        break;
                    case 'day':
                        if (strictEqual(julian, true)) {
                            dim = daysInJulianMonth(struct);
                        } else {
                            dim = daysInGregorianMonth(struct);
                        }

                        if (isUndefined(value)) {
                            bn = BigNumber.one();
                        }

                        if (!inDayRange(bn, dim)) {
                            struct = {};
                            return true;
                        }

                        break;
                    case 'hour':
                        if (isUndefined(value)) {
                            bn = BigNumber.zero();
                        }

                        if (!inHourRange(bn)) {
                            struct = {};
                            return true;
                        }

                        break;
                    case 'minute':
                        if (isUndefined(value)) {
                            bn = BigNumber.zero();
                        }

                        if (!inMinuteRange(bn, struct.hour)) {
                            struct = {};
                            return true;
                        }

                        break;
                    case 'second':
                        if (isUndefined(value)) {
                            bn = BigNumber.zero();
                        }

                        if (!inSecondRange(bn, struct)) {
                            struct = {};
                            return true;
                        }

                        break;
                    case 'millisecond':
                        if (isUndefined(value)) {
                            bn = BigNumber.zero();
                        }

                        if (!inMillisecondRange(bn, struct.hour)) {
                            struct = {};
                            return true;
                        }

                        break;
                    case 'offset':
                        if (isUndefined(value)) {
                            bn = BigNumber.zero();
                        }

                        if (!inOffsetRange(bn)) {
                            struct = {};
                            return true;
                        }

                        break;
                    default:
                        throw new Error(element);
                    }

                    struct[element.full] = bn;

                    return false;
                });
            }

            return struct;
        }

        function structToObject(struct) {
            var newObject = {};

            if (isPlainObject(struct)) {
                arrayForEach(objectKeys(struct), function (key) {
                    newObject[key] = struct[key].toString();
                });
            }

            return newObject;
        }

        function dateToStruct(date) {
            var struct = {};

            if (isDateValid(date)) {
                arrayForEach(fullKeys, function (element) {
                    var value = new BigNumber(date[element.local]());

                    if (strictEqual(element.full, 'month')) {
                        value = value.plus(1);
                    }

                    struct[element.full] = value;
                });
            }

            return struct;
        }

        function julianToJd(struct) {
            var year = struct.year,
                month,
                a,
                b;

            month = struct.month;
            if (month.lte(2)) {
                year = year.minus(1);
                month = month.plus(12);
            }

            a = year.plus(4716).times(365.25).floor();
            b = month.plus(1).times(30.6001).floor();

            return a.plus(b).plus(struct.day).minus(1524.5).plus(timeTo(struct, 'day'));
        }

        /*
        function julianToJdn(struct) {
            return julianToJd(struct).round(1, 1);
        }
        */

        function jdToGregorian(julianDate) {
            var struct = {},
                jd = new BigNumber(julianDate),
                a,
                b;

            if (jd.isFinite()) {
                jd = jd.plus(0.5);
                a = jd.plus(68569).floor();
                b = a.times(4).div(146097).floor();
                a = a.minus(b.times(146097).plus(3).div(4).floor());
                struct.year = a.plus(1).times(4000).div(1461001).floor();
                a = a.minus(struct.year.times(1461).div(4).floor()).plus(31);
                struct.month = a.times(80).div(2447).floor();
                struct.day = a.minus(struct.month.times(2447).div(80).floor());
                a = struct.month.div(11).floor();
                struct.month = struct.month.plus(2).minus(a.times(12));
                struct.year = b.minus(49).times(100).plus(struct.year).plus(a).floor();
                struct.offset = BigNumber.zero();
                extend(struct, fractionToTime(jd.modf().abs(), 'day'));
            }

            return struct;
        }

        function jdToJulian(julianDate) {
            var struct = {},
                jd = new BigNumber(julianDate),
                a,
                b,
                c,
                d,
                e,
                g;

            if (jd.isFinite()) {
                jd = jd.plus(0.5);
                a = jd.floor();
                b = a.plus(1524);
                c = b.minus(122.1).div(365.25).floor();
                d = c.times(365.25).floor();
                g = b.minus(d);
                e = g.div(30.6001).floor();

                struct.day = g.minus(e.times(30.6001).floor());
                if (e.lt(14)) {
                    struct.month = e.minus(1);
                } else {
                    struct.month = e.minus(13);
                }

                if (struct.month.gt(2)) {
                    struct.year = c.minus(4716);
                } else {
                    struct.year = c.minus(4715);
                }

                struct.offset = BigNumber.zero();
                extend(struct, fractionToTime(jd.modf().abs(), 'day'));
            }

            return struct;
        }

        function gregorianToMJD(struct) {
            return gregorianToJd(struct).minus(2400000.5);
        }

        function julianToMJD(struct) {
            return julianToJd(struct).minus(2400000.5);
        }

        /*
        function jdToMJD(jd) {
            return jd.minus(2400000.5);
        }
        */

        function gregorianToJulian(struct) {
            var newStruct;

            if (isValid(struct)) {
                newStruct = jdToJulian(gregorianToJd(struct));
            } else {
                newStruct = {};
            }

            return newStruct;
        }

        function julianToGregorian(struct) {
            var newStruct;

            if (isValid(struct)) {
                newStruct = jdToGregorian(julianToJd(struct));
            } else {
                newStruct = {};
            }

            return newStruct;
        }

        function toUT(struct) {
            return jdToGregorian(gregorianToJd(struct).times(86400000).plus(struct.offset.times(60000)).div(86400000));
        }

        function toTT(struct) {
            var offset = struct.offset,
                structTT = jdToGregorian(gregorianToJd(struct).times(86400000).minus(deltaTime(struct)).div(86400000));

            structTT.offset = offset;

            return structTT;
        }

        function addDT(struct) {
            var offset = struct.offset,
                structTT = jdToGregorian(gregorianToJd(struct).times(86400000).plus(deltaTime(struct)).div(86400000));

            structTT.offset = offset;

            return structTT;
        }

        function subDT(struct) {
            var offset = struct.offset,
                structTT = jdToGregorian(gregorianToJd(struct).times(86400000).plus(deltaTime(struct)).div(86400000));

            structTT.offset = offset;

            return structTT;
        }

        function bnGetTimezoneOffset() {
            return new BigNumber(new Date().getTimezoneOffset());
        }

        function toLocal(struct) {
            var timezoneOffset = bnGetTimezoneOffset(),
                structLocal = jdToGregorian(gregorianToJd(struct).times(86400000).plus(struct.offset.times(60000)).minus(bnGetTimezoneOffset().times(60000)).div(86400000));

            structLocal.offset = timezoneOffset;

            return structLocal;
        }

        /*
        function toTAI(struct) {
            var offset = struct.offset,
                structTT = jdToGregorian(gregorianToJd(struct).times(86400000).minus(deltaTime(struct)).minus(32184).div(86400000));

            structTT.offset = offset;

            return structTT;
        }

        function toGPS(struct) {
              var offset = struct.offset,
                structTT = jdToGregorian(gregorianToJd(struct).times(86400000).minus(deltaTime(struct)).minus(51184).div(86400000));

            structTT.offset = offset;

            return structTT;
        }
        */

        /**
         * Converts a date struct to an ISO extended dateTime stamp.
         * This routine needs changing so that the type of ISO dateTime stamp can be choosen.
         * @private
         * @function
         * @param {object} struct
         * @param {number} userPadding
         * @return {string}
         */
        function toISOString(struct, userPadding) {
            var string,
                index,
                count,
                padding,
                last,
                value,
                key,
                number;

            number = toNumber(userPadding);
            if (lt(number, 5) || !numberIsFinite(number)) {
                number = 6;
            }

            index = 0;
            string = '';
            for (count = 0; lt(count, 3); count += 1) {
                if (isUndefined(struct[fullKeys[count].full])) {
                    index = 3;
                    break;
                }
            }

            for (last = fullKeys.length - 1; lt(index, last); index += 1) {
                key = fullKeys[index].full;
                value = struct[key];
                if (strictEqual(key, 'year')) {
                    if (value.lt(0)) {
                        string += '-';
                        padding = number;
                    } else if (value.gte(10000)) {
                        string += '+';
                        padding = number;
                    } else {
                        padding = 4;
                    }
                } else if (strictEqual(key, 'hour')) {
                    string += 'T';
                    padding = 2;
                } else if (strictEqual(key, 'millisecond')) {
                    padding = 3;
                } else {
                    padding = 2;
                }

                string += value.abs().padLeadingZero(padding);
                if (lt(index, 2)) {
                    string += '-';
                } else if (inRange(index, 3, 4)) {
                    string += ':';
                } else if (strictEqual(key, 'second')) {
                    string += '.';
                }
            }

            value = struct.offset;
            if (value.isZero()) {
                string += 'Z';
            } else {
                if (value.lte(0)) {
                    string += '+';
                } else {
                    string += '-';
                }

                value = fractionToTime(value.abs(), 'minute');
                string += value.hour.padLeadingZero(2);
                string += ':';
                string += value.minute.padLeadingZero(2);
            }

            return string;
        }

        /**
         * Returns true if the ISO timeDate stamp has the correct character counts/looks like an ISO timeDate stamp.
         * @private
         * @function
         * @param {string} string
         * @return {boolean}
         */
        function isoHasValidCharacterCounts(string) {
            var val;

            if (!inRange(countCharacter(string, ' ') + countCharacter(string, 'T'), 0, 1)) {
                val = false;
            } else if (!inRange(countCharacter(string, 'W'), 0, 1)) {
                val = false;
            } else if (!inRange(countCharacter(string, 'Z'), 0, 1)) {
                val = false;
            } else if (!inRange(countCharacter(string, '.') + countCharacter(string, ','), 0, 1)) {
                val = false;
            } else if (!inRange(countCharacter(string, '+'), 0, 2)) {
                val = false;
            } else if (!inRange(countCharacter(string, '-'), 0, 4)) {
                val = false;
            } else if (!inRange(countCharacter(string, ':'), 0, 4)) {
                val = false;
            } else if (lt(string.replace(/\D/g, '').length, 2)) {
                val = false;
            } else {
                val = true;
            }

            return val;
        }

        /**
         * Convert the ISO ordinal date to a date struct.
         * @private
         * @function
         * @param {(number|string|BigNumber)} year
         * @param {(number|string|BigNumber)} dayOfYear
         * @return {object}
         */
        function ordinalToCalendar(year, dayOfYear) {
            var struct = {
                year: new BigNumber(year),
                month: BigNumber.one(),
                day: BigNumber.one(),
                hour: BigNumber.zero(),
                minute: BigNumber.zero(),
                second: BigNumber.zero(),
                millisecond: BigNumber.zero()
            },
                daysInYear = daysInGregorianYear(struct),
                result;

            dayOfYear = new BigNumber(dayOfYear);
            if (dayOfYear.inRange(1, daysInYear)) {
                struct = jdToGregorian(gregorianToJd(struct).plus(dayOfYear).minus(1));
                result = {
                    sign: 1,
                    year: struct.year,
                    month: struct.month,
                    day: struct.day
                };
            }

            return result;
        }

        /**
         * Convert the ISO week date to a date struct.
         * @private
         * @function
         * @param {(number|string|BigNumber)} year
         * @param {(number|string|BigNumber)} week
         * @param {(number|string|BigNumber)} weekDay
         * @return {object}
         */
        function weekDateToCalendar(year, week, weekDay) {
            var struct = {
                year: new BigNumber(year),
                month: BigNumber.one(),
                day: new BigNumber(4),
                hour: BigNumber.zero(),
                minute: BigNumber.zero(),
                second: BigNumber.zero(),
                millisecond: BigNumber.zero()
            },
                weekDayJan4 = weekDayNumber(struct),
                dayOfYear;

            dayOfYear = new BigNumber(7).times(week).plus(weekDay).minus(weekDayJan4.plus(3));
            if (dayOfYear.lt(1)) {
                struct.year = struct.year.minus(1);
                dayOfYear = daysInGregorianYear(struct).plus(dayOfYear);
            } else if (dayOfYear.gt(daysInGregorianYear(struct))) {
                struct.year = struct.year.plus(1);
                dayOfYear = dayOfYear.minus(daysInGregorianYear(struct));
            }

            return ordinalToCalendar(struct.year, dayOfYear);
        }

        /**
         * Returns the ISO week date.
         * @private
         * @function
         * @param {object} struct
         * @return {object}
         */
        function calendarToWeekDate(struct) {
            var weekDay = weekDayNumber(struct),
                year = struct.year,
                month = struct.month,
                nearestThursday,
                val;

            nearestThursday = struct.day.plus(4).minus(weekDay);
            if (struct.month.equals(12) && nearestThursday.gt(31)) {
                val = {
                    year: year.plus(1),
                    week: BigNumber.one(),
                    weekDay: weekDay
                };
            } else {
                if (struct.month.equals(1) && nearestThursday.lt(1)) {
                    year = struct.year.minus(1);
                    month = new BigNumber(12);
                    nearestThursday = nearestThursday.plus(31);
                }

                val = {
                    year: year,
                    week: dayOfGregorianYear({
                        year: year,
                        month: month,
                        day: nearestThursday
                    }).div(7).floor().plus(1),
                    weekDay: weekDay
                };
            }

            return val;
        }

        /**
         * ISO says that the first week of a year is the first week containing
         * a Thursday. Extending that says that the first week of the month is
         * the first week containing a Thursday. ICU agrees.
         * @private
         * @function
         * @param {object} struct
         * @return {BigNumber}
         */
        function calendarToWeekOfMonth(struct) {
            return struct.day.plus(4).minus(weekDayNumber(struct)).plus(6).div(7).floor();
        }

        /**
         * Returns the ISO weekDay number.
         * @private
         * @function
         * @param {object} struct
         * @return {BigNumber}
         */
        function weekDayOfMonth(struct) {
            return struct.day.minus(1).div(7).plus(1).floor();
        }

        /**
         * Returns true if BigNumber is any number except if it is minus zero.
         * @private
         * @function
         * @param {BigNumber} bn
         * @param {string} sign
         * @return {boolean}
         */
        function isNotNegativeZero(bn, sign) {
            return strictEqual(sign, '+') || !bn.isZero() || (bn.isZero() && !strictEqual(sign, '-'));
        }

        /**
         * Covert offset hours and minutes to minutes.
         * @private
         * @function
         * @param {(number|string|BigNumber)} hour
         * @param {(number|string|BigNumber)} minute
         * @return {BigNumber}
         */
        function hourMinuteToMinutes(hour, minute) {
            return new BigNumber(hour).times(60).plus(minute);
        }

        /**
         * Covert the fractional part of hours to a time object.
         * @private
         * @function
         * @param {(number|string)} number
         * @return {object.BigNumber}
         */
        function hourFractionToTime(number) {
            return fractionToTime('0.' + number, 'hour');
        }

        /**
         * Covert the fractional part of minutes to a time object.
         * @private
         * @function
         * @param {(number|string)} number
         * @return {object.BigNumber}
         */
        function minuteFractionToTime(number) {
            return fractionToTime('0.' + number, 'minute');
        }

        /**
         * Covert the fractional part of seconds to a time object.
         * @private
         * @function
         * @param {(number|string)} number
         * @return {object.BigNumber}
         */
        function secondFractionToTime(number) {
            return fractionToTime('0.' + number, 'second');
        }

        /**
         * Changes a '-' or '+' character to a multipler value '-1' or '+1' string.
         * @private
         * @function
         * @param {string} sign
         * @return {string}
         */
        function toSignMultipler(sign) {
            return sign + '1';
        }

        /**
         * Splits the given string into its date and time string components.
         * @private
         * @function
         * @param {string} string
         * @return {object}
         */
        function isoSplitDateTime(string) {
            var dtObject = {
                date: '',
                time: ''
            },
                firstSplit = stringSplit(stringTrim(string), /[T ]/),
                splitLength = firstSplit.length,
                element;

            if (inRange(splitLength, 1, 2)) {
                if (strictEqual(splitLength, 1)) {
                    element = arrayFirst(firstSplit);
                    // we make a best guess
                    if (strictEqual(element.slice(-4), '-') || firstCharIs(element, '+') || firstCharIs(element, '-') || strictEqual(element.length, 2) || gte(countCharacter(element, '-'), 2) || stringContains(element, 'W')) {
                        // only ordinal dates have a "-" at -4
                        // only dates begin with "+" or "-"
                        // dates and times can be only 2 digits but will default to date unless preceeded with " " or "T"
                        // only dates have 2 or more "-"
                        // only dates have a week number "W"
                        dtObject.date = element;
                        dtObject.time = '00';
                    } else if (lastCharIs(element, 'Z') || stringContains(element, ':') || stringContains(element, '.') || stringContains(element, ',') || stringContains(element, '+') || strictEqual(element.slice(-3), '-')) {
                        // only times end with a "Z"
                        // only times contain a ":" or a "." or a ","
                        // only times contain a "+" that is not at the beginning
                        // only times have a "-" at -3
                        dtObject.date = '00';
                        dtObject.time = element;
                    } else {
                        // otherwise we guess it is a date
                        dtObject.date = element;
                        dtObject.time = '00';
                    }
                } else {
                    dtObject.date = arrayFirst(firstSplit) || '00';
                    dtObject.time = arrayLast(firstSplit);
                }
            }

            return dtObject;
        }

        /**
         * Holds the a list of RegExps and functions for testing basic and extended ISO 8601 date patterns.
         * @private
         * @readonly
         * @type {object.array.object}
         * @see {@link http://en.wikipedia.org/wiki/ISO_8601}
         */
        datePatterns = {

            /**
             * The basic date patterns.
             * @private
             * @type {array.object}
             */
            basic: [{
                /**
                 * yy
                 * @private
                 */
                regex: /^(\d{2})$/,
                func: function (rxResult) {
                    return {
                        year: new BigNumber(rxResult[1] + '00'),
                        month: BigNumber.one(),
                        day: BigNumber.one()
                    };
                }
            }, {
                /**
                 * yyyy
                 * @private
                 */
                regex: /^(\d{4})$/,
                func: function (rxResult) {
                    return {
                        year: new BigNumber(rxResult[1]),
                        month: BigNumber.one(),
                        day: BigNumber.one()
                    };
                }
            }, {
                /**
                 * yyyyMMdd
                 * @private
                 */
                regex: /^(\d{4})(\d{2})(\d{2})$/,
                func: function (rxResult) {
                    return {
                        year: new BigNumber(rxResult[1]),
                        month: new BigNumber(rxResult[2]),
                        day: new BigNumber(rxResult[3])
                    };
                }
            }, {
                /**
                 * yyyyddd
                 * @private
                 */
                regex: /^(\d{4})(\d{3})$/,
                func: function (rxResult) {
                    return ordinalToCalendar(rxResult[1], rxResult[2]);
                }
            }, {
                /**
                 * yyyyWww
                 * @private
                 */
                regex: /^(\d{4})W(\d{2})$/,
                func: function (rxResult) {
                    return weekDateToCalendar(rxResult[1], rxResult[2], 1);
                }
            }, {
                /**
                 * yyyyWwwD
                 * @private
                 */
                regex: /^(\d{4})W(\d{2})([1-7]{1})$/,
                func: function (rxResult) {
                    return weekDateToCalendar(rxResult[1], rxResult[2], rxResult[3]);
                }
            }],

            /**
             * The extended date patterns.
             * @private
             * @type {array.object}
             */
            extended: [{
                // need to add tests for -0
                /**
                 * -+[..y]yyyyy-MM
                 * @private
                 */
                regex: /^([\-+]{1})(\d{5,})-(\d{2})$/,
                func: function (rxResult) {
                    return {
                        year: new BigNumber(rxResult[2]).times(toSignMultipler(rxResult[1])),
                        month: new BigNumber(rxResult[3]),
                        day: BigNumber.one()
                    };
                }
            }, {
                /**
                 * yyyy-MM
                 * @private
                 */
                regex: /^(\d{4})-(\d{2})$/,
                func: function (rxResult) {
                    return {
                        year: new BigNumber(rxResult[1]),
                        month: new BigNumber(rxResult[2]),
                        day: BigNumber.one()
                    };
                }
            }, {
                /**
                 * yyyy-MM-dd
                 * @private
                 */
                regex: /^(\d{4})-(\d{2})-(\d{2})$/,
                func: function (rxResult) {
                    return {
                        year: new BigNumber(rxResult[1]),
                        month: new BigNumber(rxResult[2]),
                        day: new BigNumber(rxResult[3])
                    };
                }
            }, {
                /**
                 * -+[..y]yyyyy-MM-dd
                 * @private
                 */
                regex: /^([\-+]{1})(\d{5,})-(\d{2})-(\d{2})$/,
                func: function (rxResult) {
                    return {
                        year: new BigNumber(rxResult[2]).times(toSignMultipler(rxResult[1])),
                        month: new BigNumber(rxResult[3]),
                        day: new BigNumber(rxResult[4])
                    };
                }
            }, {
                /**
                 * yyyy-DDD
                 * @private
                 */
                regex: /^(\d{4})-(\d{3})$/,
                func: function (rxResult) {
                    return ordinalToCalendar(rxResult[1], rxResult[2]);
                }
            }, {
                /**
                 * yyyy-Www
                 * @private
                 */
                regex: /^(\d{4})-W(\d{2})$/,
                func: function (rxResult) {
                    return weekDateToCalendar(rxResult[1], rxResult[2], 1);
                }
            }, {
                /**
                 * yyyy-Www-D
                 * @private
                 */
                regex: /^(\d{4})-W(\d{2})-([1-7]{1})$/,
                func: function (rxResult) {
                    return weekDateToCalendar(rxResult[1], rxResult[2], rxResult[3]);
                }
            }, {
                /**
                 * -+[..y]yyyy-DDD
                 * @private
                 */
                regex: /^([\-+]{1})(\d{5,})-(\d{3})$/,
                func: function (rxResult) {
                    return ordinalToCalendar(new BigNumber(rxResult[2]).times(toSignMultipler(rxResult[1])), rxResult[3]);
                }
            }, {
                /**
                 * -+[..y]yyyyy-Www
                 * @private
                 */
                regex: /^([\-+]{1})(\d{5,})-W(\d{2})$/,
                func: function (rxResult) {
                    return weekDateToCalendar(new BigNumber(rxResult[2]).times(toSignMultipler(rxResult[1])), rxResult[3], 1);
                }
            }, {
                /**
                 * -+[..y]yyyyy-Www-D
                 * @private
                 */
                regex: /^([\-+]{1})(\d{5,})-W(\d{2})-([1-7]{1})$/,
                func: function (rxResult) {
                    return weekDateToCalendar(new BigNumber(rxResult[2]).times(toSignMultipler(rxResult[1])), rxResult[3], rxResult[4]);
                }
            }]
        };

        /** Make datePatterns readonly */
        deepFreeze(datePatterns);

        /**
         * Holds the a list of RegExps and functions for testing basic and extended ISO 8601 time patterns.
         * @private
         * @readonly
         * @type {object.array.object}
         * @see {@link http://en.wikipedia.org/wiki/ISO_8601}
         */
        timePatterns = {

            /**
             * The basic time patterns.
             * @private
             * @type {array.object}
             */
            basic: [{
                /**
                 * HH
                 * @private
                 */
                regex: /^(\d{2})$/,
                func: function (rxResult) {
                    return {
                        hour: new BigNumber(rxResult[1]),
                        minute: BigNumber.zero(),
                        second: BigNumber.zero(),
                        millisecond: BigNumber.zero(),
                        offset: bnGetTimezoneOffset()
                    };
                }
            }, {
                /**
                 * HHMM
                 * @private
                 */
                regex: /^(\d{2})(\d{2})$/,
                func: function (rxResult) {
                    return {
                        hour: new BigNumber(rxResult[1]),
                        minute: new BigNumber(rxResult[2]),
                        second: BigNumber.zero(),
                        millisecond: BigNumber.zero(),
                        offset: bnGetTimezoneOffset()
                    };
                }
            }, {
                /**
                 * HHMMSS
                 * @private
                 */
                regex: /^(\d{2})(\d{2})(\d{2})$/,
                func: function (rxResult) {
                    return {
                        hour: new BigNumber(rxResult[1]),
                        minute: new BigNumber(rxResult[2]),
                        second: new BigNumber(rxResult[3]),
                        millisecond: BigNumber.zero(),
                        offset: bnGetTimezoneOffset()
                    };
                }
            }, {
                /**
                 * HHZ
                 * @private
                 */
                regex: /^(\d{2})Z$/,
                func: function (rxResult) {
                    return {
                        hour: new BigNumber(rxResult[1]),
                        minute: BigNumber.zero(),
                        second: BigNumber.zero(),
                        millisecond: BigNumber.zero(),
                        offset: BigNumber.zero()
                    };
                }
            }, {
                /**
                 * HHMMZ
                 * @private
                 */
                regex: /^(\d{2})(\d{2})Z$/,
                func: function (rxResult) {
                    return {
                        hour: new BigNumber(rxResult[1]),
                        minute: new BigNumber(rxResult[2]),
                        second: BigNumber.zero(),
                        millisecond: BigNumber.zero(),
                        offset: BigNumber.zero()
                    };
                }
            }, {
                /**
                 * HHMMSSZ
                 * @private
                 */
                regex: /^(\d{2})(\d{2})(\d{2})Z$/,
                func: function (rxResult) {
                    return {
                        hour: new BigNumber(rxResult[1]),
                        minute: new BigNumber(rxResult[2]),
                        second: new BigNumber(rxResult[3]),
                        millisecond: BigNumber.zero(),
                        offset: BigNumber.zero()
                    };
                }
            }, {
                /**
                 * HH-+ZZ
                 * @private
                 */
                regex: /^(\d{2})([\-+]{1})(\d{2})$/,
                func: function (rxResult) {
                    var sign = rxResult[2],
                        offset = hourMinuteToMinutes(rxResult[3], 0),
                        val;

                    if (isNotNegativeZero(offset, sign)) {
                        val = {
                            hour: new BigNumber(rxResult[1]),
                            minute: BigNumber.zero(),
                            second: BigNumber.zero(),
                            millisecond: BigNumber.zero(),
                            offset: offset.times(toSignMultipler(sign)).neg()
                        };
                    }

                    return val;
                }
            }, {
                /**
                 * HHMM-+ZZ
                 * @private
                 */
                regex: /^(\d{2})(\d{2})([\-+]{1})(\d{2})$/,
                func: function (rxResult) {
                    var sign = rxResult[3],
                        offset = hourMinuteToMinutes(rxResult[4], 0),
                        val;

                    if (isNotNegativeZero(offset, sign)) {
                        val = {
                            hour: new BigNumber(rxResult[1]),
                            minute: new BigNumber(rxResult[2]),
                            second: BigNumber.zero(),
                            millisecond: BigNumber.zero(),
                            offset: offset.times(toSignMultipler(sign)).neg()
                        };
                    }

                    return val;
                }
            }, {
                /**
                 * HHMMSS-+ZZ
                 * @private
                 */
                regex: /^(\d{2})(\d{2})(\d{2})([\-+]{1})(\d{2})$/,
                func: function (rxResult) {
                    var sign = rxResult[4],
                        offset = hourMinuteToMinutes(rxResult[5], 0),
                        val;

                    if (isNotNegativeZero(offset, sign)) {
                        val = {
                            hour: new BigNumber(rxResult[1]),
                            minute: new BigNumber(rxResult[2]),
                            second: new BigNumber(rxResult[3]),
                            millisecond: BigNumber.zero(),
                            offset: offset.times(toSignMultipler(sign)).neg()
                        };
                    }

                    return val;
                }
            }, {
                /**
                 * HH-+ZZZZ
                 * @private
                 */
                regex: /^(\d{2})([\-+]{1})(\d{2})(\d{2})$/,
                func: function (rxResult) {
                    var sign = rxResult[2],
                        offset = hourMinuteToMinutes(rxResult[3], rxResult[4]),
                        val;

                    if (isNotNegativeZero(offset, sign)) {
                        val = {
                            hour: new BigNumber(rxResult[1]),
                            minute: BigNumber.zero(),
                            second: BigNumber.zero(),
                            millisecond: BigNumber.zero(),
                            offset: offset.times(toSignMultipler(sign)).neg()
                        };
                    }

                    return val;
                }
            }, {
                /**
                 * HHMM-+ZZZZ
                 * @private
                 */
                regex: /^(\d{2})(\d{2})([\-+]{1})(\d{2})(\d{2})$/,
                func: function (rxResult) {
                    var sign = rxResult[3],
                        offset = hourMinuteToMinutes(rxResult[4], rxResult[5]),
                        val;

                    if (isNotNegativeZero(offset, sign)) {
                        val = {
                            hour: new BigNumber(rxResult[1]),
                            minute: new BigNumber(rxResult[2]),
                            second: BigNumber.zero(),
                            millisecond: BigNumber.zero(),
                            offset: offset.times(toSignMultipler(sign)).neg()
                        };
                    }

                    return val;
                }
            }, {
                /**
                 * HHMMSS-+ZZZZ
                 * @private
                 */
                regex: /^(\d{2})(\d{2})(\d{2})([\-+]{1})(\d{2})(\d{2})$/,
                func: function (rxResult) {
                    var sign = rxResult[4],
                        offset = hourMinuteToMinutes(rxResult[5], rxResult[6]),
                        val;

                    if (isNotNegativeZero(offset, sign)) {
                        val = {
                            hour: new BigNumber(rxResult[1]),
                            minute: new BigNumber(rxResult[2]),
                            second: new BigNumber(rxResult[3]),
                            millisecond: BigNumber.zero(),
                            offset: offset.times(toSignMultipler(sign)).neg()
                        };
                    }

                    return val;
                }
            }, {
                /**
                 * HH.,[..f]f
                 * @private
                 */
                regex: /^(\d{2})[\.,]{1}(\d{1,})$/,
                func: function (rxResult) {
                    var val = hourFractionToTime(rxResult[2]);

                    val.hour = new BigNumber(rxResult[1]);
                    val.offset = bnGetTimezoneOffset();

                    return val;
                }
            }, {
                /**
                 * HHMM.,[..f]f
                 * @private
                 */
                regex: /^(\d{2})(\d{2})[\.,]{1}(\d{1,})$/,
                func: function (rxResult) {
                    var val = minuteFractionToTime(rxResult[3]);

                    val.hour = new BigNumber(rxResult[1]);
                    val.minute = new BigNumber(rxResult[2]);
                    val.offset = bnGetTimezoneOffset();

                    return val;
                }
            }, {
                /**
                 * HHMMSS.,[..f]f
                 * @private
                 */
                regex: /^(\d{2})(\d{2})(\d{2})[\.,]{1}(\d{1,})$/,
                func: function (rxResult) {
                    var val = secondFractionToTime(rxResult[4]);

                    val.hour = new BigNumber(rxResult[1]);
                    val.minute = new BigNumber(rxResult[2]);
                    val.second = new BigNumber(rxResult[3]);
                    val.offset = bnGetTimezoneOffset();

                    return val;
                }
            }, {
                /**
                 * HH.,[..f]fZ
                 * @private
                 */
                regex: /^(\d{2})[\.,]{1}(\d{1,})Z$/,
                func: function (rxResult) {
                    var val = hourFractionToTime(rxResult[2]);

                    val.hour = new BigNumber(rxResult[1]);
                    val.offset = BigNumber.zero();

                    return val;
                }
            }, {
                /**
                 * HHMM.,[..f]fZ
                 * @private
                 */
                regex: /^(\d{2})(\d{2})[\.,]{1}(\d{1,})Z$/,
                func: function (rxResult) {
                    var val = minuteFractionToTime(rxResult[3]);

                    val.hour = new BigNumber(rxResult[1]);
                    val.minute = new BigNumber(rxResult[1]);
                    val.offset = BigNumber.zero();

                    return val;
                }
            }, {
                /**
                 * HHMMSS.,[..f]fZ
                 * @private
                 */
                regex: /^(\d{2})(\d{2})(\d{2})[\.,]{1}(\d{1,})Z$/,
                func: function (rxResult) {
                    var val = secondFractionToTime(rxResult[4]);

                    val.hour = new BigNumber(rxResult[1]);
                    val.minute = new BigNumber(rxResult[2]);
                    val.second = new BigNumber(rxResult[3]);
                    val.offset = BigNumber.zero();

                    return val;
                }
            }, {
                /**
                 * HH.,[..f]f-+ZZ
                 * @private
                 */
                regex: /^(\d{2})[\.,]{1}(\d{1,})([\-+]{1})(\d{2})$/,
                func: function (rxResult) {
                    var sign = rxResult[3],
                        offset = hourMinuteToMinutes(rxResult[4], 0),
                        val;

                    if (isNotNegativeZero(offset, sign)) {
                        val = hourFractionToTime(rxResult[2]);
                        val.hour = new BigNumber(rxResult[1]);
                        val.offset = offset.times(toSignMultipler(sign)).neg();
                    }

                    return val;
                }
            }, {
                /**
                 * HHMM.,[..f]f-+ZZ
                 * @private
                 */
                regex: /^(\d{2})(\d{2})[\.,]{1}(\d{1,})([\-+]{1})(\d{2})$/,
                func: function (rxResult) {
                    var sign = rxResult[4],
                        offset = hourMinuteToMinutes(rxResult[5], 0),
                        val;

                    if (isNotNegativeZero(offset, sign)) {
                        val = minuteFractionToTime(rxResult[3]);
                        val.hour = new BigNumber(rxResult[1]);
                        val.minute = new BigNumber(rxResult[2]);
                        val.offset = offset.times(toSignMultipler(sign)).neg();
                    }

                    return val;
                }
            }, {
                /**
                 * HHMMSS.,[..f]f-+ZZ
                 * @private
                 */
                regex: /^(\d{2})(\d{2})(\d{2})[\.,]{1}(\d{1,})([\-+]{1})(\d{2})$/,
                func: function (rxResult) {
                    var sign = rxResult[5],
                        offset = hourMinuteToMinutes(rxResult[6], 0),
                        val;

                    if (isNotNegativeZero(offset, sign)) {
                        val = secondFractionToTime(rxResult[4]);
                        val.hour = new BigNumber(rxResult[1]);
                        val.minute = new BigNumber(rxResult[2]);
                        val.minute = new BigNumber(rxResult[3]);
                        val.offset = offset.times(toSignMultipler(sign)).neg();
                    }

                    return val;
                }
            }, {
                /**
                 * HH.,[..f]f-+ZZZZ
                 * @private
                 */
                regex: /^(\d{2})[\.,]{1}(\d{1,})([\-+]{1})(\d{2})(\d{2})$/,
                func: function (rxResult) {
                    var sign = rxResult[3],
                        offset = hourMinuteToMinutes(rxResult[4], rxResult[5]),
                        val;

                    if (isNotNegativeZero(offset, sign)) {
                        val = hourFractionToTime(rxResult[2]);
                        val.hour = new BigNumber(rxResult[1]);
                        val.offset = offset.times(toSignMultipler(sign)).neg();
                    }

                    return val;
                }
            }, {
                /**
                 * HHMM.,[..f]f-+ZZZZ
                 * @private
                 */
                regex: /^(\d{2})(\d{2})[\.,]{1}(\d{1,})([\-+]{1})(\d{2})(\d{2})$/,
                func: function (rxResult) {
                    var sign = rxResult[4],
                        offset = hourMinuteToMinutes(rxResult[5], rxResult[6]),
                        val;

                    if (isNotNegativeZero(offset, sign)) {
                        val = minuteFractionToTime(rxResult[3]);
                        val.hour = new BigNumber(rxResult[1]);
                        val.minute = new BigNumber(rxResult[2]);
                        val.offset = offset.times(toSignMultipler(sign)).neg();
                    }

                    return val;
                }
            }, {
                /**
                 * HHMMSS.,[..f]f-+ZZZZ
                 * @private
                 */
                regex: /^(\d{2})(\d{2})(\d{2})[\.,]{1}(\d{1,})([\-+]{1})(\d{2})(\d{2})$/,
                func: function (rxResult) {
                    var sign = rxResult[5],
                        offset = hourMinuteToMinutes(rxResult[6], rxResult[7]),
                        val;

                    if (isNotNegativeZero(offset, sign)) {
                        val = secondFractionToTime(rxResult[4]);
                        val.hour = new BigNumber(rxResult[1]);
                        val.minute = new BigNumber(rxResult[2]);
                        val.minute = new BigNumber(rxResult[3]);
                        val.offset = offset.times(toSignMultipler(sign)).neg();
                    }

                    return val;
                }
            }],

            /**
             * The extended time patterns.
             * @private
             * @type {array.object}
             */
            extended: [{
                /**
                 * HH
                 * @private
                 */
                regex: /^(\d{2})$/,
                func: function (rxResult) {
                    return {
                        hour: new BigNumber(rxResult[1]),
                        minute: BigNumber.zero(),
                        second: BigNumber.zero(),
                        millisecond: BigNumber.zero(),
                        offset: bnGetTimezoneOffset()
                    };
                }
            }, {
                /**
                 * HH:MM
                 * @private
                 */
                regex: /^(\d{2}):(\d{2})$/,
                func: function (rxResult) {
                    return {
                        hour: new BigNumber(rxResult[1]),
                        minute: new BigNumber(rxResult[2]),
                        second: BigNumber.zero(),
                        millisecond: BigNumber.zero(),
                        offset: bnGetTimezoneOffset()
                    };
                }
            }, {
                /**
                 * HH:MM:SS
                 * @private
                 */
                regex: /^(\d{2}):(\d{2}):(\d{2})$/,
                func: function (rxResult) {
                    return {
                        hour: new BigNumber(rxResult[1]),
                        minute: new BigNumber(rxResult[2]),
                        second: new BigNumber(rxResult[3]),
                        millisecond: BigNumber.zero(),
                        offset: bnGetTimezoneOffset()
                    };
                }
            }, {
                /**
                 * HHZ
                 * @private
                 */
                regex: /^(\d{2})Z$/,
                func: function (rxResult) {
                    return {
                        hour: new BigNumber(rxResult[1]),
                        minute: BigNumber.zero(),
                        second: BigNumber.zero(),
                        millisecond: BigNumber.zero(),
                        offset: BigNumber.zero()
                    };
                }
            }, {
                /**
                 * HH:MMZ
                 * @private
                 */
                regex: /^(\d{2}):(\d{2})Z$/,
                func: function (rxResult) {
                    return {
                        hour: new BigNumber(rxResult[1]),
                        minute: new BigNumber(rxResult[2]),
                        second: BigNumber.zero(),
                        millisecond: BigNumber.zero(),
                        offset: BigNumber.zero()
                    };
                }
            }, {
                /**
                 * HH:MM:SSZ
                 * @private
                 */
                regex: /^(\d{2}):(\d{2}):(\d{2})Z$/,
                func: function (rxResult) {
                    return {
                        hour: new BigNumber(rxResult[1]),
                        minute: new BigNumber(rxResult[2]),
                        second: new BigNumber(rxResult[3]),
                        millisecond: BigNumber.zero(),
                        offset: BigNumber.zero()
                    };
                }
            }, {
                /**
                 * HH-+ZZ
                 * @private
                 */
                regex: /^(\d{2})([\-+]{1})(\d{2})$/,
                func: function (rxResult) {
                    var sign = rxResult[2],
                        offset = hourMinuteToMinutes(rxResult[3], 0),
                        val;

                    if (isNotNegativeZero(offset, sign)) {
                        val = {
                            hour: new BigNumber(rxResult[1]),
                            minute: BigNumber.zero(),
                            second: BigNumber.zero(),
                            millisecond: BigNumber.zero(),
                            offset: offset.times(toSignMultipler(sign)).neg()
                        };
                    }

                    return val;
                }
            }, {
                /**
                 * HH:MM-+ZZ
                 * @private
                 */
                regex: /^(\d{2}):(\d{2})([\-+]{1})(\d{2})$/,
                func: function (rxResult) {
                    var sign = rxResult[3],
                        offset = hourMinuteToMinutes(rxResult[4], 0),
                        val;

                    if (isNotNegativeZero(offset, sign)) {
                        val = {
                            hour: new BigNumber(rxResult[1]),
                            minute: new BigNumber(rxResult[2]),
                            second: BigNumber.zero(),
                            millisecond: BigNumber.zero(),
                            offset: offset.times(toSignMultipler(sign)).neg()
                        };
                    }

                    return val;
                }
            }, {
                /**
                 * HH:MM:SS-+ZZ
                 * @private
                 */
                regex: /^(\d{2}):(\d{2}):(\d{2})([\-+]{1})(\d{2})$/,
                func: function (rxResult) {
                    var sign = rxResult[4],
                        offset = hourMinuteToMinutes(rxResult[5], 0),
                        val;

                    if (isNotNegativeZero(offset, sign)) {
                        val = {
                            hour: new BigNumber(rxResult[1]),
                            minute: new BigNumber(rxResult[2]),
                            second: new BigNumber(rxResult[3]),
                            millisecond: BigNumber.zero(),
                            offset: offset.times(toSignMultipler(sign)).neg()
                        };
                    }

                    return val;
                }
            }, {
                /**
                 * HH-+ZZ:ZZ
                 * @private
                 */
                regex: /^(\d{2})([\-+]{1})(\d{2}):(\d{2})$/,
                func: function (rxResult) {
                    var sign = rxResult[2],
                        offset = hourMinuteToMinutes(rxResult[3], rxResult[4]),
                        val;

                    if (isNotNegativeZero(offset, sign)) {
                        val = {
                            hour: new BigNumber(rxResult[1]),
                            minute: BigNumber.zero(),
                            second: BigNumber.zero(),
                            millisecond: BigNumber.zero(),
                            offset: offset.times(toSignMultipler(sign)).neg()
                        };
                    }

                    return val;
                }
            }, {
                /**
                 * HH:MM-+ZZ:ZZ
                 * @private
                 */
                regex: /^(\d{2}):(\d{2})([\-+]{1})(\d{2}):(\d{2})$/,
                func: function (rxResult) {
                    var sign = rxResult[3],
                        offset = hourMinuteToMinutes(rxResult[4], rxResult[5]),
                        val;

                    if (isNotNegativeZero(offset, sign)) {
                        val = {
                            hour: new BigNumber(rxResult[1]),
                            minute: new BigNumber(rxResult[2]),
                            second: BigNumber.zero(),
                            millisecond: BigNumber.zero(),
                            offset: offset.times(toSignMultipler(sign)).neg()
                        };
                    }

                    return val;
                }
            }, {
                /**
                 * HH:MM:SS-+ZZ:ZZ
                 * @private
                 */
                regex: /^(\d{2}):(\d{2}):(\d{2})([\-+]{1})(\d{2}):(\d{2})$/,
                func: function (rxResult) {
                    var sign = rxResult[4],
                        offset = hourMinuteToMinutes(rxResult[5], rxResult[6]),
                        val;

                    if (isNotNegativeZero(offset, sign)) {
                        val = {
                            hour: new BigNumber(rxResult[1]),
                            minute: new BigNumber(rxResult[2]),
                            second: new BigNumber(rxResult[3]),
                            millisecond: BigNumber.zero(),
                            offset: offset.times(toSignMultipler(sign)).neg()
                        };
                    }

                    return val;
                }
            }, {
                /**
                 * HH.,[..f]f
                 * @private
                 */
                regex: /^(\d{2})[\.,]{1}(\d{1,})$/,
                func: function (rxResult) {
                    var val = hourFractionToTime(rxResult[2]);

                    val.hour = new BigNumber(rxResult[1]);
                    val.offset = bnGetTimezoneOffset();

                    return val;
                }
            }, {
                /**
                 * HH:MM.,[..f]f
                 * @private
                 */
                regex: /^(\d{2}):(\d{2})[\.,]{1}(\d{1,})$/,
                func: function (rxResult) {
                    var val = minuteFractionToTime(rxResult[3]);

                    val.hour = new BigNumber(rxResult[1]);
                    val.minute = new BigNumber(rxResult[2]);
                    val.offset = bnGetTimezoneOffset();

                    return val;
                }
            }, {
                /**
                 * HH:MM:SS.,[..f]f
                 * @private
                 */
                regex: /^(\d{2}):(\d{2}):(\d{2})[\.,]{1}(\d{1,})$/,
                func: function (rxResult) {
                    var val = secondFractionToTime(rxResult[4]);

                    val.hour = new BigNumber(rxResult[1]);
                    val.minute = new BigNumber(rxResult[2]);
                    val.second = new BigNumber(rxResult[3]);
                    val.offset = bnGetTimezoneOffset();

                    return val;
                }
            }, {
                /**
                 * HH.,[..f]fZ
                 * @private
                 */
                regex: /^(\d{2})[\.,]{1}(\d{1,})Z$/,
                func: function (rxResult) {
                    var val = hourFractionToTime(rxResult[2]);

                    val.hour = new BigNumber(rxResult[1]);
                    val.offset = BigNumber.zero();

                    return val;
                }
            }, {
                /**
                 * HH:MM.,[..f]fZ
                 * @private
                 */
                regex: /^(\d{2}):(\d{2})[\.,]{1}(\d{1,})Z$/,
                func: function (rxResult) {
                    var val = minuteFractionToTime(rxResult[3]);

                    val.hour = new BigNumber(rxResult[1]);
                    val.minute = new BigNumber(rxResult[1]);
                    val.offset = BigNumber.zero();

                    return val;
                }
            }, {
                /**
                 * HH:MM:SS.,[..f]fZ
                 * @private
                 */
                regex: /^(\d{2}):(\d{2}):(\d{2})[\.,]{1}(\d{1,})Z$/,
                func: function (rxResult) {
                    var val = secondFractionToTime(rxResult[4]);

                    val.hour = new BigNumber(rxResult[1]);
                    val.minute = new BigNumber(rxResult[2]);
                    val.second = new BigNumber(rxResult[3]);
                    val.offset = BigNumber.zero();

                    return val;
                }
            }, {
                /**
                 * HH.,[..f]f-+ZZ
                 * @private
                 */
                regex: /^(\d{2})[\.,]{1}(\d{1,})([\-+]{1})(\d{2})$/,
                func: function (rxResult) {
                    var sign = rxResult[3],
                        offset = hourMinuteToMinutes(rxResult[4], 0),
                        val;

                    if (isNotNegativeZero(offset, sign)) {
                        val = hourFractionToTime(rxResult[2]);
                        val.hour = new BigNumber(rxResult[1]);
                        val.offset = offset.times(toSignMultipler(sign)).neg();
                    }

                    return val;
                }
            }, {
                /**
                 * HH:MM.,[..f]f-+ZZ
                 * @private
                 */
                regex: /^(\d{2}):(\d{2})[\.,]{1}(\d{1,})([\-+]{1})(\d{2})$/,
                func: function (rxResult) {
                    var sign = rxResult[4],
                        offset = hourMinuteToMinutes(rxResult[5], 0),
                        val;

                    if (isNotNegativeZero(offset, sign)) {
                        val = minuteFractionToTime(rxResult[3]);
                        val.hour = new BigNumber(rxResult[1]);
                        val.minute = new BigNumber(rxResult[2]);
                        val.offset = offset.times(toSignMultipler(sign)).neg();
                    }

                    return val;
                }
            }, {
                /**
                 * HH:MM:SS.,[..f]f-+ZZ
                 * @private
                 */
                regex: /^(\d{2}):(\d{2}):(\d{2})[\.,]{1}(\d{1,})([\-+]{1})(\d{2})$/,
                func: function (rxResult) {
                    var sign = rxResult[5],
                        offset = hourMinuteToMinutes(rxResult[6], 0),
                        val;

                    if (isNotNegativeZero(offset, sign)) {
                        val = secondFractionToTime(rxResult[4]);
                        val.hour = new BigNumber(rxResult[1]);
                        val.minute = new BigNumber(rxResult[2]);
                        val.second = new BigNumber(rxResult[3]);
                        val.offset = offset.times(toSignMultipler(sign)).neg();
                    }

                    return val;
                }
            }, {
                /**
                 * HH.,[..f]f-+ZZ:ZZ
                 * @private
                 */
                regex: /^(\d{2})[\.,]{1}(\d{1,})([\-+]{1})(\d{2}):(\d{2})$/,
                func: function (rxResult) {
                    var sign = rxResult[3],
                        offset = hourMinuteToMinutes(rxResult[4], rxResult[5]),
                        val;

                    if (isNotNegativeZero(offset, sign)) {
                        val = hourFractionToTime(rxResult[2]);
                        val.hour = new BigNumber(rxResult[1]);
                        val.offset = offset.times(toSignMultipler(sign)).neg();
                    }

                    return val;
                }
            }, {
                /**
                 * HH:MM.,[..f]f-+ZZ:ZZ
                 * @private
                 */
                regex: /^(\d{2}):(\d{2})[\.,]{1}(\d{1,})([\-+]{1})(\d{2}):(\d{2})$/,
                func: function (rxResult) {
                    var sign = rxResult[4],
                        offset = hourMinuteToMinutes(rxResult[5], rxResult[6]),
                        val;

                    if (isNotNegativeZero(offset, sign)) {
                        val = minuteFractionToTime(rxResult[3]);
                        val.hour = new BigNumber(rxResult[1]);
                        val.minute = new BigNumber(rxResult[2]);
                        val.offset = offset.times(toSignMultipler(sign)).neg();
                    }

                    return val;
                }
            }, {
                /**
                 * HH:MM:SS.,[..f]f-+ZZ:ZZ
                 * @private
                 */
                regex: /^(\d{2}):(\d{2}):(\d{2})[\.,]{1}(\d{1,})([\-+]{1})(\d{2}):(\d{2})$/,
                func: function (rxResult) {
                    var sign = rxResult[5],
                        offset = hourMinuteToMinutes(rxResult[6], rxResult[7]),
                        val;

                    if (isNotNegativeZero(offset, sign)) {
                        val = secondFractionToTime(rxResult[4]);
                        val.hour = new BigNumber(rxResult[1]);
                        val.minute = new BigNumber(rxResult[2]);
                        val.second = new BigNumber(rxResult[3]);
                        val.offset = offset.times(toSignMultipler(sign)).neg();
                    }

                    return val;
                }
            }]
        };

        /** Make timePatterns readonly */
        deepFreeze(timePatterns);

        /**
         * Takes a give string an parses it as a given ISO timestamp returning the date and time matches as an object.
         * Uses datePatterns and timePatterns for precision matching.
         * @private
         * @function
         * @param {string} isoString
         * @return {object}
         */
        function isoParse(isoString) {
            // Unused variable for JScript NFE bug
            // http://kangax.github.io/nfe
            var dtObject = {
                input: isoString
            },
                nfeSearchPatterns,
                searchString;

            if (isString(isoString) && !isEmptyString(isoString) && !invalidISOCharsRx.test(isoString) && isoHasValidCharacterCounts(isoString)) {
                tempSafariNFE = function nfeSearchPatterns(pattern) {
                    var rxResult = pattern.regex.exec(searchString),
                        val = false,
                        result;

                    if (!isNull(rxResult)) {
                        result = pattern.func(rxResult);
                        if (!isUndefined(result)) {
                            extend(dtObject, result);
                        }

                        val = true;
                    }

                    return val;
                };

                extend(dtObject, isoSplitDateTime(isoString));
                searchString = dtObject.date;
                if (!arraySome(datePatterns.basic, tempSafariNFE)) {
                    if (arraySome(datePatterns.extended, tempSafariNFE)) {
                        searchString = dtObject.time;
                        arraySome(timePatterns.extended, tempSafariNFE);
                    }
                } else {
                    searchString = dtObject.time;
                    arraySome(timePatterns.basic, tempSafariNFE);
                }
            }


            nfeSearchPatterns = null;

            return dtObject;
        }

        /**
         * Converts the given Gregorian structure to an appropriate structure depending on the AstroDate instance settings.
         * @private
         * @function
         * @param {AstroDate} thisAstroDate
         * @param {object} struct
         * @return {object}
         */
        function getCorrectStruct(thisAstroDate, struct) {
            if (thisAstroDate.isDT()) {
                if (thisAstroDate.isUT2TT()) {
                    struct = subDT(struct);
                } else {
                    struct = addDT(struct);
                }
            }

            /*
            if (thisAstroDate.isTT()) {
                struct = toTT(struct);
            }
            */

            if (thisAstroDate.isUT()) {
                struct = toUT(struct);
            } else if (thisAstroDate.isLocal()) {
                struct = toLocal(struct);
            }

            return struct;
        }

        /**
         * Left pads a number with '0's so that it is of the require length as given by size.
         * @private
         * @function
         * @param {number|string} num
         * @param {number} size
         * @return {string}
         */
        function cldrPadLeadingZero(num, size) {
            var strNum = anyToString(checkObjectCoercible(num)),
                firsrCharacter,
                val;

            if (isDigits(strNum) && new BigNumber(strNum).isFinite()) {
                firsrCharacter = firstChar(strNum);
                val = '';
                if (strictEqual(firsrCharacter, '-')) {
                    strNum = strNum.slice(1);
                    size -= 1;
                    val = firsrCharacter;
                }

                val += padLeadingChar(strNum, '0', size);
            } else {
                val = strNum;
            }

            return val;
        }

        /**
         * Replaces the given token pattern in the given pattern with the supplied string value.
         * @private
         * @function
         * @param {string} pattern
         * @param {string} token
         * @param {string} value
         * @return {string}
         */
        function replaceToken(pattern, token, value) {
            if (!isString(token) || isEmptyString(token)) {
                throw new Error();
            }

            var firstCharacter,
                count,
                copyMatch,
                noWrap;

            if ((/^\{\d\}$/).test(token)) {
                token = escapeRegex(token);
                copyMatch = token;
                noWrap = true;
            } else {
                firstCharacter = firstChar(token);
                if (!(/^\S\{\d+,\d*\}$/).test(token)) {
                    count = token.length;
                    if (!strictEqual(count, countCharacter(token, firstCharacter))) {
                        throw new Error(token);
                    }
                }

                copyMatch = '(?:^|[^' + firstCharacter + '])(' + token + ')(?:[^' + firstCharacter + ']|$)';
            }

            /**
             * Replaces tokens, handles padding choice and wraps replacements (if required) in sinqle quotes so they are ignored in future.
             * @private
             * @function
             * @param {string} $0
             * @param {string} $1
             * @return {string}
             */
            function replacer($0, $1) {
                var val;

                if ($1) {
                    val = cldrPadLeadingZero(value, $1.length);
                } else {
                    val = value;
                }

                if (!strictEqual(noWrap, true)) {
                    val = wrapInChar(val, '\'');
                }

                return $0.replace(new RegExp(token, 'g'), val);
            }

            /**
             * Returns strings of non-tokens untouched or calls the replacer on strings with tokens.
             * @private
             * @function
             * @param {string} $0
             * @param {string} $1
             * @param {string} $2
             * @return {string}
             */
            function tokenReplacer($0, $1, $2) {
                var val;

                if ($0) {
                    if ($1) {
                        val = $1.replace(new RegExp(copyMatch, 'g'), replacer);
                    } else {
                        val = $2;
                    }
                }

                return val;
            }

            return pattern.replace(replaceTokenRX, tokenReplacer);
        }

        /**
         * Remove all non-token from a given pattern and returns a string with any tokens that remain.
         * @private
         * @function
         * @param {string} pattern
         * @return {string}
         */
        function remainingTokens(pattern) {
            function tokenReplacer($0, $1, $2) {
                var val;

                if ($0 && $1 && !$2) {
                    val = $1;
                } else {
                    val = '';
                }

                return val;
            }

            return pattern.replace(replaceTokenRX, tokenReplacer).replace(unmatchedTokenRx, '');
        }

        /**
         * Returns true if there are any remaining tokens in the given pattern.
         * @private
         * @function
         * @param {string} pattern
         * @return {boolean}
         */
        function hasRemainingTokens(pattern) {
            return !isEmptyString(remainingTokens(pattern));
        }

        /**
         * Remove all signle quote characters from a given dtring.
         * @private
         * @function
         * @param {string} string
         * @return {string}
         */
        function stripSingleQuotes(string) {
            return replaceAll(string, '\'', '');
        }

        /**
         * Replace all occurences of '-' with '_'.
         * @private
         * @function
         * @param {string} string
         * @return {string}
         */
        function minusToUnderscore(string) {
            return replaceAll(string, '-', '_');
        }

        /*
        calendarTypes = {
            julian: {
                abbreviated: 'OS',
                wide: 'Julian',
                narrow: 'O'
            },
            gregorian: {
                abbreviated: 'NS',
                wide: 'Gregorian',
                narrow: 'N'
            }
        };

        deepFreeze(calendarTypes);
        */

        /**
         * Split a string at '_'s.
         * @private
         * @function
         * @param {string} string
         * @return {array.<string>}
         */
        function splitUnderscore(string) {
            return string.split('_');
        }

        /**
         * Canonalizes a locale string.
         * @private
         * @function
         * @param {string} locale
         * @return {string}
         */
        function canonicalizeLocale(locale) {
            var val = [],
                firstSplit,
                firstSplitLength,
                element,
                elementLength,
                script,
                region;

            if (isString(locale) && (/^([a-z]{2,3}|[a-z]{2,3}[\-_][a-z]{2}|[a-z]{2,3}[\-_][a-z]{4}|[a-z]{2,3}[\-_][a-z]{4}[\-_][a-z]{2})$/i).test(locale)) {
                firstSplit = splitUnderscore(minusToUnderscore(locale));
                firstSplitLength = firstSplit.length;
                val.push(firstSplit[0].toLowerCase());
                if (!strictEqual(firstSplitLength, 1)) {
                    element = firstSplit[1];
                    if (strictEqual(firstSplitLength, 2)) {
                        elementLength = element.length;
                        if (strictEqual(elementLength, 2)) {
                            region = element.toUpperCase();
                        } else {
                            script = element.charAt(0).toUpperCase() + element.slice(1).toLowerCase();
                        }
                    } else {
                        script = element.charAt(0).toUpperCase() + element.slice(1).toLowerCase();
                        region = firstSplit[2].toUpperCase();
                    }
                }

                if (!isUndefined(script) && !strictEqual(script, 'Zzzz')) {
                    val.push(script);
                }

                if (!isUndefined(region) && !strictEqual(region, 'ZZ')) {
                    val.push(region);
                }
            }

            return val.join('_');
        }

        /**
         * Perform a locale lookup from the CLDR likeySubtags given a full or patial locale string.
         * @private
         * @function
         * @param {string} locale
         * @return {string}
         */
        function lookupLocale(locale) {
            var canonicalizedLocale = canonicalizeLocale(locale),
                likelySubtags,
                lookup,
                firstSplit,
                lang,
                script,
                region,
                length,
                element,
                elementLength;

            if (!isEmptyString(canonicalizedLocale)) {
                likelySubtags = supplemental.likelySubtags;
                lookup = likelySubtags[canonicalizedLocale];
                if (isUndefined(lookup)) {
                    firstSplit = splitUnderscore(canonicalizedLocale);
                    length = firstSplit.length;
                    lang = arrayFirst(firstSplit);
                    if (strictEqual(length, 3)) {
                        region = arrayLast(firstSplit);
                        script = firstSplit[1];
                    } else if (strictEqual(length, 2)) {
                        element = arrayLast(firstSplit);
                        elementLength = element.length;
                        if (strictEqual(elementLength, 2)) {
                            region = element;
                        } else {
                            script = element;
                        }
                    }

                    if (isUndefined(lookup) && !isUndefined(region)) {
                        lookup = likelySubtags[[lang, region].join('_')];
                    }

                    if (isUndefined(lookup) && !isUndefined(script)) {
                        lookup = likelySubtags[[lang, script].join('_')];
                    }

                    if (isUndefined(lookup)) {
                        if (!isUndefined(languages[canonicalizedLocale])) {
                            lookup = canonicalizedLocale;
                        }
                    }

                    if (isUndefined(lookup)) {
                        lookup = likelySubtags[lang];
                    }

                    if (isUndefined(lookup) && !isUndefined(script)) {
                        lookup = likelySubtags[['und', script].join('_')];
                    }
                }
            }

            if (isUndefined(lookup)) {
                lookup = '';
            }

            return lookup;
        }

        /**
         * Finds a loaded language from the given locale string.
         * @private
         * @function
         * @param {string} locale
         * @return {string}
         */
        function languageLoaded(locale) {
            var loaded,
                lang,
                firstSplit;

            if (!isEmptyString(locale)) {
                lang = minusToUnderscore(locale);
                if (!isUndefined(languages[lang])) {
                    loaded = lang;
                } else {
                    firstSplit = splitUnderscore(lookupLocale(locale));
                    lang = [arrayFirst(firstSplit), arrayLast(firstSplit)].join('_');
                    if (!isUndefined(languages[lang])) {
                        loaded = lang;
                    } else {
                        lang = arrayFirst(firstSplit);
                        if (!isUndefined(languages[lang])) {
                            loaded = lang;
                        }
                    }
                }
            } else {
                loaded = '';
            }

            return loaded;
        }

        /**
         * Gets the region part of a locale string.
         * @private
         * @function
         * @param {string} locale
         * @return {string}
         */
        function getRegion(locale) {
            return arrayLast(splitUnderscore(locale));
        }

        /**
         * Takes a date pattern of tokens and replaces those tokens with the appropriate CLDR translations.
         * @private
         * @see {@link http://www.unicode.org/reports/tr35/tr35-dates.html#Date_Field_Symbol_Table}
         * @function
         * @param {object} struct
         * @param {string} pattern
         * @param {boolean} julian
         * @param {string} lang
         * @param {string} locale
         * @return {string}
         */
        // struct should not be UTC but UT
        function formatDate(struct, pattern, julian, lang, locale) {
            var gregorian = languages[lang].dates.calendars.gregorian,
                dateFormats = gregorian.dateFormats,
                eras = gregorian.eras,
                standAlone = arrayLast(nameTypes),
                months = gregorian.months,
                monthsFormat = months.format,
                monthsStandAlone = months[standAlone],
                days = gregorian.days,
                daysFormat = days.format,
                daysStandAlone = days[standAlone],
                shortStr = arrayLast(formatTypes),
                weekDate = calendarToWeekDate(struct), // should use alternative CLDR
                dayKey = cldrDayKey(struct),
                eraNum,
                eraNumStr,
                year,
                yearSign,
                month,
                dayOfYear,
                dayStr,
                week,
                dayOfWeekLocaleNumber,
                mjd;

            if (arrayContains(formatTypes, pattern)) {
                /*
                switch (pattern) {
                case 'long':
                    calendarPattern = '\'(\'CCCC\')\'';
                    break;
                case 'medium':
                    calendarPattern = '\'(\'C\')\'';
                    break;
                case 'short':
                    calendarPattern = '\'(\'CCCCCC\')\'';
                    break;
                default:
                    calendarPattern = '\'(\'CCCC\')\'';
                }
                */

                pattern = dateFormats[pattern];

            }

            /*
            if (julian) {
                calendarType = 'julian';
            } else {
                calendarType = 'gregorian';
            }
            */

            /*
            pattern = replaceToken(pattern, 'CCCCC', calendarTypes[calendarType].narrow);
            pattern = replaceToken(pattern, 'CCCC', calendarTypes[calendarType].wide);
            pattern = replaceToken(pattern, 'C{1,3}', calendarTypes[calendarType].abbreviated);
            */

            if (struct.year.lt(1)) {
                eraNum = 0;
            } else {
                eraNum = 1;
            }

            eraNumStr = eraNum.toString();
            pattern = replaceToken(pattern, 'GGGGG', eras.eraNarrow[eraNumStr]);
            pattern = replaceToken(pattern, 'GGGG', eras.eraNames[eraNumStr]);
            pattern = replaceToken(pattern, 'G{1,3}', eras.eraAbbr[eraNumStr]);

            year = struct.year.plus(eraNum - 1);
            if (year.lt(0)) {
                yearSign = '-';
            } else {
                yearSign = '';
            }

            pattern = replaceToken(pattern, 'y{3,}', year);
            pattern = replaceToken(pattern, 'yy', yearSign + year.toString().slice(-2));
            pattern = replaceToken(pattern, 'y', year);
            pattern = replaceToken(pattern, 'U{1,}', year);

            pattern = replaceToken(pattern, 'u{1,}', struct.year);

            pattern = replaceToken(pattern, 'Y{1,}', weekDate.year);
            week = weekDate.week.toString();
            pattern = replaceToken(pattern, 'w{1,2}', week);
            pattern = replaceToken(pattern, 'W', calendarToWeekOfMonth(struct));

            /*
            pattern = replaceToken(pattern, 'Q{1,2}', value);
            pattern = replaceToken(pattern, 'QQQ', value);
            pattern = replaceToken(pattern, 'QQQQ', value);
            pattern = replaceToken(pattern, 'q{1,2}', value);
            pattern = replaceToken(pattern, 'qqq', value);
            pattern = replaceToken(pattern, 'qqqq', value);
            */

            month = struct.month.toString();
            pattern = replaceToken(pattern, 'MMMMM', monthsFormat.narrow[month]);
            pattern = replaceToken(pattern, 'MMMM', monthsFormat.wide[month]);
            pattern = replaceToken(pattern, 'MMM', monthsFormat.abbreviated[month]);
            pattern = replaceToken(pattern, 'M{1,2}', month);
            pattern = replaceToken(pattern, 'LLLLL', monthsStandAlone.narrow[month]);
            pattern = replaceToken(pattern, 'LLLL', monthsStandAlone.wide[month]);
            pattern = replaceToken(pattern, 'LLL', monthsStandAlone.abbreviated[month]);
            pattern = replaceToken(pattern, 'L{1,2}', month);

            pattern = replaceToken(pattern, 'd{1,2}', struct.day);
            if (julian) {
                dayOfYear = dayOfJulianYear(gregorianToJulian(struct));
            } else {
                dayOfYear = dayOfGregorianYear(struct);
            }

            pattern = replaceToken(pattern, 'D{1,3}', dayOfYear);

            pattern = replaceToken(pattern, 'F', weekDayOfMonth(struct));
            if (julian) {
                mjd = julianToMJD(toUT(struct));
            } else {
                mjd = gregorianToMJD(toUT(struct));
            }

            pattern = replaceToken(pattern, 'g{1,}', mjd);

            dayStr = daysFormat[shortStr][dayKey];
            pattern = replaceToken(pattern, 'EEEEEE', dayStr);
            pattern = replaceToken(pattern, 'eeeeee', dayStr);
            dayStr = daysFormat.narrow[dayKey];
            pattern = replaceToken(pattern, 'EEEEE', dayStr);
            pattern = replaceToken(pattern, 'eeeee', dayStr);
            dayStr = daysFormat.wide[dayKey];
            pattern = replaceToken(pattern, 'EEEE', dayStr);
            pattern = replaceToken(pattern, 'eeee', dayStr);
            dayStr = daysFormat.abbreviated[dayKey];
            pattern = replaceToken(pattern, 'EEE', dayStr);
            pattern = replaceToken(pattern, 'eee', dayStr);

            pattern = replaceToken(pattern, 'E{1,2}', weekDate.weekDay);

            dayOfWeekLocaleNumber = mod(1 + (7 - arrayIndexOf(dayKeys, supplemental.weekData.firstDay[getRegion(locale)]) + arrayIndexOf(dayKeys, dayKey)), 7);
            pattern = replaceToken(pattern, 'e{1,2}', dayOfWeekLocaleNumber);

            pattern = replaceToken(pattern, 'cccccc', daysStandAlone[shortStr][dayKey]);
            pattern = replaceToken(pattern, 'ccccc', daysStandAlone.narrow[dayKey]);
            pattern = replaceToken(pattern, 'cccc', daysStandAlone.wide[dayKey]);
            pattern = replaceToken(pattern, 'ccc', daysStandAlone.abbreviated[dayKey]);
            pattern = replaceToken(pattern, 'c{1,2}', dayOfWeekLocaleNumber);

            return pattern;
        }

        /**
         * Formats ISO timezone tokens with the appropriate CLDR translations.
         * @private
         * @see {@link http://www.unicode.org/reports/tr35/tr35-dates.html#Using_Time_Zone_Names}
         * @function
         * @param {object} struct
         * @param {string} lang
         * @param {boolean} withZ
         * @param {string} format
         * @param {string} width
         * @return {string}
         */
        // ISO 8601 time zone formats.
        function formatIsoTimeZone(struct, lang, withZ, format, width) {
            var timeZoneNames = languages[lang].dates.timeZoneNames,
                offsetFormats = timeZoneNames.hourFormat.split(';'),
                offsetFormat,
                offset,
                pattern;

            if (withZ && struct.offset.isZero()) {
                pattern = 'Z';
            } else {
                if (struct.offset.lte(0)) {
                    offsetFormat = arrayFirst(offsetFormats);
                } else {
                    offsetFormat = arrayLast(offsetFormats);
                }

                offsetFormat = offsetFormat.replace(/([\-+])H:/, '$1HH:');
                offset = fractionToTime(struct.offset.abs(), 'minute');
                offsetFormat = replaceToken(offsetFormat, 'H{1,2}', offset.hour);


                if (strictEqual(format, 'basic')) {
                    if (strictEqual(width, arrayLast(formatTypes)) && offset.minute.isZero()) {
                        pattern = arrayFirst(offsetFormat.split(':'));
                    } else {
                        offsetFormat = offsetFormat.replace(':', '');
                        pattern = replaceToken(offsetFormat, 'm{1,2}', offset.minute);
                    }
                } else {
                    pattern = replaceToken(offsetFormat, 'm{1,2}', offset.minute);
                }

                if (hasRemainingTokens(pattern)) {
                    throw new Error('formatIsoTimeZone has remaining tokens! ' + remainingTokens(pattern));
                }
            }

            return stripSingleQuotes(pattern);
        }

        /**
         * Formats localized GMT timezone tokens with the appropriate CLDR translations.
         * @private
         * @see {@link http://www.unicode.org/reports/tr35/tr35-dates.html#Using_Time_Zone_Names}
         * @function
         * @param {object} struct
         * @param {string} lang
         * @param {string} width
         * @return {string}
         */
        // The localized GMT format.
        function formatLocalisedGMT(struct, lang, width) {
            var timeZoneNames = languages[lang].dates.timeZoneNames,
                offsetFormats = timeZoneNames.hourFormat.split(';'),
                offsetFormat,
                offset,
                requestedShort,
                pattern;

            if (struct.offset.isZero()) {
                pattern = timeZoneNames.gmtZeroFormat;
            } else {
                if (struct.offset.lte(0)) {
                    offsetFormat = arrayFirst(offsetFormats);
                } else {
                    offsetFormat = arrayLast(offsetFormats);
                }

                requestedShort = strictEqual(width, arrayLast(formatTypes));
                if (requestedShort) {
                    offsetFormat = offsetFormat.replace('HH', 'H');
                } else {
                    offsetFormat = offsetFormat.replace(/([\-+])H:/, '$1HH:');
                }

                offset = fractionToTime(struct.offset.abs(), 'minute');
                offsetFormat = replaceToken(offsetFormat, 'H{1,2}', offset.hour);
                if (requestedShort && offset.minute.isZero()) {
                    pattern = arrayFirst(offsetFormat.split(':'));
                } else {
                    pattern = replaceToken(offsetFormat, 'm{1,2}', offset.minute);
                }

                if (hasRemainingTokens(pattern)) {
                    throw new Error('formatLocalisedGMT has remaining tokens! ' + remainingTokens(pattern));
                }

                pattern = replaceToken(timeZoneNames.gmtFormat, '{0}', pattern);
            }

            return stripSingleQuotes(pattern);
        }

        /**
         * Takes a time pattern of tokens and replaces those tokens with the appropriate CLDR translations.
         * @private
         * @see {@link http://www.unicode.org/reports/tr35/tr35-dates.html#Date_Field_Symbol_Table}
         * @function
         * @param {object} struct
         * @param {string} pattern
         * @param {string} lang
         * @return {string}
         */
        // struct should not be UTC but UT
        function formatTime(struct, pattern, lang) {
            var language = languages[lang],
                gregorian = language.dates.calendars.gregorian,
                shortLocalisedGMT,
                longLocalisedGMT,
                isoBasicShort,
                isoBasicShortNoZ,
                isoBasic,
                isoBasicNoZ,
                isoExtended,
                isoExtendedNoZ,
                dayPeriod,
                hour;

            if (arrayContains(formatTypes, pattern)) {
                pattern = gregorian.timeFormats[pattern];
            }

            if (struct.hour.inRange(12, 23)) {
                dayPeriod = 'pm';
            } else {
                dayPeriod = 'am';
            }

            pattern = replaceToken(pattern, 'a', gregorian.dayPeriods.format.abbreviated[dayPeriod]);
            hour = struct.hour.plus(11).mod(12).plus(1);
            pattern = replaceToken(pattern, 'h{1,2}', hour);
            pattern = replaceToken(pattern, 'H{1,2}', struct.hour);
            pattern = replaceToken(pattern, 'K{1,2}', hour.minus(1));

            // if hour is 24, needs to be handled in date too
            //temp = new AstroDate().jd(new AstroDate().jd());
            //pattern = replaceToken(pattern, 'k{1,2}', struct.hour.plus(1));

            //pattern = replaceToken(pattern, 'j{1,2}', struct.hour);

            pattern = replaceToken(pattern, 'm{1,2}', struct.minute);
            pattern = replaceToken(pattern, 's{1,2}', struct.second);
            pattern = replaceToken(pattern, 'S{1,}', struct.millisecond);

            //pattern = replaceToken(pattern, 'A{1,}', value);

            // The short localized GMT format.
            shortLocalisedGMT = formatLocalisedGMT(struct, lang, arrayLast(formatTypes));
            pattern = replaceToken(pattern, 'O', shortLocalisedGMT);
            pattern = replaceToken(pattern, 'z{1,3}', shortLocalisedGMT);
            // The long localized GMT format.
            longLocalisedGMT = formatLocalisedGMT(struct, lang);
            pattern = replaceToken(pattern, 'OOOO', longLocalisedGMT);
            pattern = replaceToken(pattern, 'zzzz', longLocalisedGMT);
            pattern = replaceToken(pattern, 'ZZZZ', longLocalisedGMT);
            pattern = replaceToken(pattern, 'vvvv', longLocalisedGMT);
            pattern = replaceToken(pattern, 'v', longLocalisedGMT);
            pattern = replaceToken(pattern, 'VVVV', longLocalisedGMT);
            // The ISO8601 basic format short
            isoBasicShort = formatIsoTimeZone(struct, lang, true, 'basic', arrayLast(formatTypes));
            pattern = replaceToken(pattern, 'X', isoBasicShort);
            // The ISO8601 basic format short no Z
            isoBasicShortNoZ = formatIsoTimeZone(struct, lang, false, 'basic', arrayLast(formatTypes));
            pattern = replaceToken(pattern, 'x', isoBasicShortNoZ);
            // The ISO8601 basic format
            isoBasic = formatIsoTimeZone(struct, lang, true, 'basic');
            pattern = replaceToken(pattern, 'Z{1,3}', isoBasic);
            pattern = replaceToken(pattern, 'XXXX', isoBasic);
            pattern = replaceToken(pattern, 'XX', isoBasic);
            // The ISO8601 basic format no Z
            isoBasicNoZ = formatIsoTimeZone(struct, lang, false, 'basic');
            pattern = replaceToken(pattern, 'xxxx', isoBasicNoZ);
            pattern = replaceToken(pattern, 'xx', isoBasicNoZ);
            //The ISO8601 extended format
            isoExtended = formatIsoTimeZone(struct, lang, true);
            pattern = replaceToken(pattern, 'XXXXX', isoExtended);
            pattern = replaceToken(pattern, 'XXX', isoExtended);
            pattern = replaceToken(pattern, 'ZZZZZ', isoExtended);
            //The ISO8601 extended format no Z
            isoExtendedNoZ = formatIsoTimeZone(struct, lang, false);
            pattern = replaceToken(pattern, 'xxxxx', isoExtendedNoZ);
            pattern = replaceToken(pattern, 'xxx', isoExtendedNoZ);

            return pattern;
        }

        /**
         * @constructor AstroDate
         * @classdesc This is what becomes exported or made global.
         * @this AstroDate
         * @param {...*} [arguments]
         * @return {AstroDate}
         *
         * @desc Used to create a new instance of a date.
         * <pre><code>
         * new AstroDate();
         * new AstroDate(value);
         * new AstroDate(dateString);
         * new AstroDate(dateObject);
         * new AstroDate(astroDateObject);
         * new AstroDate(year, month [, day, hour, minute, second, millisecond]);
         * </code></pre>
         * <ul>
         * <li><b>value</b><br>
         * Integer value representing the number of milliseconds since 1 January 1970 00:00:00 UTC (Unix Epoch).</li>
         * <li><b>dateString</b><br>
         * String value representing a date. The string must be in the format of ISO8601.</li>
         * <li><b>dateObject</b><br>
         * A Javascript Date object.</li>
         * <li><b>astroDateObject</b><br>
         * An AstroDate object.</li>
         * <li><b>year</b><br>
         * Integer or string value representing the year. The year must always be provided in full (e.g. 98 is treated as 98, not 1998).</li>
         * <li><b>month</b><br>
         * Integer or string value representing the month, beginning with 0 for January to 11 for December.</li>
         * <li><b>day</b><br>
         * Integer or string value representing the day of the month.</li>
         * <li><b>hour</b><br>
         * Integer or string value representing the hour of the day.</li>
         * <li><b>minute</b><br>
         * Integer or string value representing the minute segment of a time.</li>
         * <li><b>second</b><br>
         * Integer or string value representing the second segment of a time.</li>
         * <li><b>millisecond</b><br>
         * Integer or string value representing the millisecond segment of a time.</li>
         * </ul>
         *
         * @example <caption>Example usage of constructor.</caption>
         *
         * // If no arguments are provided, the constructor creates an AstroDate object for the
         * // current date and time according to system settings.
         * new AstroDate();
         *
         * // Integer value representing the number of milliseconds since 1 January 1970 00:00:00 UTC (Unix Epoch).
         * // -9,007,199,254,740,992 to 9,007,199,254,740,992 or NaN
         * new AstroDate(819170640000); //1995-12-17T03:24:00.000Z
         * new AstroDate(NaN); //Invalid Date
         *
         * // String value representing a date. The string must be in the format of ISO8601.
         * new AstroDate('1995-12-17T03:24:00.000Z');
         *
         * // A Javascript Date object.
         * new AstroDate(new Date(1995, 12, 17, 3, 24, 0, 0));
         *
         * // An AstroDate object.
         * new AstroDate(new AstroDate(1995, 12, 17, 3, 24, 0, 0));
         *
         * // Using an arguments list.
         * new AstroDate(1995, 12, 17, 3, 24, 0, 0);
         * new AstroDate('1995', '12', '17', '3', '24', '0', '0');
         */
        function AstroDate() {
            var args = arguments,
                input = arguments,
                argsLength = args.length,
                isJulian = false,
                isUT = false,
                isTT = false,
                isLocal = false,
                error = null,
                delta = 0,
                /**
                 * The current language of the AstroDate instance.
                 * @private
                 * @type {string}
                 */
                currentLanguage = defaultLanguage,
                /**
                 * The current locale of the AstroDate instance.
                 * @private
                 * @type {string}
                 */
                currentLocale = defaultLocale,
                struct,
                arg;

            objectDefineProperties(this, {
                /**
                 * Gets the value of a specific internal property.
                 * @readonly
                 * @protected
                 * @memberOf AstroDate
                 * @instance
                 * @function
                 * @param {*} key
                 * @return {*}
                 */
                getter: {
                    value: function (key) {
                        var got;

                        if (isUndefined(key)) {
                            got = extend({}, struct);
                        } else if (isString(key)) {
                            switch (key) {
                            case 'struct':
                                got = extend({}, struct);
                                break;
                            case 'isJulian':
                                got = isJulian;
                                break;
                            case 'isUT':
                                got = isUT;
                                break;
                            case 'isTT':
                                got = isTT;
                                break;
                            case 'DT':
                                got = delta;
                                break;
                            case 'isLocal':
                                got = isLocal;
                                break;
                            case 'args':
                                got = args;
                                break;
                            case 'input':
                                got = input;
                                break;
                            case 'error':
                                got = error;
                                break;
                            case 'lang':
                                got = currentLanguage;
                                break;
                            case 'locale':
                                got = currentLocale;
                                break;
                            default:
                                throw new SyntaxError(key);
                            }
                        } else {
                            throw new TypeError(key);
                        }

                        return got;
                    }
                },

                /**
                 * Sets the value of a specific internal property.
                 * @protected
                 * @instance
                 * @memberOf AstroDate
                 * @function
                 * @param {*} key
                 * @param {*} value
                 * @return {AstroDate}
                 * @this AstroDate
                 */
                setter: {
                    value: function (key, value) {
                        var unit = normaliseUnits(key),
                            valid = false,
                            bn,
                            dim;

                        if (unit) {
                            bn = new BigNumber(value);
                            switch (unit) {
                            case 'year':
                                valid = inYearRange(bn);
                                break;
                            case 'month':
                                valid = inMonthRange(bn);
                                break;
                            case 'day':
                                if (strictEqual(isJulian, true)) {
                                    dim = daysInJulianMonth(struct);
                                } else {
                                    dim = daysInGregorianMonth(struct);
                                }

                                valid = inDayRange(bn, dim);
                                break;
                            case 'hour':
                                valid = inHourRange(bn);
                                break;
                            case 'minute':
                                valid = inMinuteRange(bn, struct.hour);
                                break;
                            case 'second':
                                valid = inSecondRange(bn, struct);
                                break;
                            case 'millisecond':
                                valid = inMillisecondRange(bn, struct.hour);
                                break;
                            case 'offset':
                                valid = inOffsetRange(bn);
                                break;
                            default:
                                throw new Error(unit);
                            }

                            if (valid) {
                                struct[unit] = bn;
                            } else {
                                struct = {};
                            }
                        } else if (arrayIsArray(key)) {
                            struct = arrayToStruct(key, false);
                        } else if (AstroDate.isAstroDate(key)) {
                            struct = key.getter();
                            isJulian = key.isJulian();
                        } else if (isDate(key)) {
                            struct = dateToStruct(key);
                        } else if (isString(key)) {
                            switch (key) {
                            case 'input':
                                input = value;
                                break;
                            case 'error':
                                error = value;
                                break;
                            case 'struct':
                                if (isValid(value)) {
                                    struct = extend({}, value);
                                } else {
                                    struct = {};
                                }

                                break;
                            case 'isJulian':
                                isJulian = Boolean(value);
                                break;
                            case 'isUT':
                                isUT = Boolean(value);
                                break;
                            case 'isTT':
                                isTT = Boolean(value);
                                break;
                            case 'DT':
                                delta = mathSign(value) || 0;
                                break;
                            case 'isLocal':
                                isLocal = Boolean(value);
                                break;
                            case 'lang':
                                if (isString(value) && !isEmptyString(value)) {
                                    currentLanguage = value;
                                } else {
                                    currentLanguage = defaultLanguage;
                                    currentLocale = defaultLocale;
                                }

                                break;
                            case 'locale':
                                if (isString(value) && !isEmptyString(value)) {
                                    currentLocale = lookupLocale(value);
                                } else {
                                    currentLanguage = defaultLanguage;
                                    currentLocale = defaultLocale;
                                }

                                break;
                            default:
                                struct = isoParse(key);
                            }
                        } else {
                            throw new SyntaxError(key);
                        }

                        return this;
                    }
                }
            });

            switch (argsLength.toString()) {
            case '0':
                struct = dateToStruct(new Date());
                break;
            case '1':
                arg = arrayFirst(args);
                if (AstroDate.isAstroDate(arg)) {
                    isJulian = arg.getter('isJulian');
                    struct = extend({}, arg.getter());
                } else if (arrayIsArray(arg)) {
                    struct = arrayToStruct(arg, false);
                } else if (isDate(arg)) {
                    struct = dateToStruct(arg);
                } else if (isNumber(arg)) {
                    struct = dateToStruct(new Date(arg));
                } else if (isString(arg)) {
                    struct = isoParse(arg);
                } else if (isPlainObject(arg)) {
                    struct = objectToStruct(arg);
                    if (!isValid(struct)) {
                        struct = {};
                    }
                } else {
                    throw new TypeError(arg);
                }

                break;
            case '2':
                arg = arrayFirst(args);
                if (isString(arg)) {
                    arg = stringTrim(arg).toLowerCase();
                    switch (arg) {
                    case 'j':
                        arg = args[1];
                        if (arrayIsArray(arg)) {
                            struct = julianToGregorian(arrayToStruct(arg, true));
                        } else if (isPlainObject(arg)) {
                            struct = objectToStruct(arg, true);
                            if (isValid(struct, true)) {
                                struct = julianToGregorian(struct);
                            } else {
                                struct = {};
                            }
                        } else {
                            throw new TypeError(arg);
                        }

                        break;
                    case 'g':
                        arg = args[1];
                        if (arrayIsArray(arg)) {
                            struct = arrayToStruct(arg, false);
                        } else if (isPlainObject(arg)) {
                            struct = objectToStruct(arg);
                            if (!isValid(struct)) {
                                struct = {};
                            }
                        } else {
                            throw new TypeError(arg);
                        }

                        break;
                    case 'jd':
                        arg = args[1];
                        this.jd(arg);
                        break;
                    default:
                        throw new SyntaxError(arg);
                    }
                } else {
                    throw new TypeError(arg);
                }

                break;
            default:
                throw new SyntaxError(argsLength);
            }

            if (!isValid(struct)) {
                struct = {};
            }
        }

        objectDefineProperties(AstroDate.prototype, {
            /** @memberOf AstroDate.prototype
             * @function
             * @return {boolean}
             * @this AstroDate
             */
            julian: {
                value: function () {
                    return this.setter('isJulian', true);
                }
            },

            /** @memberOf AstroDate.prototype
             * @function
             * @return {boolean}
             * @this AstroDate
             */
            gregorian: {
                value: function () {
                    return this.setter('isJulian', false);
                }
            },

            /** @memberOf AstroDate.prototype
             * @function
             * @return {AstroDate}
             * @this AstroDate
             */
            local: {
                value: function () {
                    this.setter('isLocal', true);
                    this.setter('isUT', false);

                    return this;
                }
            },

            /** @memberOf AstroDate.prototype
             * @function
             * @return {AstroDate}
             * @this AstroDate
             */
            UT: {
                value: function () {
                    this.setter('isLocal', false);
                    this.setter('isUT', true);

                    return this;
                }
            },

            /** @memberOf AstroDate.prototype
             * @function
             * @return {boolean}
             * @this AstroDate
             */
            TT: {
                value: function () {
                    return this.setter('isTT', true);
                }
            },

            /** @memberOf AstroDate.prototype
             * @function
             * @return {boolean}
             * @this AstroDate
             */
            UT2TT: {
                value: function () {
                    return this.setter('DT', -1);
                }
            },

            /** @memberOf AstroDate.prototype
             * @function
             * @return {boolean}
             * @this AstroDate
             */
            TT2UT: {
                value: function () {
                    return this.setter('DT', 1);
                }
            },

            /** @memberOf AstroDate.prototype
             * @function
             * @return {boolean}
             * @this AstroDate
             */
            civil: {
                value: function () {
                    return this.setter('isTT', false);
                }
            },

            /** @memberOf AstroDate.prototype
             * @function
             * @return {AstroDate}
             * @this AstroDate
             */
            raw: {
                value: function () {
                    this.setter('isLocal', false);
                    this.setter('isUT', false);
                    this.setter('isTT', false);
                    this.setter('DT', 0);

                    return this;
                }
            },

            /** @memberOf AstroDate.prototype
             * @function
             * @return {boolean}
             * @this AstroDate
             */
            isJulian: {
                value: function () {
                    return this.getter('isJulian');
                }
            },

            /** @memberOf AstroDate.prototype
             * @function
             * @return {boolean}
             * @this AstroDate
             */
            isGregorian: {
                value: function () {
                    return !this.getter('isJulian');
                }
            },

            /** @memberOf AstroDate.prototype
             * @function
             * @return {boolean}
             * @this AstroDate
             */
            isUT: {
                value: function () {
                    return this.getter('isUT');
                }
            },

            /** @memberOf AstroDate.prototype
             * @function
             * @return {boolean}
             * @this AstroDate
             */
            isTT: {
                value: function () {
                    return this.getter('isTT');
                }
            },

            /** @memberOf AstroDate.prototype
             * @function
             * @return {boolean}
             * @this AstroDate
             */
            isUT2TT: {
                value: function () {
                    return strictEqual(this.getter('DT'), -1);
                }
            },

            /** @memberOf AstroDate.prototype
             * @function
             * @return {boolean}
             * @this AstroDate
             */
            isTT2UT: {
                value: function () {
                    return strictEqual(this.getter('DT'), 1);
                }
            },

            /** @memberOf AstroDate.prototype
             * @function
             * @return {boolean}
             * @this AstroDate
             */
            isDT: {
                value: function () {
                    return !strictEqual(this.getter('DT'), 0);
                }
            },

            /** @memberOf AstroDate.prototype
             * @function
             * @return {boolean}
             * @this AstroDate
             */
            isCivil: {
                value: function () {
                    return !this.getter('isTT');
                }
            },

            /** @memberOf AstroDate.prototype
             * @function
             * @return {boolean}
             * @this AstroDate
             */
            isLocal: {
                value: function () {
                    return this.getter('isLocal');
                }
            },

            /** @memberOf AstroDate.prototype
             * @function
             * @return {boolean}
             * @this AstroDate
             */
            isRaw: {
                value: function () {
                    return !this.getter('isUT') && !this.getter('isTT') && this.getter('isLocal');
                }
            },

            /** @memberOf AstroDate.prototype
             * @function
             * @return {string}
             * @this AstroDate
             */
            currentLang: {
                value: function () {
                    return this.getter('lang');
                }
            },

            /** @memberOf AstroDate.prototype
             * @function
             * @this AstroDate
             */
            isWeekDay: {
                value: function () {
                    var val;

                    if (this.isValid()) {
                        val = weekDayNumber(getCorrectStruct(this, this.getter())).inRange(1, 5);
                    }

                    return val;
                }
            },

            /** @memberOf AstroDate.prototype
             * @function
             * @this AstroDate
             */
            isWeekend: {
                value: function () {
                    var val;

                    if (this.isValid()) {
                        val = weekDayNumber(getCorrectStruct(this, this.getter())).inRange(6, 7);
                    }

                    return val;
                }
            },

            /** @memberOf AstroDate.prototype
             * @function
             * @this AstroDate
             */
            zone: {
                value: function () {
                    var val;

                    if (this.isValid()) {
                        val = getCorrectStruct(this, this.getter()).offset.toString();
                    }

                    return val;
                }
            },

            /** @memberOf AstroDate.prototype
             * @function
             * @return {boolean}
             * @this AstroDate
             */
            isValid: {
                value: function () {
                    return isValid(this.getter());
                }
            },

            /** @memberOf AstroDate.prototype
             * @function
             * @param {string} isoString
             * @this AstroDate
             */
            parse: {
                value: function (isoString) {
                    var val;

                    if (isString(isoString)) {
                        val = this.setter('struct', isoParse(isoString));
                    } else {
                        throw new TypeError(isoString);
                    }

                    return val;
                }
            },

            /**
             * @memberOf AstroDate.prototype
             * @function
             * @param {string} pattern
             * @this AstroDate
             *
             * @desc
             * <p>Date and time formats are specified by <em>date and time pattern</em> strings.
             * Within date and time pattern strings, all unquoted ASCII letters [A-Za-z] are reserved as
             * pattern letters representing calendar fields.
             * <code>astrodate</code> supports the date and time formatting algorithm and pattern letters defined by
             * <a href="http://www.unicode.org/reports/tr35/">UTS#35 Unicode Locale Data Markup Language (LDML)</a>.
             * The following pattern letters are currently available:</p>
             * <table border="1">
             * <thead>
             * <tr>
             * <th>Field</th>
             * <th style="text-align: center">Sym.</th>
             * <th style="text-align: center">No.</th>
             * <th>Example</th>
             * <th>Description</th>
             * </tr>
             * </thead>
             * <tbody>
             * <tr>
             * <th rowspan="3">era</th>
             * <td style="text-align: center" rowspan="3">G</td>
             * <td style="text-align: center">1..3</td>
             * <td>AD</td>
             * <td rowspan="3">Era - Replaced with the Era string for the current date.
             * One to three letters for the abbreviated form, four letters for the long form, five for the narrow form.</td>
             * </tr>
             * <tr>
             * <td style="text-align: center">4</td>
             * <td>Anno Domini</td>
             * </tr>
             * <tr>
             * <td style="text-align: center">5</td>
             * <td>A</td>
             * </tr>
             * <tr>
             * <th rowspan="6">year</th>
             * <td style="text-align: center">y</td>
             * <td style="text-align: center">1..n</td>
             * <td>1996</td>
             * <td>
             * Year. Normally the length specifies the padding, but for two letters it also specifies the maximum length.
             * Example:
             * <div align="center">
             * <center>
             * <table border="1" cellpadding="2" cellspacing="0">
             * <tbody>
             * <tr>
             * <th>Year</th>
             * <th style="text-align: right">y</th>
             * <th style="text-align: right">yy</th>
             * <th style="text-align: right">yyy</th>
             * <th style="text-align: right">yyyy</th>
             * <th style="text-align: right">yyyyy</th>
             * </tr>
             * <tr>
             * <td>AD 1</td>
             * <td style="text-align: right">1</td>
             * <td style="text-align: right">01</td>
             * <td style="text-align: right">001</td>
             * <td style="text-align: right">0001</td>
             * <td style="text-align: right">00001</td>
             * </tr>
             * <tr>
             * <td>AD 12</td>
             * <td style="text-align: right">12</td>
             * <td style="text-align: right">12</td>
             * <td style="text-align: right">012</td>
             * <td style="text-align: right">0012</td>
             * <td style="text-align: right">00012</td>
             * </tr>
             * <tr>
             * <td>AD 123</td>
             * <td style="text-align: right">123</td>
             * <td style="text-align: right">23</td>
             * <td style="text-align: right">123</td>
             * <td style="text-align: right">0123</td>
             * <td style="text-align: right">00123</td>
             * </tr>
             * <tr>
             * <td>AD 1234</td>
             * <td style="text-align: right">1234</td>
             * <td style="text-align: right">34</td>
             * <td style="text-align: right">1234</td>
             * <td style="text-align: right">1234</td>
             * <td style="text-align: right">01234</td>
             * </tr>
             * <tr>
             * <td>AD 12345</td>
             * <td style="text-align: right">12345</td>
             * <td style="text-align: right">45</td>
             * <td style="text-align: right">12345</td>
             * <td style="text-align: right">12345</td>
             * <td style="text-align: right">12345</td>
             * </tr>
             * </tbody>
             * </table>
             * </center>
             * </div>
             * </td>
             * </tr>
             * <tr>
             * <td style="text-align: center">Y</td>
             * <td style="text-align: center">1..n</td>
             * <td>1997</td>
             * <td>Year (in "Week of Year" based calendars). Normally the length specifies the padding,
             * but for two letters it also specifies the maximum length.
             * This year designation is used in ISO year-week calendar as defined by ISO 8601,
             * but can be used in non-Gregorian based calendar systems where week date processing is desired.
             * May not always be the same value as calendar year.</td>
             * </tr>
             * <tr>
             * <td style="text-align: center">u</td>
             * <td style="text-align: center">1..n</td>
             * <td>4601</td>
             * <td>Extended year. This is a single number designating the year of this calendar system,
             * encompassing all supra-year fields.
             * For example, for the Julian calendar system, year numbers are positive, with an era of BCE or CE.
             * An extended year value for the Julian calendar system assigns positive values to CE years and
             * negative values to BCE years, with 1 BCE being year 0.</td>
             * </tr>
             * <tr>
             * <td style="text-align: center" rowspan="3">U</td>
             * <td style="text-align: center">1..3</td>
             * <td>&#x7532;&#x5B50;</td>
             * <td rowspan="3">Cyclic year name. Calendars such as the Chinese lunar calendar (and related calendars)
             * and the Hindu calendars use 60-year cycles of year names.
             * Use one through three letters for the abbreviated name, four for the full name, or five for the narrow name
             * (currently the data only provides abbreviated names,
             * which will be used for all requested name widths). If the calendar does not provide cyclic year name data,
             * or if the year value to be formatted is out of the range
             * of years for which cyclic name data is provided, then numeric formatting is used (behaves like 'y').</td>
             * </tr>
             * <tr>
             * <td style="text-align: center">4</td>
             * <td>(currently also &#x7532;&#x5B50;)</td>
             * </tr>
             * <tr>
             * <td style="text-align: center">5</td>
             * <td>(currently also &#x7532;&#x5B50;)</td>
             * </tr>
             * <tr>
             * <th rowspan="6">quarter</th>
             * <td rowspan="3" style="text-align: center">Q</td>
             * <td style="text-align: center">1..2</td>
             * <td>02</td>
             * <td rowspan="3">Quarter - Use one or two for the numerical quarter, three for the abbreviation,
             * or four for the full name.</td>
             * </tr>
             * <tr>
             * <td style="text-align: center">3</td>
             * <td>Q2</td>
             * </tr>
             * <tr>
             * <td style="text-align: center">4</td>
             * <td>2nd quarter</td>
             * </tr>
             * <tr>
             * <td rowspan="3" style="text-align: center">q</td>
             * <td style="text-align: center">1..2</td>
             * <td>02</td>
             * <td rowspan="3"><b>Stand-Alone</b> Quarter - Use one or two for the numerical quarter,
             * three for the abbreviation, or four for the full name.</td>
             * </tr>
             * <tr>
             * <td style="text-align: center">3</td>
             * <td>Q2</td>
             * </tr>
             * <tr>
             * <td style="text-align: center">4</td>
             * <td>2nd quarter</td>
             * </tr>
             * <tr>
             * <th rowspan="8">month</th>
             * <td rowspan="4" style="text-align: center">M</td>
             * <td style="text-align: center">1..2</td>
             * <td>09</td>
             * <td rowspan="4">Month - Use one or two for the numerical month, three for the abbreviation,
             * four for the full name, or five for the narrow name.</td>
             * </tr>
             * <tr>
             * <td style="text-align: center">3</td>
             * <td>Sept</td>
             * </tr>
             * <tr>
             * <td style="text-align: center">4</td>
             * <td>September</td>
             * </tr>
             * <tr>
             * <td style="text-align: center">5</td>
             * <td>S</td>
             * </tr>
             * <tr>
             * <td rowspan="4" style="text-align: center">L</td>
             * <td style="text-align: center">1..2</td>
             * <td>09</td>
             * <td rowspan="4"><b>Stand-Alone</b> Month - Use one or two for the numerical month,
             * three for the abbreviation, or four for the full name, or 5 for the narrow name.</td>
             * </tr>
             * <tr>
             * <td style="text-align: center">3</td>
             * <td>Sept</td>
             * </tr>
             * <tr>
             * <td style="text-align: center">4</td>
             * <td>September</td>
             * </tr>
             * <tr>
             * <td style="text-align: center">5</td>
             * <td>S</td>
             * </tr>
             * <tr>
             * <th rowspan="2">week</th>
             * <td style="text-align: center">w</td>
             * <td style="text-align: center">1..2</td>
             * <td>27</td>
             * <td>Week of Year.</td>
             * </tr>
             * <tr>
             * <td style="text-align: center">W</td>
             * <td style="text-align: center">1</td>
             * <td>3</td>
             * <td>Week of Month. From 0..5. The first week of the month is the first week that contains a Thursday.
             * This is based on the ICU definition of week of month, and correlates to the ISO8601 week of year definition.
             * A day in the week before the week with the first Thursday will be week 0.</td>
             * </tr>
             * <tr>
             * <th rowspan="4">day</th>
             * <td style="text-align: center">d</td>
             * <td style="text-align: center">1..2</td>
             * <td>1</td>
             * <td>Date - Day of the month</td>
             * </tr>
             * <tr>
             * <td style="text-align: center">D</td>
             * <td style="text-align: center">1..3</td>
             * <td>345</td>
             * <td>Day of year</td>
             * </tr>
             * <tr>
             * <td style="text-align: center">F</td>
             * <td style="text-align: center">1</td>
             * <td>2</td>
             * <td>Day of Week in Month. The example is for the 2nd Wed in July</td>
             * </tr>
             * <tr>
             * <td style="text-align: center">g</td>
             * <td style="text-align: center">1..n</td>
             * <td>2451334</td>
             * <td>Modified Julian day. This is different from the conventional Julian day number in two regards.
             * First, it demarcates days at local zone midnight, rather than noon GMT.
             * Second, it is a local number; that is, it depends on the local time zone.
             * It can be thought of as a single number that encompasses all the date-related fields.</td>
             * </tr>
             * <tr>
             * <th rowspan="15">week<br>
             * day</th>
             * <td rowspan="5" style="text-align: center">E</td>
             * <td style="text-align: center">1..2</td>
             * <td>2</td>
             * <td rowspan="5">Day of week - Use one through two for ISO number, or three for the short day,
             * or four for the full name, five for the narrow name, or six for the short name.</td>
             * </tr>
             * <tr>
             * <td style="text-align: center">3</td>
             * <td>Tue</td>
             * </tr>
             * <tr>
             * <td style="text-align: center">4</td>
             * <td>Tuesday</td>
             * </tr>
             * <tr>
             * <td style="text-align: center">5</td>
             * <td>T</td>
             * </tr>
             * <tr>
             * <td style="text-align: center">6</td>
             * <td>Tu</td>
             * </tr>
             * <tr>
             * <td rowspan="5" style="text-align: center">e</td>
             * <td style="text-align: center">1..2</td>
             * <td>2</td>
             * <td rowspan="5">Local day of week. Same as E except adds a numeric value that will depend on the
             * local starting day of the week, using one or two letters. For this example, Monday is the first day of the week.</td>
             * </tr>
             * <tr>
             * <td style="text-align: center">3</td>
             * <td>Tue</td>
             * </tr>
             * <tr>
             * <td style="text-align: center">4</td>
             * <td>Tuesday</td>
             * </tr>
             * <tr>
             * <td style="text-align: center">5</td>
             * <td>T</td>
             * </tr>
             * <tr>
             * <td style="text-align: center">6</td>
             * <td>Tu</td>
             * </tr>
             * <tr>
             * <td rowspan="5" style="text-align: center">c</td>
             * <td style="text-align: center">1..2</td>
             * <td>2</td>
             * <td rowspan="5"><b>Stand-Alone</b> local day of week - Use one or two letters for the local numeric value
             * (same as 'e'), three for the short day, four for the full name, five for the narrow name,
             * or six for the short name.</td>
             * </tr>
             * <tr>
             * <td style="text-align: center">3</td>
             * <td>Tue</td>
             * </tr>
             * <tr>
             * <td style="text-align: center">4</td>
             * <td>Tuesday</td>
             * </tr>
             * <tr>
             * <td style="text-align: center">5</td>
             * <td>T</td>
             * </tr>
             * <tr>
             * <td style="text-align: center">6</td>
             * <td>Tu</td>
             * </tr>
             * <tr>
             * <th>period</th>
             * <td style="text-align: center">a</td>
             * <td style="text-align: center">1</td>
             * <td>AM</td>
             * <td>AM or PM</td>
             * </tr>
             * <tr>
             * <th rowspan="4">hour</th>
             * <td style="text-align: center">h</td>
             * <td style="text-align: center">1..2</td>
             * <td>11</td>
             * <td>Hour [1-12]. When used in skeleton data or in a skeleton passed in an API for flexible data pattern generation,
             * it should match the 12-hour-cycle format preferred by the locale (h or K);
             * it should not match a 24-hour-cycle format (H or k). Use hh for zero padding.</td>
             * </tr>
             * <tr>
             * <td style="text-align: center">H</td>
             * <td style="text-align: center">1..2</td>
             * <td>13</td>
             * <td>Hour [0-23]. When used in skeleton data or in a skeleton passed in an API for flexible data pattern generation,
             * it should match the 24-hour-cycle format preferred by the locale (H or k);
             * it should not match a 12-hour-cycle format (h or K). Use HH for zero padding.</td>
             * </tr>
             * <tr>
             * <td style="text-align: center">K</td>
             * <td style="text-align: center">1..2</td>
             * <td>0</td>
             * <td>Hour [0-11]. When used in a skeleton, only matches K or h, see above. Use KK for zero padding.</td>
             * </tr>
             * <tr>
             * <td style="text-align: center">k</td>
             * <td style="text-align: center">1..2</td>
             * <td>24</td>
             * <td>Hour [1-24]. When used in a skeleton, only matches k or H, see above. Use kk for zero padding.</td>
             * </tr>
             * <tr>
             * <th>minute</th>
             * <td style="text-align: center">m</td>
             * <td style="text-align: center">1..2</td>
             * <td>59</td>
             * <td>Minute. Use one or two for zero padding.</td>
             * </tr>
             * <tr>
             * <th rowspan="3">second</th>
             * <td style="text-align: center">s</td>
             * <td style="text-align: center">1..2</td>
             * <td>12</td>
             * <td>Second. Use one or two for zero padding.</td>
             * </tr>
             * <tr>
             * <td style="text-align: center">S</td>
             * <td style="text-align: center">1..n</td>
             * <td>3456</td>
             * <td>Fractional Second - truncates (like other time fields) to the count of letters.
             * (example shows display using pattern SSSS for seconds value 12.34567)</td>
             * </tr>
             * <tr>
             * <td style="text-align: center">A</td>
             * <td style="text-align: center">1..n</td>
             * <td>69540000</td>
             * <td>Milliseconds in day. This field behaves <i>exactly</i> like a composite of all time-related fields,
             * not including the zone fields. As such, it also reflects discontinuities of those fields on DST transition days.
             * On a day of DST onset, it will jump forward. On a day of DST cessation, it will jump backward.
             * This reflects the fact that is must be combined with the offset field to obtain a unique local time value.</td>
             * </tr>
             * <tr>
             * <th rowspan="23">zone</th>
             * <td rowspan="2" style="text-align: center">z</td>
             * <td style="text-align: center">1..3</td>
             * <td>PDT</td>
             * <td>The <i>short specific non-location format</i>. Where that is unavailable, falls back to the
             * <i>short localized GMT format</i> ("O").</td>
             * </tr>
             * <tr>
             * <td style="text-align: center">4</td>
             * <td>Pacific Daylight Time</td>
             * <td>The <i>long specific non-location format</i>. Where that is unavailable, falls back to the
             * <i>long localized GMT format</i> ("OOOO").</td>
             * </tr>
             * <tr>
             * <td rowspan="3" style="text-align: center">Z</td>
             * <td style="text-align: center">1..3</td>
             * <td>-0800</td>
             * <td>The <i>ISO8601 basic format</i> with hours, minutes and optional seconds fields.
             * The format is equivalent to RFC 822 zone format (when optional seconds field is absent).
             * This is equivalent to the "xxxx" specifier.</td>
             * </tr>
             * <tr>
             * <td style="text-align: center">4</td>
             * <td>GMT-8:00</td>
             * <td>The <i>long localized GMT format</i>. This is equivalent to the "OOOO" specifier.</td>
             * </tr>
             * <tr>
             * <td style="text-align: center">5</td>
             * <td>-08:00<br>
             * -07:52:58</td>
             * <td>The <i>ISO8601 extended format</i> with hours, minutes and optional seconds fields.
             * The ISO8601 UTC indicator "Z" is used when local time offset is 0. This is equivalent to the "XXXXX" specifier.</td>
             * </tr>
             * <tr>
             * <td rowspan="2" style="text-align: center">O</td>
             * <td style="text-align: center">1</td>
             * <td>GMT-8</td>
             * <td>The <i>short localized GMT format</i>.</td>
             * </tr>
             * <tr>
             * <td style="text-align: center">4</td>
             * <td>GMT-08:00</td>
             * <td>The <i>long localized GMT format</i>.</td>
             * </tr>
             * <tr>
             * <td rowspan="2" style="text-align: center">v</td>
             * <td style="text-align: center">1</td>
             * <td>PT</td>
             * <td>The <i>short generic non-location format</i>. Where that is unavailable, falls back to the
             * <i>generic location format</i> ("VVVV"), then the <i>short localized GMT format</i> as the final fallback.</td>
             * </tr>
             * <tr>
             * <td style="text-align: center">4</td>
             * <td>Pacific Time</td>
             * <td>The <i>long generic non-location format</i>. Where that is unavailable, falls back to
             * <i>generic location format</i> ("VVVV").</td>
             * </tr>
             * <tr>
             * <td rowspan="4" style="text-align: center">V</td>
             * <td style="text-align: center">1</td>
             * <td>uslax</td>
             * <td><b>NOT SUPPORTED!</b> The short time zone ID. Where that is unavailable, the special short time zone ID
             * <i>unk</i> (Unknown Zone) is used.<br>
             * <i><b>Note</b>: This specifier was originally used for a variant of the short specific non-location format,
             * but it was deprecated in the later version of the LDML specification. In CLDR 23/ICU 51,
             * the definition of the specifier was changed to designate a short time zone ID.</i></td>
             * </tr>
             * <tr>
             * <td style="text-align: center">2</td>
             * <td>America/Los_Angeles</td>
             * <td><b>NOT SUPPORTED!</b> The long time zone ID.</td>
             * </tr>
             * <tr>
             * <td style="text-align: center">3</td>
             * <td>Los Angeles</td>
             * <td><b>NOT SUPPORTED!</b> The exemplar city (location) for the time zone. Where that is unavailable,
             * the localized exemplar city name for the special zone <i>Etc/Unknown</i> is used as the fallback
             * (for example, "Unknown City").</td>
             * </tr>
             * <tr>
             * <td style="text-align: center">4</td>
             * <td>Los Angeles Time</td>
             * <td>The <i>generic location format</i>. Where that is unavailable, falls back to the
             * <i>long localized GMT format</i> ("OOOO"; Note: Fallback is only necessary with a GMT-style Time Zone ID,
             * like Etc/GMT-830.)<br>
             * This is especially useful when presenting possible timezone choices for user selection,
             * since the naming is more uniform than the "v" format.</td>
             * </tr>
             * <tr>
             * <td rowspan="5" style="text-align: center">X</td>
             * <td style="text-align: center">1</td>
             * <td>-08<br>
             * +0530<br>
             * Z</td>
             * <td>The <i>ISO8601 basic format</i> with hours field and optional minutes field.
             * The ISO8601 UTC indicator "Z" is used when local time offset is 0.</td>
             * </tr>
             * <tr>
             * <td style="text-align: center">2</td>
             * <td>-0800<br>
             * Z</td>
             * <td>The <i>ISO8601 basic format</i> with hours and minutes fields.
             * The ISO8601 UTC indicator "Z" is used when local time offset is 0.</td>
             * </tr>
             * <tr>
             * <td style="text-align: center">3</td>
             * <td>-08:00<br>
             * Z</td>
             * <td>The <i>ISO8601 extended format</i> with hours and minutes fields.
             * The ISO8601 UTC indicator "Z" is used when local time offset is 0.</td>
             * </tr>
             * <tr>
             * <td style="text-align: center">4</td>
             * <td>-0800<br>
             * -075258<br>
             * Z</td>
             * <td>The <i>ISO8601 basic format</i> with hours, minutes and optional seconds fields.
             * (Note: The seconds field is not supported by the ISO8601 specification.)
             * The ISO8601 UTC indicator "Z" is used when local time offset is 0.</td>
             * </tr>
             * <tr>
             * <td style="text-align: center">5</td>
             * <td>-08:00<br>
             * -07:52:58<br>
             * Z</td>
             * <td>The <i>ISO8601 extended format</i> with hours, minutes and optional seconds fields.
             * (Note: The seconds field is not supported by the ISO8601 specification.)
             * The ISO8601 UTC indicator "Z" is used when local time offset is 0.</td>
             * </tr>
             * <tr>
             * <td rowspan="5" style="text-align: center">x</td>
             * <td style="text-align: center">1</td>
             * <td>-08<br>
             * +0530</td>
             * <td>The <i>ISO8601 basic format</i> with hours field and optional minutes field.</td>
             * </tr>
             * <tr>
             * <td style="text-align: center">2</td>
             * <td>-0800</td>
             * <td>The <i>ISO8601 basic format</i> with hours and minutes fields.</td>
             * </tr>
             * <tr>
             * <td style="text-align: center">3</td>
             * <td>-08:00</td>
             * <td>The <i>ISO8601 extended format</i> with hours and minutes fields.</td>
             * </tr>
             * <tr>
             * <td style="text-align: center">4</td>
             * <td>-0800<br>
             * -075258</td>
             * <td>The <i>ISO8601 basic format</i> with hours, minutes and optional seconds fields.
             * (Note: The seconds field is not supported by the ISO8601 specification.)</td>
             * </tr>
             * <tr>
             * <td style="text-align: center">5</td>
             * <td>-08:00<br>
             * -07:52:58</td>
             * <td>The <i>ISO8601 extended format</i> with hours, minutes and optional seconds fields.
             * (Note: The seconds field is not supported by the ISO8601 specification.)</td>
             * </tr>
             * </tbody>
             * </table>
             * <p>Any characters in the pattern that are not in the ranges of ['a'..'z'] and ['A'..'Z']
             * will be treated as quoted text. For instance, characters like ':', '.', ' ', '#' and '@'
             * will appear in the resulting time text even they are not embraced within single quotes.</p>
             * <p>A pattern containing any invalid pattern letter will result in a thrown exception during formatting.</p>
             **/
            format: {
                value: function (pattern) {
                    var struct,
                        string,
                        isJulian,
                        lang,
                        dateTimeFormats,
                        dateTimeFormat;

                    if (this.isValid()) {
                        lang = this.currentLang();
                        if (!isString(lang) || isEmptyString(lang) || !isPlainObject(languages[lang])) {
                            if (!isString(defaultLanguage) || isEmptyString(defaultLanguage) || !isPlainObject(languages[defaultLanguage])) {
                                throw new Error('Language not loaded!');
                            }

                            lang = defaultLanguage;
                        }

                        isJulian = this.isJulian();
                        if (isJulian) {
                            struct = jdToJulian(this.jd());
                        } else {
                            struct = this.getter();
                        }

                        struct = getCorrectStruct(this, struct);
                        dateTimeFormats = languages[lang].dates.calendars.gregorian.dateTimeFormats;
                        if (!isString(pattern) || isEmptyString(pattern)) {
                            pattern = arrayFirst(formatTypes);
                        }

                        if (arrayContains(objectKeys(dateTimeFormats), pattern)) {
                            dateTimeFormat = dateTimeFormats[pattern];
                            dateTimeFormat = replaceToken(dateTimeFormat, '{1}', formatDate(struct, pattern, isJulian, lang, this.locale()));
                            dateTimeFormat = replaceToken(dateTimeFormat, '{0}', formatTime(struct, pattern, lang));
                        } else {
                            dateTimeFormat = formatDate(struct, pattern, isJulian, lang, this.locale());
                            dateTimeFormat = formatTime(struct, dateTimeFormat, lang);
                        }

                        if (hasRemainingTokens(dateTimeFormat)) {
                            throw new Error('Pattern has remaining tokens!: ' + remainingTokens(dateTimeFormat));
                        }

                        string = stripSingleQuotes(dateTimeFormat);
                    } else {
                        string = 'Invalid Date';
                    }

                    return string;
                }
            },

            /** @memberOf AstroDate.prototype
             * @function
             * @param {string} [pattern]
             * @return {string}
             * @this AstroDate
             */
            toString: {
                value: function (pattern) {
                    if (!isString(pattern) || isEmptyString(pattern) || !arrayContains(formatTypes, pattern)) {
                        pattern = arrayFirst(formatTypes);
                    }

                    return this.format(pattern);
                }
            },

            /** @memberOf AstroDate.prototype
             * @function
             * @param {string} [pattern]
             * @return {string}
             * @this AstroDate
             */
            toDateString: {
                value: function (pattern) {
                    var struct,
                        string,
                        isJulian,
                        lang;

                    if (this.isValid()) {
                        lang = this.currentLang();
                        if (!isString(lang) || isEmptyString(lang) || !isPlainObject(languages[lang])) {
                            if (!isString(defaultLanguage) || isEmptyString(defaultLanguage) || !isPlainObject(languages[defaultLanguage])) {
                                throw new Error('Language not loaded!');
                            }

                            lang = defaultLanguage;
                        }

                        isJulian = this.isJulian();
                        if (isJulian) {
                            struct = jdToJulian(this.jd());
                        } else {
                            struct = this.getter();
                        }

                        if (!isString(pattern) || isEmptyString(pattern) || !arrayContains(formatTypes, pattern)) {
                            pattern = arrayFirst(formatTypes);
                        }

                        pattern = formatDate(getCorrectStruct(this, struct), pattern, isJulian, lang, this.locale());
                        if (hasRemainingTokens(pattern)) {
                            throw new Error('Pattern has remaining tokens!: ' + remainingTokens(pattern));
                        }

                        string = stripSingleQuotes(pattern);
                    } else {
                        string = 'Invalid Date';
                    }

                    return string;
                }
            },

            /** @memberOf AstroDate.prototype
             * @function
             * @param {string} [pattern]
             * @return {string}
             * @this AstroDate
             */
            toTimeString: {
                value: function (pattern) {
                    var struct,
                        string,
                        isJulian,
                        lang;

                    if (this.isValid()) {
                        lang = this.currentLang();
                        if (!isString(lang) || isEmptyString(lang) || !isPlainObject(languages[lang])) {
                            if (!isString(defaultLanguage) || isEmptyString(defaultLanguage) || !isPlainObject(languages[defaultLanguage])) {
                                throw new Error('Language not loaded!');
                            }

                            lang = defaultLanguage;
                        }

                        isJulian = this.isJulian();
                        if (isJulian) {
                            struct = jdToJulian(this.jd());
                        } else {
                            struct = this.getter();
                        }

                        if (!isString(pattern) || isEmptyString(pattern) || !arrayContains(formatTypes, pattern)) {
                            pattern = arrayFirst(formatTypes);
                        }

                        pattern = formatTime(getCorrectStruct(this, struct), pattern, lang);
                        if (hasRemainingTokens(pattern)) {
                            throw new Error('Pattern has remaining tokens!: ' + remainingTokens(pattern));
                        }

                        string = stripSingleQuotes(pattern);
                    } else {
                        string = 'Invalid Date';
                    }

                    return string;
                }
            },

            /** @memberOf AstroDate.prototype
             * @function
             * @return {string}
             * @this AstroDate
             */
            toISOString: {
                value: function (padding) {
                    var val;

                    if (this.isValid()) {
                        // should be gregorian?!
                        // add weekDate = calendarToWeekDate(struct)
                        val = toISOString(getCorrectStruct(this, this.getter()), padding);
                    } else {
                        val = 'Invalid Date';
                    }

                    return val;
                }
            },

            /** @memberOf AstroDate.prototype
             * @function
             * @return {string}
             * @this AstroDate
             */
            valueOf: {
                value: function () {
                    var val;

                    if (this.isJulian()) {
                        val = this.jd();
                    } else {
                        val = this.getTime();
                    }

                    return val;
                }
            },

            /** @memberOf AstroDate.prototype
             * @function
             * @this AstroDate
             */
            unix: {
                value: function () {
                    var struct,
                        val;

                    if (this.isValid()) {
                        if (this.isTT()) {
                            struct = toTT(this.getter());
                        } else {
                            struct = this.getter();
                        }

                        val = getTime(toUT(struct)).div(1000).trunc().toString();
                    }

                    return val;
                }
            },

            /** @memberOf AstroDate.prototype
             * @function
             * @param {object} [dateObject]
             * @this AstroDate
             */
            object: {
                value: function (dateObject) {
                    var struct,
                        val;

                    if (isUndefined(dateObject)) {
                        if (this.isValid()) {
                            struct = getCorrectStruct(this, this.getter());
                            if (this.isJulian()) {
                                val = structToObject(gregorianToJulian(struct));
                            } else {
                                val = structToObject(struct);
                            }
                        }
                    } else if (isPlainObject(dateObject)) {
                        val = this.setter('struct', objectToStruct(dateObject, this.isJulian()));
                    } else {
                        throw new TypeError(dateObject);
                    }

                    return val;
                }
            },

            /** @memberOf AstroDate.prototype
             * @function
             * @return {AstroDate}
             * @this AstroDate
             */
            clone: {
                value: function () {
                    return new AstroDate(this);
                }
            },

            /** @memberOf AstroDate.prototype
             * @function
             * @param {array} [dateArray]
             * @this AstroDate
             */
            array: {
                value: function (dateArray) {
                    var struct,
                        val;

                    if (isUndefined(dateArray)) {
                        if (this.isValid()) {
                            struct = getCorrectStruct(this, this.getter());
                            if (this.isJulian()) {
                                val = structToArrayOfString(gregorianToJulian(struct));
                            } else {
                                val = structToArrayOfString(struct);
                            }
                        }
                    } else if (arrayIsArray(dateArray)) {
                        val = this.setter('struct', arrayToStruct(dateArray, this.isJulian()));
                    } else {
                        throw new TypeError(dateArray);
                    }

                    return val;
                }
            },

            /** @memberOf AstroDate.prototype
             * @function
             * @param {window.Date} [date]
             * @this AstroDate
             */
            date: {
                value: function (date) {
                    var val;

                    if (isUndefined(date)) {
                        if (this.isValid()) {
                            val = new Date(parseInt(this.getTime(), 10));
                        } else {
                            val = new Date(NaN);
                        }
                    } else if (isDate(date)) {
                        val = this.setter(date);
                    } else {
                        throw new TypeError(date);
                    }

                    return val;
                }
            },

            /** @memberOf AstroDate.prototype
             * @function
             * @this AstroDate
             */
            getTime: {
                value: function () {
                    var struct,
                        val;

                    if (this.isValid()) {
                        if (this.isTT()) {
                            struct = toTT(this.getter());
                        } else {
                            struct = this.getter();
                        }

                        val = getTime(toUT(struct)).toString();
                    }

                    return val;
                }
            },

            /** @memberOf AstroDate.prototype
             * @function
             * @this AstroDate
             */
            deltaTime: {
                value: function () {
                    var val;

                    if (this.isValid()) {
                        val = deltaTime(getCorrectStruct(this, this.getter())).toString();
                    }

                    return val;
                }
            },

            /** @memberOf AstroDate.prototype
             * @function
             * @param {string} unit
             * @this AstroDate
             */
            timeTo: {
                value: function (unit) {
                    var val;

                    if (this.isValid()) {
                        val = timeTo(getCorrectStruct(this, this.getter()), normaliseUnits(unit)).toString();
                    }

                    return val;
                }
            },

            /**
             * The Julian Date (JD) of any instant is the Julian day number for the preceding noon plus the fraction of the day since that instant.
             * Julian Dates are expressed as a Julian day number with a decimal fraction added.
             * For example, the Julian Date for 00:30:00.0 UT 1 January 2013 is 2456293.520833334
             * If argument is passed then this function acts as a setter; otherwise it is a getter.
             * If AstroDate is invalid then undefined is returned.
             * Throws an error if the argument is not of the correct type.
             * @memberOf AstroDate.prototype
             * @function
             * @param {(number|string)} [jd]
             * @return {string|undefined}
             * @this AstroDate
             */
            jd: {
                value: function (jd) {
                    var struct,
                        val;

                    if (isUndefined(jd)) {
                        if (this.isValid()) {
                            if (this.isTT()) {
                                struct = toTT(this.getter());
                            } else {
                                struct = this.getter();
                            }

                            val = gregorianToJd(toUT(struct)).toFixed(BigNumber.config().DECIMAL_PLACES);
                        }
                    } else if (isNumber(jd) || isString(jd) || (jd && jd instanceof BigNumber)) {
                        val = this.setter('struct', jdToGregorian(jd));
                    } else {
                        throw new TypeError(jd);
                    }

                    return val;
                }
            },

            /** @memberOf AstroDate.prototype
             * @function
             * @this AstroDate
             */
            jdn: {
                value: function () {
                    var struct,
                        val;

                    if (this.isValid()) {
                        if (this.isTT()) {
                            struct = toTT(this.getter());
                        } else {
                            struct = this.getter();
                        }

                        val = gregorianToJdn(toUT(struct)).toString();
                    }

                    return val;
                }
            },

            /** @memberOf AstroDate.prototype
             * @function
             * @this AstroDate
             */
            mjd: {
                value: function () {
                    var struct,
                        val;

                    if (this.isValid()) {
                        if (this.isTT()) {
                            struct = toTT(this.getter());
                        } else {
                            struct = this.getter();
                        }

                        val = gregorianToMJD(toUT(struct)).toString();
                    }

                    return val;
                }
            },

            /** @memberOf AstroDate.prototype
             * @function
             * @this AstroDate
             */
            easter: {
                value: function () {
                    var struct,
                        val,
                        a,
                        b,
                        c,
                        d,
                        e,
                        f,
                        g,
                        h,
                        i,
                        k,
                        l,
                        m,
                        n;

                    if (this.isValid()) {
                        struct = getCorrectStruct(this, this.getter());
                        if (this.isJulian()) {
                            a = struct.year.mod(4);
                            b = struct.year.mod(7);
                            c = struct.year.mod(19);
                            d = c.times(19).plus(15).mod(30);
                            e = a.times(2).plus(b.times(4)).minus(d).plus(34).mod(7);
                            f = d.plus(e).plus(114);
                            val = new AstroDate([struct.year, f.div(31).floor().minus(1), f.mod(31).plus(1)]);
                        } else {
                            a = struct.year.mod(19);
                            b = struct.year.div(100).floor();
                            c = struct.year.mod(100).floor();
                            d = b.div(4);
                            e = b.mod(4);
                            f = b.plus(8).div(25).floor();
                            g = b.minus(f).plus(1).div(3).floor();
                            h = new BigNumber(19).times(a).plus(b).minus(d).minus(g).plus(15).mod(30);
                            i = c.div(4).floor();
                            k = c.mod(4);
                            l = new BigNumber(32).plus(e.times(2)).plus(i.times(2)).minus(h).minus(k).mod(7);
                            m = a.plus(h.times(11)).plus(l.times(22)).div(451).floor();
                            n = h.plus(l).minus(m.times(7)).plus(114);
                            val = new AstroDate([struct.year, n.div(31).floor(), n.mod(31).plus(1)]);
                        }
                    }

                    return val;
                }
            },

            /** @memberOf AstroDate.prototype
             * @function
             * @this AstroDate
             */
            isLeapYear: {
                value: function () {
                    var struct,
                        val;

                    if (this.isValid()) {
                        struct = getCorrectStruct(this, this.getter());
                        if (this.isJulian()) {
                            val = isJulianLeapYear(gregorianToJulian(struct));
                        } else {
                            val = isGregorianLeapYear(struct);
                        }
                    }

                    return val;
                }
            },

            /** @memberOf AstroDate.prototype
             * @function
             * @this AstroDate
             */
            daysInYear: {
                value: function () {
                    var struct,
                        val;

                    if (this.isValid()) {
                        struct = getCorrectStruct(this, this.getter());
                        if (this.isJulian()) {
                            val = daysInJulianYear(gregorianToJulian(struct)).toString();
                        } else {
                            val = daysInGregorianYear(struct).toString();
                        }
                    }

                    return val;
                }
            },

            /** @memberOf AstroDate.prototype
             * @function
             * @this AstroDate
             */
            daysInMonth: {
                value: function () {
                    var struct,
                        val;

                    if (this.isValid()) {
                        struct = getCorrectStruct(this, this.getter());
                        if (this.isJulian()) {
                            val = daysInJulianMonth(gregorianToJulian(struct)).toString();
                        } else {
                            val = daysInGregorianMonth(struct).toString();
                        }
                    }

                    return val;
                }
            },

            /** @memberOf AstroDate.prototype
             * @function
             * @param {string} [jsonString]
             * @return {string}
             * @this AstroDate
             */
            json: {
                value: function (jsonString) {
                    var struct,
                        propArray,
                        val;

                    if (isUndefined(jsonString)) {
                        if (isFunction(JSON.stringify)) {
                            val = JSON.stringify(this.object());
                        } else {
                            struct = this.object();
                            propArray = arrayMap(objectKeys(struct), function (key) {
                                return '"' + key + '":"' + struct[key] + '"';
                            });

                            val = '{' + propArray.join(',') + '}';
                        }
                    } else if (isString(jsonString)) {
                        if (isFunction(JSON.parse)) {
                            struct = objectToStruct(JSON.parse(jsonString), this.isJulian());
                        } else {
                            /*jslint evil: true */
                            struct = objectToStruct(new Function('return' + jsonString)(), this.isJulian());
                            /*jslint evil:   false */
                        }

                        if (!isValid(struct)) {
                            throw new SyntaxError(struct);
                        }

                        val = this.setter('struct', struct);
                    } else {
                        throw new TypeError(jsonString);
                    }

                    return val;
                }
            },

            /** @memberOf AstroDate.prototype
             * @function
             * @return {string}
             * @this AstroDate
             */
            toJSON: {
                value: function (padding, type) {
                    return this.toISOString(padding, type);
                }
            },

            /** @memberOf AstroDate.prototype
             * @function
             * @this AstroDate
             */
            calendarToWeekDate: {
                value: function () {
                    var val;

                    if (this.isValid()) {
                        val = structToObject(calendarToWeekDate(getCorrectStruct(this, this.getter())));
                    }

                    return val;
                }
            },

            /** @memberOf AstroDate.prototype
             * @function
             * @param {string} [id]
             * @return {string}
             * @this AstroDate
             */
            lang: {
                value: function (id) {
                    var val,
                        lang;

                    if (isString(id) && !isEmptyString(id)) {
                        lang = minusToUnderscore(id);
                        if (isPlainObject(languages[lang])) {
                            this.setter('lang', lang);
                            this.setter('locale', lookupLocale(lang));
                        }

                        val = this;
                    } else {
                        val = this.getter('lang');
                    }

                    return val;
                }
            },

            /** @memberOf AstroDate.prototype
             * @function
             * @param {string} [id]
             * @return {string}
             * @this AstroDate
             */
            locale: {
                value: function (id) {
                    var lang,
                        val;

                    if (isString(id) && !isEmptyString(id)) {
                        lang = languageLoaded(id);
                        if (!isEmptyString(lang)) {
                            this.setter('lang', lang);
                            this.setter('locale', lookupLocale(id));
                        }

                        val = this;
                    } else {
                        val = this.getter('locale');
                    }

                    return val;
                }
            }
        });

        objectDefineProperties(AstroDate, {
            /** @memberOf AstroDate
             * @function
             * @return {string}
             */
            version: {
                value: function () {
                    return VERSION;
                }
            },

            /** @memberOf AstroDate
             * @function
             * @param {string} [id]
             * @param {object} [object]
             * @param {boolean} [freeze]
             * @return {string}
             */
            lang: {
                value: function (id, object, freeze) {
                    var lang;

                    if (isString(id) && !isEmptyString(id)) {
                        lang = minusToUnderscore(id);
                        if (isPlainObject(object)) {
                            languages[lang] = object;
                            if (!strictEqual(freeze, false)) {
                                deepFreeze(languages[lang]);
                            }
                        }

                        if (isPlainObject(languages[lang])) {
                            defaultLanguage = lang;
                            defaultLocale = lookupLocale(lang);
                        }
                    }

                    return defaultLanguage;
                }
            },

            /** @memberOf AstroDate
             * @function
             * @return {array.<String>}
             */
            langs: {
                value: function () {
                    return objectKeys(languages);
                }
            },

            /** @memberOf AstroDate
             * @function
             * @param {string} [id] The string representing the required locale, e.g. 'en_GB'
             * @return {string} Returns the current locale, e.g. 'en_GB'
             */
            locale: {
                value: function (id) {
                    var lang;

                    if (isString(id) && !isEmptyString(id)) {
                        lang = languageLoaded(id);
                        if (!isEmptyString(lang)) {
                            defaultLanguage = lang;
                            defaultLocale = lookupLocale(id);
                        }
                    }

                    return defaultLocale;
                }
            },

            /** @memberOf AstroDate
             * @function
             * @param {object} object
             * @param {boolean} freeze
             * @return {object}
             */
            leapSeconds: {
                value: function (object, freeze) {
                    if (isPlainObject(object)) {
                        leapSeconds = object;
                        if (!strictEqual(freeze, false)) {
                            deepFreeze(leapSeconds);
                        }
                    }

                    return leapSeconds;
                }
            },

            /** @memberOf AstroDate
             * @function
             * @param {object} object
             * @param {boolean} freeze
             * @return {object}
             */
            supplemental: {
                value: function (object, freeze) {
                    if (isPlainObject(object)) {
                        supplemental = object;
                        if (!strictEqual(freeze, false)) {
                            deepFreeze(supplemental);
                        }
                    }

                    return supplemental;
                }
            },

            /** @memberOf AstroDate
             * @function
             * @return {BigNumber}
             */
            BigNumber: {
                value: BigNumber
            },

            /** @memberOf AstroDate
             * @function
             * @param {string} unitString
             */
            normaliseUnits: {
                value: function (unitString) {
                    return normaliseUnits(unitString);
                }
            },

            /**
             * Tests if the provided input is an instance of AstroDate.
             * @memberOf AstroDate
             * @function
             * @param {object} inputArg
             * @return {boolean}
             */
            isAstroDate: {
                value: function (inputArg) {
                    return isObject(inputArg) && objectInstanceOf(inputArg, AstroDate);
                }
            },

            /**
             * Time is measured in ECMAScript in milliseconds since 01 January, 1970 UTC. In time values leap seconds
             * are ignored. It is assumed that there are exactly 86,400,000 milliseconds per day.
             * @memberOf AstroDate
             * @function
             * @return {string}
             */
            now: {
                value: function () {
                    return new AstroDate().getTime();
                }
            },

            /**
             * The Julian Date (JD) of any instant is the Julian day number for the preceding noon plus the fraction of the day since that instant.
             * Julian Dates are expressed as a Julian day number with a decimal fraction added.
             * For example, the Julian Date for 00:30:00.0 UT 1 January 2013 is 2456293.520833334
             * @memberOf AstroDate
             * @function
             * @return {string}
             */
            jd: {
                value: function () {
                    return new AstroDate().jd();
                }
            },
            /**
             * The Julian Day Number (JDN) is the integer assigned to a whole solar day in the Julian day count starting from noon Greenwich Mean Time,
             * with Julian day number 0 assigned to the day starting at noon on 1 January 4713 BC proleptic Julian calendar (24 November 4714 BC, in the proleptic Gregorian calendar).
             * For example, the Julian day number for 1 January 2000 was 2,451,545.0
             * @memberOf AstroDate
             * @function
             * @return {string}
             */
            jdn: {
                value: function () {
                    return new AstroDate().jdn();
                }
            },

            /**
             * The Modified Julian Date (MJD) was introduced by the Smithsonian Astrophysical Observatory in 1957 to record the orbit of
             * Sputnik via an IBM 704 (36-bit machine) and using only 18 bits until August 7, 2576.
             * MJD is the epoch of OpenVMS, using 63-bit date/time postponing the next Y2K campaign to July 31, 31086 02:48:05.47.
             * MJD is defined relative to midnight, rather than noon.
             * @memberOf AstroDate
             * @function
             * @return {string}
             */
            mjd: {
                value: function () {
                    return new AstroDate().mjd();
                }
            },

            /**
             * The time now represented in Unix time.
             * Unix time, or POSIX time, is a system for describing instants in time,
             * defined as the number of seconds that have elapsed since 00:00:00 Coordinated Universal Time (UTC),
             * Thursday, 1 January 1970, not counting leap seconds.
             * It is used widely in Unix-like and many other operating systems and file formats.
             * Due to its handling of leap seconds, it is neither a linear representation of time nor a true representation of UTC.
             * Unix time may be checked on most Unix systems by typing date +%s on the command line.
             * @memberOf AstroDate
             * @function
             * @return {string}
             */
            unix: {
                value: function () {
                    return new AstroDate().unix();
                }
            }
        });

        /* jshint quotmark: false, -W100 */
        leapSeconds = deepFreeze({
            "1972": {
                "6": {
                    "30": "1"
                },
                "12": {
                    "31": "1"
                }
            },
            "1973": {
                "12": {
                    "31": "1"
                }
            },
            "1974": {
                "12": {
                    "31": "1"
                }
            },
            "1975": {
                "12": {
                    "31": "1"
                }
            },
            "1976": {
                "12": {
                    "31": "1"
                }
            },
            "1977": {
                "12": {
                    "31": "1"
                }
            },
            "1978": {
                "12": {
                    "31": "1"
                }
            },
            "1979": {
                "12": {
                    "31": "1"
                }
            },
            "1981": {
                "6": {
                    "30": "1"
                }
            },
            "1982": {
                "6": {
                    "30": "1"
                }
            },
            "1983": {
                "6": {
                    "30": "1"
                }
            },
            "1985": {
                "6": {
                    "30": "1"
                }
            },
            "1987": {
                "12": {
                    "31": "1"
                }
            },
            "1989": {
                "12": {
                    "31": "1"
                }
            },
            "1990": {
                "12": {
                    "31": "1"
                }
            },
            "1992": {
                "6": {
                    "30": "1"
                }
            },
            "1993": {
                "6": {
                    "30": "1"
                }
            },
            "1994": {
                "6": {
                    "30": "1"
                }
            },
            "1995": {
                "12": {
                    "31": "1"
                }
            },
            "1997": {
                "6": {
                    "30": "1"
                }
            },
            "1998": {
                "12": {
                    "31": "1"
                }
            },
            "2005": {
                "12": {
                    "31": "1"
                }
            },
            "2008": {
                "12": {
                    "31": "1"
                }
            },
            "2012": {
                "6": {
                    "30": "1"
                }
            }
        });

        supplemental = deepFreeze({
            "likelySubtags": {
                "aa": "aa_Latn_ET",
                "ab": "ab_Cyrl_GE",
                "ace": "ace_Latn_ID",
                "ady": "ady_Cyrl_RU",
                "af": "af_Latn_ZA",
                "agq": "agq_Latn_CM",
                "ak": "ak_Latn_GH",
                "alt": "alt_Cyrl_RU",
                "am": "am_Ethi_ET",
                "amo": "amo_Latn_NG",
                "ar": "ar_Arab_EG",
                "as": "as_Beng_IN",
                "asa": "asa_Latn_TZ",
                "ast": "ast_Latn_ES",
                "av": "av_Cyrl_RU",
                "awa": "awa_Deva_IN",
                "ay": "ay_Latn_BO",
                "az": "az_Latn_AZ",
                "az_Arab": "az_Arab_IR",
                "az_IR": "az_Arab_IR",
                "az_RU": "az_Cyrl_RU",
                "ba": "ba_Cyrl_RU",
                "bal": "bal_Arab_PK",
                "ban": "ban_Latn_ID",
                "bas": "bas_Latn_CM",
                "bax": "bax_Bamu_CM",
                "bbc": "bbc_Latn_ID",
                "be": "be_Cyrl_BY",
                "bem": "bem_Latn_ZM",
                "bez": "bez_Latn_TZ",
                "bfq": "bfq_Taml_IN",
                "bft": "bft_Arab_PK",
                "bfy": "bfy_Deva_IN",
                "bg": "bg_Cyrl_BG",
                "bhb": "bhb_Deva_IN",
                "bho": "bho_Deva_IN",
                "bi": "bi_Latn_VU",
                "bik": "bik_Latn_PH",
                "bin": "bin_Latn_NG",
                "bjj": "bjj_Deva_IN",
                "bku": "bku_Latn_PH",
                "bm": "bm_Latn_ML",
                "bn": "bn_Beng_BD",
                "bo": "bo_Tibt_CN",
                "bqv": "bqv_Latn_CI",
                "br": "br_Latn_FR",
                "bra": "bra_Deva_IN",
                "brx": "brx_Deva_IN",
                "bs": "bs_Latn_BA",
                "bss": "bss_Latn_CM",
                "btv": "btv_Deva_PK",
                "bua": "bua_Cyrl_RU",
                "buc": "buc_Latn_YT",
                "bug": "bug_Latn_ID",
                "bya": "bya_Latn_ID",
                "byn": "byn_Ethi_ER",
                "ca": "ca_Latn_ES",
                "cch": "cch_Latn_NG",
                "ccp": "ccp_Beng_IN",
                "ce": "ce_Cyrl_RU",
                "ceb": "ceb_Latn_PH",
                "cgg": "cgg_Latn_UG",
                "ch": "ch_Latn_GU",
                "chk": "chk_Latn_FM",
                "chm": "chm_Cyrl_RU",
                "chp": "chp_Latn_CA",
                "chr": "chr_Cher_US",
                "cja": "cja_Arab_KH",
                "cjm": "cjm_Cham_VN",
                "ckb": "ckb_Arab_IQ",
                "co": "co_Latn_FR",
                "cr": "cr_Cans_CA",
                "crk": "crk_Cans_CA",
                "cs": "cs_Latn_CZ",
                "csb": "csb_Latn_PL",
                "cv": "cv_Cyrl_RU",
                "cy": "cy_Latn_GB",
                "da": "da_Latn_DK",
                "dar": "dar_Cyrl_RU",
                "dav": "dav_Latn_KE",
                "de": "de_Latn_DE",
                "den": "den_Latn_CA",
                "dgr": "dgr_Latn_CA",
                "dje": "dje_Latn_NE",
                "doi": "doi_Arab_IN",
                "dsb": "dsb_Latn_DE",
                "dua": "dua_Latn_CM",
                "dv": "dv_Thaa_MV",
                "dyo": "dyo_Latn_SN",
                "dyu": "dyu_Latn_BF",
                "dz": "dz_Tibt_BT",
                "ebu": "ebu_Latn_KE",
                "ee": "ee_Latn_GH",
                "efi": "efi_Latn_NG",
                "el": "el_Grek_GR",
                "en": "en_Latn_US",
                "eo": "eo_Latn_001",
                "es": "es_Latn_ES",
                "et": "et_Latn_EE",
                "eu": "eu_Latn_ES",
                "ewo": "ewo_Latn_CM",
                "fa": "fa_Arab_IR",
                "fan": "fan_Latn_GQ",
                "ff": "ff_Latn_SN",
                "fi": "fi_Latn_FI",
                "fil": "fil_Latn_PH",
                "fj": "fj_Latn_FJ",
                "fo": "fo_Latn_FO",
                "fon": "fon_Latn_BJ",
                "fr": "fr_Latn_FR",
                "fur": "fur_Latn_IT",
                "fy": "fy_Latn_NL",
                "ga": "ga_Latn_IE",
                "gaa": "gaa_Latn_GH",
                "gag": "gag_Latn_MD",
                "gbm": "gbm_Deva_IN",
                "gcr": "gcr_Latn_GF",
                "gd": "gd_Latn_GB",
                "gez": "gez_Ethi_ET",
                "gil": "gil_Latn_KI",
                "gl": "gl_Latn_ES",
                "gn": "gn_Latn_PY",
                "gon": "gon_Telu_IN",
                "gor": "gor_Latn_ID",
                "grt": "grt_Beng_IN",
                "gsw": "gsw_Latn_CH",
                "gu": "gu_Gujr_IN",
                "guz": "guz_Latn_KE",
                "gv": "gv_Latn_IM",
                "gwi": "gwi_Latn_CA",
                "ha": "ha_Latn_NG",
                "ha_CM": "ha_Arab_CM",
                "ha_SD": "ha_Arab_SD",
                "haw": "haw_Latn_US",
                "he": "he_Hebr_IL",
                "hi": "hi_Deva_IN",
                "hil": "hil_Latn_PH",
                "hne": "hne_Deva_IN",
                "hnn": "hnn_Latn_PH",
                "ho": "ho_Latn_PG",
                "hoc": "hoc_Deva_IN",
                "hoj": "hoj_Deva_IN",
                "hr": "hr_Latn_HR",
                "ht": "ht_Latn_HT",
                "hu": "hu_Latn_HU",
                "hy": "hy_Armn_AM",
                "ia": "ia_Latn_FR",
                "ibb": "ibb_Latn_NG",
                "id": "id_Latn_ID",
                "ig": "ig_Latn_NG",
                "ii": "ii_Yiii_CN",
                "ik": "ik_Latn_US",
                "ilo": "ilo_Latn_PH",
                "in": "in_Latn_ID",
                "inh": "inh_Cyrl_RU",
                "is": "is_Latn_IS",
                "it": "it_Latn_IT",
                "iu": "iu_Cans_CA",
                "iw": "iw_Hebr_IL",
                "ja": "ja_Jpan_JP",
                "jgo": "jgo_Latn_CM",
                "ji": "ji_Hebr_UA",
                "jmc": "jmc_Latn_TZ",
                "jv": "jv_Latn_ID",
                "jw": "jw_Latn_ID",
                "ka": "ka_Geor_GE",
                "kaa": "kaa_Cyrl_UZ",
                "kab": "kab_Latn_DZ",
                "kaj": "kaj_Latn_NG",
                "kam": "kam_Latn_KE",
                "kbd": "kbd_Cyrl_RU",
                "kcg": "kcg_Latn_NG",
                "kde": "kde_Latn_TZ",
                "kdt": "kdt_Thai_TH",
                "kea": "kea_Latn_CV",
                "ken": "ken_Latn_CM",
                "kfo": "kfo_Latn_CI",
                "kfr": "kfr_Deva_IN",
                "kg": "kg_Latn_CD",
                "kha": "kha_Latn_IN",
                "khb": "khb_Talu_CN",
                "khq": "khq_Latn_ML",
                "kht": "kht_Mymr_IN",
                "ki": "ki_Latn_KE",
                "kj": "kj_Latn_NA",
                "kk": "kk_Cyrl_KZ",
                "kk_AF": "kk_Arab_AF",
                "kk_Arab": "kk_Arab_CN",
                "kk_CN": "kk_Arab_CN",
                "kk_IR": "kk_Arab_IR",
                "kk_MN": "kk_Arab_MN",
                "kkj": "kkj_Latn_CM",
                "kl": "kl_Latn_GL",
                "kln": "kln_Latn_KE",
                "km": "km_Khmr_KH",
                "kmb": "kmb_Latn_AO",
                "kn": "kn_Knda_IN",
                "ko": "ko_Kore_KR",
                "koi": "koi_Cyrl_RU",
                "kok": "kok_Deva_IN",
                "kos": "kos_Latn_FM",
                "kpe": "kpe_Latn_LR",
                "krc": "krc_Cyrl_RU",
                "kri": "kri_Latn_SL",
                "krl": "krl_Latn_RU",
                "kru": "kru_Deva_IN",
                "ks": "ks_Arab_IN",
                "ksb": "ksb_Latn_TZ",
                "ksf": "ksf_Latn_CM",
                "ksh": "ksh_Latn_DE",
                "ku": "ku_Latn_TR",
                "ku_Arab": "ku_Arab_IQ",
                "ku_LB": "ku_Arab_LB",
                "kum": "kum_Cyrl_RU",
                "kv": "kv_Cyrl_RU",
                "kw": "kw_Latn_GB",
                "ky": "ky_Cyrl_KG",
                "ky_Arab": "ky_Arab_CN",
                "ky_CN": "ky_Arab_CN",
                "ky_Latn": "ky_Latn_TR",
                "ky_TR": "ky_Latn_TR",
                "la": "la_Latn_VA",
                "lag": "lag_Latn_TZ",
                "lah": "lah_Arab_PK",
                "lb": "lb_Latn_LU",
                "lbe": "lbe_Cyrl_RU",
                "lcp": "lcp_Thai_CN",
                "lep": "lep_Lepc_IN",
                "lez": "lez_Cyrl_RU",
                "lg": "lg_Latn_UG",
                "li": "li_Latn_NL",
                "lif": "lif_Deva_NP",
                "lis": "lis_Lisu_CN",
                "lki": "lki_Arab_IR",
                "lkt": "lkt_Latn_US",
                "lmn": "lmn_Telu_IN",
                "ln": "ln_Latn_CD",
                "lo": "lo_Laoo_LA",
                "lol": "lol_Latn_CD",
                "lt": "lt_Latn_LT",
                "lu": "lu_Latn_CD",
                "lua": "lua_Latn_CD",
                "luo": "luo_Latn_KE",
                "luy": "luy_Latn_KE",
                "lv": "lv_Latn_LV",
                "lwl": "lwl_Thai_TH",
                "mad": "mad_Latn_ID",
                "mag": "mag_Deva_IN",
                "mai": "mai_Deva_IN",
                "mak": "mak_Latn_ID",
                "man": "man_Latn_GM",
                "man_GN": "man_Nkoo_GN",
                "man_Nkoo": "man_Nkoo_GN",
                "mas": "mas_Latn_KE",
                "mdf": "mdf_Cyrl_RU",
                "mdh": "mdh_Latn_PH",
                "mdr": "mdr_Latn_ID",
                "men": "men_Latn_SL",
                "mer": "mer_Latn_KE",
                "mfe": "mfe_Latn_MU",
                "mg": "mg_Latn_MG",
                "mgh": "mgh_Latn_MZ",
                "mgo": "mgo_Latn_CM",
                "mh": "mh_Latn_MH",
                "mi": "mi_Latn_NZ",
                "min": "min_Latn_ID",
                "mk": "mk_Cyrl_MK",
                "ml": "ml_Mlym_IN",
                "mn": "mn_Cyrl_MN",
                "mn_CN": "mn_Mong_CN",
                "mn_Mong": "mn_Mong_CN",
                "mni": "mni_Beng_IN",
                "mnw": "mnw_Mymr_MM",
                "mo": "mo_Latn_RO",
                "mos": "mos_Latn_BF",
                "mr": "mr_Deva_IN",
                "ms": "ms_Latn_MY",
                "ms_CC": "ms_Arab_CC",
                "ms_ID": "ms_Arab_ID",
                "mt": "mt_Latn_MT",
                "mua": "mua_Latn_CM",
                "mwr": "mwr_Deva_IN",
                "my": "my_Mymr_MM",
                "myv": "myv_Cyrl_RU",
                "na": "na_Latn_NR",
                "nap": "nap_Latn_IT",
                "naq": "naq_Latn_NA",
                "nb": "nb_Latn_NO",
                "nd": "nd_Latn_ZW",
                "nds": "nds_Latn_DE",
                "ne": "ne_Deva_NP",
                "new": "new_Deva_NP",
                "ng": "ng_Latn_NA",
                "niu": "niu_Latn_NU",
                "nl": "nl_Latn_NL",
                "nmg": "nmg_Latn_CM",
                "nn": "nn_Latn_NO",
                "nnh": "nnh_Latn_CM",
                "no": "no_Latn_NO",
                "nod": "nod_Lana_TH",
                "nr": "nr_Latn_ZA",
                "nso": "nso_Latn_ZA",
                "nus": "nus_Latn_SD",
                "nv": "nv_Latn_US",
                "ny": "ny_Latn_MW",
                "nym": "nym_Latn_TZ",
                "nyn": "nyn_Latn_UG",
                "oc": "oc_Latn_FR",
                "om": "om_Latn_ET",
                "or": "or_Orya_IN",
                "os": "os_Cyrl_GE",
                "pa": "pa_Guru_IN",
                "pa_Arab": "pa_Arab_PK",
                "pa_PK": "pa_Arab_PK",
                "pag": "pag_Latn_PH",
                "pam": "pam_Latn_PH",
                "pap": "pap_Latn_AW",
                "pau": "pau_Latn_PW",
                "pl": "pl_Latn_PL",
                "pon": "pon_Latn_FM",
                "prd": "prd_Arab_IR",
                "ps": "ps_Arab_AF",
                "pt": "pt_Latn_BR",
                "qu": "qu_Latn_PE",
                "raj": "raj_Latn_IN",
                "rcf": "rcf_Latn_RE",
                "rej": "rej_Latn_ID",
                "rjs": "rjs_Deva_NP",
                "rkt": "rkt_Beng_BD",
                "rm": "rm_Latn_CH",
                "rn": "rn_Latn_BI",
                "ro": "ro_Latn_RO",
                "rof": "rof_Latn_TZ",
                "ru": "ru_Cyrl_RU",
                "rw": "rw_Latn_RW",
                "rwk": "rwk_Latn_TZ",
                "sa": "sa_Deva_IN",
                "saf": "saf_Latn_GH",
                "sah": "sah_Cyrl_RU",
                "saq": "saq_Latn_KE",
                "sas": "sas_Latn_ID",
                "sat": "sat_Latn_IN",
                "saz": "saz_Saur_IN",
                "sbp": "sbp_Latn_TZ",
                "scn": "scn_Latn_IT",
                "sco": "sco_Latn_GB",
                "sd": "sd_Arab_PK",
                "sd_Deva": "sd_Deva_IN",
                "sdh": "sdh_Arab_IR",
                "se": "se_Latn_NO",
                "seh": "seh_Latn_MZ",
                "ses": "ses_Latn_ML",
                "sg": "sg_Latn_CF",
                "shi": "shi_Tfng_MA",
                "shn": "shn_Mymr_MM",
                "si": "si_Sinh_LK",
                "sid": "sid_Latn_ET",
                "sk": "sk_Latn_SK",
                "sl": "sl_Latn_SI",
                "sm": "sm_Latn_WS",
                "sma": "sma_Latn_SE",
                "smj": "smj_Latn_SE",
                "smn": "smn_Latn_FI",
                "sms": "sms_Latn_FI",
                "sn": "sn_Latn_ZW",
                "snk": "snk_Latn_ML",
                "so": "so_Latn_SO",
                "sq": "sq_Latn_AL",
                "sr": "sr_Cyrl_RS",
                "sr_ME": "sr_Latn_ME",
                "sr_RO": "sr_Latn_RO",
                "sr_RU": "sr_Latn_RU",
                "sr_TR": "sr_Latn_TR",
                "srn": "srn_Latn_SR",
                "srr": "srr_Latn_SN",
                "ss": "ss_Latn_ZA",
                "ssy": "ssy_Latn_ER",
                "st": "st_Latn_ZA",
                "su": "su_Latn_ID",
                "suk": "suk_Latn_TZ",
                "sus": "sus_Latn_GN",
                "sv": "sv_Latn_SE",
                "sw": "sw_Latn_TZ",
                "swb": "swb_Arab_YT",
                "swc": "swc_Latn_CD",
                "syl": "syl_Beng_BD",
                "syr": "syr_Syrc_IQ",
                "ta": "ta_Taml_IN",
                "tbw": "tbw_Latn_PH",
                "tcy": "tcy_Knda_IN",
                "tdd": "tdd_Tale_CN",
                "te": "te_Telu_IN",
                "tem": "tem_Latn_SL",
                "teo": "teo_Latn_UG",
                "tet": "tet_Latn_TL",
                "tg": "tg_Cyrl_TJ",
                "tg_Arab": "tg_Arab_PK",
                "tg_PK": "tg_Arab_PK",
                "th": "th_Thai_TH",
                "ti": "ti_Ethi_ET",
                "tig": "tig_Ethi_ER",
                "tiv": "tiv_Latn_NG",
                "tk": "tk_Latn_TM",
                "tkl": "tkl_Latn_TK",
                "tl": "tl_Latn_PH",
                "tmh": "tmh_Latn_NE",
                "tn": "tn_Latn_ZA",
                "to": "to_Latn_TO",
                "tpi": "tpi_Latn_PG",
                "tr": "tr_Latn_TR",
                "trv": "trv_Latn_TW",
                "ts": "ts_Latn_ZA",
                "tsg": "tsg_Latn_PH",
                "tt": "tt_Cyrl_RU",
                "tts": "tts_Thai_TH",
                "tum": "tum_Latn_MW",
                "tvl": "tvl_Latn_TV",
                "twq": "twq_Latn_NE",
                "ty": "ty_Latn_PF",
                "tyv": "tyv_Cyrl_RU",
                "tzm": "tzm_Latn_MA",
                "udm": "udm_Cyrl_RU",
                "ug": "ug_Arab_CN",
                "ug_Cyrl": "ug_Cyrl_KZ",
                "ug_KZ": "ug_Cyrl_KZ",
                "ug_MN": "ug_Cyrl_MN",
                "uk": "uk_Cyrl_UA",
                "uli": "uli_Latn_FM",
                "umb": "umb_Latn_AO",
                "und": "en_Latn_US",
                "und_AD": "ca_Latn_AD",
                "und_AE": "ar_Arab_AE",
                "und_AF": "fa_Arab_AF",
                "und_AL": "sq_Latn_AL",
                "und_AM": "hy_Armn_AM",
                "und_AO": "pt_Latn_AO",
                "und_AQ": "und_Latn_AQ",
                "und_AR": "es_Latn_AR",
                "und_Arab": "ar_Arab_EG",
                "und_Arab_CC": "ms_Arab_CC",
                "und_Arab_CN": "ug_Arab_CN",
                "und_Arab_GB": "ks_Arab_GB",
                "und_Arab_ID": "ms_Arab_ID",
                "und_Arab_IN": "ur_Arab_IN",
                "und_Arab_KH": "cja_Arab_KH",
                "und_Arab_MN": "kk_Arab_MN",
                "und_Arab_MU": "ur_Arab_MU",
                "und_Arab_NG": "ha_Arab_NG",
                "und_Arab_PK": "ur_Arab_PK",
                "und_Arab_TJ": "fa_Arab_TJ",
                "und_Arab_TR": "zza_Arab_TR",
                "und_Arab_YT": "swb_Arab_YT",
                "und_Armi": "arc_Armi_IR",
                "und_Armn": "hy_Armn_AM",
                "und_AS": "sm_Latn_AS",
                "und_AT": "de_Latn_AT",
                "und_Avst": "ae_Avst_IR",
                "und_AW": "nl_Latn_AW",
                "und_AX": "sv_Latn_AX",
                "und_AZ": "az_Latn_AZ",
                "und_BA": "bs_Latn_BA",
                "und_Bali": "ban_Bali_ID",
                "und_Bamu": "bax_Bamu_CM",
                "und_Batk": "bbc_Batk_ID",
                "und_BD": "bn_Beng_BD",
                "und_BE": "nl_Latn_BE",
                "und_Beng": "bn_Beng_BD",
                "und_BF": "fr_Latn_BF",
                "und_BG": "bg_Cyrl_BG",
                "und_BH": "ar_Arab_BH",
                "und_BI": "rn_Latn_BI",
                "und_BJ": "fr_Latn_BJ",
                "und_BL": "fr_Latn_BL",
                "und_BN": "ms_Latn_BN",
                "und_BO": "es_Latn_BO",
                "und_Bopo": "zh_Bopo_TW",
                "und_BQ": "pap_Latn_BQ",
                "und_BR": "pt_Latn_BR",
                "und_Brah": "pra_Brah_IN",
                "und_Brai": "und_Brai_FR",
                "und_BT": "dz_Tibt_BT",
                "und_Bugi": "bug_Bugi_ID",
                "und_Buhd": "bku_Buhd_PH",
                "und_BV": "und_Latn_BV",
                "und_BY": "be_Cyrl_BY",
                "und_Cakm": "ccp_Cakm_BD",
                "und_Cans": "cr_Cans_CA",
                "und_Cari": "xcr_Cari_TR",
                "und_CD": "sw_Latn_CD",
                "und_CF": "fr_Latn_CF",
                "und_CG": "fr_Latn_CG",
                "und_CH": "de_Latn_CH",
                "und_Cham": "cjm_Cham_VN",
                "und_Cher": "chr_Cher_US",
                "und_CI": "fr_Latn_CI",
                "und_CL": "es_Latn_CL",
                "und_CM": "fr_Latn_CM",
                "und_CN": "zh_Hans_CN",
                "und_CO": "es_Latn_CO",
                "und_Copt": "cop_Copt_EG",
                "und_CP": "und_Latn_CP",
                "und_Cprt": "grc_Cprt_CY",
                "und_CR": "es_Latn_CR",
                "und_CU": "es_Latn_CU",
                "und_CV": "pt_Latn_CV",
                "und_CW": "pap_Latn_CW",
                "und_CY": "el_Grek_CY",
                "und_Cyrl": "ru_Cyrl_RU",
                "und_Cyrl_AL": "mk_Cyrl_AL",
                "und_Cyrl_BA": "sr_Cyrl_BA",
                "und_Cyrl_GE": "ab_Cyrl_GE",
                "und_Cyrl_GR": "mk_Cyrl_GR",
                "und_Cyrl_MD": "uk_Cyrl_MD",
                "und_Cyrl_PL": "be_Cyrl_PL",
                "und_Cyrl_RO": "bg_Cyrl_RO",
                "und_Cyrl_SK": "uk_Cyrl_SK",
                "und_Cyrl_TR": "kbd_Cyrl_TR",
                "und_Cyrl_XK": "sr_Cyrl_XK",
                "und_CZ": "cs_Latn_CZ",
                "und_DE": "de_Latn_DE",
                "und_Deva": "hi_Deva_IN",
                "und_Deva_BT": "ne_Deva_BT",
                "und_Deva_MU": "bho_Deva_MU",
                "und_Deva_PK": "btv_Deva_PK",
                "und_DJ": "aa_Latn_DJ",
                "und_DK": "da_Latn_DK",
                "und_DO": "es_Latn_DO",
                "und_DZ": "ar_Arab_DZ",
                "und_EA": "es_Latn_EA",
                "und_EC": "es_Latn_EC",
                "und_EE": "et_Latn_EE",
                "und_EG": "ar_Arab_EG",
                "und_Egyp": "egy_Egyp_EG",
                "und_EH": "ar_Arab_EH",
                "und_ER": "ti_Ethi_ER",
                "und_ES": "es_Latn_ES",
                "und_ET": "am_Ethi_ET",
                "und_Ethi": "am_Ethi_ET",
                "und_FI": "fi_Latn_FI",
                "und_FM": "chk_Latn_FM",
                "und_FO": "fo_Latn_FO",
                "und_FR": "fr_Latn_FR",
                "und_GA": "fr_Latn_GA",
                "und_GE": "ka_Geor_GE",
                "und_Geor": "ka_Geor_GE",
                "und_GF": "fr_Latn_GF",
                "und_GH": "ak_Latn_GH",
                "und_GL": "kl_Latn_GL",
                "und_Glag": "cu_Glag_BG",
                "und_GN": "fr_Latn_GN",
                "und_Goth": "got_Goth_UA",
                "und_GP": "fr_Latn_GP",
                "und_GQ": "es_Latn_GQ",
                "und_GR": "el_Grek_GR",
                "und_Grek": "el_Grek_GR",
                "und_GS": "und_Latn_GS",
                "und_GT": "es_Latn_GT",
                "und_Gujr": "gu_Gujr_IN",
                "und_Guru": "pa_Guru_IN",
                "und_GW": "pt_Latn_GW",
                "und_Hang": "ko_Hang_KR",
                "und_Hani": "zh_Hani_CN",
                "und_Hano": "hnn_Hano_PH",
                "und_Hans": "zh_Hans_CN",
                "und_Hant": "zh_Hant_TW",
                "und_Hebr": "he_Hebr_IL",
                "und_Hebr_CA": "yi_Hebr_CA",
                "und_Hebr_GB": "yi_Hebr_GB",
                "und_Hebr_SE": "yi_Hebr_SE",
                "und_Hebr_UA": "yi_Hebr_UA",
                "und_Hebr_US": "yi_Hebr_US",
                "und_Hira": "ja_Hira_JP",
                "und_HK": "zh_Hant_HK",
                "und_HM": "und_Latn_HM",
                "und_HN": "es_Latn_HN",
                "und_HR": "hr_Latn_HR",
                "und_HT": "ht_Latn_HT",
                "und_HU": "hu_Latn_HU",
                "und_IC": "es_Latn_IC",
                "und_ID": "id_Latn_ID",
                "und_IL": "he_Hebr_IL",
                "und_IN": "hi_Deva_IN",
                "und_IQ": "ar_Arab_IQ",
                "und_IR": "fa_Arab_IR",
                "und_IS": "is_Latn_IS",
                "und_IT": "it_Latn_IT",
                "und_Ital": "ett_Ital_IT",
                "und_Java": "jv_Java_ID",
                "und_JO": "ar_Arab_JO",
                "und_JP": "ja_Jpan_JP",
                "und_Jpan": "ja_Jpan_JP",
                "und_Kali": "eky_Kali_MM",
                "und_Kana": "ja_Kana_JP",
                "und_KG": "ky_Cyrl_KG",
                "und_KH": "km_Khmr_KH",
                "und_Khar": "pra_Khar_PK",
                "und_Khmr": "km_Khmr_KH",
                "und_KM": "ar_Arab_KM",
                "und_Knda": "kn_Knda_IN",
                "und_Kore": "ko_Kore_KR",
                "und_KP": "ko_Kore_KP",
                "und_KR": "ko_Kore_KR",
                "und_Kthi": "bh_Kthi_IN",
                "und_KW": "ar_Arab_KW",
                "und_KZ": "ru_Cyrl_KZ",
                "und_LA": "lo_Laoo_LA",
                "und_Lana": "nod_Lana_TH",
                "und_Laoo": "lo_Laoo_LA",
                "und_Latn_AF": "tk_Latn_AF",
                "und_Latn_AM": "az_Latn_AM",
                "und_Latn_BG": "tr_Latn_BG",
                "und_Latn_CN": "za_Latn_CN",
                "und_Latn_CY": "tr_Latn_CY",
                "und_Latn_DZ": "fr_Latn_DZ",
                "und_Latn_ET": "en_Latn_ET",
                "und_Latn_GE": "ku_Latn_GE",
                "und_Latn_GR": "tr_Latn_GR",
                "und_Latn_IL": "ro_Latn_IL",
                "und_Latn_IR": "tk_Latn_IR",
                "und_Latn_KM": "fr_Latn_KM",
                "und_Latn_KZ": "de_Latn_KZ",
                "und_Latn_LB": "fr_Latn_LB",
                "und_Latn_MA": "fr_Latn_MA",
                "und_Latn_MK": "sq_Latn_MK",
                "und_Latn_MO": "pt_Latn_MO",
                "und_Latn_MR": "fr_Latn_MR",
                "und_Latn_RU": "krl_Latn_RU",
                "und_Latn_SY": "fr_Latn_SY",
                "und_Latn_TN": "fr_Latn_TN",
                "und_Latn_TW": "trv_Latn_TW",
                "und_Latn_UA": "pl_Latn_UA",
                "und_LB": "ar_Arab_LB",
                "und_Lepc": "lep_Lepc_IN",
                "und_LI": "de_Latn_LI",
                "und_Limb": "lif_Limb_IN",
                "und_Linb": "grc_Linb_GR",
                "und_Lisu": "lis_Lisu_CN",
                "und_LK": "si_Sinh_LK",
                "und_LS": "st_Latn_LS",
                "und_LT": "lt_Latn_LT",
                "und_LU": "fr_Latn_LU",
                "und_LV": "lv_Latn_LV",
                "und_LY": "ar_Arab_LY",
                "und_Lyci": "xlc_Lyci_TR",
                "und_Lydi": "xld_Lydi_TR",
                "und_MA": "ar_Arab_MA",
                "und_Mand": "myz_Mand_IR",
                "und_MC": "fr_Latn_MC",
                "und_MD": "ro_Latn_MD",
                "und_ME": "sr_Latn_ME",
                "und_Merc": "xmr_Merc_SD",
                "und_Mero": "xmr_Mero_SD",
                "und_MF": "fr_Latn_MF",
                "und_MG": "mg_Latn_MG",
                "und_MK": "mk_Cyrl_MK",
                "und_ML": "bm_Latn_ML",
                "und_Mlym": "ml_Mlym_IN",
                "und_MM": "my_Mymr_MM",
                "und_MN": "mn_Cyrl_MN",
                "und_MO": "zh_Hant_MO",
                "und_Mong": "mn_Mong_CN",
                "und_MQ": "fr_Latn_MQ",
                "und_MR": "ar_Arab_MR",
                "und_MT": "mt_Latn_MT",
                "und_Mtei": "mni_Mtei_IN",
                "und_MU": "mfe_Latn_MU",
                "und_MV": "dv_Thaa_MV",
                "und_MX": "es_Latn_MX",
                "und_MY": "ms_Latn_MY",
                "und_Mymr": "my_Mymr_MM",
                "und_Mymr_IN": "kht_Mymr_IN",
                "und_Mymr_TH": "mnw_Mymr_TH",
                "und_MZ": "pt_Latn_MZ",
                "und_NA": "af_Latn_NA",
                "und_NC": "fr_Latn_NC",
                "und_NE": "ha_Latn_NE",
                "und_NI": "es_Latn_NI",
                "und_Nkoo": "man_Nkoo_GN",
                "und_NL": "nl_Latn_NL",
                "und_NO": "nb_Latn_NO",
                "und_NP": "ne_Deva_NP",
                "und_Ogam": "sga_Ogam_IE",
                "und_Olck": "sat_Olck_IN",
                "und_OM": "ar_Arab_OM",
                "und_Orkh": "otk_Orkh_MN",
                "und_Orya": "or_Orya_IN",
                "und_Osma": "so_Osma_SO",
                "und_PA": "es_Latn_PA",
                "und_PE": "es_Latn_PE",
                "und_PF": "fr_Latn_PF",
                "und_PG": "tpi_Latn_PG",
                "und_PH": "fil_Latn_PH",
                "und_Phag": "lzh_Phag_CN",
                "und_Phli": "pal_Phli_IR",
                "und_Phnx": "phn_Phnx_LB",
                "und_PK": "ur_Arab_PK",
                "und_PL": "pl_Latn_PL",
                "und_Plrd": "hmd_Plrd_CN",
                "und_PM": "fr_Latn_PM",
                "und_PR": "es_Latn_PR",
                "und_Prti": "xpr_Prti_IR",
                "und_PS": "ar_Arab_PS",
                "und_PT": "pt_Latn_PT",
                "und_PW": "pau_Latn_PW",
                "und_PY": "gn_Latn_PY",
                "und_QA": "ar_Arab_QA",
                "und_RE": "fr_Latn_RE",
                "und_Rjng": "rej_Rjng_ID",
                "und_RO": "ro_Latn_RO",
                "und_RS": "sr_Cyrl_RS",
                "und_RU": "ru_Cyrl_RU",
                "und_Runr": "non_Runr_SE",
                "und_RW": "rw_Latn_RW",
                "und_SA": "ar_Arab_SA",
                "und_Samr": "smp_Samr_IL",
                "und_Sarb": "xsa_Sarb_YE",
                "und_Saur": "saz_Saur_IN",
                "und_SC": "fr_Latn_SC",
                "und_SD": "ar_Arab_SD",
                "und_SE": "sv_Latn_SE",
                "und_Shaw": "en_Shaw_GB",
                "und_Shrd": "sa_Shrd_IN",
                "und_SI": "sl_Latn_SI",
                "und_Sinh": "si_Sinh_LK",
                "und_SJ": "nb_Latn_SJ",
                "und_SK": "sk_Latn_SK",
                "und_SM": "it_Latn_SM",
                "und_SN": "fr_Latn_SN",
                "und_SO": "so_Latn_SO",
                "und_Sora": "srb_Sora_IN",
                "und_SR": "nl_Latn_SR",
                "und_ST": "pt_Latn_ST",
                "und_Sund": "su_Sund_ID",
                "und_SV": "es_Latn_SV",
                "und_SY": "ar_Arab_SY",
                "und_Sylo": "syl_Sylo_BD",
                "und_Syrc": "syr_Syrc_IQ",
                "und_Tagb": "tbw_Tagb_PH",
                "und_Takr": "doi_Takr_IN",
                "und_Tale": "tdd_Tale_CN",
                "und_Talu": "khb_Talu_CN",
                "und_Taml": "ta_Taml_IN",
                "und_Tavt": "blt_Tavt_VN",
                "und_TD": "fr_Latn_TD",
                "und_Telu": "te_Telu_IN",
                "und_TF": "fr_Latn_TF",
                "und_Tfng": "zgh_Tfng_MA",
                "und_TG": "fr_Latn_TG",
                "und_Tglg": "fil_Tglg_PH",
                "und_TH": "th_Thai_TH",
                "und_Thaa": "dv_Thaa_MV",
                "und_Thai": "th_Thai_TH",
                "und_Thai_CN": "lcp_Thai_CN",
                "und_Thai_KH": "kdt_Thai_KH",
                "und_Thai_LA": "kdt_Thai_LA",
                "und_Tibt": "bo_Tibt_CN",
                "und_TJ": "tg_Cyrl_TJ",
                "und_TK": "tkl_Latn_TK",
                "und_TL": "pt_Latn_TL",
                "und_TM": "tk_Latn_TM",
                "und_TN": "ar_Arab_TN",
                "und_TO": "to_Latn_TO",
                "und_TR": "tr_Latn_TR",
                "und_TV": "tvl_Latn_TV",
                "und_TW": "zh_Hant_TW",
                "und_TZ": "sw_Latn_TZ",
                "und_UA": "uk_Cyrl_UA",
                "und_UG": "sw_Latn_UG",
                "und_Ugar": "uga_Ugar_SY",
                "und_UY": "es_Latn_UY",
                "und_UZ": "uz_Latn_UZ",
                "und_VA": "la_Latn_VA",
                "und_Vaii": "vai_Vaii_LR",
                "und_VE": "es_Latn_VE",
                "und_VN": "vi_Latn_VN",
                "und_VU": "bi_Latn_VU",
                "und_WF": "fr_Latn_WF",
                "und_WS": "sm_Latn_WS",
                "und_XK": "sq_Latn_XK",
                "und_Xpeo": "peo_Xpeo_IR",
                "und_Xsux": "akk_Xsux_IQ",
                "und_YE": "ar_Arab_YE",
                "und_Yiii": "ii_Yiii_CN",
                "und_YT": "fr_Latn_YT",
                "unr": "unr_Beng_IN",
                "unr_Deva": "unr_Deva_NP",
                "unr_NP": "unr_Deva_NP",
                "unx": "unx_Beng_IN",
                "ur": "ur_Arab_PK",
                "uz": "uz_Latn_UZ",
                "uz_AF": "uz_Arab_AF",
                "uz_Arab": "uz_Arab_AF",
                "uz_CN": "uz_Cyrl_CN",
                "vai": "vai_Vaii_LR",
                "ve": "ve_Latn_ZA",
                "vi": "vi_Latn_VN",
                "vo": "vo_Latn_001",
                "vun": "vun_Latn_TZ",
                "wa": "wa_Latn_BE",
                "wae": "wae_Latn_CH",
                "wal": "wal_Ethi_ET",
                "war": "war_Latn_PH",
                "wo": "wo_Latn_SN",
                "xh": "xh_Latn_ZA",
                "xog": "xog_Latn_UG",
                "xsr": "xsr_Deva_NP",
                "yao": "yao_Latn_MZ",
                "yap": "yap_Latn_FM",
                "yav": "yav_Latn_CM",
                "yi": "yi_Hebr_UA",
                "yo": "yo_Latn_NG",
                "za": "za_Latn_CN",
                "zgh": "zgh_Tfng_MA",
                "zh": "zh_Hans_CN",
                "zh_AU": "zh_Hant_AU",
                "zh_BN": "zh_Hant_BN",
                "zh_GB": "zh_Hant_GB",
                "zh_GF": "zh_Hant_GF",
                "zh_Hant": "zh_Hant_TW",
                "zh_HK": "zh_Hant_HK",
                "zh_ID": "zh_Hant_ID",
                "zh_MO": "zh_Hant_MO",
                "zh_MY": "zh_Hant_MY",
                "zh_PA": "zh_Hant_PA",
                "zh_PF": "zh_Hant_PF",
                "zh_PH": "zh_Hant_PH",
                "zh_SR": "zh_Hant_SR",
                "zh_TH": "zh_Hant_TH",
                "zh_TW": "zh_Hant_TW",
                "zh_US": "zh_Hant_US",
                "zh_VN": "zh_Hant_VN",
                "zu": "zu_Latn_ZA",
                "zza": "zza_Arab_TR"
            },
            "timeData": {
                "001": {
                    "_allowed": "H h",
                    "_preferred": "H"
                },
                "AD": {
                    "_allowed": "H",
                    "_preferred": "H"
                },
                "AE": {
                    "_allowed": "H h",
                    "_preferred": "h"
                },
                "AG": {
                    "_allowed": "H h",
                    "_preferred": "h"
                },
                "AL": {
                    "_allowed": "H h",
                    "_preferred": "h"
                },
                "AM": {
                    "_allowed": "H",
                    "_preferred": "H"
                },
                "AO": {
                    "_allowed": "H",
                    "_preferred": "H"
                },
                "AS": {
                    "_allowed": "H h",
                    "_preferred": "h"
                },
                "AT": {
                    "_allowed": "H",
                    "_preferred": "H"
                },
                "AU": {
                    "_allowed": "H h",
                    "_preferred": "h"
                },
                "AW": {
                    "_allowed": "H",
                    "_preferred": "H"
                },
                "AX": {
                    "_allowed": "H",
                    "_preferred": "H"
                },
                "BB": {
                    "_allowed": "H h",
                    "_preferred": "h"
                },
                "BD": {
                    "_allowed": "H h",
                    "_preferred": "h"
                },
                "BE": {
                    "_allowed": "H",
                    "_preferred": "H"
                },
                "BF": {
                    "_allowed": "H",
                    "_preferred": "H"
                },
                "BH": {
                    "_allowed": "H h",
                    "_preferred": "h"
                },
                "BJ": {
                    "_allowed": "H",
                    "_preferred": "H"
                },
                "BL": {
                    "_allowed": "H",
                    "_preferred": "H"
                },
                "BM": {
                    "_allowed": "H h",
                    "_preferred": "h"
                },
                "BN": {
                    "_allowed": "H h",
                    "_preferred": "h"
                },
                "BR": {
                    "_allowed": "H",
                    "_preferred": "H"
                },
                "BS": {
                    "_allowed": "H h",
                    "_preferred": "h"
                },
                "BT": {
                    "_allowed": "H h",
                    "_preferred": "h"
                },
                "BW": {
                    "_allowed": "H h",
                    "_preferred": "h"
                },
                "CA": {
                    "_allowed": "H h",
                    "_preferred": "h"
                },
                "CD": {
                    "_allowed": "H",
                    "_preferred": "H"
                },
                "CI": {
                    "_allowed": "H",
                    "_preferred": "H"
                },
                "CN": {
                    "_allowed": "H h",
                    "_preferred": "h"
                },
                "CO": {
                    "_allowed": "H h",
                    "_preferred": "h"
                },
                "CP": {
                    "_allowed": "H",
                    "_preferred": "H"
                },
                "CV": {
                    "_allowed": "H",
                    "_preferred": "H"
                },
                "CY": {
                    "_allowed": "H h",
                    "_preferred": "h"
                },
                "CZ": {
                    "_allowed": "H",
                    "_preferred": "H"
                },
                "DE": {
                    "_allowed": "H",
                    "_preferred": "H"
                },
                "DJ": {
                    "_allowed": "H h",
                    "_preferred": "h"
                },
                "DK": {
                    "_allowed": "H",
                    "_preferred": "H"
                },
                "DM": {
                    "_allowed": "H h",
                    "_preferred": "h"
                },
                "DZ": {
                    "_allowed": "H h",
                    "_preferred": "h"
                },
                "EE": {
                    "_allowed": "H",
                    "_preferred": "H"
                },
                "EG": {
                    "_allowed": "H h",
                    "_preferred": "h"
                },
                "EH": {
                    "_allowed": "H h",
                    "_preferred": "h"
                },
                "ER": {
                    "_allowed": "H h",
                    "_preferred": "h"
                },
                "ET": {
                    "_allowed": "H h",
                    "_preferred": "h"
                },
                "FI": {
                    "_allowed": "H",
                    "_preferred": "H"
                },
                "FJ": {
                    "_allowed": "H h",
                    "_preferred": "h"
                },
                "FM": {
                    "_allowed": "H h",
                    "_preferred": "h"
                },
                "FR": {
                    "_allowed": "H",
                    "_preferred": "H"
                },
                "GA": {
                    "_allowed": "H",
                    "_preferred": "H"
                },
                "GD": {
                    "_allowed": "H h",
                    "_preferred": "h"
                },
                "GF": {
                    "_allowed": "H",
                    "_preferred": "H"
                },
                "GH": {
                    "_allowed": "H h",
                    "_preferred": "h"
                },
                "GL": {
                    "_allowed": "H h",
                    "_preferred": "h"
                },
                "GM": {
                    "_allowed": "H h",
                    "_preferred": "h"
                },
                "GN": {
                    "_allowed": "H",
                    "_preferred": "H"
                },
                "GP": {
                    "_allowed": "H",
                    "_preferred": "H"
                },
                "GR": {
                    "_allowed": "H h",
                    "_preferred": "h"
                },
                "GU": {
                    "_allowed": "H h",
                    "_preferred": "h"
                },
                "GW": {
                    "_allowed": "H",
                    "_preferred": "H"
                },
                "GY": {
                    "_allowed": "H h",
                    "_preferred": "h"
                },
                "HK": {
                    "_allowed": "H h",
                    "_preferred": "h"
                },
                "HR": {
                    "_allowed": "H",
                    "_preferred": "H"
                },
                "IL": {
                    "_allowed": "H",
                    "_preferred": "H"
                },
                "IN": {
                    "_allowed": "H h",
                    "_preferred": "h"
                },
                "IQ": {
                    "_allowed": "H h",
                    "_preferred": "h"
                },
                "IS": {
                    "_allowed": "H",
                    "_preferred": "H"
                },
                "IT": {
                    "_allowed": "H",
                    "_preferred": "H"
                },
                "JM": {
                    "_allowed": "H h",
                    "_preferred": "h"
                },
                "JO": {
                    "_allowed": "H h",
                    "_preferred": "h"
                },
                "JP": {
                    "_allowed": "H K h",
                    "_preferred": "H"
                },
                "KH": {
                    "_allowed": "H h",
                    "_preferred": "h"
                },
                "KI": {
                    "_allowed": "H h",
                    "_preferred": "h"
                },
                "KN": {
                    "_allowed": "H h",
                    "_preferred": "h"
                },
                "KP": {
                    "_allowed": "H h",
                    "_preferred": "h"
                },
                "KR": {
                    "_allowed": "H h",
                    "_preferred": "h"
                },
                "KW": {
                    "_allowed": "H h",
                    "_preferred": "h"
                },
                "KY": {
                    "_allowed": "H h",
                    "_preferred": "h"
                },
                "LB": {
                    "_allowed": "H h",
                    "_preferred": "h"
                },
                "LC": {
                    "_allowed": "H h",
                    "_preferred": "h"
                },
                "LR": {
                    "_allowed": "H h",
                    "_preferred": "h"
                },
                "LS": {
                    "_allowed": "H h",
                    "_preferred": "h"
                },
                "LY": {
                    "_allowed": "H h",
                    "_preferred": "h"
                },
                "MA": {
                    "_allowed": "H h",
                    "_preferred": "h"
                },
                "MC": {
                    "_allowed": "H",
                    "_preferred": "H"
                },
                "MD": {
                    "_allowed": "H",
                    "_preferred": "H"
                },
                "MF": {
                    "_allowed": "H",
                    "_preferred": "H"
                },
                "MH": {
                    "_allowed": "H h",
                    "_preferred": "h"
                },
                "ML": {
                    "_allowed": "H",
                    "_preferred": "H"
                },
                "MO": {
                    "_allowed": "H h",
                    "_preferred": "h"
                },
                "MP": {
                    "_allowed": "H h",
                    "_preferred": "h"
                },
                "MQ": {
                    "_allowed": "H",
                    "_preferred": "H"
                },
                "MR": {
                    "_allowed": "H h",
                    "_preferred": "h"
                },
                "MW": {
                    "_allowed": "H h",
                    "_preferred": "h"
                },
                "MY": {
                    "_allowed": "H h",
                    "_preferred": "h"
                },
                "MZ": {
                    "_allowed": "H",
                    "_preferred": "H"
                },
                "NA": {
                    "_allowed": "H h",
                    "_preferred": "h"
                },
                "NC": {
                    "_allowed": "H",
                    "_preferred": "H"
                },
                "NE": {
                    "_allowed": "H",
                    "_preferred": "H"
                },
                "NG": {
                    "_allowed": "H h",
                    "_preferred": "h"
                },
                "NL": {
                    "_allowed": "H",
                    "_preferred": "H"
                },
                "NZ": {
                    "_allowed": "H h",
                    "_preferred": "h"
                },
                "OM": {
                    "_allowed": "H h",
                    "_preferred": "h"
                },
                "PG": {
                    "_allowed": "H h",
                    "_preferred": "h"
                },
                "PK": {
                    "_allowed": "H h",
                    "_preferred": "h"
                },
                "PM": {
                    "_allowed": "H",
                    "_preferred": "H"
                },
                "PR": {
                    "_allowed": "H h",
                    "_preferred": "h"
                },
                "PS": {
                    "_allowed": "H h",
                    "_preferred": "h"
                },
                "PT": {
                    "_allowed": "H",
                    "_preferred": "H"
                },
                "PW": {
                    "_allowed": "H h",
                    "_preferred": "h"
                },
                "QA": {
                    "_allowed": "H h",
                    "_preferred": "h"
                },
                "RE": {
                    "_allowed": "H",
                    "_preferred": "H"
                },
                "RO": {
                    "_allowed": "H",
                    "_preferred": "H"
                },
                "RU": {
                    "_allowed": "H",
                    "_preferred": "H"
                },
                "SA": {
                    "_allowed": "H h",
                    "_preferred": "h"
                },
                "SB": {
                    "_allowed": "H h",
                    "_preferred": "h"
                },
                "SD": {
                    "_allowed": "H h",
                    "_preferred": "h"
                },
                "SE": {
                    "_allowed": "H",
                    "_preferred": "H"
                },
                "SG": {
                    "_allowed": "H h",
                    "_preferred": "h"
                },
                "SI": {
                    "_allowed": "H",
                    "_preferred": "H"
                },
                "SJ": {
                    "_allowed": "H",
                    "_preferred": "H"
                },
                "SK": {
                    "_allowed": "H",
                    "_preferred": "H"
                },
                "SL": {
                    "_allowed": "H h",
                    "_preferred": "h"
                },
                "SM": {
                    "_allowed": "H",
                    "_preferred": "H"
                },
                "SO": {
                    "_allowed": "H h",
                    "_preferred": "h"
                },
                "SR": {
                    "_allowed": "H",
                    "_preferred": "H"
                },
                "SS": {
                    "_allowed": "H h",
                    "_preferred": "h"
                },
                "ST": {
                    "_allowed": "H",
                    "_preferred": "H"
                },
                "SY": {
                    "_allowed": "H h",
                    "_preferred": "h"
                },
                "SZ": {
                    "_allowed": "H h",
                    "_preferred": "h"
                },
                "TC": {
                    "_allowed": "H h",
                    "_preferred": "h"
                },
                "TD": {
                    "_allowed": "H h",
                    "_preferred": "h"
                },
                "TG": {
                    "_allowed": "H",
                    "_preferred": "H"
                },
                "TN": {
                    "_allowed": "H h",
                    "_preferred": "h"
                },
                "TR": {
                    "_allowed": "H",
                    "_preferred": "H"
                },
                "TT": {
                    "_allowed": "H h",
                    "_preferred": "h"
                },
                "TW": {
                    "_allowed": "H h",
                    "_preferred": "h"
                },
                "UM": {
                    "_allowed": "H h",
                    "_preferred": "h"
                },
                "US": {
                    "_allowed": "H h",
                    "_preferred": "h"
                },
                "VC": {
                    "_allowed": "H h",
                    "_preferred": "h"
                },
                "VG": {
                    "_allowed": "H h",
                    "_preferred": "h"
                },
                "VI": {
                    "_allowed": "H h",
                    "_preferred": "h"
                },
                "VU": {
                    "_allowed": "H h",
                    "_preferred": "h"
                },
                "WF": {
                    "_allowed": "H",
                    "_preferred": "H"
                },
                "WS": {
                    "_allowed": "H h",
                    "_preferred": "h"
                },
                "YE": {
                    "_allowed": "H h",
                    "_preferred": "h"
                },
                "YT": {
                    "_allowed": "H",
                    "_preferred": "H"
                },
                "ZA": {
                    "_allowed": "H h",
                    "_preferred": "h"
                },
                "ZM": {
                    "_allowed": "H h",
                    "_preferred": "h"
                },
                "ZW": {
                    "_allowed": "H h",
                    "_preferred": "h"
                }
            },
            "weekData": {
                "minDays": {
                    "001": "1",
                    "AD": "4",
                    "AN": "4",
                    "AT": "4",
                    "AX": "4",
                    "BE": "4",
                    "BG": "4",
                    "CH": "4",
                    "CZ": "4",
                    "DE": "4",
                    "DK": "4",
                    "EE": "4",
                    "ES": "4",
                    "FI": "4",
                    "FJ": "4",
                    "FO": "4",
                    "FR": "4",
                    "GB": "4",
                    "GF": "4",
                    "GG": "4",
                    "GI": "4",
                    "GP": "4",
                    "GR": "4",
                    "GU": "1",
                    "HU": "4",
                    "IE": "4",
                    "IM": "4",
                    "IS": "4",
                    "IT": "4",
                    "JE": "4",
                    "LI": "4",
                    "LT": "4",
                    "LU": "4",
                    "MC": "4",
                    "MQ": "4",
                    "NL": "4",
                    "NO": "4",
                    "PL": "4",
                    "PT": "4",
                    "RE": "4",
                    "SE": "4",
                    "SJ": "4",
                    "SK": "4",
                    "SM": "4",
                    "UM": "1",
                    "US": "1",
                    "VA": "4",
                    "VI": "1"
                },
                "firstDay": {
                    "001": "mon",
                    "AD": "mon",
                    "AE": "sat",
                    "AF": "sat",
                    "AG": "sun",
                    "AI": "mon",
                    "AL": "mon",
                    "AM": "mon",
                    "AN": "mon",
                    "AR": "sun",
                    "AS": "sun",
                    "AT": "mon",
                    "AU": "sun",
                    "AX": "mon",
                    "AZ": "mon",
                    "BA": "mon",
                    "BD": "fri",
                    "BE": "mon",
                    "BG": "mon",
                    "BH": "sat",
                    "BM": "mon",
                    "BN": "mon",
                    "BR": "sun",
                    "BS": "sun",
                    "BT": "sun",
                    "BW": "sun",
                    "BY": "sun",
                    "BZ": "sun",
                    "CA": "sun",
                    "CH": "mon",
                    "CL": "mon",
                    "CM": "mon",
                    "CN": "sun",
                    "CO": "sun",
                    "CR": "mon",
                    "CY": "mon",
                    "CZ": "mon",
                    "DE": "mon",
                    "DJ": "sat",
                    "DK": "mon",
                    "DM": "sun",
                    "DO": "sun",
                    "DZ": "sat",
                    "EC": "mon",
                    "EE": "mon",
                    "EG": "sat",
                    "ES": "mon",
                    "ET": "sun",
                    "FI": "mon",
                    "FJ": "mon",
                    "FO": "mon",
                    "FR": "mon",
                    "GB": "mon",
                    "GE": "mon",
                    "GF": "mon",
                    "GP": "mon",
                    "GR": "mon",
                    "GT": "sun",
                    "GU": "sun",
                    "HK": "sun",
                    "HN": "sun",
                    "HR": "mon",
                    "HU": "mon",
                    "ID": "sun",
                    "IE": "sun",
                    "IL": "sun",
                    "IN": "sun",
                    "IQ": "sat",
                    "IR": "sat",
                    "IS": "mon",
                    "IT": "mon",
                    "JM": "sun",
                    "JO": "sat",
                    "JP": "sun",
                    "KE": "sun",
                    "KG": "mon",
                    "KH": "sun",
                    "KR": "sun",
                    "KW": "sat",
                    "KZ": "mon",
                    "LA": "sun",
                    "LB": "mon",
                    "LI": "mon",
                    "LK": "mon",
                    "LT": "mon",
                    "LU": "mon",
                    "LV": "mon",
                    "LY": "sat",
                    "MA": "sat",
                    "MC": "mon",
                    "MD": "mon",
                    "ME": "mon",
                    "MH": "sun",
                    "MK": "mon",
                    "MM": "sun",
                    "MN": "mon",
                    "MO": "sun",
                    "MQ": "mon",
                    "MT": "sun",
                    "MV": "fri",
                    "MX": "sun",
                    "MY": "mon",
                    "MZ": "sun",
                    "NI": "sun",
                    "NL": "mon",
                    "NO": "mon",
                    "NP": "sun",
                    "NZ": "sun",
                    "OM": "sat",
                    "PA": "sun",
                    "PE": "sun",
                    "PH": "sun",
                    "PK": "sun",
                    "PL": "mon",
                    "PR": "sun",
                    "PT": "mon",
                    "PY": "sun",
                    "QA": "sat",
                    "RE": "mon",
                    "RO": "mon",
                    "RS": "mon",
                    "RU": "mon",
                    "SA": "sun",
                    "SD": "sat",
                    "SE": "mon",
                    "SG": "sun",
                    "SI": "mon",
                    "SK": "mon",
                    "SM": "mon",
                    "SV": "sun",
                    "SY": "sat",
                    "TH": "sun",
                    "TJ": "mon",
                    "TM": "mon",
                    "TN": "sun",
                    "TR": "mon",
                    "TT": "sun",
                    "TW": "sun",
                    "UA": "mon",
                    "UM": "sun",
                    "US": "sun",
                    "UY": "mon",
                    "UZ": "mon",
                    "VA": "mon",
                    "VE": "sun",
                    "VI": "sun",
                    "VN": "mon",
                    "WS": "sun",
                    "XK": "mon",
                    "YE": "sun",
                    "ZA": "sun",
                    "ZW": "sun"
                },
                "firstDay-alt-variant": {
                    "GB": "sun"
                },
                "weekendStart": {
                    "001": "sat",
                    "AE": "fri",
                    "AF": "thu",
                    "BH": "fri",
                    "DZ": "thu",
                    "EG": "fri",
                    "IL": "fri",
                    "IN": "sun",
                    "IQ": "fri",
                    "IR": "thu",
                    "JO": "fri",
                    "KW": "fri",
                    "LY": "fri",
                    "MA": "fri",
                    "OM": "thu",
                    "QA": "fri",
                    "SA": "fri",
                    "SD": "fri",
                    "SY": "fri",
                    "TN": "fri",
                    "YE": "fri"
                },
                "weekendEnd": {
                    "001": "sun",
                    "AE": "sat",
                    "AF": "fri",
                    "BH": "sat",
                    "DZ": "fri",
                    "EG": "sat",
                    "IL": "sat",
                    "IQ": "sat",
                    "IR": "fri",
                    "JO": "sat",
                    "KW": "sat",
                    "LY": "sat",
                    "MA": "sat",
                    "OM": "fri",
                    "QA": "sat",
                    "SA": "sat",
                    "SD": "sat",
                    "SY": "sat",
                    "TN": "sat",
                    "YE": "sat"
                }
            }
        });

        languages = deepFreeze({
            "ar": {
                "dates": {
                    "calendars": {
                        "gregorian": {
                            "months": {
                                "format": {
                                    "abbreviated": {
                                        "1": "يناير",
                                        "2": "فبراير",
                                        "3": "مارس",
                                        "4": "أبريل",
                                        "5": "مايو",
                                        "6": "يونيو",
                                        "7": "يوليو",
                                        "8": "أغسطس",
                                        "9": "سبتمبر",
                                        "10": "أكتوبر",
                                        "11": "نوفمبر",
                                        "12": "ديسمبر"
                                    },
                                    "narrow": {
                                        "1": "ي",
                                        "2": "ف",
                                        "3": "م",
                                        "4": "أ",
                                        "5": "و",
                                        "6": "ن",
                                        "7": "ل",
                                        "8": "غ",
                                        "9": "س",
                                        "10": "ك",
                                        "11": "ب",
                                        "12": "د"
                                    },
                                    "wide": {
                                        "1": "يناير",
                                        "2": "فبراير",
                                        "3": "مارس",
                                        "4": "أبريل",
                                        "5": "مايو",
                                        "6": "يونيو",
                                        "7": "يوليو",
                                        "8": "أغسطس",
                                        "9": "سبتمبر",
                                        "10": "أكتوبر",
                                        "11": "نوفمبر",
                                        "12": "ديسمبر"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "1": "يناير",
                                        "2": "فبراير",
                                        "3": "مارس",
                                        "4": "أبريل",
                                        "5": "مايو",
                                        "6": "يونيو",
                                        "7": "يوليو",
                                        "8": "أغسطس",
                                        "9": "سبتمبر",
                                        "10": "أكتوبر",
                                        "11": "نوفمبر",
                                        "12": "ديسمبر"
                                    },
                                    "narrow": {
                                        "1": "ي",
                                        "2": "ف",
                                        "3": "م",
                                        "4": "أ",
                                        "5": "و",
                                        "6": "ن",
                                        "7": "ل",
                                        "8": "غ",
                                        "9": "س",
                                        "10": "ك",
                                        "11": "ب",
                                        "12": "د"
                                    },
                                    "wide": {
                                        "1": "يناير",
                                        "2": "فبراير",
                                        "3": "مارس",
                                        "4": "أبريل",
                                        "5": "مايو",
                                        "6": "يونيو",
                                        "7": "يوليو",
                                        "8": "أغسطس",
                                        "9": "سبتمبر",
                                        "10": "أكتوبر",
                                        "11": "نوفمبر",
                                        "12": "ديسمبر"
                                    }
                                }
                            },
                            "days": {
                                "format": {
                                    "abbreviated": {
                                        "sun": "الأحد",
                                        "mon": "الاثنين",
                                        "tue": "الثلاثاء",
                                        "wed": "الأربعاء",
                                        "thu": "الخميس",
                                        "fri": "الجمعة",
                                        "sat": "السبت"
                                    },
                                    "narrow": {
                                        "sun": "ح",
                                        "mon": "ن",
                                        "tue": "ث",
                                        "wed": "ر",
                                        "thu": "خ",
                                        "fri": "ج",
                                        "sat": "س"
                                    },
                                    "short": {
                                        "sun": "الأحد",
                                        "mon": "الاثنين",
                                        "tue": "الثلاثاء",
                                        "wed": "الأربعاء",
                                        "thu": "الخميس",
                                        "fri": "الجمعة",
                                        "sat": "السبت"
                                    },
                                    "wide": {
                                        "sun": "الأحد",
                                        "mon": "الاثنين",
                                        "tue": "الثلاثاء",
                                        "wed": "الأربعاء",
                                        "thu": "الخميس",
                                        "fri": "الجمعة",
                                        "sat": "السبت"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "sun": "الأحد",
                                        "mon": "الاثنين",
                                        "tue": "الثلاثاء",
                                        "wed": "الأربعاء",
                                        "thu": "الخميس",
                                        "fri": "الجمعة",
                                        "sat": "السبت"
                                    },
                                    "narrow": {
                                        "sun": "ح",
                                        "mon": "ن",
                                        "tue": "ث",
                                        "wed": "ر",
                                        "thu": "خ",
                                        "fri": "ج",
                                        "sat": "س"
                                    },
                                    "short": {
                                        "sun": "الأحد",
                                        "mon": "الاثنين",
                                        "tue": "الثلاثاء",
                                        "wed": "الأربعاء",
                                        "thu": "الخميس",
                                        "fri": "الجمعة",
                                        "sat": "السبت"
                                    },
                                    "wide": {
                                        "sun": "الأحد",
                                        "mon": "الاثنين",
                                        "tue": "الثلاثاء",
                                        "wed": "الأربعاء",
                                        "thu": "الخميس",
                                        "fri": "الجمعة",
                                        "sat": "السبت"
                                    }
                                }
                            },
                            "quarters": {
                                "format": {
                                    "abbreviated": {
                                        "1": "الربع الأول",
                                        "2": "الربع الثاني",
                                        "3": "الربع الثالث",
                                        "4": "الربع الرابع"
                                    },
                                    "narrow": {
                                        "1": "١",
                                        "2": "٢",
                                        "3": "٣",
                                        "4": "٤"
                                    },
                                    "wide": {
                                        "1": "الربع الأول",
                                        "2": "الربع الثاني",
                                        "3": "الربع الثالث",
                                        "4": "الربع الرابع"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "1": "الربع الأول",
                                        "2": "الربع الثاني",
                                        "3": "الربع الثالث",
                                        "4": "الربع الرابع"
                                    },
                                    "narrow": {
                                        "1": "١",
                                        "2": "٢",
                                        "3": "٣",
                                        "4": "٤"
                                    },
                                    "wide": {
                                        "1": "الربع الأول",
                                        "2": "الربع الثاني",
                                        "3": "الربع الثالث",
                                        "4": "الربع الرابع"
                                    }
                                }
                            },
                            "dayPeriods": {
                                "format": {
                                    "abbreviated": {
                                        "am": "ص",
                                        "pm": "م"
                                    },
                                    "narrow": {
                                        "am": "ص",
                                        "pm": "م"
                                    },
                                    "wide": {
                                        "am": "ص",
                                        "pm": "م"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "am": "ص",
                                        "pm": "م"
                                    },
                                    "narrow": {
                                        "am": "ص",
                                        "pm": "م"
                                    },
                                    "wide": {
                                        "am": "ص",
                                        "pm": "م"
                                    }
                                }
                            },
                            "eras": {
                                "eraNames": {
                                    "0": "قبل الميلاد",
                                    "1": "ميلادي",
                                    "0-alt-variant": "BCE",
                                    "1-alt-variant": "CE"
                                },
                                "eraAbbr": {
                                    "0": "ق.م",
                                    "1": "م",
                                    "0-alt-variant": "BCE",
                                    "1-alt-variant": "CE"
                                },
                                "eraNarrow": {
                                    "0": "ق.م",
                                    "1": "م",
                                    "0-alt-variant": "BCE",
                                    "1-alt-variant": "CE"
                                }
                            },
                            "dateFormats": {
                                "full": "EEEE، d MMMM، y",
                                "long": "d MMMM، y",
                                "medium": "dd‏/MM‏/y",
                                "short": "d‏/M‏/y"
                            },
                            "timeFormats": {
                                "full": "h:mm:ss a zzzz",
                                "long": "h:mm:ss a z",
                                "medium": "h:mm:ss a",
                                "short": "h:mm a"
                            },
                            "dateTimeFormats": {
                                "full": "{1} {0}",
                                "long": "{1} {0}",
                                "medium": "{1} {0}",
                                "short": "{1} {0}",
                                "availableFormats": {
                                    "d": "d",
                                    "Ed": "E، d",
                                    "Ehm": "E h:mm a",
                                    "EHm": "E HH:mm",
                                    "Ehms": "E h:mm:ss a",
                                    "EHms": "E HH:mm:ss",
                                    "Gy": "y G",
                                    "GyMMM": "MMM y G",
                                    "GyMMMd": "d MMM، y G",
                                    "GyMMMEd": "E، d MMM، y G",
                                    "h": "h a",
                                    "H": "HH",
                                    "hm": "h:mm a",
                                    "Hm": "HH:mm",
                                    "hms": "h:mm:ss a",
                                    "Hms": "HH:mm:ss",
                                    "M": "L",
                                    "Md": "d/‏M",
                                    "MEd": "E، d/M",
                                    "MMdd": "dd‏/MM",
                                    "MMM": "LLL",
                                    "MMMd": "d MMM",
                                    "MMMEd": "E، d MMM",
                                    "MMMMd": "d MMMM",
                                    "MMMMEd": "E، d MMMM",
                                    "ms": "mm:ss",
                                    "y": "y",
                                    "yM": "M‏/y",
                                    "yMd": "d‏/M‏/y",
                                    "yMEd": "E، d/‏M/‏y",
                                    "yMM": "MM‏/y",
                                    "yMMM": "MMM y",
                                    "yMMMd": "d MMM، y",
                                    "yMMMEd": "E، d MMM، y",
                                    "yMMMM": "MMMM y",
                                    "yQQQ": "QQQ y",
                                    "yQQQQ": "QQQQ y"
                                },
                                "appendItems": {
                                    "Day": "{0} ({2}: {1})",
                                    "Day-Of-Week": "{0} {1}",
                                    "Era": "{1} {0}",
                                    "Hour": "{0} ({2}: {1})",
                                    "Minute": "{0} ({2}: {1})",
                                    "Month": "{0} ({2}: {1})",
                                    "Quarter": "{0} ({2}: {1})",
                                    "Second": "{0} ({2}: {1})",
                                    "Timezone": "{0} {1}",
                                    "Week": "{0} ({2}: {1})",
                                    "Year": "{1} {0}"
                                },
                                "intervalFormats": {
                                    "intervalFormatFallback": "{0} – {1}",
                                    "d": {
                                        "d": "d–d"
                                    },
                                    "h": {
                                        "a": "h a – h a",
                                        "h": "h–h a"
                                    },
                                    "H": {
                                        "H": "HH–HH"
                                    },
                                    "hm": {
                                        "a": "h:mm a – h:mm a",
                                        "h": "h:mm–h:mm a",
                                        "m": "h:mm–h:mm a"
                                    },
                                    "Hm": {
                                        "H": "HH:mm–HH:mm",
                                        "m": "HH:mm–HH:mm"
                                    },
                                    "hmv": {
                                        "a": "h:mm a – h:mm a v",
                                        "h": "h:mm–h:mm a v",
                                        "m": "h:mm–h:mm a v"
                                    },
                                    "Hmv": {
                                        "H": "HH:mm–HH:mm v",
                                        "m": "HH:mm–HH:mm v"
                                    },
                                    "hv": {
                                        "a": "h a – h a v",
                                        "h": "h–h a v"
                                    },
                                    "Hv": {
                                        "H": "HH–HH v"
                                    },
                                    "M": {
                                        "M": "M–M"
                                    },
                                    "Md": {
                                        "d": "M/d – M/d",
                                        "M": "M/d – M/d"
                                    },
                                    "MEd": {
                                        "d": "E، d/‏M –‏ E، d/‏M",
                                        "M": "E، d/‏M – E، d/‏M"
                                    },
                                    "MMM": {
                                        "M": "MMM–MMM"
                                    },
                                    "MMMd": {
                                        "d": "d–d MMM",
                                        "M": "d MMM – d MMM"
                                    },
                                    "MMMEd": {
                                        "d": "E، d – E، d MMM",
                                        "M": "E، d MMM – E، d MMM"
                                    },
                                    "MMMM": {
                                        "M": "LLLL–LLLL"
                                    },
                                    "y": {
                                        "y": "y–y"
                                    },
                                    "yM": {
                                        "M": "M‏/y – M‏/y",
                                        "y": "M‏/y – M‏/y"
                                    },
                                    "yMd": {
                                        "d": "d‏/M‏/y – d‏/M‏/y",
                                        "M": "d‏/M‏/y – d‏/M‏/y",
                                        "y": "d‏/M‏/y – d‏/M‏/y"
                                    },
                                    "yMEd": {
                                        "d": "E، dd‏/MM‏/y – E، dd‏/MM‏/y",
                                        "M": "E، d‏/M‏/y – E، d‏/M‏/y",
                                        "y": "E، d‏/M‏/y – E، d‏/M‏/y"
                                    },
                                    "yMMM": {
                                        "M": "MMM – MMM، y",
                                        "y": "MMM، y – MMM، y"
                                    },
                                    "yMMMd": {
                                        "d": "d–d MMM، y",
                                        "M": "d MMM – d MMM، y",
                                        "y": "d MMM، y – d MMM، y"
                                    },
                                    "yMMMEd": {
                                        "d": "E، d – E، d MMM، y",
                                        "M": "E، d MMM – E، d MMM، y",
                                        "y": "E، d MMM، y – E، d MMM، y"
                                    },
                                    "yMMMM": {
                                        "M": "MMMM – MMMM، y",
                                        "y": "MMMM، y – MMMM، y"
                                    }
                                }
                            }
                        }
                    },
                    "timeZoneNames": {
                        "hourFormat": "+HH:mm;-HH:mm",
                        "gmtFormat": "جرينتش{0}",
                        "gmtZeroFormat": "جرينتش",
                        "regionFormat": "توقيت {0}",
                        "regionFormat-type-daylight": "توقيت {0} الصيفي",
                        "regionFormat-type-standard": "توقيت {0} الرسمي",
                        "fallbackFormat": "{1} ({0})"
                    }
                }
            },
            "ca": {
                "dates": {
                    "calendars": {
                        "gregorian": {
                            "months": {
                                "format": {
                                    "abbreviated": {
                                        "1": "gen.",
                                        "2": "feb.",
                                        "3": "març",
                                        "4": "abr.",
                                        "5": "maig",
                                        "6": "juny",
                                        "7": "jul.",
                                        "8": "ag.",
                                        "9": "set.",
                                        "10": "oct.",
                                        "11": "nov.",
                                        "12": "des."
                                    },
                                    "narrow": {
                                        "1": "GN",
                                        "2": "FB",
                                        "3": "MÇ",
                                        "4": "AB",
                                        "5": "MG",
                                        "6": "JN",
                                        "7": "JL",
                                        "8": "AG",
                                        "9": "ST",
                                        "10": "OC",
                                        "11": "NV",
                                        "12": "DS"
                                    },
                                    "wide": {
                                        "1": "gener",
                                        "2": "febrer",
                                        "3": "març",
                                        "4": "abril",
                                        "5": "maig",
                                        "6": "juny",
                                        "7": "juliol",
                                        "8": "agost",
                                        "9": "setembre",
                                        "10": "octubre",
                                        "11": "novembre",
                                        "12": "desembre"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "1": "gen.",
                                        "2": "feb.",
                                        "3": "març",
                                        "4": "abr.",
                                        "5": "maig",
                                        "6": "juny",
                                        "7": "jul.",
                                        "8": "ag.",
                                        "9": "set.",
                                        "10": "oct.",
                                        "11": "nov.",
                                        "12": "des."
                                    },
                                    "narrow": {
                                        "1": "GN",
                                        "2": "FB",
                                        "3": "MÇ",
                                        "4": "AB",
                                        "5": "MG",
                                        "6": "JN",
                                        "7": "JL",
                                        "8": "AG",
                                        "9": "ST",
                                        "10": "OC",
                                        "11": "NV",
                                        "12": "DS"
                                    },
                                    "wide": {
                                        "1": "gener",
                                        "2": "febrer",
                                        "3": "març",
                                        "4": "abril",
                                        "5": "maig",
                                        "6": "juny",
                                        "7": "juliol",
                                        "8": "agost",
                                        "9": "setembre",
                                        "10": "octubre",
                                        "11": "novembre",
                                        "12": "desembre"
                                    }
                                }
                            },
                            "days": {
                                "format": {
                                    "abbreviated": {
                                        "sun": "dg.",
                                        "mon": "dl.",
                                        "tue": "dt.",
                                        "wed": "dc.",
                                        "thu": "dj.",
                                        "fri": "dv.",
                                        "sat": "ds."
                                    },
                                    "narrow": {
                                        "sun": "dg",
                                        "mon": "dl",
                                        "tue": "dt",
                                        "wed": "dc",
                                        "thu": "dj",
                                        "fri": "dv",
                                        "sat": "ds"
                                    },
                                    "short": {
                                        "sun": "dg.",
                                        "mon": "dl.",
                                        "tue": "dt.",
                                        "wed": "dc.",
                                        "thu": "dj.",
                                        "fri": "dv.",
                                        "sat": "ds."
                                    },
                                    "wide": {
                                        "sun": "diumenge",
                                        "mon": "dilluns",
                                        "tue": "dimarts",
                                        "wed": "dimecres",
                                        "thu": "dijous",
                                        "fri": "divendres",
                                        "sat": "dissabte"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "sun": "dg.",
                                        "mon": "dl.",
                                        "tue": "dt.",
                                        "wed": "dc.",
                                        "thu": "dj.",
                                        "fri": "dv.",
                                        "sat": "ds."
                                    },
                                    "narrow": {
                                        "sun": "dg",
                                        "mon": "dl",
                                        "tue": "dt",
                                        "wed": "dc",
                                        "thu": "dj",
                                        "fri": "dv",
                                        "sat": "ds"
                                    },
                                    "short": {
                                        "sun": "dg.",
                                        "mon": "dl.",
                                        "tue": "dm.",
                                        "wed": "dc.",
                                        "thu": "dj.",
                                        "fri": "dv.",
                                        "sat": "ds."
                                    },
                                    "wide": {
                                        "sun": "diumenge",
                                        "mon": "dilluns",
                                        "tue": "dimarts",
                                        "wed": "dimecres",
                                        "thu": "dijous",
                                        "fri": "divendres",
                                        "sat": "dissabte"
                                    }
                                }
                            },
                            "quarters": {
                                "format": {
                                    "abbreviated": {
                                        "1": "1T",
                                        "2": "2T",
                                        "3": "3T",
                                        "4": "4T"
                                    },
                                    "narrow": {
                                        "1": "1",
                                        "2": "2",
                                        "3": "3",
                                        "4": "4"
                                    },
                                    "wide": {
                                        "1": "1r trimestre",
                                        "2": "2n trimestre",
                                        "3": "3r trimestre",
                                        "4": "4t trimestre"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "1": "1T",
                                        "2": "2T",
                                        "3": "3T",
                                        "4": "4T"
                                    },
                                    "narrow": {
                                        "1": "1",
                                        "2": "2",
                                        "3": "3",
                                        "4": "4"
                                    },
                                    "wide": {
                                        "1": "1r trimestre",
                                        "2": "2n trimestre",
                                        "3": "3r trimestre",
                                        "4": "4t trimestre"
                                    }
                                }
                            },
                            "dayPeriods": {
                                "format": {
                                    "abbreviated": {
                                        "am": "a. m.",
                                        "pm": "p. m."
                                    },
                                    "narrow": {
                                        "am": "a.m.",
                                        "pm": "p.m."
                                    },
                                    "wide": {
                                        "am": "a. m.",
                                        "pm": "p. m."
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "am": "a. m.",
                                        "pm": "p. m."
                                    },
                                    "narrow": {
                                        "am": "a.m.",
                                        "pm": "p.m."
                                    },
                                    "wide": {
                                        "am": "a. m.",
                                        "pm": "p. m."
                                    }
                                }
                            },
                            "eras": {
                                "eraNames": {
                                    "0": "abans de Crist",
                                    "1": "després de Crist",
                                    "0-alt-variant": "a. de la n. e.",
                                    "1-alt-variant": "de la n. e."
                                },
                                "eraAbbr": {
                                    "0": "aC",
                                    "1": "dC",
                                    "0-alt-variant": "a. de la n. e.",
                                    "1-alt-variant": "de la n.e."
                                },
                                "eraNarrow": {
                                    "0": "aC",
                                    "1": "dC",
                                    "0-alt-variant": "a. de la n. e.",
                                    "1-alt-variant": "de la n.e."
                                }
                            },
                            "dateFormats": {
                                "full": "EEEE, d MMMM 'de' y",
                                "long": "d MMMM 'de' y",
                                "medium": "dd/MM/y",
                                "short": "d/M/yy"
                            },
                            "timeFormats": {
                                "full": "H.mm.ss zzzz",
                                "long": "H.mm.ss z",
                                "medium": "H.mm.ss",
                                "short": "H.mm"
                            },
                            "dateTimeFormats": {
                                "full": "{1} {0}",
                                "long": "{1} {0}",
                                "medium": "{1} {0}",
                                "short": "{1} {0}",
                                "availableFormats": {
                                    "d": "d",
                                    "Ed": "E d",
                                    "Ehm": "E h:mm a",
                                    "EHm": "E H:mm",
                                    "Ehms": "E h:mm:ss a",
                                    "EHms": "E H:mm:ss",
                                    "Gy": "y G",
                                    "GyMMM": "LLL y G",
                                    "GyMMMd": "d MMM y G",
                                    "GyMMMEd": "E, d MMM, y G",
                                    "GyMMMM": "LLLL 'de' y G",
                                    "h": "h a",
                                    "H": "H",
                                    "hm": "h:mm a",
                                    "Hm": "HH:mm",
                                    "hms": "h:mm:ss a",
                                    "Hms": "HH:mm:ss",
                                    "M": "L",
                                    "Md": "d/M",
                                    "MEd": "E d/M",
                                    "MMM": "LLL",
                                    "MMMd": "d MMM",
                                    "MMMEd": "E d MMM",
                                    "MMMMd": "d MMMM",
                                    "MMMMEd": "E d MMMM",
                                    "ms": "mm:ss",
                                    "y": "y",
                                    "yM": "M/y",
                                    "yMd": "d/M/y",
                                    "yMEd": "E, d/M/y",
                                    "yMMM": "LLL y",
                                    "yMMMd": "d MMM y",
                                    "yMMMEd": "E, d MMM, y",
                                    "yMMMM": "LLLL 'de' y",
                                    "yQQQ": "QQQ y",
                                    "yQQQQ": "QQQQ y"
                                },
                                "appendItems": {
                                    "Day": "{0} ({2}: {1})",
                                    "Day-Of-Week": "{0} {1}",
                                    "Era": "{1} {0}",
                                    "Hour": "{0} ({2}: {1})",
                                    "Minute": "{0} ({2}: {1})",
                                    "Month": "{0} ({2}: {1})",
                                    "Quarter": "{0} ({2}: {1})",
                                    "Second": "{0} ({2}: {1})",
                                    "Timezone": "{0} {1}",
                                    "Week": "{0} ({2}: {1})",
                                    "Year": "{1} {0}"
                                },
                                "intervalFormats": {
                                    "intervalFormatFallback": "{0} - {1}",
                                    "d": {
                                        "d": "d-d"
                                    },
                                    "h": {
                                        "a": "h a - h a",
                                        "h": "h-h a"
                                    },
                                    "H": {
                                        "H": "H-H"
                                    },
                                    "hm": {
                                        "a": "h.mm a -h.mm a",
                                        "h": "h:mm-h:mm a",
                                        "m": "h:mm-h:mm a"
                                    },
                                    "Hm": {
                                        "H": "HH.mm-HH.mm",
                                        "m": "HH.mm-HH.mm"
                                    },
                                    "hmv": {
                                        "a": "h:mm a - h:mm a v",
                                        "h": "h:mm–h:mm a v",
                                        "m": "h:mm-h:mm a v"
                                    },
                                    "Hmv": {
                                        "H": "HH.mm-HH.mm v",
                                        "m": "HH.mm-HH.mm v"
                                    },
                                    "hv": {
                                        "a": "h a - h a v",
                                        "h": "h-h a v"
                                    },
                                    "Hv": {
                                        "H": "H-H v"
                                    },
                                    "M": {
                                        "M": "M-M"
                                    },
                                    "Md": {
                                        "d": "dd/MM - dd/MM",
                                        "M": "dd/MM - dd/MM"
                                    },
                                    "MEd": {
                                        "d": "E dd/MM - E dd/MM",
                                        "M": "E dd/MM - E dd/MM"
                                    },
                                    "MMM": {
                                        "M": "LLL-LLL"
                                    },
                                    "MMMd": {
                                        "d": "d-d MMM",
                                        "M": "d MMM - d MMM"
                                    },
                                    "MMMEd": {
                                        "d": "E d - E d MMM",
                                        "M": "E d MMM - E d MMM"
                                    },
                                    "y": {
                                        "y": "y-y"
                                    },
                                    "yM": {
                                        "M": "MM/y - MM/y",
                                        "y": "MM/y - MM/y"
                                    },
                                    "yMd": {
                                        "d": "dd/MM/y - dd/MM/y",
                                        "M": "dd/MM/y - dd/MM/y",
                                        "y": "dd/MM/y - dd/MM/y"
                                    },
                                    "yMEd": {
                                        "d": "E dd/MM/y - E dd/MM/y",
                                        "M": "E dd/MM/y - E dd/MM/y",
                                        "y": "E dd/MM/y - E dd/MM/y"
                                    },
                                    "yMMM": {
                                        "M": "LLL-LLL 'de' y",
                                        "y": "LLL 'de' y - LLL 'de' y"
                                    },
                                    "yMMMd": {
                                        "d": "d-d MMM 'de' y",
                                        "M": "d MMM - d MMM 'de' y",
                                        "y": "d MMM 'de' y - d MMM 'de' y"
                                    },
                                    "yMMMEd": {
                                        "d": "E d - E d MMM 'de' y",
                                        "M": "E d MMM - E d MMM 'de' y",
                                        "y": "E d MMM 'de' y - E d MMM 'de' y"
                                    },
                                    "yMMMM": {
                                        "M": "LLLL-LLLL 'de' y",
                                        "y": "LLLL 'de' y - LLLL 'de' y"
                                    }
                                }
                            }
                        }
                    },
                    "timeZoneNames": {
                        "hourFormat": "+HH:mm;-HH:mm",
                        "gmtFormat": "GMT{0}",
                        "gmtZeroFormat": "GMT",
                        "regionFormat": "Hora de: {0}",
                        "regionFormat-type-daylight": "Horari d'estiu, {0}",
                        "regionFormat-type-standard": "Hora estàndard, {0}",
                        "fallbackFormat": "{1} ({0})"
                    }
                }
            },
            "cs": {
                "dates": {
                    "calendars": {
                        "gregorian": {
                            "months": {
                                "format": {
                                    "abbreviated": {
                                        "1": "led",
                                        "2": "úno",
                                        "3": "bře",
                                        "4": "dub",
                                        "5": "kvě",
                                        "6": "čvn",
                                        "7": "čvc",
                                        "8": "srp",
                                        "9": "zář",
                                        "10": "říj",
                                        "11": "lis",
                                        "12": "pro"
                                    },
                                    "narrow": {
                                        "1": "1",
                                        "2": "2",
                                        "3": "3",
                                        "4": "4",
                                        "5": "5",
                                        "6": "6",
                                        "7": "7",
                                        "8": "8",
                                        "9": "9",
                                        "10": "10",
                                        "11": "11",
                                        "12": "12"
                                    },
                                    "wide": {
                                        "1": "ledna",
                                        "2": "února",
                                        "3": "března",
                                        "4": "dubna",
                                        "5": "května",
                                        "6": "června",
                                        "7": "července",
                                        "8": "srpna",
                                        "9": "září",
                                        "10": "října",
                                        "11": "listopadu",
                                        "12": "prosince"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "1": "led",
                                        "2": "úno",
                                        "3": "bře",
                                        "4": "dub",
                                        "5": "kvě",
                                        "6": "čvn",
                                        "7": "čvc",
                                        "8": "srp",
                                        "9": "zář",
                                        "10": "říj",
                                        "11": "lis",
                                        "12": "pro"
                                    },
                                    "narrow": {
                                        "1": "l",
                                        "2": "ú",
                                        "3": "b",
                                        "4": "d",
                                        "5": "k",
                                        "6": "č",
                                        "7": "č",
                                        "8": "s",
                                        "9": "z",
                                        "10": "ř",
                                        "11": "l",
                                        "12": "p"
                                    },
                                    "wide": {
                                        "1": "leden",
                                        "2": "únor",
                                        "3": "březen",
                                        "4": "duben",
                                        "5": "květen",
                                        "6": "červen",
                                        "7": "červenec",
                                        "8": "srpen",
                                        "9": "září",
                                        "10": "říjen",
                                        "11": "listopad",
                                        "12": "prosinec"
                                    }
                                }
                            },
                            "days": {
                                "format": {
                                    "abbreviated": {
                                        "sun": "ne",
                                        "mon": "po",
                                        "tue": "út",
                                        "wed": "st",
                                        "thu": "čt",
                                        "fri": "pá",
                                        "sat": "so"
                                    },
                                    "narrow": {
                                        "sun": "N",
                                        "mon": "P",
                                        "tue": "Ú",
                                        "wed": "S",
                                        "thu": "Č",
                                        "fri": "P",
                                        "sat": "S"
                                    },
                                    "short": {
                                        "sun": "ne",
                                        "mon": "po",
                                        "tue": "út",
                                        "wed": "st",
                                        "thu": "čt",
                                        "fri": "pá",
                                        "sat": "so"
                                    },
                                    "wide": {
                                        "sun": "neděle",
                                        "mon": "pondělí",
                                        "tue": "úterý",
                                        "wed": "středa",
                                        "thu": "čtvrtek",
                                        "fri": "pátek",
                                        "sat": "sobota"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "sun": "ne",
                                        "mon": "po",
                                        "tue": "út",
                                        "wed": "st",
                                        "thu": "čt",
                                        "fri": "pá",
                                        "sat": "so"
                                    },
                                    "narrow": {
                                        "sun": "N",
                                        "mon": "P",
                                        "tue": "Ú",
                                        "wed": "S",
                                        "thu": "Č",
                                        "fri": "P",
                                        "sat": "S"
                                    },
                                    "short": {
                                        "sun": "ne",
                                        "mon": "po",
                                        "tue": "út",
                                        "wed": "st",
                                        "thu": "čt",
                                        "fri": "pá",
                                        "sat": "so"
                                    },
                                    "wide": {
                                        "sun": "neděle",
                                        "mon": "pondělí",
                                        "tue": "úterý",
                                        "wed": "středa",
                                        "thu": "čtvrtek",
                                        "fri": "pátek",
                                        "sat": "sobota"
                                    }
                                }
                            },
                            "quarters": {
                                "format": {
                                    "abbreviated": {
                                        "1": "Q1",
                                        "2": "Q2",
                                        "3": "Q3",
                                        "4": "Q4"
                                    },
                                    "narrow": {
                                        "1": "1",
                                        "2": "2",
                                        "3": "3",
                                        "4": "4"
                                    },
                                    "wide": {
                                        "1": "1. čtvrtletí",
                                        "2": "2. čtvrtletí",
                                        "3": "3. čtvrtletí",
                                        "4": "4. čtvrtletí"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "1": "Q1",
                                        "2": "Q2",
                                        "3": "Q3",
                                        "4": "Q4"
                                    },
                                    "narrow": {
                                        "1": "1",
                                        "2": "2",
                                        "3": "3",
                                        "4": "4"
                                    },
                                    "wide": {
                                        "1": "1. čtvrtletí",
                                        "2": "2. čtvrtletí",
                                        "3": "3. čtvrtletí",
                                        "4": "4. čtvrtletí"
                                    }
                                }
                            },
                            "dayPeriods": {
                                "format": {
                                    "abbreviated": {
                                        "am": "AM",
                                        "pm": "PM"
                                    },
                                    "narrow": {
                                        "am": "AM",
                                        "pm": "PM"
                                    },
                                    "wide": {
                                        "am": "AM",
                                        "pm": "PM"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "am": "AM",
                                        "pm": "PM"
                                    },
                                    "narrow": {
                                        "am": "AM",
                                        "pm": "PM"
                                    },
                                    "wide": {
                                        "am": "AM",
                                        "pm": "PM"
                                    }
                                }
                            },
                            "eras": {
                                "eraNames": {
                                    "0": "př. n. l.",
                                    "1": "n. l.",
                                    "0-alt-variant": "BCE",
                                    "1-alt-variant": "CE"
                                },
                                "eraAbbr": {
                                    "0": "př. n. l.",
                                    "1": "n. l.",
                                    "0-alt-variant": "BCE",
                                    "1-alt-variant": "CE"
                                },
                                "eraNarrow": {
                                    "0": "př.n.l.",
                                    "1": "n.l.",
                                    "0-alt-variant": "BCE",
                                    "1-alt-variant": "CE"
                                }
                            },
                            "dateFormats": {
                                "full": "EEEE d. MMMM y",
                                "long": "d. MMMM y",
                                "medium": "d. M. y",
                                "short": "dd.MM.yy"
                            },
                            "timeFormats": {
                                "full": "H:mm:ss zzzz",
                                "long": "H:mm:ss z",
                                "medium": "H:mm:ss",
                                "short": "H:mm"
                            },
                            "dateTimeFormats": {
                                "full": "{1} {0}",
                                "long": "{1} {0}",
                                "medium": "{1} {0}",
                                "short": "{1} {0}",
                                "availableFormats": {
                                    "d": "d.",
                                    "Ed": "E d.",
                                    "Ehm": "E h:mm a",
                                    "EHm": "E H:mm",
                                    "Ehms": "E h:mm:ss a",
                                    "EHms": "E H:mm:ss",
                                    "Gy": "y G",
                                    "GyMMM": "LLLL y G",
                                    "GyMMMd": "d. M. y G",
                                    "GyMMMEd": "E d. M. y G",
                                    "GyMMMMd": "d. MMMM y G",
                                    "GyMMMMEd": "E d. MMMM y G",
                                    "h": "h a",
                                    "H": "H",
                                    "hm": "h:mm a",
                                    "Hm": "H:mm",
                                    "hms": "h:mm:ss a",
                                    "Hms": "H:mm:ss",
                                    "M": "L",
                                    "Md": "d. M.",
                                    "MEd": "E d. M.",
                                    "MMM": "LLL",
                                    "MMMd": "d. M.",
                                    "MMMEd": "E d. M.",
                                    "MMMMd": "d. MMMM",
                                    "MMMMEd": "E d. MMMM",
                                    "ms": "mm:ss",
                                    "y": "y",
                                    "yM": "M/y",
                                    "yMd": "d. M. y",
                                    "yMEd": "E d. M. y",
                                    "yMMM": "LLLL y",
                                    "yMMMd": "d. M. y",
                                    "yMMMEd": "E d. M. y",
                                    "yMMMM": "LLLL y",
                                    "yMMMMd": "d. MMMM y",
                                    "yMMMMEd": "E d. MMMM y",
                                    "yQQQ": "QQQ y",
                                    "yQQQQ": "QQQQ y"
                                },
                                "appendItems": {
                                    "Day": "{0} ({2}: {1})",
                                    "Day-Of-Week": "{0} {1}",
                                    "Era": "{1} {0}",
                                    "Hour": "{0} ({2}: {1})",
                                    "Minute": "{0} ({2}: {1})",
                                    "Month": "{0} ({2}: {1})",
                                    "Quarter": "{0} ({2}: {1})",
                                    "Second": "{0} ({2}: {1})",
                                    "Timezone": "{0} {1}",
                                    "Week": "{0} ({2}: {1})",
                                    "Year": "{1} {0}"
                                },
                                "intervalFormats": {
                                    "intervalFormatFallback": "{0} – {1}",
                                    "d": {
                                        "d": "d.–d."
                                    },
                                    "h": {
                                        "a": "h a – h a",
                                        "h": "h–h a"
                                    },
                                    "H": {
                                        "H": "H–H"
                                    },
                                    "hm": {
                                        "a": "h:mm a – h:mm a",
                                        "h": "h:mm–h:mm a",
                                        "m": "h:mm–h:mm a"
                                    },
                                    "Hm": {
                                        "H": "H:mm–H:mm",
                                        "m": "H:mm–H:mm"
                                    },
                                    "hmv": {
                                        "a": "h:mm a – h:mm a v",
                                        "h": "h:mm–h:mm a v",
                                        "m": "h:mm–h:mm a v"
                                    },
                                    "Hmv": {
                                        "H": "H:mm–H:mm v",
                                        "m": "H:mm–H:mm v"
                                    },
                                    "hv": {
                                        "a": "h a – h a v",
                                        "h": "h–h a v"
                                    },
                                    "Hv": {
                                        "H": "H–H v"
                                    },
                                    "M": {
                                        "M": "M–M"
                                    },
                                    "Md": {
                                        "d": "d. M. – d. M.",
                                        "M": "d. M. – d. M."
                                    },
                                    "MEd": {
                                        "d": "E d. M. – E d. M.",
                                        "M": "E d. M. – E d. M."
                                    },
                                    "MMM": {
                                        "M": "MMM–MMM"
                                    },
                                    "MMMd": {
                                        "d": "d.–d. M.",
                                        "M": "d. M. – d. M."
                                    },
                                    "MMMEd": {
                                        "d": "E d. M. – E d. M.",
                                        "M": "E d. M. – E d. M."
                                    },
                                    "y": {
                                        "y": "y–y"
                                    },
                                    "yM": {
                                        "M": "M/y – M/y",
                                        "y": "M/y – M/y"
                                    },
                                    "yMd": {
                                        "d": "dd.MM.y – dd.MM.y",
                                        "M": "dd.MM.y – dd.MM.y",
                                        "y": "dd.MM.y – dd.MM.y"
                                    },
                                    "yMEd": {
                                        "d": "E dd.MM.y – E dd.MM.y",
                                        "M": "E dd.MM.y – E dd.MM.y",
                                        "y": "E dd.MM.y – E dd.MM.y"
                                    },
                                    "yMMM": {
                                        "M": "MMM–MMM y",
                                        "y": "MMM y – MMM y"
                                    },
                                    "yMMMd": {
                                        "d": "d.–d. M. y",
                                        "M": "d. M. – d. M. y",
                                        "y": "d. M. y – d. M. y"
                                    },
                                    "yMMMEd": {
                                        "d": "E d. M. – E d. M. y",
                                        "M": "E d. M. – E d. M. y",
                                        "y": "E d. M. y – E d. M. y"
                                    },
                                    "yMMMM": {
                                        "M": "LLLL–LLLL y",
                                        "y": "LLLL y – LLLL y"
                                    }
                                }
                            }
                        }
                    },
                    "timeZoneNames": {
                        "hourFormat": "+H:mm;-H:mm",
                        "gmtFormat": "GMT{0}",
                        "gmtZeroFormat": "GMT",
                        "regionFormat": "Časové pásmo {0}",
                        "regionFormat-type-daylight": "{0} (+1)",
                        "regionFormat-type-standard": "{0} (+0)",
                        "fallbackFormat": "{1} ({0})"
                    }
                }
            },
            "da": {
                "dates": {
                    "calendars": {
                        "gregorian": {
                            "months": {
                                "format": {
                                    "abbreviated": {
                                        "1": "jan.",
                                        "2": "feb.",
                                        "3": "mar.",
                                        "4": "apr.",
                                        "5": "maj",
                                        "6": "jun.",
                                        "7": "jul.",
                                        "8": "aug.",
                                        "9": "sep.",
                                        "10": "okt.",
                                        "11": "nov.",
                                        "12": "dec."
                                    },
                                    "narrow": {
                                        "1": "J",
                                        "2": "F",
                                        "3": "M",
                                        "4": "A",
                                        "5": "M",
                                        "6": "J",
                                        "7": "J",
                                        "8": "A",
                                        "9": "S",
                                        "10": "O",
                                        "11": "N",
                                        "12": "D"
                                    },
                                    "wide": {
                                        "1": "januar",
                                        "2": "februar",
                                        "3": "marts",
                                        "4": "april",
                                        "5": "maj",
                                        "6": "juni",
                                        "7": "juli",
                                        "8": "august",
                                        "9": "september",
                                        "10": "oktober",
                                        "11": "november",
                                        "12": "december"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "1": "jan",
                                        "2": "feb",
                                        "3": "mar",
                                        "4": "apr",
                                        "5": "maj",
                                        "6": "jun",
                                        "7": "jul",
                                        "8": "aug",
                                        "9": "sep",
                                        "10": "okt",
                                        "11": "nov",
                                        "12": "dec"
                                    },
                                    "narrow": {
                                        "1": "J",
                                        "2": "F",
                                        "3": "M",
                                        "4": "A",
                                        "5": "M",
                                        "6": "J",
                                        "7": "J",
                                        "8": "A",
                                        "9": "S",
                                        "10": "O",
                                        "11": "N",
                                        "12": "D"
                                    },
                                    "wide": {
                                        "1": "januar",
                                        "2": "februar",
                                        "3": "marts",
                                        "4": "april",
                                        "5": "maj",
                                        "6": "juni",
                                        "7": "juli",
                                        "8": "august",
                                        "9": "september",
                                        "10": "oktober",
                                        "11": "november",
                                        "12": "december"
                                    }
                                }
                            },
                            "days": {
                                "format": {
                                    "abbreviated": {
                                        "sun": "søn.",
                                        "mon": "man.",
                                        "tue": "tir.",
                                        "wed": "ons.",
                                        "thu": "tor.",
                                        "fri": "fre.",
                                        "sat": "lør."
                                    },
                                    "narrow": {
                                        "sun": "S",
                                        "mon": "M",
                                        "tue": "T",
                                        "wed": "O",
                                        "thu": "T",
                                        "fri": "F",
                                        "sat": "L"
                                    },
                                    "short": {
                                        "sun": "sø",
                                        "mon": "ma",
                                        "tue": "ti",
                                        "wed": "on",
                                        "thu": "to",
                                        "fri": "fr",
                                        "sat": "lø"
                                    },
                                    "wide": {
                                        "sun": "søndag",
                                        "mon": "mandag",
                                        "tue": "tirsdag",
                                        "wed": "onsdag",
                                        "thu": "torsdag",
                                        "fri": "fredag",
                                        "sat": "lørdag"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "sun": "søn",
                                        "mon": "man",
                                        "tue": "tir",
                                        "wed": "ons",
                                        "thu": "tor",
                                        "fri": "fre",
                                        "sat": "lør"
                                    },
                                    "narrow": {
                                        "sun": "S",
                                        "mon": "M",
                                        "tue": "T",
                                        "wed": "O",
                                        "thu": "T",
                                        "fri": "F",
                                        "sat": "L"
                                    },
                                    "short": {
                                        "sun": "sø",
                                        "mon": "ma",
                                        "tue": "ti",
                                        "wed": "on",
                                        "thu": "to",
                                        "fri": "fr",
                                        "sat": "lø"
                                    },
                                    "wide": {
                                        "sun": "søndag",
                                        "mon": "mandag",
                                        "tue": "tirsdag",
                                        "wed": "onsdag",
                                        "thu": "torsdag",
                                        "fri": "fredag",
                                        "sat": "lørdag"
                                    }
                                }
                            },
                            "quarters": {
                                "format": {
                                    "abbreviated": {
                                        "1": "K1",
                                        "2": "K2",
                                        "3": "K3",
                                        "4": "K4"
                                    },
                                    "narrow": {
                                        "1": "1",
                                        "2": "2",
                                        "3": "3",
                                        "4": "4"
                                    },
                                    "wide": {
                                        "1": "1. kvartal",
                                        "2": "2. kvartal",
                                        "3": "3. kvartal",
                                        "4": "4. kvartal"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "1": "K1",
                                        "2": "K2",
                                        "3": "K3",
                                        "4": "K4"
                                    },
                                    "narrow": {
                                        "1": "1",
                                        "2": "2",
                                        "3": "3",
                                        "4": "4"
                                    },
                                    "wide": {
                                        "1": "1. kvartal",
                                        "2": "2. kvartal",
                                        "3": "3. kvartal",
                                        "4": "4. kvartal"
                                    }
                                }
                            },
                            "dayPeriods": {
                                "format": {
                                    "abbreviated": {
                                        "am": "AM",
                                        "noon": "middag",
                                        "pm": "PM"
                                    },
                                    "narrow": {
                                        "am": "AM",
                                        "noon": "middag",
                                        "pm": "PM"
                                    },
                                    "wide": {
                                        "am": "AM",
                                        "noon": "middag",
                                        "pm": "PM"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "am": "AM",
                                        "noon": "middag",
                                        "pm": "PM"
                                    },
                                    "narrow": {
                                        "am": "AM",
                                        "noon": "middag",
                                        "pm": "PM"
                                    },
                                    "wide": {
                                        "am": "formiddag",
                                        "noon": "middag",
                                        "pm": "eftermiddag"
                                    }
                                }
                            },
                            "eras": {
                                "eraNames": {
                                    "0": "f.Kr.",
                                    "1": "e.Kr.",
                                    "0-alt-variant": "før vesterlandsk tidsregning",
                                    "1-alt-variant": "vesterlandsk tidsregning"
                                },
                                "eraAbbr": {
                                    "0": "f.Kr.",
                                    "1": "e.Kr.",
                                    "0-alt-variant": "f.v.t.",
                                    "1-alt-variant": "v.t."
                                },
                                "eraNarrow": {
                                    "0": "fKr",
                                    "1": "eKr",
                                    "0-alt-variant": "fvt",
                                    "1-alt-variant": "vt"
                                }
                            },
                            "dateFormats": {
                                "full": "EEEE 'den' d. MMMM y",
                                "long": "d. MMM y",
                                "medium": "dd/MM/y",
                                "short": "dd/MM/yy"
                            },
                            "timeFormats": {
                                "full": "HH.mm.ss zzzz",
                                "long": "HH.mm.ss z",
                                "medium": "HH.mm.ss",
                                "short": "HH.mm"
                            },
                            "dateTimeFormats": {
                                "full": "{1} 'kl.' {0}",
                                "long": "{1} 'kl.' {0}",
                                "medium": "{1} {0}",
                                "short": "{1} {0}",
                                "availableFormats": {
                                    "d": "d.",
                                    "Ed": "E 'd'. d.",
                                    "Ehm": "E h.mm a",
                                    "EHm": "E HH.mm",
                                    "Ehms": "E h.mm.ss a",
                                    "EHms": "E HH.mm.ss",
                                    "Gy": "y G",
                                    "GyMMM": "MMM y G",
                                    "GyMMMd": "d. MMM y G",
                                    "GyMMMEd": "E d. MMM y G",
                                    "h": "h a",
                                    "H": "HH",
                                    "hm": "h.mm a",
                                    "Hm": "HH.mm",
                                    "hms": "h.mm.ss a",
                                    "Hms": "HH.mm.ss",
                                    "M": "M",
                                    "Md": "d/M",
                                    "MEd": "E d/M",
                                    "MMdd": "dd/MM",
                                    "MMM": "MMM",
                                    "MMMd": "d. MMM",
                                    "MMMEd": "E d. MMM",
                                    "MMMMEd": "E d. MMMM",
                                    "ms": "mm.ss",
                                    "y": "y",
                                    "yM": "M/y",
                                    "yMd": "d/M/y",
                                    "yMEd": "E d/M/y",
                                    "yMM": "MM/y",
                                    "yMMM": "MMM y",
                                    "yMMMd": "d. MMM y",
                                    "yMMMEd": "E d. MMM y",
                                    "yQQQ": "QQQ y",
                                    "yQQQQ": "QQQQ y"
                                },
                                "appendItems": {
                                    "Day": "{0} ({2}: {1})",
                                    "Day-Of-Week": "{0} {1}",
                                    "Era": "{1} {0}",
                                    "Hour": "{0} ({2}: {1})",
                                    "Minute": "{0} ({2}: {1})",
                                    "Month": "{0} ({2}: {1})",
                                    "Quarter": "{0} ({2}: {1})",
                                    "Second": "{0} ({2}: {1})",
                                    "Timezone": "{0} {1}",
                                    "Week": "{0} ({2}: {1})",
                                    "Year": "{1} {0}"
                                },
                                "intervalFormats": {
                                    "intervalFormatFallback": "{0} – {1}",
                                    "d": {
                                        "d": "d.–d."
                                    },
                                    "h": {
                                        "a": "h a – h a",
                                        "h": "h–h a"
                                    },
                                    "H": {
                                        "H": "HH–HH"
                                    },
                                    "hm": {
                                        "a": "h.mm a – h.mm a",
                                        "h": "h.mm–h.mm a",
                                        "m": "h.mm–h.mm a"
                                    },
                                    "Hm": {
                                        "H": "HH.mm–HH.mm",
                                        "m": "HH.mm–HH.mm"
                                    },
                                    "hmv": {
                                        "a": "h.mm a – h.mm a v",
                                        "h": "h.mm–h.mm a v",
                                        "m": "h.mm–h.mm a v"
                                    },
                                    "Hmv": {
                                        "H": "HH.mm–HH.mm v",
                                        "m": "HH.mm–HH.mm v"
                                    },
                                    "hv": {
                                        "a": "h a – h a v",
                                        "h": "h–h a v"
                                    },
                                    "Hv": {
                                        "H": "HH–HH v"
                                    },
                                    "M": {
                                        "M": "M–M"
                                    },
                                    "Md": {
                                        "d": "dd/MM – dd/MM",
                                        "M": "dd/MM – dd/MM"
                                    },
                                    "MEd": {
                                        "d": "E dd/MM – E dd/MM",
                                        "M": "E dd/MM – E dd/MM"
                                    },
                                    "MMM": {
                                        "M": "MMM–MMM"
                                    },
                                    "MMMd": {
                                        "d": "d.–d. MMM",
                                        "M": "d. MMM – d. MMM"
                                    },
                                    "MMMEd": {
                                        "d": "E 'den' d. – E 'den' d. MMM",
                                        "M": "E 'den' d. MMM – E 'den' d. MMM"
                                    },
                                    "y": {
                                        "y": "y–y"
                                    },
                                    "yM": {
                                        "M": "MM/y – MM/y",
                                        "y": "MM/y – MM/y"
                                    },
                                    "yMd": {
                                        "d": "dd/MM/y – dd/MM/y",
                                        "M": "dd/MM/y – dd/MM/y",
                                        "y": "dd/MM/y – dd/MM/y"
                                    },
                                    "yMEd": {
                                        "d": "E dd/MM/y – E dd/MM/y",
                                        "M": "E dd/MM/y – E dd/MM/y",
                                        "y": "E dd/MM/y – E dd/MM/y"
                                    },
                                    "yMMM": {
                                        "M": "MMM–MMM y",
                                        "y": "MMM y – MMM y"
                                    },
                                    "yMMMd": {
                                        "d": "d.–d. MMM y",
                                        "M": "d. MMM – d. MMM y",
                                        "y": "d. MMM y – d. MMM y"
                                    },
                                    "yMMMEd": {
                                        "d": "E 'den' d. – E 'den' d. MMM y",
                                        "M": "E 'den' d. MMM – E 'den' d. MMM y",
                                        "y": "E 'den' d. MMM y – E 'den' d. MMM y"
                                    },
                                    "yMMMM": {
                                        "M": "MMMM–MMMM y",
                                        "y": "MMMM y – MMMM y"
                                    }
                                }
                            }
                        }
                    },
                    "timeZoneNames": {
                        "hourFormat": "+HH.mm;-HH.mm",
                        "gmtFormat": "GMT{0}",
                        "gmtZeroFormat": "GMT",
                        "regionFormat": "Tidszone for {0}",
                        "regionFormat-type-daylight": "{0} (+1)",
                        "regionFormat-type-standard": "{0} (+0)",
                        "fallbackFormat": "{1} ({0})"
                    }
                }
            },
            "de": {
                "dates": {
                    "calendars": {
                        "gregorian": {
                            "months": {
                                "format": {
                                    "abbreviated": {
                                        "1": "Jan.",
                                        "2": "Feb.",
                                        "3": "März",
                                        "4": "Apr.",
                                        "5": "Mai",
                                        "6": "Juni",
                                        "7": "Juli",
                                        "8": "Aug.",
                                        "9": "Sep.",
                                        "10": "Okt.",
                                        "11": "Nov.",
                                        "12": "Dez."
                                    },
                                    "narrow": {
                                        "1": "J",
                                        "2": "F",
                                        "3": "M",
                                        "4": "A",
                                        "5": "M",
                                        "6": "J",
                                        "7": "J",
                                        "8": "A",
                                        "9": "S",
                                        "10": "O",
                                        "11": "N",
                                        "12": "D"
                                    },
                                    "wide": {
                                        "1": "Januar",
                                        "2": "Februar",
                                        "3": "März",
                                        "4": "April",
                                        "5": "Mai",
                                        "6": "Juni",
                                        "7": "Juli",
                                        "8": "August",
                                        "9": "September",
                                        "10": "Oktober",
                                        "11": "November",
                                        "12": "Dezember"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "1": "Jan",
                                        "2": "Feb",
                                        "3": "Mär",
                                        "4": "Apr",
                                        "5": "Mai",
                                        "6": "Jun",
                                        "7": "Jul",
                                        "8": "Aug",
                                        "9": "Sep",
                                        "10": "Okt",
                                        "11": "Nov",
                                        "12": "Dez"
                                    },
                                    "narrow": {
                                        "1": "J",
                                        "2": "F",
                                        "3": "M",
                                        "4": "A",
                                        "5": "M",
                                        "6": "J",
                                        "7": "J",
                                        "8": "A",
                                        "9": "S",
                                        "10": "O",
                                        "11": "N",
                                        "12": "D"
                                    },
                                    "wide": {
                                        "1": "Januar",
                                        "2": "Februar",
                                        "3": "März",
                                        "4": "April",
                                        "5": "Mai",
                                        "6": "Juni",
                                        "7": "Juli",
                                        "8": "August",
                                        "9": "September",
                                        "10": "Oktober",
                                        "11": "November",
                                        "12": "Dezember"
                                    }
                                }
                            },
                            "days": {
                                "format": {
                                    "abbreviated": {
                                        "sun": "So.",
                                        "mon": "Mo.",
                                        "tue": "Di.",
                                        "wed": "Mi.",
                                        "thu": "Do.",
                                        "fri": "Fr.",
                                        "sat": "Sa."
                                    },
                                    "narrow": {
                                        "sun": "S",
                                        "mon": "M",
                                        "tue": "D",
                                        "wed": "M",
                                        "thu": "D",
                                        "fri": "F",
                                        "sat": "S"
                                    },
                                    "short": {
                                        "sun": "So.",
                                        "mon": "Mo.",
                                        "tue": "Di.",
                                        "wed": "Mi.",
                                        "thu": "Do.",
                                        "fri": "Fr.",
                                        "sat": "Sa."
                                    },
                                    "wide": {
                                        "sun": "Sonntag",
                                        "mon": "Montag",
                                        "tue": "Dienstag",
                                        "wed": "Mittwoch",
                                        "thu": "Donnerstag",
                                        "fri": "Freitag",
                                        "sat": "Samstag"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "sun": "So",
                                        "mon": "Mo",
                                        "tue": "Di",
                                        "wed": "Mi",
                                        "thu": "Do",
                                        "fri": "Fr",
                                        "sat": "Sa"
                                    },
                                    "narrow": {
                                        "sun": "S",
                                        "mon": "M",
                                        "tue": "D",
                                        "wed": "M",
                                        "thu": "D",
                                        "fri": "F",
                                        "sat": "S"
                                    },
                                    "short": {
                                        "sun": "So.",
                                        "mon": "Mo.",
                                        "tue": "Di.",
                                        "wed": "Mi.",
                                        "thu": "Do.",
                                        "fri": "Fr.",
                                        "sat": "Sa."
                                    },
                                    "wide": {
                                        "sun": "Sonntag",
                                        "mon": "Montag",
                                        "tue": "Dienstag",
                                        "wed": "Mittwoch",
                                        "thu": "Donnerstag",
                                        "fri": "Freitag",
                                        "sat": "Samstag"
                                    }
                                }
                            },
                            "quarters": {
                                "format": {
                                    "abbreviated": {
                                        "1": "Q1",
                                        "2": "Q2",
                                        "3": "Q3",
                                        "4": "Q4"
                                    },
                                    "narrow": {
                                        "1": "1",
                                        "2": "2",
                                        "3": "3",
                                        "4": "4"
                                    },
                                    "wide": {
                                        "1": "1. Quartal",
                                        "2": "2. Quartal",
                                        "3": "3. Quartal",
                                        "4": "4. Quartal"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "1": "Q1",
                                        "2": "Q2",
                                        "3": "Q3",
                                        "4": "Q4"
                                    },
                                    "narrow": {
                                        "1": "1",
                                        "2": "2",
                                        "3": "3",
                                        "4": "4"
                                    },
                                    "wide": {
                                        "1": "1. Quartal",
                                        "2": "2. Quartal",
                                        "3": "3. Quartal",
                                        "4": "4. Quartal"
                                    }
                                }
                            },
                            "dayPeriods": {
                                "format": {
                                    "abbreviated": {
                                        "afternoon": "nachmittags",
                                        "am": "vorm.",
                                        "earlyMorning": "morgens",
                                        "evening": "abends",
                                        "morning": "vormittags",
                                        "night": "nachts",
                                        "noon": "Mittag",
                                        "pm": "nachm."
                                    },
                                    "narrow": {
                                        "afternoon": "nachmittags",
                                        "am": "vorm.",
                                        "earlyMorning": "morgens",
                                        "evening": "abends",
                                        "morning": "vormittags",
                                        "night": "nachts",
                                        "noon": "Mittag",
                                        "pm": "nachm."
                                    },
                                    "wide": {
                                        "afternoon": "nachmittags",
                                        "am": "vorm.",
                                        "earlyMorning": "morgens",
                                        "evening": "abends",
                                        "morning": "vormittags",
                                        "night": "nachts",
                                        "noon": "Mittag",
                                        "pm": "nachm."
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "afternoon": "nachmittags",
                                        "am": "vorm.",
                                        "earlyMorning": "morgens",
                                        "evening": "abends",
                                        "morning": "vormittags",
                                        "night": "nachts",
                                        "noon": "Mittag",
                                        "pm": "nachm."
                                    },
                                    "narrow": {
                                        "afternoon": "nachmittags",
                                        "am": "vorm.",
                                        "earlyMorning": "morgens",
                                        "evening": "abends",
                                        "morning": "vormittags",
                                        "night": "nachts",
                                        "noon": "Mittag",
                                        "pm": "nachm."
                                    },
                                    "wide": {
                                        "afternoon": "Nachmittag",
                                        "am": "vorm.",
                                        "earlyMorning": "Morgen",
                                        "evening": "Abend",
                                        "morning": "Vormittag",
                                        "night": "Nacht",
                                        "noon": "Mittag",
                                        "pm": "nachm."
                                    }
                                }
                            },
                            "eras": {
                                "eraNames": {
                                    "0": "v. Chr.",
                                    "1": "n. Chr.",
                                    "0-alt-variant": "vor der gewöhnlichen Zeitrechnung",
                                    "1-alt-variant": "der gewöhnlichen Zeitrechnung"
                                },
                                "eraAbbr": {
                                    "0": "v. Chr.",
                                    "1": "n. Chr.",
                                    "0-alt-variant": "v. u. Z.",
                                    "1-alt-variant": "u. Z."
                                },
                                "eraNarrow": {
                                    "0": "v. Chr.",
                                    "1": "n. Chr.",
                                    "0-alt-variant": "vdZ",
                                    "1-alt-variant": "dZ"
                                }
                            },
                            "dateFormats": {
                                "full": "EEEE, d. MMMM y",
                                "long": "d. MMMM y",
                                "medium": "dd.MM.y",
                                "short": "dd.MM.yy"
                            },
                            "timeFormats": {
                                "full": "HH:mm:ss zzzz",
                                "long": "HH:mm:ss z",
                                "medium": "HH:mm:ss",
                                "short": "HH:mm"
                            },
                            "dateTimeFormats": {
                                "full": "{1} {0}",
                                "long": "{1} {0}",
                                "medium": "{1} {0}",
                                "short": "{1} {0}",
                                "availableFormats": {
                                    "d": "d",
                                    "Ed": "E, d.",
                                    "Ehm": "E h:mm a",
                                    "EHm": "E, HH:mm",
                                    "Ehms": "E, h:mm:ss a",
                                    "EHms": "E, HH:mm:ss",
                                    "Gy": "y G",
                                    "GyMMM": "MMM y G",
                                    "GyMMMd": "d. MMM y G",
                                    "GyMMMEd": "E, d. MMM y G",
                                    "h": "h a",
                                    "H": "HH 'Uhr'",
                                    "hm": "h:mm a",
                                    "Hm": "HH:mm",
                                    "hms": "h:mm:ss a",
                                    "Hms": "HH:mm:ss",
                                    "M": "L",
                                    "Md": "d.M.",
                                    "MEd": "E, d.M.",
                                    "MMd": "d.MM.",
                                    "MMdd": "dd.MM.",
                                    "MMM": "LLL",
                                    "MMMd": "d. MMM",
                                    "MMMEd": "E, d. MMM",
                                    "MMMMdd": "dd. MMMM",
                                    "MMMMEd": "E, d. MMMM",
                                    "ms": "mm:ss",
                                    "y": "y",
                                    "yM": "M.y",
                                    "yMd": "d.M.y",
                                    "yMEd": "E, d.M.y",
                                    "yMM": "MM.y",
                                    "yMMdd": "dd.MM.y",
                                    "yMMM": "MMM y",
                                    "yMMMd": "d. MMM y",
                                    "yMMMEd": "E, d. MMM y",
                                    "yMMMM": "MMMM y",
                                    "yQQQ": "QQQ y",
                                    "yQQQQ": "QQQQ y"
                                },
                                "appendItems": {
                                    "Day": "{0} ({2}: {1})",
                                    "Day-Of-Week": "{0} {1}",
                                    "Era": "{1} {0}",
                                    "Hour": "{0} ({2}: {1})",
                                    "Minute": "{0} ({2}: {1})",
                                    "Month": "{0} ({2}: {1})",
                                    "Quarter": "{0} ({2}: {1})",
                                    "Second": "{0} ({2}: {1})",
                                    "Timezone": "{0} {1}",
                                    "Week": "{0} ({2}: {1})",
                                    "Year": "{1} {0}"
                                },
                                "intervalFormats": {
                                    "intervalFormatFallback": "{0} - {1}",
                                    "d": {
                                        "d": "d.-d."
                                    },
                                    "h": {
                                        "a": "h a - h a",
                                        "h": "h-h a"
                                    },
                                    "H": {
                                        "H": "HH-HH 'Uhr'"
                                    },
                                    "hm": {
                                        "a": "h:mm a - h:mm a",
                                        "h": "h:mm-h:mm a",
                                        "m": "h:mm-h:mm a"
                                    },
                                    "Hm": {
                                        "H": "HH:mm-HH:mm",
                                        "m": "HH:mm-HH:mm"
                                    },
                                    "hmv": {
                                        "a": "h:mm a - h:mm a v",
                                        "h": "h:mm-h:mm a v",
                                        "m": "h:mm-h:mm a v"
                                    },
                                    "Hmv": {
                                        "H": "HH:mm-HH:mm v",
                                        "m": "HH:mm-HH:mm v"
                                    },
                                    "hv": {
                                        "a": "h a - h a v",
                                        "h": "h-h a v"
                                    },
                                    "Hv": {
                                        "H": "HH-HH 'Uhr' v"
                                    },
                                    "M": {
                                        "M": "M.-M."
                                    },
                                    "Md": {
                                        "d": "dd.MM. - dd.MM.",
                                        "M": "dd.MM. - dd.MM."
                                    },
                                    "MEd": {
                                        "d": "E, dd.MM. - E, dd.MM.",
                                        "M": "E, dd.MM. - E, dd.MM."
                                    },
                                    "MMM": {
                                        "M": "MMM-MMM"
                                    },
                                    "MMMd": {
                                        "d": "d.-d. MMM",
                                        "M": "d. MMM - d. MMM"
                                    },
                                    "MMMEd": {
                                        "d": "E, d. - E, d. MMM",
                                        "M": "E, d. MMM - E, d. MMM"
                                    },
                                    "MMMM": {
                                        "M": "LLLL-LLLL"
                                    },
                                    "y": {
                                        "y": "y-y"
                                    },
                                    "yM": {
                                        "M": "MM.y - MM.y",
                                        "y": "MM.y - MM.y"
                                    },
                                    "yMd": {
                                        "d": "dd.MM.y - dd.MM.y",
                                        "M": "dd.MM.y - dd.MM.y",
                                        "y": "dd.MM.y - dd.MM.y"
                                    },
                                    "yMEd": {
                                        "d": "E, dd.MM.y - E, dd.MM.y",
                                        "M": "E, dd.MM.y - E, dd.MM.y",
                                        "y": "E, dd.MM.y - E, dd.MM.y"
                                    },
                                    "yMMM": {
                                        "M": "MMM-MMM y",
                                        "y": "MMM y - MMM y"
                                    },
                                    "yMMMd": {
                                        "d": "d.-d. MMM y",
                                        "M": "d. MMM - d. MMM y",
                                        "y": "d. MMM y - d. MMM y"
                                    },
                                    "yMMMEd": {
                                        "d": "E, d. - E, d. MMM y",
                                        "M": "E, d. MMM - E, d. MMM y",
                                        "y": "E, d. MMM y - E, d. MMM y"
                                    },
                                    "yMMMM": {
                                        "M": "MMMM-MMMM y",
                                        "y": "MMMM y - MMMM y"
                                    }
                                }
                            }
                        }
                    },
                    "timeZoneNames": {
                        "hourFormat": "+HH:mm;-HH:mm",
                        "gmtFormat": "GMT{0}",
                        "gmtZeroFormat": "GMT",
                        "regionFormat": "{0} Zeit",
                        "regionFormat-type-daylight": "{0} Sommerzeit",
                        "regionFormat-type-standard": "{0} Normalzeit",
                        "fallbackFormat": "{1} ({0})"
                    }
                }
            },
            "el": {
                "dates": {
                    "calendars": {
                        "gregorian": {
                            "months": {
                                "format": {
                                    "abbreviated": {
                                        "1": "Ιαν",
                                        "2": "Φεβ",
                                        "3": "Μαρ",
                                        "4": "Απρ",
                                        "5": "Μαΐ",
                                        "6": "Ιουν",
                                        "7": "Ιουλ",
                                        "8": "Αυγ",
                                        "9": "Σεπ",
                                        "10": "Οκτ",
                                        "11": "Νοε",
                                        "12": "Δεκ"
                                    },
                                    "narrow": {
                                        "1": "Ι",
                                        "2": "Φ",
                                        "3": "Μ",
                                        "4": "Α",
                                        "5": "Μ",
                                        "6": "Ι",
                                        "7": "Ι",
                                        "8": "Α",
                                        "9": "Σ",
                                        "10": "Ο",
                                        "11": "Ν",
                                        "12": "Δ"
                                    },
                                    "wide": {
                                        "1": "Ιανουαρίου",
                                        "2": "Φεβρουαρίου",
                                        "3": "Μαρτίου",
                                        "4": "Απριλίου",
                                        "5": "Μαΐου",
                                        "6": "Ιουνίου",
                                        "7": "Ιουλίου",
                                        "8": "Αυγούστου",
                                        "9": "Σεπτεμβρίου",
                                        "10": "Οκτωβρίου",
                                        "11": "Νοεμβρίου",
                                        "12": "Δεκεμβρίου"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "1": "Ιαν",
                                        "2": "Φεβ",
                                        "3": "Μάρ",
                                        "4": "Απρ",
                                        "5": "Μάι",
                                        "6": "Ιούν",
                                        "7": "Ιούλ",
                                        "8": "Αύγ",
                                        "9": "Σεπ",
                                        "10": "Οκτ",
                                        "11": "Νοέ",
                                        "12": "Δεκ"
                                    },
                                    "narrow": {
                                        "1": "Ι",
                                        "2": "Φ",
                                        "3": "Μ",
                                        "4": "Α",
                                        "5": "Μ",
                                        "6": "Ι",
                                        "7": "Ι",
                                        "8": "Α",
                                        "9": "Σ",
                                        "10": "Ο",
                                        "11": "Ν",
                                        "12": "Δ"
                                    },
                                    "wide": {
                                        "1": "Ιανουάριος",
                                        "2": "Φεβρουάριος",
                                        "3": "Μάρτιος",
                                        "4": "Απρίλιος",
                                        "5": "Μάιος",
                                        "6": "Ιούνιος",
                                        "7": "Ιούλιος",
                                        "8": "Αύγουστος",
                                        "9": "Σεπτέμβριος",
                                        "10": "Οκτώβριος",
                                        "11": "Νοέμβριος",
                                        "12": "Δεκέμβριος"
                                    }
                                }
                            },
                            "days": {
                                "format": {
                                    "abbreviated": {
                                        "sun": "Κυρ",
                                        "mon": "Δευ",
                                        "tue": "Τρί",
                                        "wed": "Τετ",
                                        "thu": "Πέμ",
                                        "fri": "Παρ",
                                        "sat": "Σάβ"
                                    },
                                    "narrow": {
                                        "sun": "Κ",
                                        "mon": "Δ",
                                        "tue": "Τ",
                                        "wed": "Τ",
                                        "thu": "Π",
                                        "fri": "Π",
                                        "sat": "Σ"
                                    },
                                    "short": {
                                        "sun": "Κυ",
                                        "mon": "Δε",
                                        "tue": "Τρ",
                                        "wed": "Τε",
                                        "thu": "Πέ",
                                        "fri": "Πα",
                                        "sat": "Σά"
                                    },
                                    "wide": {
                                        "sun": "Κυριακή",
                                        "mon": "Δευτέρα",
                                        "tue": "Τρίτη",
                                        "wed": "Τετάρτη",
                                        "thu": "Πέμπτη",
                                        "fri": "Παρασκευή",
                                        "sat": "Σάββατο"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "sun": "Κυρ",
                                        "mon": "Δευ",
                                        "tue": "Τρί",
                                        "wed": "Τετ",
                                        "thu": "Πέμ",
                                        "fri": "Παρ",
                                        "sat": "Σάβ"
                                    },
                                    "narrow": {
                                        "sun": "Κ",
                                        "mon": "Δ",
                                        "tue": "Τ",
                                        "wed": "Τ",
                                        "thu": "Π",
                                        "fri": "Π",
                                        "sat": "Σ"
                                    },
                                    "short": {
                                        "sun": "Κυ",
                                        "mon": "Δε",
                                        "tue": "Τρ",
                                        "wed": "Τε",
                                        "thu": "Πέ",
                                        "fri": "Πα",
                                        "sat": "Σά"
                                    },
                                    "wide": {
                                        "sun": "Κυριακή",
                                        "mon": "Δευτέρα",
                                        "tue": "Τρίτη",
                                        "wed": "Τετάρτη",
                                        "thu": "Πέμπτη",
                                        "fri": "Παρασκευή",
                                        "sat": "Σάββατο"
                                    }
                                }
                            },
                            "quarters": {
                                "format": {
                                    "abbreviated": {
                                        "1": "Τ1",
                                        "2": "Τ2",
                                        "3": "Τ3",
                                        "4": "Τ4"
                                    },
                                    "narrow": {
                                        "1": "1",
                                        "2": "2",
                                        "3": "3",
                                        "4": "4"
                                    },
                                    "wide": {
                                        "1": "1ο τρίμηνο",
                                        "2": "2ο τρίμηνο",
                                        "3": "3ο τρίμηνο",
                                        "4": "4ο τρίμηνο"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "1": "Τ1",
                                        "2": "Τ2",
                                        "3": "Τ3",
                                        "4": "Τ4"
                                    },
                                    "narrow": {
                                        "1": "1",
                                        "2": "2",
                                        "3": "3",
                                        "4": "4"
                                    },
                                    "wide": {
                                        "1": "1ο τρίμηνο",
                                        "2": "2ο τρίμηνο",
                                        "3": "3ο τρίμηνο",
                                        "4": "4ο τρίμηνο"
                                    }
                                }
                            },
                            "dayPeriods": {
                                "format": {
                                    "abbreviated": {
                                        "am": "π.μ.",
                                        "pm": "μ.μ."
                                    },
                                    "narrow": {
                                        "am": "π.μ.",
                                        "pm": "μ.μ."
                                    },
                                    "wide": {
                                        "am": "π.μ.",
                                        "pm": "μ.μ."
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "am": "π.μ.",
                                        "pm": "μ.μ."
                                    },
                                    "narrow": {
                                        "am": "π.μ.",
                                        "pm": "μ.μ."
                                    },
                                    "wide": {
                                        "am": "π.μ.",
                                        "pm": "μ.μ."
                                    }
                                }
                            },
                            "eras": {
                                "eraNames": {
                                    "0": "π.Χ.",
                                    "1": "μ.Χ.",
                                    "0-alt-variant": "π.Κ.Χ.",
                                    "1-alt-variant": "ΚΧ"
                                },
                                "eraAbbr": {
                                    "0": "π.Χ.",
                                    "1": "μ.Χ.",
                                    "0-alt-variant": "π.Κ.Χ.",
                                    "1-alt-variant": "ΚΧ"
                                },
                                "eraNarrow": {
                                    "0": "π.Χ.",
                                    "1": "μ.Χ.",
                                    "0-alt-variant": "π.Κ.Χ.",
                                    "1-alt-variant": "ΚΧ"
                                }
                            },
                            "dateFormats": {
                                "full": "EEEE, d MMMM y",
                                "long": "d MMMM y",
                                "medium": "d MMM y",
                                "short": "d/M/yy"
                            },
                            "timeFormats": {
                                "full": "h:mm:ss a zzzz",
                                "long": "h:mm:ss a z",
                                "medium": "h:mm:ss a",
                                "short": "h:mm a"
                            },
                            "dateTimeFormats": {
                                "full": "{1} - {0}",
                                "long": "{1} - {0}",
                                "medium": "{1} - {0}",
                                "short": "{1} - {0}",
                                "availableFormats": {
                                    "d": "d",
                                    "Ed": "E d",
                                    "Ehm": "E h:mm a",
                                    "EHm": "E HH:mm",
                                    "Ehms": "E h:mm:ss a",
                                    "EHms": "E HH:mm:ss",
                                    "Gy": "y G",
                                    "GyMMM": "LLL y G",
                                    "GyMMMd": "d MMM y G",
                                    "GyMMMEd": "E, d MMM y G",
                                    "h": "h a",
                                    "H": "HH",
                                    "HHmm": "HH:mm",
                                    "HHmmss": "HH:mm:ss",
                                    "hm": "h:mm a",
                                    "Hm": "HH:mm",
                                    "hms": "h:mm:ss a",
                                    "Hms": "HH:mm:ss",
                                    "M": "L",
                                    "Md": "d/M",
                                    "MEd": "E, d/M",
                                    "MMM": "LLL",
                                    "MMMd": "d MMM",
                                    "MMMEd": "E, d MMM",
                                    "MMMMd": "d MMMM",
                                    "MMMMEd": "E, d MMMM",
                                    "ms": "mm:ss",
                                    "y": "y",
                                    "yM": "M/y",
                                    "yMd": "d/M/y",
                                    "yMEd": "E, d/M/y",
                                    "yMMM": "LLL y",
                                    "yMMMd": "d MMM y",
                                    "yMMMEd": "E, d MMM y",
                                    "yMMMM": "LLLL y",
                                    "yQQQ": "y QQQ",
                                    "yQQQQ": "y QQQQ"
                                },
                                "appendItems": {
                                    "Day": "{0} ({2}: {1})",
                                    "Day-Of-Week": "{0} {1}",
                                    "Era": "{1} {0}",
                                    "Hour": "{0} ({2}: {1})",
                                    "Minute": "{0} ({2}: {1})",
                                    "Month": "{0} ({2}: {1})",
                                    "Quarter": "{0} ({2}: {1})",
                                    "Second": "{0} ({2}: {1})",
                                    "Timezone": "{0} {1}",
                                    "Week": "{0} ({2}: {1})",
                                    "Year": "{1} {0}"
                                },
                                "intervalFormats": {
                                    "intervalFormatFallback": "{0} - {1}",
                                    "d": {
                                        "d": "d-d"
                                    },
                                    "h": {
                                        "a": "h a - h a",
                                        "h": "h-h a"
                                    },
                                    "H": {
                                        "H": "HH–HH"
                                    },
                                    "hm": {
                                        "a": "h:mm a - h:mm a",
                                        "h": "h:mm-h:mm a",
                                        "m": "h:mm-h:mm a"
                                    },
                                    "Hm": {
                                        "H": "HH:mm–HH:mm",
                                        "m": "HH:mm–HH:mm"
                                    },
                                    "hmv": {
                                        "a": "h:mm a - h:mm a v",
                                        "h": "h:mm-h:mm a v",
                                        "m": "h:mm-h:mm a v"
                                    },
                                    "Hmv": {
                                        "H": "HH:mm–HH:mm v",
                                        "m": "HH:mm–HH:mm v"
                                    },
                                    "hv": {
                                        "a": "h a - h a v",
                                        "h": "h-h a v"
                                    },
                                    "Hv": {
                                        "H": "HH–HH v"
                                    },
                                    "M": {
                                        "M": "M-M"
                                    },
                                    "Md": {
                                        "d": "dd/MM - dd/MM",
                                        "M": "dd/MM - dd/MM"
                                    },
                                    "MEd": {
                                        "d": "E, dd/MM - E, dd/MM",
                                        "M": "E, dd/MM - E, dd/MM"
                                    },
                                    "MMM": {
                                        "M": "LLL-LLL"
                                    },
                                    "MMMd": {
                                        "d": "dd-dd MMM",
                                        "M": "dd MMM - dd MMM"
                                    },
                                    "MMMEd": {
                                        "d": "E, dd - E, dd MMM",
                                        "M": "E, dd MMM - E, dd MMM"
                                    },
                                    "y": {
                                        "y": "y-y"
                                    },
                                    "yM": {
                                        "M": "MM/y - MM/y",
                                        "y": "MM/y - MM/y"
                                    },
                                    "yMd": {
                                        "d": "dd/MM/y - dd/MM/y",
                                        "M": "dd/MM/y - dd/MM/y",
                                        "y": "dd/MM/y - dd/MM/y"
                                    },
                                    "yMEd": {
                                        "d": "E, dd/MM/y - E, dd/MM/y",
                                        "M": "E, dd/MM/y - E, dd/MM/y",
                                        "y": "E, dd/MM/y - E, dd/MM/y"
                                    },
                                    "yMMM": {
                                        "M": "LLL-LLL y",
                                        "y": "MMM y - MMM y"
                                    },
                                    "yMMMd": {
                                        "d": "dd-dd MMM y",
                                        "M": "dd MMM - dd MMM y",
                                        "y": "dd MMM y - dd MMM y"
                                    },
                                    "yMMMEd": {
                                        "d": "E, dd MMM - E, dd MMM y",
                                        "M": "E, dd MMM - E, dd MMM y",
                                        "y": "E, dd MMM y - E, dd MMM y"
                                    },
                                    "yMMMM": {
                                        "M": "LLLL-LLLL y",
                                        "y": "LLLL y - LLLL y"
                                    }
                                }
                            }
                        }
                    },
                    "timeZoneNames": {
                        "hourFormat": "+HH:mm;-HH:mm",
                        "gmtFormat": "GMT{0}",
                        "gmtZeroFormat": "GMT",
                        "regionFormat": "Ώρα ({0})",
                        "regionFormat-type-daylight": "Θερινή ώρα ({0})",
                        "regionFormat-type-standard": "Χειμερινή ώρα ({0})",
                        "fallbackFormat": "[{1} ({0})]"
                    }
                }
            },
            "en": {
                "dates": {
                    "calendars": {
                        "gregorian": {
                            "months": {
                                "format": {
                                    "abbreviated": {
                                        "1": "Jan",
                                        "2": "Feb",
                                        "3": "Mar",
                                        "4": "Apr",
                                        "5": "May",
                                        "6": "Jun",
                                        "7": "Jul",
                                        "8": "Aug",
                                        "9": "Sep",
                                        "10": "Oct",
                                        "11": "Nov",
                                        "12": "Dec"
                                    },
                                    "narrow": {
                                        "1": "J",
                                        "2": "F",
                                        "3": "M",
                                        "4": "A",
                                        "5": "M",
                                        "6": "J",
                                        "7": "J",
                                        "8": "A",
                                        "9": "S",
                                        "10": "O",
                                        "11": "N",
                                        "12": "D"
                                    },
                                    "wide": {
                                        "1": "January",
                                        "2": "February",
                                        "3": "March",
                                        "4": "April",
                                        "5": "May",
                                        "6": "June",
                                        "7": "July",
                                        "8": "August",
                                        "9": "September",
                                        "10": "October",
                                        "11": "November",
                                        "12": "December"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "1": "Jan",
                                        "2": "Feb",
                                        "3": "Mar",
                                        "4": "Apr",
                                        "5": "May",
                                        "6": "Jun",
                                        "7": "Jul",
                                        "8": "Aug",
                                        "9": "Sep",
                                        "10": "Oct",
                                        "11": "Nov",
                                        "12": "Dec"
                                    },
                                    "narrow": {
                                        "1": "J",
                                        "2": "F",
                                        "3": "M",
                                        "4": "A",
                                        "5": "M",
                                        "6": "J",
                                        "7": "J",
                                        "8": "A",
                                        "9": "S",
                                        "10": "O",
                                        "11": "N",
                                        "12": "D"
                                    },
                                    "wide": {
                                        "1": "January",
                                        "2": "February",
                                        "3": "March",
                                        "4": "April",
                                        "5": "May",
                                        "6": "June",
                                        "7": "July",
                                        "8": "August",
                                        "9": "September",
                                        "10": "October",
                                        "11": "November",
                                        "12": "December"
                                    }
                                }
                            },
                            "days": {
                                "format": {
                                    "abbreviated": {
                                        "sun": "Sun",
                                        "mon": "Mon",
                                        "tue": "Tue",
                                        "wed": "Wed",
                                        "thu": "Thu",
                                        "fri": "Fri",
                                        "sat": "Sat"
                                    },
                                    "narrow": {
                                        "sun": "S",
                                        "mon": "M",
                                        "tue": "T",
                                        "wed": "W",
                                        "thu": "T",
                                        "fri": "F",
                                        "sat": "S"
                                    },
                                    "short": {
                                        "sun": "Su",
                                        "mon": "Mo",
                                        "tue": "Tu",
                                        "wed": "We",
                                        "thu": "Th",
                                        "fri": "Fr",
                                        "sat": "Sa"
                                    },
                                    "wide": {
                                        "sun": "Sunday",
                                        "mon": "Monday",
                                        "tue": "Tuesday",
                                        "wed": "Wednesday",
                                        "thu": "Thursday",
                                        "fri": "Friday",
                                        "sat": "Saturday"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "sun": "Sun",
                                        "mon": "Mon",
                                        "tue": "Tue",
                                        "wed": "Wed",
                                        "thu": "Thu",
                                        "fri": "Fri",
                                        "sat": "Sat"
                                    },
                                    "narrow": {
                                        "sun": "S",
                                        "mon": "M",
                                        "tue": "T",
                                        "wed": "W",
                                        "thu": "T",
                                        "fri": "F",
                                        "sat": "S"
                                    },
                                    "short": {
                                        "sun": "Su",
                                        "mon": "Mo",
                                        "tue": "Tu",
                                        "wed": "We",
                                        "thu": "Th",
                                        "fri": "Fr",
                                        "sat": "Sa"
                                    },
                                    "wide": {
                                        "sun": "Sunday",
                                        "mon": "Monday",
                                        "tue": "Tuesday",
                                        "wed": "Wednesday",
                                        "thu": "Thursday",
                                        "fri": "Friday",
                                        "sat": "Saturday"
                                    }
                                }
                            },
                            "quarters": {
                                "format": {
                                    "abbreviated": {
                                        "1": "Q1",
                                        "2": "Q2",
                                        "3": "Q3",
                                        "4": "Q4"
                                    },
                                    "narrow": {
                                        "1": "1",
                                        "2": "2",
                                        "3": "3",
                                        "4": "4"
                                    },
                                    "wide": {
                                        "1": "1st quarter",
                                        "2": "2nd quarter",
                                        "3": "3rd quarter",
                                        "4": "4th quarter"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "1": "Q1",
                                        "2": "Q2",
                                        "3": "Q3",
                                        "4": "Q4"
                                    },
                                    "narrow": {
                                        "1": "1",
                                        "2": "2",
                                        "3": "3",
                                        "4": "4"
                                    },
                                    "wide": {
                                        "1": "1st quarter",
                                        "2": "2nd quarter",
                                        "3": "3rd quarter",
                                        "4": "4th quarter"
                                    }
                                }
                            },
                            "dayPeriods": {
                                "format": {
                                    "abbreviated": {
                                        "am": "AM",
                                        "am-alt-variant": "a.m.",
                                        "noon": "noon",
                                        "pm": "PM",
                                        "pm-alt-variant": "p.m."
                                    },
                                    "narrow": {
                                        "am": "a",
                                        "am-alt-variant": "a.m.",
                                        "noon": "n",
                                        "pm": "p",
                                        "pm-alt-variant": "p.m."
                                    },
                                    "wide": {
                                        "am": "AM",
                                        "am-alt-variant": "a.m.",
                                        "noon": "noon",
                                        "pm": "PM",
                                        "pm-alt-variant": "p.m."
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "am": "AM",
                                        "am-alt-variant": "a.m.",
                                        "noon": "noon",
                                        "pm": "PM",
                                        "pm-alt-variant": "p.m."
                                    },
                                    "narrow": {
                                        "am": "a",
                                        "am-alt-variant": "a.m.",
                                        "noon": "n",
                                        "pm": "p",
                                        "pm-alt-variant": "p.m."
                                    },
                                    "wide": {
                                        "am": "AM",
                                        "am-alt-variant": "a.m.",
                                        "noon": "noon",
                                        "pm": "PM",
                                        "pm-alt-variant": "p.m."
                                    }
                                }
                            },
                            "eras": {
                                "eraNames": {
                                    "0": "Before Christ",
                                    "1": "Anno Domini",
                                    "0-alt-variant": "Before Common Era",
                                    "1-alt-variant": "Common Era"
                                },
                                "eraAbbr": {
                                    "0": "BC",
                                    "1": "AD",
                                    "0-alt-variant": "BCE",
                                    "1-alt-variant": "CE"
                                },
                                "eraNarrow": {
                                    "0": "B",
                                    "1": "A",
                                    "0-alt-variant": "BCE",
                                    "1-alt-variant": "CE"
                                }
                            },
                            "dateFormats": {
                                "full": "EEEE, MMMM d, y",
                                "long": "MMMM d, y",
                                "medium": "MMM d, y",
                                "short": "M/d/yy"
                            },
                            "timeFormats": {
                                "full": "h:mm:ss a zzzz",
                                "long": "h:mm:ss a z",
                                "medium": "h:mm:ss a",
                                "short": "h:mm a"
                            },
                            "dateTimeFormats": {
                                "full": "{1} 'at' {0}",
                                "long": "{1} 'at' {0}",
                                "medium": "{1}, {0}",
                                "short": "{1}, {0}",
                                "availableFormats": {
                                    "d": "d",
                                    "Ed": "d E",
                                    "Ehm": "E h:mm a",
                                    "EHm": "E HH:mm",
                                    "Ehms": "E h:mm:ss a",
                                    "EHms": "E HH:mm:ss",
                                    "Gy": "y G",
                                    "GyMMM": "MMM y G",
                                    "GyMMMd": "MMM d, y G",
                                    "GyMMMEd": "E, MMM d, y G",
                                    "h": "h a",
                                    "H": "HH",
                                    "hm": "h:mm a",
                                    "Hm": "HH:mm",
                                    "hms": "h:mm:ss a",
                                    "Hms": "HH:mm:ss",
                                    "M": "L",
                                    "Md": "M/d",
                                    "MEd": "E, M/d",
                                    "MMM": "LLL",
                                    "MMMd": "MMM d",
                                    "MMMEd": "E, MMM d",
                                    "ms": "mm:ss",
                                    "y": "y",
                                    "yM": "M/y",
                                    "yMd": "M/d/y",
                                    "yMEd": "E, M/d/y",
                                    "yMMM": "MMM y",
                                    "yMMMd": "MMM d, y",
                                    "yMMMEd": "E, MMM d, y",
                                    "yQQQ": "QQQ y",
                                    "yQQQQ": "QQQQ y"
                                },
                                "appendItems": {
                                    "Day": "{0} ({2}: {1})",
                                    "Day-Of-Week": "{0} {1}",
                                    "Era": "{0} {1}",
                                    "Hour": "{0} ({2}: {1})",
                                    "Minute": "{0} ({2}: {1})",
                                    "Month": "{0} ({2}: {1})",
                                    "Quarter": "{0} ({2}: {1})",
                                    "Second": "{0} ({2}: {1})",
                                    "Timezone": "{0} {1}",
                                    "Week": "{0} ({2}: {1})",
                                    "Year": "{0} {1}"
                                },
                                "intervalFormats": {
                                    "intervalFormatFallback": "{0} – {1}",
                                    "d": {
                                        "d": "d – d"
                                    },
                                    "h": {
                                        "a": "h a – h a",
                                        "h": "h – h a"
                                    },
                                    "H": {
                                        "H": "HH – HH"
                                    },
                                    "hm": {
                                        "a": "h:mm a – h:mm a",
                                        "h": "h:mm – h:mm a",
                                        "m": "h:mm – h:mm a"
                                    },
                                    "Hm": {
                                        "H": "HH:mm – HH:mm",
                                        "m": "HH:mm – HH:mm"
                                    },
                                    "hmv": {
                                        "a": "h:mm a – h:mm a v",
                                        "h": "h:mm – h:mm a v",
                                        "m": "h:mm – h:mm a v"
                                    },
                                    "Hmv": {
                                        "H": "HH:mm – HH:mm v",
                                        "m": "HH:mm – HH:mm v"
                                    },
                                    "hv": {
                                        "a": "h a – h a v",
                                        "h": "h – h a v"
                                    },
                                    "Hv": {
                                        "H": "HH – HH v"
                                    },
                                    "M": {
                                        "M": "M – M"
                                    },
                                    "Md": {
                                        "d": "M/d – M/d",
                                        "M": "M/d – M/d"
                                    },
                                    "MEd": {
                                        "d": "E, M/d – E, M/d",
                                        "M": "E, M/d – E, M/d"
                                    },
                                    "MMM": {
                                        "M": "MMM – MMM"
                                    },
                                    "MMMd": {
                                        "d": "MMM d – d",
                                        "M": "MMM d – MMM d"
                                    },
                                    "MMMEd": {
                                        "d": "E, MMM d – E, MMM d",
                                        "M": "E, MMM d – E, MMM d"
                                    },
                                    "y": {
                                        "y": "y – y"
                                    },
                                    "yM": {
                                        "M": "M/y – M/y",
                                        "y": "M/y – M/y"
                                    },
                                    "yMd": {
                                        "d": "M/d/y – M/d/y",
                                        "M": "M/d/y – M/d/y",
                                        "y": "M/d/y – M/d/y"
                                    },
                                    "yMEd": {
                                        "d": "E, M/d/y – E, M/d/y",
                                        "M": "E, M/d/y – E, M/d/y",
                                        "y": "E, M/d/y – E, M/d/y"
                                    },
                                    "yMMM": {
                                        "M": "MMM – MMM y",
                                        "y": "MMM y – MMM y"
                                    },
                                    "yMMMd": {
                                        "d": "MMM d – d, y",
                                        "M": "MMM d – MMM d, y",
                                        "y": "MMM d, y – MMM d, y"
                                    },
                                    "yMMMEd": {
                                        "d": "E, MMM d – E, MMM d, y",
                                        "M": "E, MMM d – E, MMM d, y",
                                        "y": "E, MMM d, y – E, MMM d, y"
                                    },
                                    "yMMMM": {
                                        "M": "MMMM – MMMM y",
                                        "y": "MMMM y – MMMM y"
                                    }
                                }
                            }
                        }
                    },
                    "timeZoneNames": {
                        "hourFormat": "+HH:mm;-HH:mm",
                        "gmtFormat": "GMT{0}",
                        "gmtZeroFormat": "GMT",
                        "regionFormat": "{0} Time",
                        "regionFormat-type-daylight": "{0} Daylight Time",
                        "regionFormat-type-standard": "{0} Standard Time",
                        "fallbackFormat": "{1} ({0})"
                    }
                }
            },
            "en-AU": {
                "dates": {
                    "calendars": {
                        "gregorian": {
                            "months": {
                                "format": {
                                    "abbreviated": {
                                        "1": "Jan",
                                        "2": "Feb",
                                        "3": "Mar",
                                        "4": "Apr",
                                        "5": "May",
                                        "6": "Jun",
                                        "7": "Jul",
                                        "8": "Aug",
                                        "9": "Sep",
                                        "10": "Oct",
                                        "11": "Nov",
                                        "12": "Dec"
                                    },
                                    "narrow": {
                                        "1": "J",
                                        "2": "F",
                                        "3": "M",
                                        "4": "A",
                                        "5": "M",
                                        "6": "J",
                                        "7": "J",
                                        "8": "A",
                                        "9": "S",
                                        "10": "O",
                                        "11": "N",
                                        "12": "D"
                                    },
                                    "wide": {
                                        "1": "January",
                                        "2": "February",
                                        "3": "March",
                                        "4": "April",
                                        "5": "May",
                                        "6": "June",
                                        "7": "July",
                                        "8": "August",
                                        "9": "September",
                                        "10": "October",
                                        "11": "November",
                                        "12": "December"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "1": "Jan",
                                        "2": "Feb",
                                        "3": "Mar",
                                        "4": "Apr",
                                        "5": "May",
                                        "6": "Jun",
                                        "7": "Jul",
                                        "8": "Aug",
                                        "9": "Sep",
                                        "10": "Oct",
                                        "11": "Nov",
                                        "12": "Dec"
                                    },
                                    "narrow": {
                                        "1": "J",
                                        "2": "F",
                                        "3": "M",
                                        "4": "A",
                                        "5": "M",
                                        "6": "J",
                                        "7": "J",
                                        "8": "A",
                                        "9": "S",
                                        "10": "O",
                                        "11": "N",
                                        "12": "D"
                                    },
                                    "wide": {
                                        "1": "January",
                                        "2": "February",
                                        "3": "March",
                                        "4": "April",
                                        "5": "May",
                                        "6": "June",
                                        "7": "July",
                                        "8": "August",
                                        "9": "September",
                                        "10": "October",
                                        "11": "November",
                                        "12": "December"
                                    }
                                }
                            },
                            "days": {
                                "format": {
                                    "abbreviated": {
                                        "sun": "Sun",
                                        "mon": "Mon",
                                        "tue": "Tue",
                                        "wed": "Wed",
                                        "thu": "Thu",
                                        "fri": "Fri",
                                        "sat": "Sat"
                                    },
                                    "narrow": {
                                        "sun": "S",
                                        "mon": "M",
                                        "tue": "T",
                                        "wed": "W",
                                        "thu": "T",
                                        "fri": "F",
                                        "sat": "S"
                                    },
                                    "short": {
                                        "sun": "Su",
                                        "mon": "Mo",
                                        "tue": "Tu",
                                        "wed": "We",
                                        "thu": "Th",
                                        "fri": "Fr",
                                        "sat": "Sa"
                                    },
                                    "wide": {
                                        "sun": "Sunday",
                                        "mon": "Monday",
                                        "tue": "Tuesday",
                                        "wed": "Wednesday",
                                        "thu": "Thursday",
                                        "fri": "Friday",
                                        "sat": "Saturday"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "sun": "Sun",
                                        "mon": "Mon",
                                        "tue": "Tue",
                                        "wed": "Wed",
                                        "thu": "Thu",
                                        "fri": "Fri",
                                        "sat": "Sat"
                                    },
                                    "narrow": {
                                        "sun": "S",
                                        "mon": "M",
                                        "tue": "T",
                                        "wed": "W",
                                        "thu": "T",
                                        "fri": "F",
                                        "sat": "S"
                                    },
                                    "short": {
                                        "sun": "Su",
                                        "mon": "Mo",
                                        "tue": "Tu",
                                        "wed": "We",
                                        "thu": "Th",
                                        "fri": "Fr",
                                        "sat": "Sa"
                                    },
                                    "wide": {
                                        "sun": "Sunday",
                                        "mon": "Monday",
                                        "tue": "Tuesday",
                                        "wed": "Wednesday",
                                        "thu": "Thursday",
                                        "fri": "Friday",
                                        "sat": "Saturday"
                                    }
                                }
                            },
                            "quarters": {
                                "format": {
                                    "abbreviated": {
                                        "1": "Q1",
                                        "2": "Q2",
                                        "3": "Q3",
                                        "4": "Q4"
                                    },
                                    "narrow": {
                                        "1": "1",
                                        "2": "2",
                                        "3": "3",
                                        "4": "4"
                                    },
                                    "wide": {
                                        "1": "1st quarter",
                                        "2": "2nd quarter",
                                        "3": "3rd quarter",
                                        "4": "4th quarter"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "1": "Q1",
                                        "2": "Q2",
                                        "3": "Q3",
                                        "4": "Q4"
                                    },
                                    "narrow": {
                                        "1": "1",
                                        "2": "2",
                                        "3": "3",
                                        "4": "4"
                                    },
                                    "wide": {
                                        "1": "1st quarter",
                                        "2": "2nd quarter",
                                        "3": "3rd quarter",
                                        "4": "4th quarter"
                                    }
                                }
                            },
                            "dayPeriods": {
                                "format": {
                                    "abbreviated": {
                                        "am": "am",
                                        "am-alt-variant": "a.m.",
                                        "noon": "noon",
                                        "pm": "pm",
                                        "pm-alt-variant": "p.m."
                                    },
                                    "narrow": {
                                        "am": "a",
                                        "am-alt-variant": "a.m.",
                                        "noon": "n",
                                        "pm": "p",
                                        "pm-alt-variant": "p.m."
                                    },
                                    "wide": {
                                        "am": "am",
                                        "am-alt-variant": "a.m.",
                                        "noon": "noon",
                                        "pm": "pm",
                                        "pm-alt-variant": "p.m."
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "am": "am",
                                        "am-alt-variant": "a.m.",
                                        "noon": "noon",
                                        "pm": "pm",
                                        "pm-alt-variant": "p.m."
                                    },
                                    "narrow": {
                                        "am": "a",
                                        "am-alt-variant": "a.m.",
                                        "noon": "n",
                                        "pm": "p",
                                        "pm-alt-variant": "p.m."
                                    },
                                    "wide": {
                                        "am": "am",
                                        "am-alt-variant": "a.m.",
                                        "noon": "noon",
                                        "pm": "pm",
                                        "pm-alt-variant": "p.m."
                                    }
                                }
                            },
                            "eras": {
                                "eraNames": {
                                    "0": "Before Christ",
                                    "1": "Anno Domini",
                                    "0-alt-variant": "Before Common Era",
                                    "1-alt-variant": "Common Era"
                                },
                                "eraAbbr": {
                                    "0": "BC",
                                    "1": "AD",
                                    "0-alt-variant": "BCE",
                                    "1-alt-variant": "CE"
                                },
                                "eraNarrow": {
                                    "0": "B",
                                    "1": "A",
                                    "0-alt-variant": "BCE",
                                    "1-alt-variant": "CE"
                                }
                            },
                            "dateFormats": {
                                "full": "EEEE, d MMMM y",
                                "long": "d MMMM y",
                                "medium": "d MMM y",
                                "short": "d/MM/y"
                            },
                            "timeFormats": {
                                "full": "h:mm:ss a zzzz",
                                "long": "h:mm:ss a z",
                                "medium": "h:mm:ss a",
                                "short": "h:mm a"
                            },
                            "dateTimeFormats": {
                                "full": "{1} {0}",
                                "long": "{1} {0}",
                                "medium": "{1} {0}",
                                "short": "{1} {0}",
                                "availableFormats": {
                                    "d": "d",
                                    "Ed": "E d",
                                    "Ehm": "E h:mm a",
                                    "EHm": "E HH:mm",
                                    "Ehms": "E h:mm:ss a",
                                    "EHms": "E HH:mm:ss",
                                    "Gy": "y G",
                                    "GyMMM": "MMM y G",
                                    "GyMMMd": "d MMM y G",
                                    "GyMMMEd": "E, d MMM y G",
                                    "h": "h a",
                                    "H": "HH",
                                    "hm": "h:mm a",
                                    "Hm": "HH:mm",
                                    "hms": "h:mm:ss a",
                                    "Hms": "HH:mm:ss",
                                    "M": "LL",
                                    "Md": "dd/MM",
                                    "MEd": "E dd/MM",
                                    "MMdd": "dd/MM",
                                    "MMM": "LLL",
                                    "MMMd": "d MMM",
                                    "MMMEd": "E d MMM",
                                    "MMMMd": "d MMMM",
                                    "ms": "mm:ss",
                                    "y": "y",
                                    "yM": "MM/y",
                                    "yMd": "d/M/y",
                                    "yMEd": "E, d/M/y",
                                    "yMMM": "MMM y",
                                    "yMMMd": "d MMM y",
                                    "yMMMEd": "E, d MMM y",
                                    "yMMMM": "MMMM y",
                                    "yQQQ": "QQQ y",
                                    "yQQQQ": "QQQQ y"
                                },
                                "appendItems": {
                                    "Day": "{0} ({2}: {1})",
                                    "Day-Of-Week": "{0} {1}",
                                    "Era": "{0} {1}",
                                    "Hour": "{0} ({2}: {1})",
                                    "Minute": "{0} ({2}: {1})",
                                    "Month": "{0} ({2}: {1})",
                                    "Quarter": "{0} ({2}: {1})",
                                    "Second": "{0} ({2}: {1})",
                                    "Timezone": "{0} {1}",
                                    "Week": "{0} ({2}: {1})",
                                    "Year": "{0} {1}"
                                },
                                "intervalFormats": {
                                    "intervalFormatFallback": "{0} - {1}",
                                    "d": {
                                        "d": "d-d"
                                    },
                                    "h": {
                                        "a": "h a - h a",
                                        "h": "h-h a"
                                    },
                                    "H": {
                                        "H": "HH–HH"
                                    },
                                    "hm": {
                                        "a": "h:mm a - h:mm a",
                                        "h": "h:mm-h:mm a",
                                        "m": "h:mm-h:mm a"
                                    },
                                    "Hm": {
                                        "H": "HH:mm–HH:mm",
                                        "m": "HH:mm–HH:mm"
                                    },
                                    "hmv": {
                                        "a": "h:mm a - h:mm a v",
                                        "h": "h:mm-h:mm a v",
                                        "m": "h:mm-h:mm a v"
                                    },
                                    "Hmv": {
                                        "H": "HH:mm–HH:mm v",
                                        "m": "HH:mm–HH:mm v"
                                    },
                                    "hv": {
                                        "a": "h a - h a v",
                                        "h": "h-h a v"
                                    },
                                    "Hv": {
                                        "H": "HH–HH v"
                                    },
                                    "M": {
                                        "M": "M-M"
                                    },
                                    "Md": {
                                        "d": "d/MM - d/MM",
                                        "M": "d/MM - d/MM"
                                    },
                                    "MEd": {
                                        "d": "E, d/MM - E, d/MM",
                                        "M": "E, d/MM - E, d/MM"
                                    },
                                    "MMM": {
                                        "M": "MMM-MMM"
                                    },
                                    "MMMd": {
                                        "d": "d-d MMM",
                                        "M": "d MMM - d MMM"
                                    },
                                    "MMMEd": {
                                        "d": "E, d - E, d MMM",
                                        "M": "E, d MMM - E, d MMM"
                                    },
                                    "y": {
                                        "y": "y-y"
                                    },
                                    "yM": {
                                        "M": "MM/y - MM/y",
                                        "y": "MM/y - MM/y"
                                    },
                                    "yMd": {
                                        "d": "d/MM/y - d/MM/y",
                                        "M": "d/MM/y - d/MM/y",
                                        "y": "d/MM/y - d/MM/y"
                                    },
                                    "yMEd": {
                                        "d": "E, d/MM/y - E, d/MM/y",
                                        "M": "E, d/MM/y - E, d/MM/y",
                                        "y": "E, d/MM/y - E, d/MM/y"
                                    },
                                    "yMMM": {
                                        "M": "MMM-MMM y",
                                        "y": "MMM y - MMM y"
                                    },
                                    "yMMMd": {
                                        "d": "d-d MMM y",
                                        "M": "d MMM - d MMM y",
                                        "y": "d MMM y - d MMM y"
                                    },
                                    "yMMMEd": {
                                        "d": "E, d - E, d MMM y",
                                        "M": "E, d MMM - E, d MMM y",
                                        "y": "E, d MMM y - E, d MMM y"
                                    },
                                    "yMMMM": {
                                        "M": "MMMM–MMMM y",
                                        "y": "MMMM y – MMMM y"
                                    }
                                }
                            }
                        }
                    },
                    "timeZoneNames": {
                        "hourFormat": "+HH:mm;-HH:mm",
                        "gmtFormat": "GMT{0}",
                        "gmtZeroFormat": "GMT",
                        "regionFormat": "{0} Time",
                        "regionFormat-type-daylight": "{0} Daylight Time",
                        "regionFormat-type-standard": "{0} Standard Time",
                        "fallbackFormat": "{1} ({0})"
                    }
                }
            },
            "en-CA": {
                "dates": {
                    "calendars": {
                        "gregorian": {
                            "months": {
                                "format": {
                                    "abbreviated": {
                                        "1": "Jan",
                                        "2": "Feb",
                                        "3": "Mar",
                                        "4": "Apr",
                                        "5": "May",
                                        "6": "Jun",
                                        "7": "Jul",
                                        "8": "Aug",
                                        "9": "Sep",
                                        "10": "Oct",
                                        "11": "Nov",
                                        "12": "Dec"
                                    },
                                    "narrow": {
                                        "1": "J",
                                        "2": "F",
                                        "3": "M",
                                        "4": "A",
                                        "5": "M",
                                        "6": "J",
                                        "7": "J",
                                        "8": "A",
                                        "9": "S",
                                        "10": "O",
                                        "11": "N",
                                        "12": "D"
                                    },
                                    "wide": {
                                        "1": "January",
                                        "2": "February",
                                        "3": "March",
                                        "4": "April",
                                        "5": "May",
                                        "6": "June",
                                        "7": "July",
                                        "8": "August",
                                        "9": "September",
                                        "10": "October",
                                        "11": "November",
                                        "12": "December"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "1": "Jan",
                                        "2": "Feb",
                                        "3": "Mar",
                                        "4": "Apr",
                                        "5": "May",
                                        "6": "Jun",
                                        "7": "Jul",
                                        "8": "Aug",
                                        "9": "Sep",
                                        "10": "Oct",
                                        "11": "Nov",
                                        "12": "Dec"
                                    },
                                    "narrow": {
                                        "1": "J",
                                        "2": "F",
                                        "3": "M",
                                        "4": "A",
                                        "5": "M",
                                        "6": "J",
                                        "7": "J",
                                        "8": "A",
                                        "9": "S",
                                        "10": "O",
                                        "11": "N",
                                        "12": "D"
                                    },
                                    "wide": {
                                        "1": "January",
                                        "2": "February",
                                        "3": "March",
                                        "4": "April",
                                        "5": "May",
                                        "6": "June",
                                        "7": "July",
                                        "8": "August",
                                        "9": "September",
                                        "10": "October",
                                        "11": "November",
                                        "12": "December"
                                    }
                                }
                            },
                            "days": {
                                "format": {
                                    "abbreviated": {
                                        "sun": "Sun",
                                        "mon": "Mon",
                                        "tue": "Tue",
                                        "wed": "Wed",
                                        "thu": "Thu",
                                        "fri": "Fri",
                                        "sat": "Sat"
                                    },
                                    "narrow": {
                                        "sun": "S",
                                        "mon": "M",
                                        "tue": "T",
                                        "wed": "W",
                                        "thu": "T",
                                        "fri": "F",
                                        "sat": "S"
                                    },
                                    "short": {
                                        "sun": "Su",
                                        "mon": "Mo",
                                        "tue": "Tu",
                                        "wed": "We",
                                        "thu": "Th",
                                        "fri": "Fr",
                                        "sat": "Sa"
                                    },
                                    "wide": {
                                        "sun": "Sunday",
                                        "mon": "Monday",
                                        "tue": "Tuesday",
                                        "wed": "Wednesday",
                                        "thu": "Thursday",
                                        "fri": "Friday",
                                        "sat": "Saturday"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "sun": "Sun",
                                        "mon": "Mon",
                                        "tue": "Tue",
                                        "wed": "Wed",
                                        "thu": "Thu",
                                        "fri": "Fri",
                                        "sat": "Sat"
                                    },
                                    "narrow": {
                                        "sun": "S",
                                        "mon": "M",
                                        "tue": "T",
                                        "wed": "W",
                                        "thu": "T",
                                        "fri": "F",
                                        "sat": "S"
                                    },
                                    "short": {
                                        "sun": "Su",
                                        "mon": "Mo",
                                        "tue": "Tu",
                                        "wed": "We",
                                        "thu": "Th",
                                        "fri": "Fr",
                                        "sat": "Sa"
                                    },
                                    "wide": {
                                        "sun": "Sunday",
                                        "mon": "Monday",
                                        "tue": "Tuesday",
                                        "wed": "Wednesday",
                                        "thu": "Thursday",
                                        "fri": "Friday",
                                        "sat": "Saturday"
                                    }
                                }
                            },
                            "quarters": {
                                "format": {
                                    "abbreviated": {
                                        "1": "Q1",
                                        "2": "Q2",
                                        "3": "Q3",
                                        "4": "Q4"
                                    },
                                    "narrow": {
                                        "1": "1",
                                        "2": "2",
                                        "3": "3",
                                        "4": "4"
                                    },
                                    "wide": {
                                        "1": "1st quarter",
                                        "2": "2nd quarter",
                                        "3": "3rd quarter",
                                        "4": "4th quarter"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "1": "Q1",
                                        "2": "Q2",
                                        "3": "Q3",
                                        "4": "Q4"
                                    },
                                    "narrow": {
                                        "1": "1",
                                        "2": "2",
                                        "3": "3",
                                        "4": "4"
                                    },
                                    "wide": {
                                        "1": "1st quarter",
                                        "2": "2nd quarter",
                                        "3": "3rd quarter",
                                        "4": "4th quarter"
                                    }
                                }
                            },
                            "dayPeriods": {
                                "format": {
                                    "abbreviated": {
                                        "am": "AM",
                                        "am-alt-variant": "a.m.",
                                        "noon": "noon",
                                        "pm": "PM",
                                        "pm-alt-variant": "p.m."
                                    },
                                    "narrow": {
                                        "am": "a",
                                        "am-alt-variant": "a.m.",
                                        "noon": "n",
                                        "pm": "p",
                                        "pm-alt-variant": "p.m."
                                    },
                                    "wide": {
                                        "am": "AM",
                                        "am-alt-variant": "a.m.",
                                        "noon": "noon",
                                        "pm": "PM",
                                        "pm-alt-variant": "p.m."
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "am": "AM",
                                        "am-alt-variant": "a.m.",
                                        "noon": "noon",
                                        "pm": "PM",
                                        "pm-alt-variant": "p.m."
                                    },
                                    "narrow": {
                                        "am": "a",
                                        "am-alt-variant": "a.m.",
                                        "noon": "n",
                                        "pm": "p",
                                        "pm-alt-variant": "p.m."
                                    },
                                    "wide": {
                                        "am": "AM",
                                        "am-alt-variant": "a.m.",
                                        "noon": "noon",
                                        "pm": "PM",
                                        "pm-alt-variant": "p.m."
                                    }
                                }
                            },
                            "eras": {
                                "eraNames": {
                                    "0": "Before Christ",
                                    "1": "Anno Domini",
                                    "0-alt-variant": "Before Common Era",
                                    "1-alt-variant": "Common Era"
                                },
                                "eraAbbr": {
                                    "0": "BC",
                                    "1": "AD",
                                    "0-alt-variant": "BCE",
                                    "1-alt-variant": "CE"
                                },
                                "eraNarrow": {
                                    "0": "B",
                                    "1": "A",
                                    "0-alt-variant": "BCE",
                                    "1-alt-variant": "CE"
                                }
                            },
                            "dateFormats": {
                                "full": "EEEE, MMMM d, y",
                                "long": "MMMM d, y",
                                "medium": "MMM d, y",
                                "short": "M/d/yy"
                            },
                            "timeFormats": {
                                "full": "h:mm:ss a zzzz",
                                "long": "h:mm:ss a z",
                                "medium": "h:mm:ss a",
                                "short": "h:mm a"
                            },
                            "dateTimeFormats": {
                                "full": "{1} 'at' {0}",
                                "long": "{1} 'at' {0}",
                                "medium": "{1}, {0}",
                                "short": "{1}, {0}",
                                "availableFormats": {
                                    "d": "d",
                                    "Ed": "d E",
                                    "Ehm": "E h:mm a",
                                    "EHm": "E HH:mm",
                                    "Ehms": "E h:mm:ss a",
                                    "EHms": "E HH:mm:ss",
                                    "Gy": "y G",
                                    "GyMMM": "MMM y G",
                                    "GyMMMd": "MMM d, y G",
                                    "GyMMMEd": "E, MMM d, y G",
                                    "h": "h a",
                                    "H": "HH",
                                    "hm": "h:mm a",
                                    "Hm": "HH:mm",
                                    "hms": "h:mm:ss a",
                                    "Hms": "HH:mm:ss",
                                    "M": "L",
                                    "Md": "M/d",
                                    "MEd": "E, M/d",
                                    "MMM": "LLL",
                                    "MMMd": "MMM d",
                                    "MMMEd": "E, MMM d",
                                    "ms": "mm:ss",
                                    "y": "y",
                                    "yM": "M/y",
                                    "yMd": "M/d/y",
                                    "yMEd": "E, M/d/y",
                                    "yMMM": "MMM y",
                                    "yMMMd": "MMM d, y",
                                    "yMMMEd": "E, MMM d, y",
                                    "yQQQ": "QQQ y",
                                    "yQQQQ": "QQQQ y"
                                },
                                "appendItems": {
                                    "Day": "{0} ({2}: {1})",
                                    "Day-Of-Week": "{0} {1}",
                                    "Era": "{0} {1}",
                                    "Hour": "{0} ({2}: {1})",
                                    "Minute": "{0} ({2}: {1})",
                                    "Month": "{0} ({2}: {1})",
                                    "Quarter": "{0} ({2}: {1})",
                                    "Second": "{0} ({2}: {1})",
                                    "Timezone": "{0} {1}",
                                    "Week": "{0} ({2}: {1})",
                                    "Year": "{0} {1}"
                                },
                                "intervalFormats": {
                                    "intervalFormatFallback": "{0} – {1}",
                                    "d": {
                                        "d": "d – d"
                                    },
                                    "h": {
                                        "a": "h a – h a",
                                        "h": "h – h a"
                                    },
                                    "H": {
                                        "H": "HH – HH"
                                    },
                                    "hm": {
                                        "a": "h:mm a – h:mm a",
                                        "h": "h:mm – h:mm a",
                                        "m": "h:mm – h:mm a"
                                    },
                                    "Hm": {
                                        "H": "HH:mm – HH:mm",
                                        "m": "HH:mm – HH:mm"
                                    },
                                    "hmv": {
                                        "a": "h:mm a – h:mm a v",
                                        "h": "h:mm – h:mm a v",
                                        "m": "h:mm – h:mm a v"
                                    },
                                    "Hmv": {
                                        "H": "HH:mm – HH:mm v",
                                        "m": "HH:mm – HH:mm v"
                                    },
                                    "hv": {
                                        "a": "h a – h a v",
                                        "h": "h – h a v"
                                    },
                                    "Hv": {
                                        "H": "HH – HH v"
                                    },
                                    "M": {
                                        "M": "M – M"
                                    },
                                    "Md": {
                                        "d": "M/d – M/d",
                                        "M": "M/d – M/d"
                                    },
                                    "MEd": {
                                        "d": "E, M/d – E, M/d",
                                        "M": "E, M/d – E, M/d"
                                    },
                                    "MMM": {
                                        "M": "MMM – MMM"
                                    },
                                    "MMMd": {
                                        "d": "MMM d – d",
                                        "M": "MMM d – MMM d"
                                    },
                                    "MMMEd": {
                                        "d": "E, MMM d – E, MMM d",
                                        "M": "E, MMM d – E, MMM d"
                                    },
                                    "y": {
                                        "y": "y – y"
                                    },
                                    "yM": {
                                        "M": "M/y – M/y",
                                        "y": "M/y – M/y"
                                    },
                                    "yMd": {
                                        "d": "M/d/y – M/d/y",
                                        "M": "M/d/y – M/d/y",
                                        "y": "M/d/y – M/d/y"
                                    },
                                    "yMEd": {
                                        "d": "E, M/d/y – E, M/d/y",
                                        "M": "E, M/d/y – E, M/d/y",
                                        "y": "E, M/d/y – E, M/d/y"
                                    },
                                    "yMMM": {
                                        "M": "MMM – MMM y",
                                        "y": "MMM y – MMM y"
                                    },
                                    "yMMMd": {
                                        "d": "MMM d – d, y",
                                        "M": "MMM d – MMM d, y",
                                        "y": "MMM d, y – MMM d, y"
                                    },
                                    "yMMMEd": {
                                        "d": "E, MMM d – E, MMM d, y",
                                        "M": "E, MMM d – E, MMM d, y",
                                        "y": "E, MMM d, y – E, MMM d, y"
                                    },
                                    "yMMMM": {
                                        "M": "MMMM – MMMM y",
                                        "y": "MMMM y – MMMM y"
                                    }
                                }
                            }
                        }
                    },
                    "timeZoneNames": {
                        "hourFormat": "+HH:mm;-HH:mm",
                        "gmtFormat": "GMT{0}",
                        "gmtZeroFormat": "GMT",
                        "regionFormat": "{0} Time",
                        "regionFormat-type-daylight": "{0} Daylight Time",
                        "regionFormat-type-standard": "{0} Standard Time",
                        "fallbackFormat": "{1} ({0})"
                    }
                }
            },
            "en-GB": {
                "dates": {
                    "calendars": {
                        "gregorian": {
                            "months": {
                                "format": {
                                    "abbreviated": {
                                        "1": "Jan",
                                        "2": "Feb",
                                        "3": "Mar",
                                        "4": "Apr",
                                        "5": "May",
                                        "6": "Jun",
                                        "7": "Jul",
                                        "8": "Aug",
                                        "9": "Sep",
                                        "10": "Oct",
                                        "11": "Nov",
                                        "12": "Dec"
                                    },
                                    "narrow": {
                                        "1": "J",
                                        "2": "F",
                                        "3": "M",
                                        "4": "A",
                                        "5": "M",
                                        "6": "J",
                                        "7": "J",
                                        "8": "A",
                                        "9": "S",
                                        "10": "O",
                                        "11": "N",
                                        "12": "D"
                                    },
                                    "wide": {
                                        "1": "January",
                                        "2": "February",
                                        "3": "March",
                                        "4": "April",
                                        "5": "May",
                                        "6": "June",
                                        "7": "July",
                                        "8": "August",
                                        "9": "September",
                                        "10": "October",
                                        "11": "November",
                                        "12": "December"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "1": "Jan",
                                        "2": "Feb",
                                        "3": "Mar",
                                        "4": "Apr",
                                        "5": "May",
                                        "6": "Jun",
                                        "7": "Jul",
                                        "8": "Aug",
                                        "9": "Sep",
                                        "10": "Oct",
                                        "11": "Nov",
                                        "12": "Dec"
                                    },
                                    "narrow": {
                                        "1": "J",
                                        "2": "F",
                                        "3": "M",
                                        "4": "A",
                                        "5": "M",
                                        "6": "J",
                                        "7": "J",
                                        "8": "A",
                                        "9": "S",
                                        "10": "O",
                                        "11": "N",
                                        "12": "D"
                                    },
                                    "wide": {
                                        "1": "January",
                                        "2": "February",
                                        "3": "March",
                                        "4": "April",
                                        "5": "May",
                                        "6": "June",
                                        "7": "July",
                                        "8": "August",
                                        "9": "September",
                                        "10": "October",
                                        "11": "November",
                                        "12": "December"
                                    }
                                }
                            },
                            "days": {
                                "format": {
                                    "abbreviated": {
                                        "sun": "Sun",
                                        "mon": "Mon",
                                        "tue": "Tue",
                                        "wed": "Wed",
                                        "thu": "Thu",
                                        "fri": "Fri",
                                        "sat": "Sat"
                                    },
                                    "narrow": {
                                        "sun": "S",
                                        "mon": "M",
                                        "tue": "T",
                                        "wed": "W",
                                        "thu": "T",
                                        "fri": "F",
                                        "sat": "S"
                                    },
                                    "short": {
                                        "sun": "Su",
                                        "mon": "Mo",
                                        "tue": "Tu",
                                        "wed": "We",
                                        "thu": "Th",
                                        "fri": "Fr",
                                        "sat": "Sa"
                                    },
                                    "wide": {
                                        "sun": "Sunday",
                                        "mon": "Monday",
                                        "tue": "Tuesday",
                                        "wed": "Wednesday",
                                        "thu": "Thursday",
                                        "fri": "Friday",
                                        "sat": "Saturday"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "sun": "Sun",
                                        "mon": "Mon",
                                        "tue": "Tue",
                                        "wed": "Wed",
                                        "thu": "Thu",
                                        "fri": "Fri",
                                        "sat": "Sat"
                                    },
                                    "narrow": {
                                        "sun": "S",
                                        "mon": "M",
                                        "tue": "T",
                                        "wed": "W",
                                        "thu": "T",
                                        "fri": "F",
                                        "sat": "S"
                                    },
                                    "short": {
                                        "sun": "Su",
                                        "mon": "Mo",
                                        "tue": "Tu",
                                        "wed": "We",
                                        "thu": "Th",
                                        "fri": "Fr",
                                        "sat": "Sa"
                                    },
                                    "wide": {
                                        "sun": "Sunday",
                                        "mon": "Monday",
                                        "tue": "Tuesday",
                                        "wed": "Wednesday",
                                        "thu": "Thursday",
                                        "fri": "Friday",
                                        "sat": "Saturday"
                                    }
                                }
                            },
                            "quarters": {
                                "format": {
                                    "abbreviated": {
                                        "1": "Q1",
                                        "2": "Q2",
                                        "3": "Q3",
                                        "4": "Q4"
                                    },
                                    "narrow": {
                                        "1": "1",
                                        "2": "2",
                                        "3": "3",
                                        "4": "4"
                                    },
                                    "wide": {
                                        "1": "1st quarter",
                                        "2": "2nd quarter",
                                        "3": "3rd quarter",
                                        "4": "4th quarter"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "1": "Q1",
                                        "2": "Q2",
                                        "3": "Q3",
                                        "4": "Q4"
                                    },
                                    "narrow": {
                                        "1": "1",
                                        "2": "2",
                                        "3": "3",
                                        "4": "4"
                                    },
                                    "wide": {
                                        "1": "1st quarter",
                                        "2": "2nd quarter",
                                        "3": "3rd quarter",
                                        "4": "4th quarter"
                                    }
                                }
                            },
                            "dayPeriods": {
                                "format": {
                                    "abbreviated": {
                                        "am": "am",
                                        "am-alt-variant": "a.m.",
                                        "noon": "noon",
                                        "pm": "pm",
                                        "pm-alt-variant": "p.m."
                                    },
                                    "narrow": {
                                        "am": "a",
                                        "am-alt-variant": "a.m.",
                                        "noon": "n",
                                        "pm": "p",
                                        "pm-alt-variant": "p.m."
                                    },
                                    "wide": {
                                        "am": "am",
                                        "am-alt-variant": "a.m.",
                                        "noon": "noon",
                                        "pm": "pm",
                                        "pm-alt-variant": "p.m."
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "am": "am",
                                        "am-alt-variant": "a.m.",
                                        "noon": "noon",
                                        "pm": "pm",
                                        "pm-alt-variant": "p.m."
                                    },
                                    "narrow": {
                                        "am": "a",
                                        "am-alt-variant": "a.m.",
                                        "noon": "n",
                                        "pm": "p",
                                        "pm-alt-variant": "p.m."
                                    },
                                    "wide": {
                                        "am": "am",
                                        "am-alt-variant": "a.m.",
                                        "noon": "noon",
                                        "pm": "pm",
                                        "pm-alt-variant": "p.m."
                                    }
                                }
                            },
                            "eras": {
                                "eraNames": {
                                    "0": "Before Christ",
                                    "1": "Anno Domini",
                                    "0-alt-variant": "Before Common Era",
                                    "1-alt-variant": "Common Era"
                                },
                                "eraAbbr": {
                                    "0": "BC",
                                    "1": "AD",
                                    "0-alt-variant": "BCE",
                                    "1-alt-variant": "CE"
                                },
                                "eraNarrow": {
                                    "0": "B",
                                    "1": "A",
                                    "0-alt-variant": "BCE",
                                    "1-alt-variant": "CE"
                                }
                            },
                            "dateFormats": {
                                "full": "EEEE, d MMMM y",
                                "long": "d MMMM y",
                                "medium": "d MMM y",
                                "short": "dd/MM/y"
                            },
                            "timeFormats": {
                                "full": "HH:mm:ss zzzz",
                                "long": "HH:mm:ss z",
                                "medium": "HH:mm:ss",
                                "short": "HH:mm"
                            },
                            "dateTimeFormats": {
                                "full": "{1} {0}",
                                "long": "{1} {0}",
                                "medium": "{1} {0}",
                                "short": "{1} {0}",
                                "availableFormats": {
                                    "d": "d",
                                    "Ed": "E d",
                                    "Ehm": "E h:mm a",
                                    "EHm": "E HH:mm",
                                    "Ehms": "E h:mm:ss a",
                                    "EHms": "E HH:mm:ss",
                                    "Gy": "y G",
                                    "GyMMM": "MMM y G",
                                    "GyMMMd": "d MMM y G",
                                    "GyMMMEd": "E, d MMM y G",
                                    "h": "h a",
                                    "H": "HH",
                                    "hm": "h:mm a",
                                    "Hm": "HH:mm",
                                    "hms": "h:mm:ss a",
                                    "Hms": "HH:mm:ss",
                                    "M": "LL",
                                    "Md": "dd/MM",
                                    "MEd": "E dd/MM",
                                    "MMdd": "dd/MM",
                                    "MMM": "LLL",
                                    "MMMd": "d MMM",
                                    "MMMEd": "E d MMM",
                                    "MMMMd": "d MMMM",
                                    "ms": "mm:ss",
                                    "y": "y",
                                    "yM": "MM/y",
                                    "yMd": "dd/MM/y",
                                    "yMEd": "E, dd/MM/y",
                                    "yMMM": "MMM y",
                                    "yMMMd": "d MMM y",
                                    "yMMMEd": "E, d MMM y",
                                    "yMMMM": "MMMM y",
                                    "yQQQ": "QQQ y",
                                    "yQQQQ": "QQQQ y"
                                },
                                "appendItems": {
                                    "Day": "{0} ({2}: {1})",
                                    "Day-Of-Week": "{0} {1}",
                                    "Era": "{0} {1}",
                                    "Hour": "{0} ({2}: {1})",
                                    "Minute": "{0} ({2}: {1})",
                                    "Month": "{0} ({2}: {1})",
                                    "Quarter": "{0} ({2}: {1})",
                                    "Second": "{0} ({2}: {1})",
                                    "Timezone": "{0} {1}",
                                    "Week": "{0} ({2}: {1})",
                                    "Year": "{0} {1}"
                                },
                                "intervalFormats": {
                                    "intervalFormatFallback": "{0} – {1}",
                                    "d": {
                                        "d": "d–d"
                                    },
                                    "h": {
                                        "a": "h a – h a",
                                        "h": "h–h a"
                                    },
                                    "H": {
                                        "H": "HH–HH"
                                    },
                                    "hm": {
                                        "a": "h:mm a – h:mm a",
                                        "h": "h:mm–h:mm a",
                                        "m": "h:mm–h:mm a"
                                    },
                                    "Hm": {
                                        "H": "HH:mm–HH:mm",
                                        "m": "HH:mm–HH:mm"
                                    },
                                    "hmv": {
                                        "a": "h:mm a – h:mm a v",
                                        "h": "h:mm–h:mm a v",
                                        "m": "h:mm–h:mm a v"
                                    },
                                    "Hmv": {
                                        "H": "HH:mm–HH:mm v",
                                        "m": "HH:mm–HH:mm v"
                                    },
                                    "hv": {
                                        "a": "h a – h a v",
                                        "h": "h–h a v"
                                    },
                                    "Hv": {
                                        "H": "HH–HH v"
                                    },
                                    "M": {
                                        "M": "M–M"
                                    },
                                    "Md": {
                                        "d": "dd/MM – dd/MM",
                                        "M": "dd/MM – dd/MM"
                                    },
                                    "MEd": {
                                        "d": "E dd/MM – E dd/MM",
                                        "M": "E dd/MM – E dd/MM"
                                    },
                                    "MMM": {
                                        "M": "MMM–MMM"
                                    },
                                    "MMMd": {
                                        "d": "d–d MMM",
                                        "M": "d MMM – d MMM"
                                    },
                                    "MMMEd": {
                                        "d": "E d – E d MMM",
                                        "M": "E d MMM – E d MMM"
                                    },
                                    "y": {
                                        "y": "y-y"
                                    },
                                    "yM": {
                                        "M": "MM/y – MM/y",
                                        "y": "MM/y – MM/y"
                                    },
                                    "yMd": {
                                        "d": "dd/MM/y – dd/MM/y",
                                        "M": "dd/MM/y – dd/MM/y",
                                        "y": "dd/MM/y – dd/MM/y"
                                    },
                                    "yMEd": {
                                        "d": "E, dd/MM/y – E, dd/MM/y",
                                        "M": "E, dd/MM/y – E, dd/MM/y",
                                        "y": "E, dd/MM/y – E, dd/MM/y"
                                    },
                                    "yMMM": {
                                        "M": "MMM–MMM y",
                                        "y": "MMM y – MMM y"
                                    },
                                    "yMMMd": {
                                        "d": "d–d MMM y",
                                        "M": "d MMM – d MMM y",
                                        "y": "d MMM y – d MMM y"
                                    },
                                    "yMMMEd": {
                                        "d": "E, d – E, d MMM y",
                                        "M": "E, d MMM – E, d MMM y",
                                        "y": "E, d MMM y – E, d MMM y"
                                    },
                                    "yMMMM": {
                                        "M": "MMMM–MMMM y",
                                        "y": "MMMM y – MMMM y"
                                    }
                                }
                            }
                        }
                    },
                    "timeZoneNames": {
                        "hourFormat": "+HH:mm;-HH:mm",
                        "gmtFormat": "GMT{0}",
                        "gmtZeroFormat": "GMT",
                        "regionFormat": "{0} Time",
                        "regionFormat-type-daylight": "{0} Daylight Time",
                        "regionFormat-type-standard": "{0} Standard Time",
                        "fallbackFormat": "{1} ({0})"
                    }
                }
            },
            "en-HK": {
                "dates": {
                    "calendars": {
                        "gregorian": {
                            "months": {
                                "format": {
                                    "abbreviated": {
                                        "1": "Jan",
                                        "2": "Feb",
                                        "3": "Mar",
                                        "4": "Apr",
                                        "5": "May",
                                        "6": "Jun",
                                        "7": "Jul",
                                        "8": "Aug",
                                        "9": "Sep",
                                        "10": "Oct",
                                        "11": "Nov",
                                        "12": "Dec"
                                    },
                                    "narrow": {
                                        "1": "J",
                                        "2": "F",
                                        "3": "M",
                                        "4": "A",
                                        "5": "M",
                                        "6": "J",
                                        "7": "J",
                                        "8": "A",
                                        "9": "S",
                                        "10": "O",
                                        "11": "N",
                                        "12": "D"
                                    },
                                    "wide": {
                                        "1": "January",
                                        "2": "February",
                                        "3": "March",
                                        "4": "April",
                                        "5": "May",
                                        "6": "June",
                                        "7": "July",
                                        "8": "August",
                                        "9": "September",
                                        "10": "October",
                                        "11": "November",
                                        "12": "December"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "1": "Jan",
                                        "2": "Feb",
                                        "3": "Mar",
                                        "4": "Apr",
                                        "5": "May",
                                        "6": "Jun",
                                        "7": "Jul",
                                        "8": "Aug",
                                        "9": "Sep",
                                        "10": "Oct",
                                        "11": "Nov",
                                        "12": "Dec"
                                    },
                                    "narrow": {
                                        "1": "J",
                                        "2": "F",
                                        "3": "M",
                                        "4": "A",
                                        "5": "M",
                                        "6": "J",
                                        "7": "J",
                                        "8": "A",
                                        "9": "S",
                                        "10": "O",
                                        "11": "N",
                                        "12": "D"
                                    },
                                    "wide": {
                                        "1": "January",
                                        "2": "February",
                                        "3": "March",
                                        "4": "April",
                                        "5": "May",
                                        "6": "June",
                                        "7": "July",
                                        "8": "August",
                                        "9": "September",
                                        "10": "October",
                                        "11": "November",
                                        "12": "December"
                                    }
                                }
                            },
                            "days": {
                                "format": {
                                    "abbreviated": {
                                        "sun": "Sun",
                                        "mon": "Mon",
                                        "tue": "Tue",
                                        "wed": "Wed",
                                        "thu": "Thu",
                                        "fri": "Fri",
                                        "sat": "Sat"
                                    },
                                    "narrow": {
                                        "sun": "S",
                                        "mon": "M",
                                        "tue": "T",
                                        "wed": "W",
                                        "thu": "T",
                                        "fri": "F",
                                        "sat": "S"
                                    },
                                    "short": {
                                        "sun": "Su",
                                        "mon": "Mo",
                                        "tue": "Tu",
                                        "wed": "We",
                                        "thu": "Th",
                                        "fri": "Fr",
                                        "sat": "Sa"
                                    },
                                    "wide": {
                                        "sun": "Sunday",
                                        "mon": "Monday",
                                        "tue": "Tuesday",
                                        "wed": "Wednesday",
                                        "thu": "Thursday",
                                        "fri": "Friday",
                                        "sat": "Saturday"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "sun": "Sun",
                                        "mon": "Mon",
                                        "tue": "Tue",
                                        "wed": "Wed",
                                        "thu": "Thu",
                                        "fri": "Fri",
                                        "sat": "Sat"
                                    },
                                    "narrow": {
                                        "sun": "S",
                                        "mon": "M",
                                        "tue": "T",
                                        "wed": "W",
                                        "thu": "T",
                                        "fri": "F",
                                        "sat": "S"
                                    },
                                    "short": {
                                        "sun": "Su",
                                        "mon": "Mo",
                                        "tue": "Tu",
                                        "wed": "We",
                                        "thu": "Th",
                                        "fri": "Fr",
                                        "sat": "Sa"
                                    },
                                    "wide": {
                                        "sun": "Sunday",
                                        "mon": "Monday",
                                        "tue": "Tuesday",
                                        "wed": "Wednesday",
                                        "thu": "Thursday",
                                        "fri": "Friday",
                                        "sat": "Saturday"
                                    }
                                }
                            },
                            "quarters": {
                                "format": {
                                    "abbreviated": {
                                        "1": "Q1",
                                        "2": "Q2",
                                        "3": "Q3",
                                        "4": "Q4"
                                    },
                                    "narrow": {
                                        "1": "1",
                                        "2": "2",
                                        "3": "3",
                                        "4": "4"
                                    },
                                    "wide": {
                                        "1": "1st quarter",
                                        "2": "2nd quarter",
                                        "3": "3rd quarter",
                                        "4": "4th quarter"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "1": "Q1",
                                        "2": "Q2",
                                        "3": "Q3",
                                        "4": "Q4"
                                    },
                                    "narrow": {
                                        "1": "1",
                                        "2": "2",
                                        "3": "3",
                                        "4": "4"
                                    },
                                    "wide": {
                                        "1": "1st quarter",
                                        "2": "2nd quarter",
                                        "3": "3rd quarter",
                                        "4": "4th quarter"
                                    }
                                }
                            },
                            "dayPeriods": {
                                "format": {
                                    "abbreviated": {
                                        "am": "am",
                                        "am-alt-variant": "a.m.",
                                        "noon": "noon",
                                        "pm": "pm",
                                        "pm-alt-variant": "p.m."
                                    },
                                    "narrow": {
                                        "am": "a",
                                        "am-alt-variant": "a.m.",
                                        "noon": "n",
                                        "pm": "p",
                                        "pm-alt-variant": "p.m."
                                    },
                                    "wide": {
                                        "am": "am",
                                        "am-alt-variant": "a.m.",
                                        "noon": "noon",
                                        "pm": "pm",
                                        "pm-alt-variant": "p.m."
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "am": "am",
                                        "am-alt-variant": "a.m.",
                                        "noon": "noon",
                                        "pm": "pm",
                                        "pm-alt-variant": "p.m."
                                    },
                                    "narrow": {
                                        "am": "a",
                                        "am-alt-variant": "a.m.",
                                        "noon": "n",
                                        "pm": "p",
                                        "pm-alt-variant": "p.m."
                                    },
                                    "wide": {
                                        "am": "am",
                                        "am-alt-variant": "a.m.",
                                        "noon": "noon",
                                        "pm": "pm",
                                        "pm-alt-variant": "p.m."
                                    }
                                }
                            },
                            "eras": {
                                "eraNames": {
                                    "0": "Before Christ",
                                    "1": "Anno Domini",
                                    "0-alt-variant": "Before Common Era",
                                    "1-alt-variant": "Common Era"
                                },
                                "eraAbbr": {
                                    "0": "BC",
                                    "1": "AD",
                                    "0-alt-variant": "BCE",
                                    "1-alt-variant": "CE"
                                },
                                "eraNarrow": {
                                    "0": "B",
                                    "1": "A",
                                    "0-alt-variant": "BCE",
                                    "1-alt-variant": "CE"
                                }
                            },
                            "dateFormats": {
                                "full": "EEEE, d MMMM, y",
                                "long": "d MMMM, y",
                                "medium": "d MMM, y",
                                "short": "d/M/yy"
                            },
                            "timeFormats": {
                                "full": "h:mm:ss a zzzz",
                                "long": "h:mm:ss a z",
                                "medium": "h:mm:ss a",
                                "short": "h:mm a"
                            },
                            "dateTimeFormats": {
                                "full": "{1} {0}",
                                "long": "{1} {0}",
                                "medium": "{1} {0}",
                                "short": "{1} {0}",
                                "availableFormats": {
                                    "d": "d",
                                    "Ed": "E d",
                                    "Ehm": "E h:mm a",
                                    "EHm": "E HH:mm",
                                    "Ehms": "E h:mm:ss a",
                                    "EHms": "E HH:mm:ss",
                                    "Gy": "y G",
                                    "GyMMM": "MMM y G",
                                    "GyMMMd": "d MMM y G",
                                    "GyMMMEd": "E, d MMM y G",
                                    "h": "h a",
                                    "H": "HH",
                                    "hm": "h:mm a",
                                    "Hm": "HH:mm",
                                    "hms": "h:mm:ss a",
                                    "Hms": "HH:mm:ss",
                                    "M": "LL",
                                    "Md": "dd/MM",
                                    "MEd": "E dd/MM",
                                    "MMdd": "dd/MM",
                                    "MMM": "LLL",
                                    "MMMd": "d MMM",
                                    "MMMEd": "E, d MMM",
                                    "MMMMd": "d MMMM",
                                    "MMMMEd": "E, d MMMM",
                                    "ms": "mm:ss",
                                    "y": "y",
                                    "yM": "MM/y",
                                    "yMd": "d/M/y",
                                    "yMEd": "E, dd/MM/y",
                                    "yMMM": "MMM y",
                                    "yMMMd": "d MMM, y",
                                    "yMMMEd": "E, d MMM, y",
                                    "yMMMM": "MMMM y",
                                    "yQQQ": "QQQ y",
                                    "yQQQQ": "QQQQ y"
                                },
                                "appendItems": {
                                    "Day": "{0} ({2}: {1})",
                                    "Day-Of-Week": "{0} {1}",
                                    "Era": "{0} {1}",
                                    "Hour": "{0} ({2}: {1})",
                                    "Minute": "{0} ({2}: {1})",
                                    "Month": "{0} ({2}: {1})",
                                    "Quarter": "{0} ({2}: {1})",
                                    "Second": "{0} ({2}: {1})",
                                    "Timezone": "{0} {1}",
                                    "Week": "{0} ({2}: {1})",
                                    "Year": "{0} {1}"
                                },
                                "intervalFormats": {
                                    "intervalFormatFallback": "{0} – {1}",
                                    "d": {
                                        "d": "d–d"
                                    },
                                    "h": {
                                        "a": "h a – h a",
                                        "h": "h–h a"
                                    },
                                    "H": {
                                        "H": "HH–HH"
                                    },
                                    "hm": {
                                        "a": "h:mm a – h:mm a",
                                        "h": "h:mm–h:mm a",
                                        "m": "h:mm–h:mm a"
                                    },
                                    "Hm": {
                                        "H": "HH:mm–HH:mm",
                                        "m": "HH:mm–HH:mm"
                                    },
                                    "hmv": {
                                        "a": "h:mm a – h:mm a v",
                                        "h": "h:mm–h:mm a v",
                                        "m": "h:mm–h:mm a v"
                                    },
                                    "Hmv": {
                                        "H": "HH:mm–HH:mm v",
                                        "m": "HH:mm–HH:mm v"
                                    },
                                    "hv": {
                                        "a": "h a – h a v",
                                        "h": "h–h a v"
                                    },
                                    "Hv": {
                                        "H": "HH–HH v"
                                    },
                                    "M": {
                                        "M": "M–M"
                                    },
                                    "Md": {
                                        "d": "d/M – d/M",
                                        "M": "d/M – d/M"
                                    },
                                    "MEd": {
                                        "d": "E, d/M – E, d/M",
                                        "M": "E, d/M – E, d/M"
                                    },
                                    "MMM": {
                                        "M": "MMM–MMM"
                                    },
                                    "MMMd": {
                                        "d": "d–d MMM",
                                        "M": "d MMM – d MMM"
                                    },
                                    "MMMEd": {
                                        "d": "E, d MMM – E, d MMM",
                                        "M": "E, d MMM – E, d MMM"
                                    },
                                    "y": {
                                        "y": "y-y"
                                    },
                                    "yM": {
                                        "M": "MM/y – MM/y",
                                        "y": "MM/y – MM/y"
                                    },
                                    "yMd": {
                                        "d": "d/M/y – d/M/y",
                                        "M": "d/M/y – d/M/y",
                                        "y": "d/M/y – d/M/y"
                                    },
                                    "yMEd": {
                                        "d": "E, d/M/y – E, d/M/y",
                                        "M": "E, d/M/y – E, d/M/y",
                                        "y": "E, d/M/y – E, d/M/y"
                                    },
                                    "yMMM": {
                                        "M": "MMM–MMM y",
                                        "y": "MMM y – MMM y"
                                    },
                                    "yMMMd": {
                                        "d": "d–d MMM, y",
                                        "M": "d MMM – d MMM, y",
                                        "y": "d MMM, y – d MMM, y"
                                    },
                                    "yMMMEd": {
                                        "d": "E, d MMM – E, d MMM, y",
                                        "M": "E, d MMM – E, d MMM, y",
                                        "y": "E, d MMM, y – E, d MMM, y"
                                    },
                                    "yMMMM": {
                                        "M": "MMMM–MMMM y",
                                        "y": "MMMM y – MMMM y"
                                    }
                                }
                            }
                        }
                    },
                    "timeZoneNames": {
                        "hourFormat": "+HH:mm;-HH:mm",
                        "gmtFormat": "GMT{0}",
                        "gmtZeroFormat": "GMT",
                        "regionFormat": "{0} Time",
                        "regionFormat-type-daylight": "{0} Daylight Time",
                        "regionFormat-type-standard": "{0} Standard Time",
                        "fallbackFormat": "{1} ({0})"
                    }
                }
            },
            "en-IN": {
                "dates": {
                    "calendars": {
                        "gregorian": {
                            "months": {
                                "format": {
                                    "abbreviated": {
                                        "1": "Jan",
                                        "2": "Feb",
                                        "3": "Mar",
                                        "4": "Apr",
                                        "5": "May",
                                        "6": "Jun",
                                        "7": "Jul",
                                        "8": "Aug",
                                        "9": "Sep",
                                        "10": "Oct",
                                        "11": "Nov",
                                        "12": "Dec"
                                    },
                                    "narrow": {
                                        "1": "J",
                                        "2": "F",
                                        "3": "M",
                                        "4": "A",
                                        "5": "M",
                                        "6": "J",
                                        "7": "J",
                                        "8": "A",
                                        "9": "S",
                                        "10": "O",
                                        "11": "N",
                                        "12": "D"
                                    },
                                    "wide": {
                                        "1": "January",
                                        "2": "February",
                                        "3": "March",
                                        "4": "April",
                                        "5": "May",
                                        "6": "June",
                                        "7": "July",
                                        "8": "August",
                                        "9": "September",
                                        "10": "October",
                                        "11": "November",
                                        "12": "December"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "1": "Jan",
                                        "2": "Feb",
                                        "3": "Mar",
                                        "4": "Apr",
                                        "5": "May",
                                        "6": "Jun",
                                        "7": "Jul",
                                        "8": "Aug",
                                        "9": "Sep",
                                        "10": "Oct",
                                        "11": "Nov",
                                        "12": "Dec"
                                    },
                                    "narrow": {
                                        "1": "J",
                                        "2": "F",
                                        "3": "M",
                                        "4": "A",
                                        "5": "M",
                                        "6": "J",
                                        "7": "J",
                                        "8": "A",
                                        "9": "S",
                                        "10": "O",
                                        "11": "N",
                                        "12": "D"
                                    },
                                    "wide": {
                                        "1": "January",
                                        "2": "February",
                                        "3": "March",
                                        "4": "April",
                                        "5": "May",
                                        "6": "June",
                                        "7": "July",
                                        "8": "August",
                                        "9": "September",
                                        "10": "October",
                                        "11": "November",
                                        "12": "December"
                                    }
                                }
                            },
                            "days": {
                                "format": {
                                    "abbreviated": {
                                        "sun": "Sun",
                                        "mon": "Mon",
                                        "tue": "Tue",
                                        "wed": "Wed",
                                        "thu": "Thu",
                                        "fri": "Fri",
                                        "sat": "Sat"
                                    },
                                    "narrow": {
                                        "sun": "S",
                                        "mon": "M",
                                        "tue": "T",
                                        "wed": "W",
                                        "thu": "T",
                                        "fri": "F",
                                        "sat": "S"
                                    },
                                    "short": {
                                        "sun": "Su",
                                        "mon": "Mo",
                                        "tue": "Tu",
                                        "wed": "We",
                                        "thu": "Th",
                                        "fri": "Fr",
                                        "sat": "Sa"
                                    },
                                    "wide": {
                                        "sun": "Sunday",
                                        "mon": "Monday",
                                        "tue": "Tuesday",
                                        "wed": "Wednesday",
                                        "thu": "Thursday",
                                        "fri": "Friday",
                                        "sat": "Saturday"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "sun": "Sun",
                                        "mon": "Mon",
                                        "tue": "Tue",
                                        "wed": "Wed",
                                        "thu": "Thu",
                                        "fri": "Fri",
                                        "sat": "Sat"
                                    },
                                    "narrow": {
                                        "sun": "S",
                                        "mon": "M",
                                        "tue": "T",
                                        "wed": "W",
                                        "thu": "T",
                                        "fri": "F",
                                        "sat": "S"
                                    },
                                    "short": {
                                        "sun": "Su",
                                        "mon": "Mo",
                                        "tue": "Tu",
                                        "wed": "We",
                                        "thu": "Th",
                                        "fri": "Fr",
                                        "sat": "Sa"
                                    },
                                    "wide": {
                                        "sun": "Sunday",
                                        "mon": "Monday",
                                        "tue": "Tuesday",
                                        "wed": "Wednesday",
                                        "thu": "Thursday",
                                        "fri": "Friday",
                                        "sat": "Saturday"
                                    }
                                }
                            },
                            "quarters": {
                                "format": {
                                    "abbreviated": {
                                        "1": "Q1",
                                        "2": "Q2",
                                        "3": "Q3",
                                        "4": "Q4"
                                    },
                                    "narrow": {
                                        "1": "1",
                                        "2": "2",
                                        "3": "3",
                                        "4": "4"
                                    },
                                    "wide": {
                                        "1": "1st quarter",
                                        "2": "2nd quarter",
                                        "3": "3rd quarter",
                                        "4": "4th quarter"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "1": "Q1",
                                        "2": "Q2",
                                        "3": "Q3",
                                        "4": "Q4"
                                    },
                                    "narrow": {
                                        "1": "1",
                                        "2": "2",
                                        "3": "3",
                                        "4": "4"
                                    },
                                    "wide": {
                                        "1": "1st quarter",
                                        "2": "2nd quarter",
                                        "3": "3rd quarter",
                                        "4": "4th quarter"
                                    }
                                }
                            },
                            "dayPeriods": {
                                "format": {
                                    "abbreviated": {
                                        "am": "am",
                                        "am-alt-variant": "a.m.",
                                        "noon": "noon",
                                        "pm": "pm",
                                        "pm-alt-variant": "p.m."
                                    },
                                    "narrow": {
                                        "am": "a",
                                        "am-alt-variant": "a.m.",
                                        "noon": "n",
                                        "pm": "p",
                                        "pm-alt-variant": "p.m."
                                    },
                                    "wide": {
                                        "am": "am",
                                        "am-alt-variant": "a.m.",
                                        "noon": "noon",
                                        "pm": "pm",
                                        "pm-alt-variant": "p.m."
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "am": "am",
                                        "am-alt-variant": "a.m.",
                                        "noon": "noon",
                                        "pm": "pm",
                                        "pm-alt-variant": "p.m."
                                    },
                                    "narrow": {
                                        "am": "a",
                                        "am-alt-variant": "a.m.",
                                        "noon": "n",
                                        "pm": "p",
                                        "pm-alt-variant": "p.m."
                                    },
                                    "wide": {
                                        "am": "am",
                                        "am-alt-variant": "a.m.",
                                        "noon": "noon",
                                        "pm": "pm",
                                        "pm-alt-variant": "p.m."
                                    }
                                }
                            },
                            "eras": {
                                "eraNames": {
                                    "0": "Before Christ",
                                    "1": "Anno Domini",
                                    "0-alt-variant": "Before Common Era",
                                    "1-alt-variant": "Common Era"
                                },
                                "eraAbbr": {
                                    "0": "BC",
                                    "1": "AD",
                                    "0-alt-variant": "BCE",
                                    "1-alt-variant": "CE"
                                },
                                "eraNarrow": {
                                    "0": "B",
                                    "1": "A",
                                    "0-alt-variant": "BCE",
                                    "1-alt-variant": "CE"
                                }
                            },
                            "dateFormats": {
                                "full": "EEEE d MMMM y",
                                "long": "d MMMM y",
                                "medium": "dd-MMM-y",
                                "short": "dd/MM/yy"
                            },
                            "timeFormats": {
                                "full": "h:mm:ss a zzzz",
                                "long": "h:mm:ss a z",
                                "medium": "h:mm:ss a",
                                "short": "h:mm a"
                            },
                            "dateTimeFormats": {
                                "full": "{1} {0}",
                                "long": "{1} {0}",
                                "medium": "{1} {0}",
                                "short": "{1} {0}",
                                "availableFormats": {
                                    "d": "d",
                                    "Ed": "E d",
                                    "Ehm": "E h:mm a",
                                    "EHm": "E HH:mm",
                                    "Ehms": "E h:mm:ss a",
                                    "EHms": "E HH:mm:ss",
                                    "Gy": "y G",
                                    "GyMMM": "MMM y G",
                                    "GyMMMd": "d MMM y G",
                                    "GyMMMEd": "E, d MMM y G",
                                    "h": "h a",
                                    "H": "HH",
                                    "hm": "h:mm a",
                                    "Hm": "HH:mm",
                                    "hms": "h:mm:ss a",
                                    "Hms": "HH:mm:ss",
                                    "M": "LL",
                                    "Md": "dd/MM",
                                    "MEd": "E dd/MM",
                                    "MMdd": "dd/MM",
                                    "MMM": "LLL",
                                    "MMMd": "d MMM",
                                    "MMMEd": "E d MMM",
                                    "MMMMd": "d MMMM",
                                    "ms": "mm:ss",
                                    "y": "y",
                                    "yM": "MM/y",
                                    "yMd": "d/M/y",
                                    "yMEd": "E d/M/y",
                                    "yMMM": "MMM y",
                                    "yMMMd": "d MMM y",
                                    "yMMMEd": "E d MMM, y",
                                    "yMMMM": "MMMM y",
                                    "yQQQ": "QQQ y",
                                    "yQQQQ": "QQQQ y"
                                },
                                "appendItems": {
                                    "Day": "{0} ({2}: {1})",
                                    "Day-Of-Week": "{0} {1}",
                                    "Era": "{0} {1}",
                                    "Hour": "{0} ({2}: {1})",
                                    "Minute": "{0} ({2}: {1})",
                                    "Month": "{0} ({2}: {1})",
                                    "Quarter": "{0} ({2}: {1})",
                                    "Second": "{0} ({2}: {1})",
                                    "Timezone": "{0} {1}",
                                    "Week": "{0} ({2}: {1})",
                                    "Year": "{0} {1}"
                                },
                                "intervalFormats": {
                                    "intervalFormatFallback": "{0} - {1}",
                                    "d": {
                                        "d": "d-d"
                                    },
                                    "h": {
                                        "a": "h a - h a",
                                        "h": "h-h a"
                                    },
                                    "H": {
                                        "H": "HH–HH"
                                    },
                                    "hm": {
                                        "a": "h:mm a - h:mm a",
                                        "h": "h:mm-h:mm a",
                                        "m": "h:mm-h:mm a"
                                    },
                                    "Hm": {
                                        "H": "HH:mm–HH:mm",
                                        "m": "HH:mm–HH:mm"
                                    },
                                    "hmv": {
                                        "a": "h:mm a - h:mm a v",
                                        "h": "h:mm-h:mm a v",
                                        "m": "h:mm-h:mm a v"
                                    },
                                    "Hmv": {
                                        "H": "HH:mm–HH:mm v",
                                        "m": "HH:mm–HH:mm v"
                                    },
                                    "hv": {
                                        "a": "h a - h a v",
                                        "h": "h-h a v"
                                    },
                                    "Hv": {
                                        "H": "HH–HH v"
                                    },
                                    "M": {
                                        "M": "M-M"
                                    },
                                    "Md": {
                                        "d": "dd/MM - dd/MM",
                                        "M": "dd/MM - dd/MM"
                                    },
                                    "MEd": {
                                        "d": "E dd/MM - E dd/MM",
                                        "M": "E dd/MM - E dd/MM"
                                    },
                                    "MMM": {
                                        "M": "MMM-MMM"
                                    },
                                    "MMMd": {
                                        "d": "d-d MMM",
                                        "M": "d MMM - d MMM"
                                    },
                                    "MMMEd": {
                                        "d": "E d - E d MMM",
                                        "M": "E d MMM - E d MMM"
                                    },
                                    "y": {
                                        "y": "y-y"
                                    },
                                    "yM": {
                                        "M": "MM/y - MM/y",
                                        "y": "MM/y - MM/y"
                                    },
                                    "yMd": {
                                        "d": "dd/MM/y - dd/MM/y",
                                        "M": "dd/MM/y - dd/MM/y",
                                        "y": "dd/MM/y - dd/MM/y"
                                    },
                                    "yMEd": {
                                        "d": "E dd/MM/y - E dd/MM/y",
                                        "M": "E dd/MM/y - E dd/MM/y",
                                        "y": "E dd/MM/y - E dd/MM/y"
                                    },
                                    "yMMM": {
                                        "M": "MMM-MMM y",
                                        "y": "MMM y - MMM y"
                                    },
                                    "yMMMd": {
                                        "d": "d-d MMM y",
                                        "M": "d MMM - d MMM y",
                                        "y": "d MMM y - d MMM y"
                                    },
                                    "yMMMEd": {
                                        "d": "E d - E d MMM y",
                                        "M": "E d MMM - E d MMM y",
                                        "y": "E d MMM y - E d MMM y"
                                    },
                                    "yMMMM": {
                                        "M": "MMMM–MMMM y",
                                        "y": "MMMM y – MMMM y"
                                    }
                                }
                            }
                        }
                    },
                    "timeZoneNames": {
                        "hourFormat": "+HH:mm;-HH:mm",
                        "gmtFormat": "GMT{0}",
                        "gmtZeroFormat": "GMT",
                        "regionFormat": "{0} Time",
                        "regionFormat-type-daylight": "{0} Daylight Time",
                        "regionFormat-type-standard": "{0} Standard Time",
                        "fallbackFormat": "{1} ({0})"
                    }
                }
            },
            "es": {
                "dates": {
                    "calendars": {
                        "gregorian": {
                            "months": {
                                "format": {
                                    "abbreviated": {
                                        "1": "ene.",
                                        "2": "feb.",
                                        "3": "mar.",
                                        "4": "abr.",
                                        "5": "may.",
                                        "6": "jun.",
                                        "7": "jul.",
                                        "8": "ago.",
                                        "9": "sept.",
                                        "10": "oct.",
                                        "11": "nov.",
                                        "12": "dic."
                                    },
                                    "narrow": {
                                        "1": "E",
                                        "2": "F",
                                        "3": "M",
                                        "4": "A",
                                        "5": "M",
                                        "6": "J",
                                        "7": "J",
                                        "8": "A",
                                        "9": "S",
                                        "10": "O",
                                        "11": "N",
                                        "12": "D"
                                    },
                                    "wide": {
                                        "1": "enero",
                                        "2": "febrero",
                                        "3": "marzo",
                                        "4": "abril",
                                        "5": "mayo",
                                        "6": "junio",
                                        "7": "julio",
                                        "8": "agosto",
                                        "9": "septiembre",
                                        "10": "octubre",
                                        "11": "noviembre",
                                        "12": "diciembre"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "1": "Ene.",
                                        "2": "Feb.",
                                        "3": "Mar.",
                                        "4": "Abr.",
                                        "5": "May.",
                                        "6": "Jun.",
                                        "7": "Jul.",
                                        "8": "Ago.",
                                        "9": "Sept.",
                                        "10": "Oct.",
                                        "11": "Nov.",
                                        "12": "Dic."
                                    },
                                    "narrow": {
                                        "1": "E",
                                        "2": "F",
                                        "3": "M",
                                        "4": "A",
                                        "5": "M",
                                        "6": "J",
                                        "7": "J",
                                        "8": "A",
                                        "9": "S",
                                        "10": "O",
                                        "11": "N",
                                        "12": "D"
                                    },
                                    "wide": {
                                        "1": "Enero",
                                        "2": "Febrero",
                                        "3": "Marzo",
                                        "4": "Abril",
                                        "5": "Mayo",
                                        "6": "Junio",
                                        "7": "Julio",
                                        "8": "Agosto",
                                        "9": "Septiembre",
                                        "10": "Octubre",
                                        "11": "Noviembre",
                                        "12": "Diciembre"
                                    }
                                }
                            },
                            "days": {
                                "format": {
                                    "abbreviated": {
                                        "sun": "dom.",
                                        "mon": "lun.",
                                        "tue": "mar.",
                                        "wed": "mié.",
                                        "thu": "jue.",
                                        "fri": "vie.",
                                        "sat": "sáb."
                                    },
                                    "narrow": {
                                        "sun": "D",
                                        "mon": "L",
                                        "tue": "M",
                                        "wed": "X",
                                        "thu": "J",
                                        "fri": "V",
                                        "sat": "S"
                                    },
                                    "short": {
                                        "sun": "DO",
                                        "mon": "LU",
                                        "tue": "MA",
                                        "wed": "MI",
                                        "thu": "JU",
                                        "fri": "VI",
                                        "sat": "SA"
                                    },
                                    "wide": {
                                        "sun": "domingo",
                                        "mon": "lunes",
                                        "tue": "martes",
                                        "wed": "miércoles",
                                        "thu": "jueves",
                                        "fri": "viernes",
                                        "sat": "sábado"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "sun": "Dom.",
                                        "mon": "Lun.",
                                        "tue": "Mar.",
                                        "wed": "Mié.",
                                        "thu": "Jue.",
                                        "fri": "Vie.",
                                        "sat": "Sáb."
                                    },
                                    "narrow": {
                                        "sun": "D",
                                        "mon": "L",
                                        "tue": "M",
                                        "wed": "M",
                                        "thu": "J",
                                        "fri": "V",
                                        "sat": "S"
                                    },
                                    "short": {
                                        "sun": "DO",
                                        "mon": "LU",
                                        "tue": "MA",
                                        "wed": "MI",
                                        "thu": "JU",
                                        "fri": "VI",
                                        "sat": "SA"
                                    },
                                    "wide": {
                                        "sun": "Domingo",
                                        "mon": "Lunes",
                                        "tue": "Martes",
                                        "wed": "Miércoles",
                                        "thu": "Jueves",
                                        "fri": "Viernes",
                                        "sat": "Sábado"
                                    }
                                }
                            },
                            "quarters": {
                                "format": {
                                    "abbreviated": {
                                        "1": "T1",
                                        "2": "T2",
                                        "3": "T3",
                                        "4": "T4"
                                    },
                                    "narrow": {
                                        "1": "1T",
                                        "2": "2T",
                                        "3": "3T",
                                        "4": "4T"
                                    },
                                    "wide": {
                                        "1": "1.er trimestre",
                                        "2": "2.º trimestre",
                                        "3": "3.er trimestre",
                                        "4": "4.º trimestre"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "1": "T1",
                                        "2": "T2",
                                        "3": "T3",
                                        "4": "T4"
                                    },
                                    "narrow": {
                                        "1": "1T",
                                        "2": "2T",
                                        "3": "3T",
                                        "4": "4T"
                                    },
                                    "wide": {
                                        "1": "1.er trimestre",
                                        "2": "2.º trimestre",
                                        "3": "3.er trimestre",
                                        "4": "4.º trimestre"
                                    }
                                }
                            },
                            "dayPeriods": {
                                "format": {
                                    "abbreviated": {
                                        "am": "a. m.",
                                        "pm": "p. m."
                                    },
                                    "narrow": {
                                        "am": "a.m.",
                                        "pm": "p.m."
                                    },
                                    "wide": {
                                        "am": "a. m.",
                                        "pm": "p. m."
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "am": "a. m.",
                                        "pm": "p. m."
                                    },
                                    "narrow": {
                                        "am": "a.m.",
                                        "pm": "p.m."
                                    },
                                    "wide": {
                                        "am": "a. m.",
                                        "pm": "p. m."
                                    }
                                }
                            },
                            "eras": {
                                "eraNames": {
                                    "0": "antes de Cristo",
                                    "1": "anno Dómini",
                                    "0-alt-variant": "a. e. c.",
                                    "1-alt-variant": "e. c."
                                },
                                "eraAbbr": {
                                    "0": "a. C.",
                                    "1": "d. C.",
                                    "0-alt-variant": "a. e. c.",
                                    "1-alt-variant": "e. c."
                                },
                                "eraNarrow": {
                                    "0": "a. C.",
                                    "1": "d. C.",
                                    "0-alt-variant": "a. e. c.",
                                    "1-alt-variant": "e. c."
                                }
                            },
                            "dateFormats": {
                                "full": "EEEE, d 'de' MMMM 'de' y",
                                "long": "d 'de' MMMM 'de' y",
                                "medium": "d/M/y",
                                "short": "d/M/yy"
                            },
                            "timeFormats": {
                                "full": "H:mm:ss (zzzz)",
                                "long": "H:mm:ss z",
                                "medium": "H:mm:ss",
                                "short": "H:mm"
                            },
                            "dateTimeFormats": {
                                "full": "{1}, {0}",
                                "long": "{1}, {0}",
                                "medium": "{1} {0}",
                                "short": "{1} {0}",
                                "availableFormats": {
                                    "d": "d",
                                    "Ed": "E d",
                                    "Ehm": "E, h:mm a",
                                    "EHm": "E, H:mm",
                                    "Ehms": "E, h:mm:ss a",
                                    "EHms": "E, H:mm:ss",
                                    "Gy": "y G",
                                    "GyMMM": "MMM 'de' y G",
                                    "GyMMMd": "d MMM 'de' y G",
                                    "GyMMMEd": "E, d 'de' MMMM 'de' y G",
                                    "h": "h a",
                                    "H": "H",
                                    "hm": "h:mm a",
                                    "Hm": "H:mm",
                                    "hms": "h:mm:ss a",
                                    "Hms": "H:mm:ss",
                                    "M": "L",
                                    "Md": "d/M",
                                    "MEd": "E, d/M",
                                    "MMd": "d/M",
                                    "MMdd": "d/M",
                                    "MMM": "LLL",
                                    "MMMd": "d 'de' MMM",
                                    "MMMdd": "dd-MMM",
                                    "MMMEd": "E d 'de' MMM",
                                    "MMMMd": "d 'de' MMMM",
                                    "ms": "mm:ss",
                                    "y": "y",
                                    "yM": "M/y",
                                    "yMd": "d/M/y",
                                    "yMEd": "EEE, d/M/y",
                                    "yMM": "M/y",
                                    "yMMM": "MMM 'de' y",
                                    "yMMMd": "d 'de' MMM 'de' y",
                                    "yMMMEd": "EEE, d 'de' MMMM 'de' y",
                                    "yMMMM": "MMMM 'de' y",
                                    "yQQQ": "QQQ y",
                                    "yQQQQ": "QQQQ 'de' y"
                                },
                                "appendItems": {
                                    "Day": "{0} ({2}: {1})",
                                    "Day-Of-Week": "{0} {1}",
                                    "Era": "{1} {0}",
                                    "Hour": "{0} ({2}: {1})",
                                    "Minute": "{0} ({2}: {1})",
                                    "Month": "{0} ({2}: {1})",
                                    "Quarter": "{0} ({2}: {1})",
                                    "Second": "{0} ({2}: {1})",
                                    "Timezone": "{0} {1}",
                                    "Week": "{0} ({2}: {1})",
                                    "Year": "{1} {0}"
                                },
                                "intervalFormats": {
                                    "intervalFormatFallback": "{0}–{1}",
                                    "d": {
                                        "d": "d–d"
                                    },
                                    "h": {
                                        "a": "h a–h a",
                                        "h": "h–h a"
                                    },
                                    "H": {
                                        "H": "H–H"
                                    },
                                    "hm": {
                                        "a": "h:mm a – h:mm a",
                                        "h": "h:mm – h:mm a",
                                        "m": "h:mm – h:mm a"
                                    },
                                    "Hm": {
                                        "H": "H:mm–H:mm",
                                        "m": "H:mm–H:mm"
                                    },
                                    "hmv": {
                                        "a": "h:mm a–h:mm a v",
                                        "h": "h:mm–h:mm a v",
                                        "m": "h:mm–h:mm a v"
                                    },
                                    "Hmv": {
                                        "H": "H:mm–H:mm v",
                                        "m": "H:mm–H:mm v"
                                    },
                                    "hv": {
                                        "a": "h a–h a v",
                                        "h": "h–h a v"
                                    },
                                    "Hv": {
                                        "H": "H–H v"
                                    },
                                    "M": {
                                        "M": "M–M"
                                    },
                                    "Md": {
                                        "d": "d/M–d/M",
                                        "M": "d/M–d/M"
                                    },
                                    "MEd": {
                                        "d": "E, d/M–E, d/M",
                                        "M": "E, d/M–E, d/M"
                                    },
                                    "MMM": {
                                        "M": "MMM–MMM"
                                    },
                                    "MMMd": {
                                        "d": "d–d MMM",
                                        "M": "d MMM–d MMM"
                                    },
                                    "MMMEd": {
                                        "d": "E, d MMM–E, d MMM",
                                        "M": "E, d MMM–E, d MMM"
                                    },
                                    "y": {
                                        "y": "y–y"
                                    },
                                    "yM": {
                                        "M": "M/y–M/y",
                                        "y": "M/y–M/y"
                                    },
                                    "yMd": {
                                        "d": "d/M/y–d/M/y",
                                        "M": "d/M/y–d/M/y",
                                        "y": "d/M/y–d/M/y"
                                    },
                                    "yMEd": {
                                        "d": "E, d/M/y–E, d/M/y",
                                        "M": "E, d/M/y–E, d/M/y",
                                        "y": "E, d/M/y–E, d/M/y"
                                    },
                                    "yMMM": {
                                        "M": "MMM–MMM y",
                                        "y": "MMM y–MMM y"
                                    },
                                    "yMMMd": {
                                        "d": "d–d MMM y",
                                        "M": "d MMM–d MMM 'de' y",
                                        "y": "d MMM 'de' y–d MMM 'de' y"
                                    },
                                    "yMMMEd": {
                                        "d": "E, d MMM–E, d MMM 'de' y",
                                        "M": "E, d MMM–E, d MMM 'de' y",
                                        "y": "E, d MMM 'de' y–E, d MMM 'de' y"
                                    },
                                    "yMMMM": {
                                        "M": "MMMM–MMMM 'de' y",
                                        "y": "MMMM 'de' y–MMMM 'de' y"
                                    }
                                }
                            }
                        }
                    },
                    "timeZoneNames": {
                        "hourFormat": "+HH:mm;-HH:mm",
                        "gmtFormat": "GMT{0}",
                        "gmtZeroFormat": "GMT",
                        "regionFormat": "Hora de {0}",
                        "regionFormat-type-daylight": "horario de verano de {0}",
                        "regionFormat-type-standard": "horario estándar de {0}",
                        "fallbackFormat": "{1} ({0})"
                    }
                }
            },
            "fi": {
                "dates": {
                    "calendars": {
                        "gregorian": {
                            "months": {
                                "format": {
                                    "abbreviated": {
                                        "1": "tammikuuta",
                                        "2": "helmikuuta",
                                        "3": "maaliskuuta",
                                        "4": "huhtikuuta",
                                        "5": "toukokuuta",
                                        "6": "kesäkuuta",
                                        "7": "heinäkuuta",
                                        "8": "elokuuta",
                                        "9": "syyskuuta",
                                        "10": "lokakuuta",
                                        "11": "marraskuuta",
                                        "12": "joulukuuta"
                                    },
                                    "narrow": {
                                        "1": "T",
                                        "2": "H",
                                        "3": "M",
                                        "4": "H",
                                        "5": "T",
                                        "6": "K",
                                        "7": "H",
                                        "8": "E",
                                        "9": "S",
                                        "10": "L",
                                        "11": "M",
                                        "12": "J"
                                    },
                                    "wide": {
                                        "1": "tammikuuta",
                                        "2": "helmikuuta",
                                        "3": "maaliskuuta",
                                        "4": "huhtikuuta",
                                        "5": "toukokuuta",
                                        "6": "kesäkuuta",
                                        "7": "heinäkuuta",
                                        "8": "elokuuta",
                                        "9": "syyskuuta",
                                        "10": "lokakuuta",
                                        "11": "marraskuuta",
                                        "12": "joulukuuta"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "1": "tammi",
                                        "2": "helmi",
                                        "3": "maalis",
                                        "4": "huhti",
                                        "5": "touko",
                                        "6": "kesä",
                                        "7": "heinä",
                                        "8": "elo",
                                        "9": "syys",
                                        "10": "loka",
                                        "11": "marras",
                                        "12": "joulu"
                                    },
                                    "narrow": {
                                        "1": "T",
                                        "2": "H",
                                        "3": "M",
                                        "4": "H",
                                        "5": "T",
                                        "6": "K",
                                        "7": "H",
                                        "8": "E",
                                        "9": "S",
                                        "10": "L",
                                        "11": "M",
                                        "12": "J"
                                    },
                                    "wide": {
                                        "1": "tammikuu",
                                        "2": "helmikuu",
                                        "3": "maaliskuu",
                                        "4": "huhtikuu",
                                        "5": "toukokuu",
                                        "6": "kesäkuu",
                                        "7": "heinäkuu",
                                        "8": "elokuu",
                                        "9": "syyskuu",
                                        "10": "lokakuu",
                                        "11": "marraskuu",
                                        "12": "joulukuu"
                                    }
                                }
                            },
                            "days": {
                                "format": {
                                    "abbreviated": {
                                        "sun": "su",
                                        "mon": "ma",
                                        "tue": "ti",
                                        "wed": "ke",
                                        "thu": "to",
                                        "fri": "pe",
                                        "sat": "la"
                                    },
                                    "narrow": {
                                        "sun": "S",
                                        "mon": "M",
                                        "tue": "T",
                                        "wed": "K",
                                        "thu": "T",
                                        "fri": "P",
                                        "sat": "L"
                                    },
                                    "short": {
                                        "sun": "su",
                                        "mon": "ma",
                                        "tue": "ti",
                                        "wed": "ke",
                                        "thu": "to",
                                        "fri": "pe",
                                        "sat": "la"
                                    },
                                    "wide": {
                                        "sun": "sunnuntaina",
                                        "mon": "maanantaina",
                                        "tue": "tiistaina",
                                        "wed": "keskiviikkona",
                                        "thu": "torstaina",
                                        "fri": "perjantaina",
                                        "sat": "lauantaina"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "sun": "su",
                                        "mon": "ma",
                                        "tue": "ti",
                                        "wed": "ke",
                                        "thu": "to",
                                        "fri": "pe",
                                        "sat": "la"
                                    },
                                    "narrow": {
                                        "sun": "S",
                                        "mon": "M",
                                        "tue": "T",
                                        "wed": "K",
                                        "thu": "T",
                                        "fri": "P",
                                        "sat": "L"
                                    },
                                    "short": {
                                        "sun": "su",
                                        "mon": "ma",
                                        "tue": "ti",
                                        "wed": "ke",
                                        "thu": "to",
                                        "fri": "pe",
                                        "sat": "la"
                                    },
                                    "wide": {
                                        "sun": "sunnuntai",
                                        "mon": "maanantai",
                                        "tue": "tiistai",
                                        "wed": "keskiviikko",
                                        "thu": "torstai",
                                        "fri": "perjantai",
                                        "sat": "lauantai"
                                    }
                                }
                            },
                            "quarters": {
                                "format": {
                                    "abbreviated": {
                                        "1": "1. nelj.",
                                        "2": "2. nelj.",
                                        "3": "3. nelj.",
                                        "4": "4. nelj."
                                    },
                                    "narrow": {
                                        "1": "1",
                                        "2": "2",
                                        "3": "3",
                                        "4": "4"
                                    },
                                    "wide": {
                                        "1": "1. neljännes",
                                        "2": "2. neljännes",
                                        "3": "3. neljännes",
                                        "4": "4. neljännes"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "1": "1. nelj.",
                                        "2": "2. nelj.",
                                        "3": "3. nelj.",
                                        "4": "4. nelj."
                                    },
                                    "narrow": {
                                        "1": "1",
                                        "2": "2",
                                        "3": "3",
                                        "4": "4"
                                    },
                                    "wide": {
                                        "1": "1. neljännes",
                                        "2": "2. neljännes",
                                        "3": "3. neljännes",
                                        "4": "4. neljännes"
                                    }
                                }
                            },
                            "dayPeriods": {
                                "format": {
                                    "abbreviated": {
                                        "am": "ap.",
                                        "pm": "ip."
                                    },
                                    "narrow": {
                                        "am": "ap.",
                                        "pm": "ip."
                                    },
                                    "wide": {
                                        "am": "ap.",
                                        "pm": "ip."
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "am": "ap.",
                                        "pm": "ip."
                                    },
                                    "narrow": {
                                        "am": "ap.",
                                        "pm": "ip."
                                    },
                                    "wide": {
                                        "am": "ap.",
                                        "pm": "ip."
                                    }
                                }
                            },
                            "eras": {
                                "eraNames": {
                                    "0": "ennen Kristuksen syntymää",
                                    "1": "jälkeen Kristuksen syntymän",
                                    "0-alt-variant": "ennen ajanlaskun alkua",
                                    "1-alt-variant": "jälkeen ajanlaskun alun"
                                },
                                "eraAbbr": {
                                    "0": "eKr.",
                                    "1": "jKr.",
                                    "0-alt-variant": "eaa.",
                                    "1-alt-variant": "jaa."
                                },
                                "eraNarrow": {
                                    "0": "eK",
                                    "1": "jK",
                                    "0-alt-variant": "eaa",
                                    "1-alt-variant": "jaa"
                                }
                            },
                            "dateFormats": {
                                "full": "cccc d. MMMM y",
                                "long": "d. MMMM y",
                                "medium": "d.M.y",
                                "short": "d.M.y"
                            },
                            "timeFormats": {
                                "full": "H.mm.ss zzzz",
                                "long": "H.mm.ss z",
                                "medium": "H.mm.ss",
                                "short": "H.mm"
                            },
                            "dateTimeFormats": {
                                "full": "{1} {0}",
                                "long": "{1} {0}",
                                "medium": "{1} {0}",
                                "short": "{1} {0}",
                                "availableFormats": {
                                    "d": "d",
                                    "Ed": "E d.",
                                    "Ehm": "E h.mm a",
                                    "EHm": "E H.mm",
                                    "Ehms": "E h.mm.ss a",
                                    "EHms": "E H.mm.ss",
                                    "Gy": "y G",
                                    "GyMMM": "LLL y G",
                                    "GyMMMd": "d. MMM y G",
                                    "GyMMMEd": "E d. MMM y G",
                                    "h": "h a",
                                    "H": "H",
                                    "hm": "h.mm a",
                                    "Hm": "H.mm",
                                    "hms": "h.mm.ss a",
                                    "Hms": "H.mm.ss",
                                    "M": "L",
                                    "Md": "d.M.",
                                    "MEd": "E d.M.",
                                    "MMM": "LLL",
                                    "MMMd": "d. MMM",
                                    "MMMEd": "ccc d. MMM",
                                    "ms": "m.ss",
                                    "y": "y",
                                    "yM": "L.y",
                                    "yMd": "d.M.y",
                                    "yMEd": "E d.M.y",
                                    "yMM": "M.y",
                                    "yMMM": "LLL y",
                                    "yMMMd": "d. MMM y",
                                    "yMMMEd": "E d. MMM y",
                                    "yMMMM": "LLLL y",
                                    "yMMMMccccd": "cccc d. MMMM y",
                                    "yQQQ": "QQQ y",
                                    "yQQQQ": "QQQQ y"
                                },
                                "appendItems": {
                                    "Day": "{0} ({2}: {1})",
                                    "Day-Of-Week": "{0} {1}",
                                    "Era": "{1} {0}",
                                    "Hour": "{0} ({2}: {1})",
                                    "Minute": "{0} ({2}: {1})",
                                    "Month": "{0} ({2}: {1})",
                                    "Quarter": "{0} ({2}: {1})",
                                    "Second": "{0} ({2}: {1})",
                                    "Timezone": "{0} {1}",
                                    "Week": "{0} ({2}: {1})",
                                    "Year": "{1} {0}"
                                },
                                "intervalFormats": {
                                    "intervalFormatFallback": "{0}–{1}",
                                    "d": {
                                        "d": "d.–d."
                                    },
                                    "h": {
                                        "a": "h a – h a",
                                        "h": "h–h a"
                                    },
                                    "H": {
                                        "H": "H–H"
                                    },
                                    "hm": {
                                        "a": "h.mm a – h.mm a",
                                        "h": "h.mm–h.mm a",
                                        "m": "h.mm–h.mm a"
                                    },
                                    "Hm": {
                                        "H": "H.mm–H.mm",
                                        "m": "H.mm–H.mm"
                                    },
                                    "hmv": {
                                        "a": "h.mm a – h.mm a v",
                                        "h": "h.mm–h.mm a v",
                                        "m": "h.mm–h.mm a v"
                                    },
                                    "Hmv": {
                                        "H": "H.mm–H.mm v",
                                        "m": "H.mm–H.mm v"
                                    },
                                    "hv": {
                                        "a": "h a – h a v",
                                        "h": "h–h a v"
                                    },
                                    "Hv": {
                                        "H": "H–H v"
                                    },
                                    "M": {
                                        "M": "L.–L."
                                    },
                                    "Md": {
                                        "d": "d.–d.M.",
                                        "M": "d.M.–d.M."
                                    },
                                    "MEd": {
                                        "d": "E d. – E d.M.",
                                        "M": "E d.M. – E d.M."
                                    },
                                    "MMM": {
                                        "M": "LLL–LLLL"
                                    },
                                    "MMMd": {
                                        "d": "d.–d. MMMM",
                                        "M": "d. MMMM – d. MMMM"
                                    },
                                    "MMMEd": {
                                        "d": "E d. – E d. MMMM",
                                        "M": "E d. MMMM – E d. MMMM"
                                    },
                                    "MMMM": {
                                        "M": "LLL–LLLL"
                                    },
                                    "y": {
                                        "y": "y–y"
                                    },
                                    "yM": {
                                        "M": "LLL–LLLL y",
                                        "y": "LLLL y – LLLL y"
                                    },
                                    "yMd": {
                                        "d": "d.–d.M.y",
                                        "M": "d.M.–d.M.y",
                                        "y": "d.M.y–d.M.y"
                                    },
                                    "yMEd": {
                                        "d": "E d.M.y – E d.M.y",
                                        "M": "E d.M.y – E d.M.y",
                                        "y": "E d.M.y – E d.M.y"
                                    },
                                    "yMMM": {
                                        "M": "LLL–LLLL y",
                                        "y": "LLLL y – LLLL y"
                                    },
                                    "yMMMd": {
                                        "d": "d.–d. MMMM y",
                                        "M": "d. MMMM – d. MMMM y",
                                        "y": "d. MMMM y – d. MMMM y"
                                    },
                                    "yMMMEd": {
                                        "d": "E d. – E d. MMMM y",
                                        "M": "E d. MMMM – E d. MMMM y",
                                        "y": "E d. MMMM y – E d. MMMM y"
                                    },
                                    "yMMMM": {
                                        "M": "LLL–LLLL y",
                                        "y": "LLLL y – LLLL y"
                                    }
                                }
                            }
                        }
                    },
                    "timeZoneNames": {
                        "hourFormat": "+H.mm;-H.mm",
                        "gmtFormat": "UTC{0}",
                        "gmtZeroFormat": "UTC",
                        "regionFormat": "aikavyöhyke: {0}",
                        "regionFormat-type-daylight": "{0} (kesäaika)",
                        "regionFormat-type-standard": "{0} (normaaliaika)",
                        "fallbackFormat": "{1} ({0})"
                    }
                }
            },
            "fr": {
                "dates": {
                    "calendars": {
                        "gregorian": {
                            "months": {
                                "format": {
                                    "abbreviated": {
                                        "1": "janv.",
                                        "2": "févr.",
                                        "3": "mars",
                                        "4": "avr.",
                                        "5": "mai",
                                        "6": "juin",
                                        "7": "juil.",
                                        "8": "août",
                                        "9": "sept.",
                                        "10": "oct.",
                                        "11": "nov.",
                                        "12": "déc."
                                    },
                                    "narrow": {
                                        "1": "J",
                                        "2": "F",
                                        "3": "M",
                                        "4": "A",
                                        "5": "M",
                                        "6": "J",
                                        "7": "J",
                                        "8": "A",
                                        "9": "S",
                                        "10": "O",
                                        "11": "N",
                                        "12": "D"
                                    },
                                    "wide": {
                                        "1": "janvier",
                                        "2": "février",
                                        "3": "mars",
                                        "4": "avril",
                                        "5": "mai",
                                        "6": "juin",
                                        "7": "juillet",
                                        "8": "août",
                                        "9": "septembre",
                                        "10": "octobre",
                                        "11": "novembre",
                                        "12": "décembre"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "1": "janv.",
                                        "2": "févr.",
                                        "3": "mars",
                                        "4": "avr.",
                                        "5": "mai",
                                        "6": "juin",
                                        "7": "juil.",
                                        "8": "août",
                                        "9": "sept.",
                                        "10": "oct.",
                                        "11": "nov.",
                                        "12": "déc."
                                    },
                                    "narrow": {
                                        "1": "J",
                                        "2": "F",
                                        "3": "M",
                                        "4": "A",
                                        "5": "M",
                                        "6": "J",
                                        "7": "J",
                                        "8": "A",
                                        "9": "S",
                                        "10": "O",
                                        "11": "N",
                                        "12": "D"
                                    },
                                    "wide": {
                                        "1": "janvier",
                                        "2": "février",
                                        "3": "mars",
                                        "4": "avril",
                                        "5": "mai",
                                        "6": "juin",
                                        "7": "juillet",
                                        "8": "août",
                                        "9": "septembre",
                                        "10": "octobre",
                                        "11": "novembre",
                                        "12": "décembre"
                                    }
                                }
                            },
                            "days": {
                                "format": {
                                    "abbreviated": {
                                        "sun": "dim.",
                                        "mon": "lun.",
                                        "tue": "mar.",
                                        "wed": "mer.",
                                        "thu": "jeu.",
                                        "fri": "ven.",
                                        "sat": "sam."
                                    },
                                    "narrow": {
                                        "sun": "D",
                                        "mon": "L",
                                        "tue": "M",
                                        "wed": "M",
                                        "thu": "J",
                                        "fri": "V",
                                        "sat": "S"
                                    },
                                    "short": {
                                        "sun": "di",
                                        "mon": "lu",
                                        "tue": "ma",
                                        "wed": "me",
                                        "thu": "je",
                                        "fri": "ve",
                                        "sat": "sa"
                                    },
                                    "wide": {
                                        "sun": "dimanche",
                                        "mon": "lundi",
                                        "tue": "mardi",
                                        "wed": "mercredi",
                                        "thu": "jeudi",
                                        "fri": "vendredi",
                                        "sat": "samedi"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "sun": "dim.",
                                        "mon": "lun.",
                                        "tue": "mar.",
                                        "wed": "mer.",
                                        "thu": "jeu.",
                                        "fri": "ven.",
                                        "sat": "sam."
                                    },
                                    "narrow": {
                                        "sun": "D",
                                        "mon": "L",
                                        "tue": "M",
                                        "wed": "M",
                                        "thu": "J",
                                        "fri": "V",
                                        "sat": "S"
                                    },
                                    "short": {
                                        "sun": "dim.",
                                        "mon": "lun.",
                                        "tue": "mar.",
                                        "wed": "mer.",
                                        "thu": "jeu.",
                                        "fri": "ven.",
                                        "sat": "sam."
                                    },
                                    "wide": {
                                        "sun": "dimanche",
                                        "mon": "lundi",
                                        "tue": "mardi",
                                        "wed": "mercredi",
                                        "thu": "jeudi",
                                        "fri": "vendredi",
                                        "sat": "samedi"
                                    }
                                }
                            },
                            "quarters": {
                                "format": {
                                    "abbreviated": {
                                        "1": "T1",
                                        "2": "T2",
                                        "3": "T3",
                                        "4": "T4"
                                    },
                                    "narrow": {
                                        "1": "1",
                                        "2": "2",
                                        "3": "3",
                                        "4": "4"
                                    },
                                    "wide": {
                                        "1": "1er trimestre",
                                        "2": "2e trimestre",
                                        "3": "3e trimestre",
                                        "4": "4e trimestre"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "1": "T1",
                                        "2": "T2",
                                        "3": "T3",
                                        "4": "T4"
                                    },
                                    "narrow": {
                                        "1": "1",
                                        "2": "2",
                                        "3": "3",
                                        "4": "4"
                                    },
                                    "wide": {
                                        "1": "1er trimestre",
                                        "2": "2e trimestre",
                                        "3": "3e trimestre",
                                        "4": "4e trimestre"
                                    }
                                }
                            },
                            "dayPeriods": {
                                "format": {
                                    "abbreviated": {
                                        "afternoon": "ap.m.",
                                        "am": "AM",
                                        "morning": "matin",
                                        "night": "soir",
                                        "noon": "midi",
                                        "pm": "PM"
                                    },
                                    "narrow": {
                                        "afternoon": "ap.-m.",
                                        "am": "a",
                                        "morning": "matin",
                                        "night": "soir",
                                        "noon": "midi",
                                        "pm": "p"
                                    },
                                    "wide": {
                                        "afternoon": "après-midi",
                                        "am": "AM",
                                        "morning": "matin",
                                        "night": "soir",
                                        "noon": "midi",
                                        "pm": "PM"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "afternoon": "ap.m.",
                                        "am": "av.m.",
                                        "morning": "matin",
                                        "night": "soir",
                                        "noon": "midi",
                                        "pm": "ap.m."
                                    },
                                    "narrow": {
                                        "afternoon": "ap.-m.",
                                        "am": "a",
                                        "morning": "matin",
                                        "night": "soir",
                                        "noon": "midi",
                                        "pm": "p"
                                    },
                                    "wide": {
                                        "afternoon": "après-midi",
                                        "am": "avant-midi",
                                        "morning": "matin",
                                        "night": "soir",
                                        "noon": "midi",
                                        "pm": "après-midi"
                                    }
                                }
                            },
                            "eras": {
                                "eraNames": {
                                    "0": "avant Jésus-Christ",
                                    "1": "après Jésus-Christ",
                                    "0-alt-variant": "AEC",
                                    "1-alt-variant": "EC"
                                },
                                "eraAbbr": {
                                    "0": "av. J.-C.",
                                    "1": "ap. J.-C.",
                                    "0-alt-variant": "AEC",
                                    "1-alt-variant": "EC"
                                },
                                "eraNarrow": {
                                    "0": "av. J.-C.",
                                    "1": "ap. J.-C.",
                                    "0-alt-variant": "AEC",
                                    "1-alt-variant": "EC"
                                }
                            },
                            "dateFormats": {
                                "full": "EEEE d MMMM y",
                                "long": "d MMMM y",
                                "medium": "d MMM y",
                                "short": "dd/MM/y"
                            },
                            "timeFormats": {
                                "full": "HH:mm:ss zzzz",
                                "long": "HH:mm:ss z",
                                "medium": "HH:mm:ss",
                                "short": "HH:mm"
                            },
                            "dateTimeFormats": {
                                "full": "{1} {0}",
                                "long": "{1} {0}",
                                "medium": "{1} {0}",
                                "short": "{1} {0}",
                                "availableFormats": {
                                    "d": "d",
                                    "Ed": "E d",
                                    "Ehm": "E h:mm a",
                                    "EHm": "E HH:mm",
                                    "Ehms": "E h:mm:ss a",
                                    "EHms": "E HH:mm:ss",
                                    "Gy": "y G",
                                    "GyMMM": "MMM y G",
                                    "GyMMMd": "d MMM y G",
                                    "GyMMMEd": "E d MMM y G",
                                    "h": "h a",
                                    "H": "HH 'h'",
                                    "hm": "h:mm a",
                                    "Hm": "HH:mm",
                                    "hms": "h:mm:ss a",
                                    "Hms": "HH:mm:ss",
                                    "M": "L",
                                    "Md": "d/M",
                                    "MEd": "E d/M",
                                    "MMM": "LLL",
                                    "MMMd": "d MMM",
                                    "MMMEd": "E d MMM",
                                    "ms": "mm:ss",
                                    "y": "y",
                                    "yM": "M/y",
                                    "yMd": "d/M/y",
                                    "yMEd": "E d/M/y",
                                    "yMMM": "MMM y",
                                    "yMMMd": "d MMM y",
                                    "yMMMEd": "E d MMM y",
                                    "yMMMM": "MMMM y",
                                    "yQQQ": "QQQ y",
                                    "yQQQQ": "QQQQ y"
                                },
                                "appendItems": {
                                    "Day": "{0} ({2}: {1})",
                                    "Day-Of-Week": "{0} {1}",
                                    "Era": "{1} {0}",
                                    "Hour": "{0} ({2}: {1})",
                                    "Minute": "{0} ({2}: {1})",
                                    "Month": "{0} ({2}: {1})",
                                    "Quarter": "{0} ({2}: {1})",
                                    "Second": "{0} ({2}: {1})",
                                    "Timezone": "{0} {1}",
                                    "Week": "{0} ({2}: {1})",
                                    "Year": "{1} {0}"
                                },
                                "intervalFormats": {
                                    "intervalFormatFallback": "{0} – {1}",
                                    "d": {
                                        "d": "d-d"
                                    },
                                    "h": {
                                        "a": "h a – h a",
                                        "h": "h – h a"
                                    },
                                    "H": {
                                        "H": "HH – HH"
                                    },
                                    "hm": {
                                        "a": "h:mm a – h:mm a",
                                        "h": "h:mm – h:mm a",
                                        "m": "h:mm – h:mm a"
                                    },
                                    "Hm": {
                                        "H": "HH:mm – HH:mm",
                                        "m": "HH:mm – HH:mm"
                                    },
                                    "hmv": {
                                        "a": "h:mm a – h:mm a v",
                                        "h": "h:mm – h:mm a v",
                                        "m": "h:mm – h:mm a v"
                                    },
                                    "Hmv": {
                                        "H": "HH:mm – HH:mm v",
                                        "m": "HH:mm – HH:mm v"
                                    },
                                    "hv": {
                                        "a": "h a – h a v",
                                        "h": "h – h a v"
                                    },
                                    "Hv": {
                                        "H": "HH – HH v"
                                    },
                                    "M": {
                                        "M": "M–M"
                                    },
                                    "Md": {
                                        "d": "dd/MM – dd/MM",
                                        "M": "dd/MM - dd/MM"
                                    },
                                    "MEd": {
                                        "d": "E dd/MM - E dd/MM",
                                        "M": "E dd/MM - E dd/MM"
                                    },
                                    "MMM": {
                                        "M": "MMM–MMM"
                                    },
                                    "MMMd": {
                                        "d": "d–d MMM",
                                        "M": "d MMM – d MMM"
                                    },
                                    "MMMEd": {
                                        "d": "E d – E d MMM",
                                        "M": "E d MMM – E d MMM"
                                    },
                                    "y": {
                                        "y": "y–y"
                                    },
                                    "yM": {
                                        "M": "MM/y – MM/y",
                                        "y": "M/y – M/y"
                                    },
                                    "yMd": {
                                        "d": "d/M/y – d/M/y",
                                        "M": "d/M/y – d/M/y",
                                        "y": "dd/MM/y – dd/MM/y"
                                    },
                                    "yMEd": {
                                        "d": "E dd/MM/y – E dd/MM/y",
                                        "M": "E dd/MM/y – E dd/MM/y",
                                        "y": "E dd/MM/y – E dd/MM/y"
                                    },
                                    "yMMM": {
                                        "M": "MMM–MMM y",
                                        "y": "MMM y – MMM y"
                                    },
                                    "yMMMd": {
                                        "d": "d–d MMM y",
                                        "M": "d MMM – d MMM y",
                                        "y": "d MMM y – d MMM y"
                                    },
                                    "yMMMEd": {
                                        "d": "E d – E d MMM y",
                                        "M": "E d MMM – E d MMM y",
                                        "y": "E d MMM y – E d MMM y"
                                    },
                                    "yMMMM": {
                                        "M": "MMMM – MMMM y",
                                        "y": "MMMM y – MMMM y"
                                    }
                                }
                            }
                        }
                    },
                    "timeZoneNames": {
                        "hourFormat": "+HH:mm;−HH:mm",
                        "gmtFormat": "UTC{0}",
                        "gmtZeroFormat": "UTC",
                        "regionFormat": "heure : {0}",
                        "regionFormat-type-daylight": "{0} (heure d’été)",
                        "regionFormat-type-standard": "{0} (heure standard)",
                        "fallbackFormat": "{1} ({0})"
                    }
                }
            },
            "he": {
                "dates": {
                    "calendars": {
                        "gregorian": {
                            "months": {
                                "format": {
                                    "abbreviated": {
                                        "1": "ינו",
                                        "2": "פבר",
                                        "3": "מרץ",
                                        "4": "אפר",
                                        "5": "מאי",
                                        "6": "יונ",
                                        "7": "יול",
                                        "8": "אוג",
                                        "9": "ספט",
                                        "10": "אוק",
                                        "11": "נוב",
                                        "12": "דצמ"
                                    },
                                    "narrow": {
                                        "1": "1",
                                        "2": "2",
                                        "3": "3",
                                        "4": "4",
                                        "5": "5",
                                        "6": "6",
                                        "7": "7",
                                        "8": "8",
                                        "9": "9",
                                        "10": "10",
                                        "11": "11",
                                        "12": "12"
                                    },
                                    "wide": {
                                        "1": "ינואר",
                                        "2": "פברואר",
                                        "3": "מרץ",
                                        "4": "אפריל",
                                        "5": "מאי",
                                        "6": "יוני",
                                        "7": "יולי",
                                        "8": "אוגוסט",
                                        "9": "ספטמבר",
                                        "10": "אוקטובר",
                                        "11": "נובמבר",
                                        "12": "דצמבר"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "1": "ינו׳",
                                        "2": "פבר׳",
                                        "3": "מרץ",
                                        "4": "אפר׳",
                                        "5": "מאי",
                                        "6": "יונ׳",
                                        "7": "יול׳",
                                        "8": "אוג׳",
                                        "9": "ספט׳",
                                        "10": "אוק׳",
                                        "11": "נוב׳",
                                        "12": "דצמ׳"
                                    },
                                    "narrow": {
                                        "1": "1",
                                        "2": "2",
                                        "3": "3",
                                        "4": "4",
                                        "5": "5",
                                        "6": "6",
                                        "7": "7",
                                        "8": "8",
                                        "9": "9",
                                        "10": "10",
                                        "11": "11",
                                        "12": "12"
                                    },
                                    "wide": {
                                        "1": "ינואר",
                                        "2": "פברואר",
                                        "3": "מרץ",
                                        "4": "אפריל",
                                        "5": "מאי",
                                        "6": "יוני",
                                        "7": "יולי",
                                        "8": "אוגוסט",
                                        "9": "ספטמבר",
                                        "10": "אוקטובר",
                                        "11": "נובמבר",
                                        "12": "דצמבר"
                                    }
                                }
                            },
                            "days": {
                                "format": {
                                    "abbreviated": {
                                        "sun": "יום א׳",
                                        "mon": "יום ב׳",
                                        "tue": "יום ג׳",
                                        "wed": "יום ד׳",
                                        "thu": "יום ה׳",
                                        "fri": "יום ו׳",
                                        "sat": "שבת"
                                    },
                                    "narrow": {
                                        "sun": "א׳",
                                        "mon": "ב׳",
                                        "tue": "ג׳",
                                        "wed": "ד׳",
                                        "thu": "ה׳",
                                        "fri": "ו׳",
                                        "sat": "ש׳"
                                    },
                                    "short": {
                                        "sun": "א׳",
                                        "mon": "ב׳",
                                        "tue": "ג׳",
                                        "wed": "ד׳",
                                        "thu": "ה׳",
                                        "fri": "ו׳",
                                        "sat": "ש׳"
                                    },
                                    "wide": {
                                        "sun": "יום ראשון",
                                        "mon": "יום שני",
                                        "tue": "יום שלישי",
                                        "wed": "יום רביעי",
                                        "thu": "יום חמישי",
                                        "fri": "יום שישי",
                                        "sat": "יום שבת"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "sun": "יום א׳",
                                        "mon": "יום ב׳",
                                        "tue": "יום ג׳",
                                        "wed": "יום ד׳",
                                        "thu": "יום ה׳",
                                        "fri": "יום ו׳",
                                        "sat": "שבת"
                                    },
                                    "narrow": {
                                        "sun": "א׳",
                                        "mon": "ב׳",
                                        "tue": "ג׳",
                                        "wed": "ד׳",
                                        "thu": "ה׳",
                                        "fri": "ו׳",
                                        "sat": "ש׳"
                                    },
                                    "short": {
                                        "sun": "א׳",
                                        "mon": "ב׳",
                                        "tue": "ג׳",
                                        "wed": "ד׳",
                                        "thu": "ה׳",
                                        "fri": "ו׳",
                                        "sat": "ש׳"
                                    },
                                    "wide": {
                                        "sun": "יום ראשון",
                                        "mon": "יום שני",
                                        "tue": "יום שלישי",
                                        "wed": "יום רביעי",
                                        "thu": "יום חמישי",
                                        "fri": "יום שישי",
                                        "sat": "יום שבת"
                                    }
                                }
                            },
                            "quarters": {
                                "format": {
                                    "abbreviated": {
                                        "1": "רבעון 1",
                                        "2": "רבעון 2",
                                        "3": "רבעון 3",
                                        "4": "רבעון 4"
                                    },
                                    "narrow": {
                                        "1": "1",
                                        "2": "2",
                                        "3": "3",
                                        "4": "4"
                                    },
                                    "wide": {
                                        "1": "רבעון 1",
                                        "2": "רבעון 2",
                                        "3": "רבעון 3",
                                        "4": "רבעון 4"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "1": "רבעון 1",
                                        "2": "רבעון 2",
                                        "3": "רבעון 3",
                                        "4": "רבעון 4"
                                    },
                                    "narrow": {
                                        "1": "ר1",
                                        "2": "ר2",
                                        "3": "ר3",
                                        "4": "ר4"
                                    },
                                    "wide": {
                                        "1": "רבעון 1",
                                        "2": "רבעון 2",
                                        "3": "רבעון 3",
                                        "4": "רבעון 4"
                                    }
                                }
                            },
                            "dayPeriods": {
                                "format": {
                                    "abbreviated": {
                                        "am": "לפנה״צ",
                                        "pm": "אחה״צ"
                                    },
                                    "narrow": {
                                        "am": "לפנה״צ",
                                        "pm": "אחה״צ"
                                    },
                                    "wide": {
                                        "am": "לפנה״צ",
                                        "pm": "אחה״צ"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "am": "לפנה״צ",
                                        "pm": "אחה״צ"
                                    },
                                    "narrow": {
                                        "am": "לפנה״צ",
                                        "pm": "אחה״צ"
                                    },
                                    "wide": {
                                        "am": "לפנה״צ",
                                        "pm": "אחה״צ"
                                    }
                                }
                            },
                            "eras": {
                                "eraNames": {
                                    "0": "לפני הספירה",
                                    "1": "לספירה",
                                    "0-alt-variant": "BCE",
                                    "1-alt-variant": "CE"
                                },
                                "eraAbbr": {
                                    "0": "לפנה״ס",
                                    "1": "לסה״נ",
                                    "0-alt-variant": "BCE",
                                    "1-alt-variant": "CE"
                                },
                                "eraNarrow": {
                                    "0": "לפנה״ס",
                                    "1": "לסה״נ",
                                    "0-alt-variant": "BCE",
                                    "1-alt-variant": "CE"
                                }
                            },
                            "dateFormats": {
                                "full": "EEEE, d בMMMM y",
                                "long": "d בMMMM y",
                                "medium": "d בMMM y",
                                "short": "dd/MM/yy"
                            },
                            "timeFormats": {
                                "full": "HH:mm:ss zzzz",
                                "long": "HH:mm:ss z",
                                "medium": "HH:mm:ss",
                                "short": "HH:mm"
                            },
                            "dateTimeFormats": {
                                "full": "{1} בשעה {0}",
                                "long": "{1} בשעה {0}",
                                "medium": "{1}, {0}",
                                "short": "{1}, {0}",
                                "availableFormats": {
                                    "d": "d",
                                    "Ed": "E ה-d",
                                    "Ehm": "E h:mm a",
                                    "EHm": "E H:mm",
                                    "Ehms": "E h:mm:ss a",
                                    "EHms": "E H:mm:ss",
                                    "Gy": "y G",
                                    "GyMMM": "MMM y G",
                                    "GyMMMd": "d בMMM y G",
                                    "GyMMMEd": "E, d בMMM y G",
                                    "h": "‏h a",
                                    "H": "HH",
                                    "hm": "h:mm a",
                                    "Hm": "HH:mm",
                                    "hms": "h:mm:ss a",
                                    "Hms": "HH:mm:ss",
                                    "M": "L",
                                    "Md": "d/M",
                                    "MEd": "E, d/M",
                                    "MMM": "LLL",
                                    "MMMd": "d בMMM",
                                    "MMMEd": "E, d בMMM",
                                    "ms": "mm:ss",
                                    "y": "y",
                                    "yM": "M.y",
                                    "yMd": "d.M.y",
                                    "yMEd": "E, d/M/y",
                                    "yMM": "MM/y",
                                    "yMMM": "MMM y",
                                    "yMMMd": "d בMMM y",
                                    "yMMMEd": "E, d בMMM y",
                                    "yMMMM": "MMMM y",
                                    "yQQQ": "y QQQ",
                                    "yQQQQ": "y QQQQ"
                                },
                                "appendItems": {
                                    "Day": "{0} ({2}: {1})",
                                    "Day-Of-Week": "{0} {1}",
                                    "Era": "{1} {0}",
                                    "Hour": "{0} ({2}: {1})",
                                    "Minute": "{0} ({2}: {1})",
                                    "Month": "{0} ({2}: {1})",
                                    "Quarter": "{0} ({2}: {1})",
                                    "Second": "{0} ({2}: {1})",
                                    "Timezone": "{0} {1}",
                                    "Week": "{0} ({2}: {1})",
                                    "Year": "{1} {0}"
                                },
                                "intervalFormats": {
                                    "intervalFormatFallback": "{0} – {1}",
                                    "d": {
                                        "d": "d–d"
                                    },
                                    "h": {
                                        "a": "h a – h a",
                                        "h": "h–h a"
                                    },
                                    "H": {
                                        "H": "H–H"
                                    },
                                    "hm": {
                                        "a": "h:mm a – h:mm a",
                                        "h": "h:mm–h:mm a",
                                        "m": "h:mm–h:mm a"
                                    },
                                    "Hm": {
                                        "H": "H:mm–H:mm",
                                        "m": "H:mm–H:mm"
                                    },
                                    "hmv": {
                                        "a": "h:mm a – h:mm a v",
                                        "h": "h:mm–h:mm a v",
                                        "m": "h:mm–h:mm a v"
                                    },
                                    "Hmv": {
                                        "H": "H:mm–H:mm v",
                                        "m": "H:mm–H:mm v"
                                    },
                                    "hv": {
                                        "a": "h a – h a v",
                                        "h": "h–h a v"
                                    },
                                    "Hv": {
                                        "H": "H–H v"
                                    },
                                    "M": {
                                        "M": "M–M"
                                    },
                                    "Md": {
                                        "d": "d.M–d.M",
                                        "M": "d.M–d.M"
                                    },
                                    "MEd": {
                                        "d": "EEEE d.M–EEEE d.M",
                                        "M": "EEEE d.M – EEEE d.M"
                                    },
                                    "MMM": {
                                        "M": "MMM–MMM"
                                    },
                                    "MMMd": {
                                        "d": "d–d MMM",
                                        "M": "d MMM–d MMM"
                                    },
                                    "MMMEd": {
                                        "d": "EEEE d MMM – EEEE d MMM",
                                        "M": "EEEE d MMM – EEEE d MMM"
                                    },
                                    "MMMM": {
                                        "M": "LLLL–LLLL"
                                    },
                                    "y": {
                                        "y": "y–y"
                                    },
                                    "yM": {
                                        "M": "M.y–M.y",
                                        "y": "M.y‏-M.y"
                                    },
                                    "yMd": {
                                        "d": "dd.M.y – dd.M.y",
                                        "M": "d.M.y – d.M.y",
                                        "y": "d.M.y – d.M.y"
                                    },
                                    "yMEd": {
                                        "d": "EEEE d.M.y – EEEE d.M.y",
                                        "M": "EEEE d.M.y – EEEE d.M.y",
                                        "y": "EEEE d.M.y – EEEE d.M.y"
                                    },
                                    "yMMM": {
                                        "M": "MMM–MMM y",
                                        "y": "MMM y – MMM y"
                                    },
                                    "yMMMd": {
                                        "d": "d–d MMM y",
                                        "M": "d MMM – d MMM y",
                                        "y": "d MMM y – d MMM y"
                                    },
                                    "yMMMEd": {
                                        "d": "EEEE d MMM – EEEE d MMM y",
                                        "M": "EEEE d MMM – EEEE d MMM y",
                                        "y": "EEEE d MMM y – EEEE d MMM y"
                                    },
                                    "yMMMM": {
                                        "M": "MMMM–MMMM y",
                                        "y": "MMMM y–MMMM y"
                                    }
                                }
                            }
                        }
                    },
                    "timeZoneNames": {
                        "hourFormat": "+HH:mm;-HH:mm",
                        "gmtFormat": "GMT{0}",
                        "gmtZeroFormat": "GMT",
                        "regionFormat": "שעון {0}",
                        "regionFormat-type-daylight": "שעון {0} (קיץ)",
                        "regionFormat-type-standard": "שעון {0} (חורף)",
                        "fallbackFormat": "{1} ({0})"
                    }
                }
            },
            "hi": {
                "dates": {
                    "calendars": {
                        "gregorian": {
                            "months": {
                                "format": {
                                    "abbreviated": {
                                        "1": "जन",
                                        "2": "फ़र",
                                        "3": "मार्च",
                                        "4": "अप्रै",
                                        "5": "मई",
                                        "6": "जून",
                                        "7": "जुला",
                                        "8": "अग",
                                        "9": "सितं",
                                        "10": "अक्टू",
                                        "11": "नवं",
                                        "12": "दिसं"
                                    },
                                    "narrow": {
                                        "1": "ज",
                                        "2": "फ़",
                                        "3": "मा",
                                        "4": "अ",
                                        "5": "म",
                                        "6": "जू",
                                        "7": "जु",
                                        "8": "अ",
                                        "9": "सि",
                                        "10": "अ",
                                        "11": "न",
                                        "12": "दि"
                                    },
                                    "wide": {
                                        "1": "जनवरी",
                                        "2": "फ़रवरी",
                                        "3": "मार्च",
                                        "4": "अप्रैल",
                                        "5": "मई",
                                        "6": "जून",
                                        "7": "जुलाई",
                                        "8": "अगस्त",
                                        "9": "सितंबर",
                                        "10": "अक्टूबर",
                                        "11": "नवंबर",
                                        "12": "दिसंबर"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "1": "जन",
                                        "2": "फ़र",
                                        "3": "मार्च",
                                        "4": "अप्रै",
                                        "5": "मई",
                                        "6": "जून",
                                        "7": "जुला",
                                        "8": "अग",
                                        "9": "सितं",
                                        "10": "अक्टू",
                                        "11": "नवं",
                                        "12": "दिसं"
                                    },
                                    "narrow": {
                                        "1": "ज",
                                        "2": "फ़",
                                        "3": "मा",
                                        "4": "अ",
                                        "5": "म",
                                        "6": "जू",
                                        "7": "जु",
                                        "8": "अ",
                                        "9": "सि",
                                        "10": "अ",
                                        "11": "न",
                                        "12": "दि"
                                    },
                                    "wide": {
                                        "1": "जनवरी",
                                        "2": "फ़रवरी",
                                        "3": "मार्च",
                                        "4": "अप्रैल",
                                        "5": "मई",
                                        "6": "जून",
                                        "7": "जुलाई",
                                        "8": "अगस्त",
                                        "9": "सितंबर",
                                        "10": "अक्टूबर",
                                        "11": "नवंबर",
                                        "12": "दिसंबर"
                                    }
                                }
                            },
                            "days": {
                                "format": {
                                    "abbreviated": {
                                        "sun": "रवि",
                                        "mon": "सोम",
                                        "tue": "मंगल",
                                        "wed": "बुध",
                                        "thu": "गुरु",
                                        "fri": "शुक्र",
                                        "sat": "शनि"
                                    },
                                    "narrow": {
                                        "sun": "र",
                                        "mon": "सो",
                                        "tue": "मं",
                                        "wed": "बु",
                                        "thu": "गु",
                                        "fri": "शु",
                                        "sat": "श"
                                    },
                                    "short": {
                                        "sun": "र",
                                        "mon": "सो",
                                        "tue": "मं",
                                        "wed": "बु",
                                        "thu": "गु",
                                        "fri": "शु",
                                        "sat": "श"
                                    },
                                    "wide": {
                                        "sun": "रविवार",
                                        "mon": "सोमवार",
                                        "tue": "मंगलवार",
                                        "wed": "बुधवार",
                                        "thu": "गुरुवार",
                                        "fri": "शुक्रवार",
                                        "sat": "शनिवार"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "sun": "रवि",
                                        "mon": "सोम",
                                        "tue": "मंगल",
                                        "wed": "बुध",
                                        "thu": "गुरु",
                                        "fri": "शुक्र",
                                        "sat": "शनि"
                                    },
                                    "narrow": {
                                        "sun": "र",
                                        "mon": "सो",
                                        "tue": "मं",
                                        "wed": "बु",
                                        "thu": "गु",
                                        "fri": "शु",
                                        "sat": "श"
                                    },
                                    "short": {
                                        "sun": "र",
                                        "mon": "सो",
                                        "tue": "मं",
                                        "wed": "बु",
                                        "thu": "गु",
                                        "fri": "शु",
                                        "sat": "श"
                                    },
                                    "wide": {
                                        "sun": "रविवार",
                                        "mon": "सोमवार",
                                        "tue": "मंगलवार",
                                        "wed": "बुधवार",
                                        "thu": "गुरुवार",
                                        "fri": "शुक्रवार",
                                        "sat": "शनिवार"
                                    }
                                }
                            },
                            "quarters": {
                                "format": {
                                    "abbreviated": {
                                        "1": "ति1",
                                        "2": "ति2",
                                        "3": "ति3",
                                        "4": "ति4"
                                    },
                                    "narrow": {
                                        "1": "1",
                                        "2": "2",
                                        "3": "3",
                                        "4": "4"
                                    },
                                    "wide": {
                                        "1": "पहली तिमाही",
                                        "2": "दूसरी तिमाही",
                                        "3": "तीसरी तिमाही",
                                        "4": "चौथी तिमाही"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "1": "ति1",
                                        "2": "ति2",
                                        "3": "ति3",
                                        "4": "ति4"
                                    },
                                    "narrow": {
                                        "1": "1",
                                        "2": "2",
                                        "3": "3",
                                        "4": "4"
                                    },
                                    "wide": {
                                        "1": "पहली तिमाही",
                                        "2": "दूसरी तिमाही",
                                        "3": "तीसरी तिमाही",
                                        "4": "चौथी तिमाही"
                                    }
                                }
                            },
                            "dayPeriods": {
                                "format": {
                                    "abbreviated": {
                                        "am": "पूर्व",
                                        "pm": "अपर"
                                    },
                                    "narrow": {
                                        "am": "पू",
                                        "pm": "अ"
                                    },
                                    "wide": {
                                        "am": "पूर्वाह्न",
                                        "pm": "अपराह्न"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "am": "पूर्व",
                                        "pm": "अपर"
                                    },
                                    "narrow": {
                                        "am": "पू",
                                        "pm": "अ"
                                    },
                                    "wide": {
                                        "am": "पूर्वाह्न",
                                        "pm": "अपराह्न"
                                    }
                                }
                            },
                            "eras": {
                                "eraNames": {
                                    "0": "ईसा-पूर्व",
                                    "1": "ईस्वी",
                                    "0-alt-variant": "BCE",
                                    "1-alt-variant": "CE"
                                },
                                "eraAbbr": {
                                    "0": "ईसा-पूर्व",
                                    "1": "ईस्वी",
                                    "0-alt-variant": "BCE",
                                    "1-alt-variant": "CE"
                                },
                                "eraNarrow": {
                                    "0": "ईसा-पूर्व",
                                    "1": "ईस्वी",
                                    "0-alt-variant": "BCE",
                                    "1-alt-variant": "CE"
                                }
                            },
                            "dateFormats": {
                                "full": "EEEE, d MMMM y",
                                "long": "d MMMM y",
                                "medium": "dd-MM-y",
                                "short": "d-M-yy"
                            },
                            "timeFormats": {
                                "full": "h:mm:ss a zzzz",
                                "long": "h:mm:ss a z",
                                "medium": "h:mm:ss a",
                                "short": "h:mm a"
                            },
                            "dateTimeFormats": {
                                "full": "{1} को {0}",
                                "long": "{1} को {0}",
                                "medium": "{1}, {0}",
                                "short": "{1}, {0}",
                                "availableFormats": {
                                    "d": "d",
                                    "Ed": "E d",
                                    "Ehm": "E h:mm a",
                                    "EHm": "E HH:mm",
                                    "Ehms": "E h:mm:ss a",
                                    "EHms": "E HH:mm:ss",
                                    "Gy": "y G",
                                    "GyMMM": "MMM G y",
                                    "GyMMMd": "d MMM, G y",
                                    "GyMMMEd": "E, d MMM, G y",
                                    "h": "h a",
                                    "H": "HH",
                                    "hm": "h:mm a",
                                    "Hm": "HH:mm",
                                    "hms": "h:mm:ss a",
                                    "Hms": "HH:mm:ss",
                                    "M": "L",
                                    "Md": "d/M",
                                    "MEd": "E, d/M",
                                    "MMdd": "dd-MM",
                                    "MMM": "LLL",
                                    "MMMd": "d MMM",
                                    "MMMdd": "dd MMM",
                                    "MMMEd": "E, d MMM",
                                    "MMMMd": "d MMMM",
                                    "MMMMEd": "E, d MMMM",
                                    "ms": "mm:ss",
                                    "y": "y",
                                    "yM": "M/y",
                                    "yMd": "d/M/y",
                                    "yMEd": "E, d/M/y",
                                    "yMM": "MM-y",
                                    "yMMdd": "dd-MM-y",
                                    "yMMM": "MMM y",
                                    "yMMMd": "d MMM, y",
                                    "yMMMEd": "E, d MMM y",
                                    "yMMMM": "MMMM y",
                                    "yQQQ": "QQQ y",
                                    "yQQQQ": "QQQQ y"
                                },
                                "appendItems": {
                                    "Day": "{0} ({2}: {1})",
                                    "Day-Of-Week": "{0} {1}",
                                    "Era": "{1} {0}",
                                    "Hour": "{0} ({2}: {1})",
                                    "Minute": "{0} ({2}: {1})",
                                    "Month": "{0} ({2}: {1})",
                                    "Quarter": "{0} ({2}: {1})",
                                    "Second": "{0} ({2}: {1})",
                                    "Timezone": "{0} {1}",
                                    "Week": "{0} ({2}: {1})",
                                    "Year": "{1} {0}"
                                },
                                "intervalFormats": {
                                    "intervalFormatFallback": "{0} – {1}",
                                    "d": {
                                        "d": "d–d"
                                    },
                                    "h": {
                                        "a": "h a – h a",
                                        "h": "h–h a"
                                    },
                                    "H": {
                                        "H": "HH–HH"
                                    },
                                    "hm": {
                                        "a": "h:mm a – h:mm a",
                                        "h": "h:mm–h:mm a",
                                        "m": "h:mm–h:mm a"
                                    },
                                    "Hm": {
                                        "H": "HH:mm–HH:mm",
                                        "m": "HH:mm–HH:mm"
                                    },
                                    "hmv": {
                                        "a": "h:mm a – h:mm a v",
                                        "h": "h:mm–h:mm a v",
                                        "m": "h:mm–h:mm a v"
                                    },
                                    "Hmv": {
                                        "H": "HH:mm–HH:mm v",
                                        "m": "HH:mm–HH:mm v"
                                    },
                                    "hv": {
                                        "a": "h a – h a v",
                                        "h": "h–h a v"
                                    },
                                    "Hv": {
                                        "H": "HH–HH v"
                                    },
                                    "M": {
                                        "M": "M–M"
                                    },
                                    "Md": {
                                        "d": "d/M – d/M",
                                        "M": "d/M – d/M"
                                    },
                                    "MEd": {
                                        "d": "E, d/M – E, d/M",
                                        "M": "E, d/M – E, d/M"
                                    },
                                    "MMM": {
                                        "M": "MMM–MMM"
                                    },
                                    "MMMd": {
                                        "d": "d MMM–d",
                                        "M": "d MMM – d MMM"
                                    },
                                    "MMMEd": {
                                        "d": "E, d MMM – E, d MMM",
                                        "M": "E, d MMM – E, d MMM"
                                    },
                                    "y": {
                                        "y": "y–y"
                                    },
                                    "yM": {
                                        "M": "M/y – M/y",
                                        "y": "M/y – M/y"
                                    },
                                    "yMd": {
                                        "d": "d/M/y – d/M/y",
                                        "M": "d/M/y – d/M/y",
                                        "y": "d/M/y – d/M/y"
                                    },
                                    "yMEd": {
                                        "d": "E, d/M/y – E, d/M/y",
                                        "M": "E, d/M/y – E, d/M/y",
                                        "y": "E, d/M/y – E, d/M/y"
                                    },
                                    "yMMM": {
                                        "M": "MMM–MMM y",
                                        "y": "MMM y – MMM y"
                                    },
                                    "yMMMd": {
                                        "d": "d MMM–d, y",
                                        "M": "d MMM – d MMM, y",
                                        "y": "d MMM, y – d MMM, y"
                                    },
                                    "yMMMEd": {
                                        "d": "E, d MMM – E, d MMM, y",
                                        "M": "E, d MMM – E, d MMM, y",
                                        "y": "E, d MMM, y – E, d MMM, y"
                                    },
                                    "yMMMM": {
                                        "M": "MMMM – MMMM y",
                                        "y": "MMMM y – MMMM y"
                                    }
                                }
                            }
                        }
                    },
                    "timeZoneNames": {
                        "hourFormat": "+HH:mm;-HH:mm",
                        "gmtFormat": "GMT{0}",
                        "gmtZeroFormat": "GMT",
                        "regionFormat": "{0} समय",
                        "regionFormat-type-daylight": "{0} डेलाइट समय",
                        "regionFormat-type-standard": "{0} मानक समय",
                        "fallbackFormat": "{1} ({0})"
                    }
                }
            },
            "hr": {
                "dates": {
                    "calendars": {
                        "gregorian": {
                            "months": {
                                "format": {
                                    "abbreviated": {
                                        "1": "sij",
                                        "2": "velj",
                                        "3": "ožu",
                                        "4": "tra",
                                        "5": "svi",
                                        "6": "lip",
                                        "7": "srp",
                                        "8": "kol",
                                        "9": "ruj",
                                        "10": "lis",
                                        "11": "stu",
                                        "12": "pro"
                                    },
                                    "narrow": {
                                        "1": "1.",
                                        "2": "2.",
                                        "3": "3.",
                                        "4": "4.",
                                        "5": "5.",
                                        "6": "6.",
                                        "7": "7.",
                                        "8": "8.",
                                        "9": "9.",
                                        "10": "10.",
                                        "11": "11.",
                                        "12": "12."
                                    },
                                    "wide": {
                                        "1": "siječnja",
                                        "2": "veljače",
                                        "3": "ožujka",
                                        "4": "travnja",
                                        "5": "svibnja",
                                        "6": "lipnja",
                                        "7": "srpnja",
                                        "8": "kolovoza",
                                        "9": "rujna",
                                        "10": "listopada",
                                        "11": "studenoga",
                                        "12": "prosinca"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "1": "sij",
                                        "2": "velj",
                                        "3": "ožu",
                                        "4": "tra",
                                        "5": "svi",
                                        "6": "lip",
                                        "7": "srp",
                                        "8": "kol",
                                        "9": "ruj",
                                        "10": "lis",
                                        "11": "stu",
                                        "12": "pro"
                                    },
                                    "narrow": {
                                        "1": "1.",
                                        "2": "2.",
                                        "3": "3.",
                                        "4": "4.",
                                        "5": "5.",
                                        "6": "6.",
                                        "7": "7.",
                                        "8": "8.",
                                        "9": "9.",
                                        "10": "10.",
                                        "11": "11.",
                                        "12": "12."
                                    },
                                    "wide": {
                                        "1": "siječanj",
                                        "2": "veljača",
                                        "3": "ožujak",
                                        "4": "travanj",
                                        "5": "svibanj",
                                        "6": "lipanj",
                                        "7": "srpanj",
                                        "8": "kolovoz",
                                        "9": "rujan",
                                        "10": "listopad",
                                        "11": "studeni",
                                        "12": "prosinac"
                                    }
                                }
                            },
                            "days": {
                                "format": {
                                    "abbreviated": {
                                        "sun": "ned",
                                        "mon": "pon",
                                        "tue": "uto",
                                        "wed": "sri",
                                        "thu": "čet",
                                        "fri": "pet",
                                        "sat": "sub"
                                    },
                                    "narrow": {
                                        "sun": "N",
                                        "mon": "P",
                                        "tue": "U",
                                        "wed": "S",
                                        "thu": "Č",
                                        "fri": "P",
                                        "sat": "S"
                                    },
                                    "short": {
                                        "sun": "ned",
                                        "mon": "pon",
                                        "tue": "uto",
                                        "wed": "sri",
                                        "thu": "čet",
                                        "fri": "pet",
                                        "sat": "sub"
                                    },
                                    "wide": {
                                        "sun": "nedjelja",
                                        "mon": "ponedjeljak",
                                        "tue": "utorak",
                                        "wed": "srijeda",
                                        "thu": "četvrtak",
                                        "fri": "petak",
                                        "sat": "subota"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "sun": "ned",
                                        "mon": "pon",
                                        "tue": "uto",
                                        "wed": "sri",
                                        "thu": "čet",
                                        "fri": "pet",
                                        "sat": "sub"
                                    },
                                    "narrow": {
                                        "sun": "n",
                                        "mon": "p",
                                        "tue": "u",
                                        "wed": "s",
                                        "thu": "č",
                                        "fri": "p",
                                        "sat": "s"
                                    },
                                    "short": {
                                        "sun": "ned",
                                        "mon": "pon",
                                        "tue": "uto",
                                        "wed": "sri",
                                        "thu": "čet",
                                        "fri": "pet",
                                        "sat": "sub"
                                    },
                                    "wide": {
                                        "sun": "nedjelja",
                                        "mon": "ponedjeljak",
                                        "tue": "utorak",
                                        "wed": "srijeda",
                                        "thu": "četvrtak",
                                        "fri": "petak",
                                        "sat": "subota"
                                    }
                                }
                            },
                            "quarters": {
                                "format": {
                                    "abbreviated": {
                                        "1": "1kv",
                                        "2": "2kv",
                                        "3": "3kv",
                                        "4": "4kv"
                                    },
                                    "narrow": {
                                        "1": "1.",
                                        "2": "2.",
                                        "3": "3.",
                                        "4": "4."
                                    },
                                    "wide": {
                                        "1": "1. kvartal",
                                        "2": "2. kvartal",
                                        "3": "3. kvartal",
                                        "4": "4. kvartal"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "1": "1kv",
                                        "2": "2kv",
                                        "3": "3kv",
                                        "4": "4kv"
                                    },
                                    "narrow": {
                                        "1": "1.",
                                        "2": "2.",
                                        "3": "3.",
                                        "4": "4."
                                    },
                                    "wide": {
                                        "1": "1. kvartal",
                                        "2": "2. kvartal",
                                        "3": "3. kvartal",
                                        "4": "4. kvartal"
                                    }
                                }
                            },
                            "dayPeriods": {
                                "format": {
                                    "abbreviated": {
                                        "afternoon": "popodne",
                                        "am": "AM",
                                        "earlyMorning": "ujutro",
                                        "evening": "navečer",
                                        "morning": "prijepodne",
                                        "night": "noću",
                                        "noon": "podne",
                                        "pm": "PM"
                                    },
                                    "narrow": {
                                        "afternoon": "popodne",
                                        "am": "AM",
                                        "earlyMorning": "ujutro",
                                        "evening": "navečer",
                                        "morning": "prijepodne",
                                        "night": "noću",
                                        "noon": "n",
                                        "pm": "PM"
                                    },
                                    "wide": {
                                        "am": "AM",
                                        "noon": "podne",
                                        "pm": "PM"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "afternoon": "popodne",
                                        "am": "AM",
                                        "earlyMorning": "ujutro",
                                        "evening": "navečer",
                                        "morning": "prijepodne",
                                        "night": "noću",
                                        "noon": "podne",
                                        "pm": "PM"
                                    },
                                    "narrow": {
                                        "afternoon": "popodne",
                                        "am": "AM",
                                        "earlyMorning": "ujutro",
                                        "evening": "navečer",
                                        "morning": "prijepodne",
                                        "night": "noću",
                                        "noon": "n",
                                        "pm": "PM"
                                    },
                                    "wide": {
                                        "am": "AM",
                                        "noon": "podne",
                                        "pm": "PM"
                                    }
                                }
                            },
                            "eras": {
                                "eraNames": {
                                    "0": "Prije Krista",
                                    "1": "Poslije Krista",
                                    "0-alt-variant": "pr. n. e.",
                                    "1-alt-variant": "n.e."
                                },
                                "eraAbbr": {
                                    "0": "pr. Kr.",
                                    "1": "p. Kr.",
                                    "0-alt-variant": "pr. n. e.",
                                    "1-alt-variant": "n.e."
                                },
                                "eraNarrow": {
                                    "0": "pr.n.e.",
                                    "1": "AD",
                                    "0-alt-variant": "pr. n. e.",
                                    "1-alt-variant": "n.e."
                                }
                            },
                            "dateFormats": {
                                "full": "EEEE, d. MMMM y.",
                                "long": "d. MMMM y.",
                                "medium": "d. MMM y.",
                                "short": "d.M.yy."
                            },
                            "timeFormats": {
                                "full": "HH:mm:ss zzzz",
                                "long": "HH:mm:ss z",
                                "medium": "HH:mm:ss",
                                "short": "HH:mm"
                            },
                            "dateTimeFormats": {
                                "full": "{1} 'u' {0}",
                                "long": "{1} 'u' {0}",
                                "medium": "{1} {0}",
                                "short": "{1} {0}",
                                "availableFormats": {
                                    "d": "d.",
                                    "Ed": "E, d.",
                                    "Ehm": "E h:mm a",
                                    "EHm": "E HH:mm",
                                    "Ehms": "E h:mm:ss a",
                                    "EHms": "E HH:mm:ss",
                                    "Gy": "y. G",
                                    "GyMMM": "LLL y. G",
                                    "GyMMMd": "d. MMM y. G",
                                    "GyMMMEd": "E, d. MMM y. G",
                                    "h": "h a",
                                    "H": "HH",
                                    "hm": "hh:mm a",
                                    "Hm": "HH:mm",
                                    "hms": "hh:mm:ss a",
                                    "Hms": "HH:mm:ss",
                                    "M": "L.",
                                    "Md": "d. M.",
                                    "MEd": "E, d. M.",
                                    "MMdd": "dd. MM.",
                                    "MMM": "LLL",
                                    "MMMd": "d. MMM",
                                    "MMMEd": "E, d. MMM",
                                    "MMMMd": "d. MMMM",
                                    "MMMMdd": "dd. MMMM",
                                    "MMMMEd": "E, d. MMMM",
                                    "ms": "mm:ss",
                                    "y": "y.",
                                    "yM": "M. y.",
                                    "yMd": "d. M. y.",
                                    "yMEd": "E, d. M. y.",
                                    "yMM": "MM. y.",
                                    "yMMM": "LLL y.",
                                    "yMMMd": "d. MMM y.",
                                    "yMMMEd": "E, d. MMM y.",
                                    "yMMMM": "LLLL y.",
                                    "yQQQ": "QQQ y.",
                                    "yQQQQ": "QQQQ y."
                                },
                                "appendItems": {
                                    "Day": "{0} ({2}: {1})",
                                    "Day-Of-Week": "{0} {1}",
                                    "Era": "{1} {0}",
                                    "Hour": "{0} ({2}: {1})",
                                    "Minute": "{0} ({2}: {1})",
                                    "Month": "{0} ({2}: {1})",
                                    "Quarter": "{0} ({2}: {1})",
                                    "Second": "{0} ({2}: {1})",
                                    "Timezone": "{0} {1}",
                                    "Week": "{0} ({2}: {1})",
                                    "Year": "{1} {0}"
                                },
                                "intervalFormats": {
                                    "intervalFormatFallback": "{0} - {1}",
                                    "d": {
                                        "d": "dd. - dd."
                                    },
                                    "h": {
                                        "a": "h a - h a",
                                        "h": "h - h'h' a"
                                    },
                                    "H": {
                                        "H": "HH-HH'h'"
                                    },
                                    "hm": {
                                        "a": "h:mm a - h:mm a",
                                        "h": "h:mm-h:mm a",
                                        "m": "h:mm-h:mm a"
                                    },
                                    "Hm": {
                                        "H": "HH:mm-HH:mm",
                                        "m": "HH:mm-HH:mm"
                                    },
                                    "hmv": {
                                        "a": "h:mm a - h:mm a v",
                                        "h": "h:mm-h:mm a v",
                                        "m": "h:mm-h:mm a v"
                                    },
                                    "Hmv": {
                                        "H": "HH:mm-HH:mm v",
                                        "m": "HH:mm-HH:mm v"
                                    },
                                    "hv": {
                                        "a": "h a - h a v",
                                        "h": "h - h 'h' a v"
                                    },
                                    "Hv": {
                                        "H": "HH - HH 'h' v"
                                    },
                                    "M": {
                                        "M": "MM. - MM."
                                    },
                                    "Md": {
                                        "d": "dd.MM. - dd.MM.",
                                        "M": "dd.MM. - dd.MM."
                                    },
                                    "MEd": {
                                        "d": "E, dd.MM. - E, dd.MM.",
                                        "M": "E, dd.MM. - E, dd.MM."
                                    },
                                    "MMM": {
                                        "M": "LLL-LLL"
                                    },
                                    "MMMd": {
                                        "d": "dd. - dd. MMM",
                                        "M": "dd. MMM - dd. MMM"
                                    },
                                    "MMMEd": {
                                        "d": "E, dd. - E, dd. MMM",
                                        "M": "E, dd. MMM - E, dd. MMM"
                                    },
                                    "y": {
                                        "y": "y. - y."
                                    },
                                    "yM": {
                                        "M": "MM.y. - MM.y.",
                                        "y": "MM.y. - MM.y."
                                    },
                                    "yMd": {
                                        "d": "dd.MM.y. - dd.MM.y.",
                                        "M": "dd.MM.y. - dd.MM.y.",
                                        "y": "dd.MM.y. - dd.MM.y."
                                    },
                                    "yMEd": {
                                        "d": "E, dd.MM.y. - E, dd.MM.y.",
                                        "M": "E, dd.MM.y. - E, dd.MM.y.",
                                        "y": "E, dd.MM.y. - E, dd.MM.y."
                                    },
                                    "yMMM": {
                                        "M": "LLL-LLL y.",
                                        "y": "LLL y. - LLL y."
                                    },
                                    "yMMMd": {
                                        "d": "dd. - dd. MMM y.",
                                        "M": "dd. MMM - dd. MMM y.",
                                        "y": "dd. MMM y. - dd. MMM y."
                                    },
                                    "yMMMEd": {
                                        "d": "E, dd. - E, dd. MMM y.",
                                        "M": "E, dd. MMM - E, dd. MMM y.",
                                        "y": "E, dd. MMM y. - E, dd. MMM y."
                                    },
                                    "yMMMM": {
                                        "M": "LLLL – LLLL y.",
                                        "y": "LLLL y. - LLLL y."
                                    }
                                }
                            }
                        }
                    },
                    "timeZoneNames": {
                        "hourFormat": "+HH:mm; -HH:mm",
                        "gmtFormat": "GMT{0}",
                        "gmtZeroFormat": "GMT",
                        "regionFormat": "{0}",
                        "regionFormat-type-daylight": "{0}, ljetno vrijeme",
                        "regionFormat-type-standard": "{0}, standardno vrijeme",
                        "fallbackFormat": "{1} ({0})"
                    }
                }
            },
            "hu": {
                "dates": {
                    "calendars": {
                        "gregorian": {
                            "months": {
                                "format": {
                                    "abbreviated": {
                                        "1": "jan.",
                                        "2": "febr.",
                                        "3": "márc.",
                                        "4": "ápr.",
                                        "5": "máj.",
                                        "6": "jún.",
                                        "7": "júl.",
                                        "8": "aug.",
                                        "9": "szept.",
                                        "10": "okt.",
                                        "11": "nov.",
                                        "12": "dec."
                                    },
                                    "narrow": {
                                        "1": "J",
                                        "2": "F",
                                        "3": "M",
                                        "4": "Á",
                                        "5": "M",
                                        "6": "J",
                                        "7": "J",
                                        "8": "A",
                                        "9": "Sz",
                                        "10": "O",
                                        "11": "N",
                                        "12": "D"
                                    },
                                    "wide": {
                                        "1": "január",
                                        "2": "február",
                                        "3": "március",
                                        "4": "április",
                                        "5": "május",
                                        "6": "június",
                                        "7": "július",
                                        "8": "augusztus",
                                        "9": "szeptember",
                                        "10": "október",
                                        "11": "november",
                                        "12": "december"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "1": "jan.",
                                        "2": "febr.",
                                        "3": "márc.",
                                        "4": "ápr.",
                                        "5": "máj.",
                                        "6": "jún.",
                                        "7": "júl.",
                                        "8": "aug.",
                                        "9": "szept.",
                                        "10": "okt.",
                                        "11": "nov.",
                                        "12": "dec."
                                    },
                                    "narrow": {
                                        "1": "J",
                                        "2": "F",
                                        "3": "M",
                                        "4": "Á",
                                        "5": "M",
                                        "6": "J",
                                        "7": "J",
                                        "8": "A",
                                        "9": "Sz",
                                        "10": "O",
                                        "11": "N",
                                        "12": "D"
                                    },
                                    "wide": {
                                        "1": "január",
                                        "2": "február",
                                        "3": "március",
                                        "4": "április",
                                        "5": "május",
                                        "6": "június",
                                        "7": "július",
                                        "8": "augusztus",
                                        "9": "szeptember",
                                        "10": "október",
                                        "11": "november",
                                        "12": "december"
                                    }
                                }
                            },
                            "days": {
                                "format": {
                                    "abbreviated": {
                                        "sun": "V",
                                        "mon": "H",
                                        "tue": "K",
                                        "wed": "Sze",
                                        "thu": "Cs",
                                        "fri": "P",
                                        "sat": "Szo"
                                    },
                                    "narrow": {
                                        "sun": "V",
                                        "mon": "H",
                                        "tue": "K",
                                        "wed": "Sz",
                                        "thu": "Cs",
                                        "fri": "P",
                                        "sat": "Sz"
                                    },
                                    "short": {
                                        "sun": "V",
                                        "mon": "H",
                                        "tue": "K",
                                        "wed": "Sze",
                                        "thu": "Cs",
                                        "fri": "P",
                                        "sat": "Szo"
                                    },
                                    "wide": {
                                        "sun": "vasárnap",
                                        "mon": "hétfő",
                                        "tue": "kedd",
                                        "wed": "szerda",
                                        "thu": "csütörtök",
                                        "fri": "péntek",
                                        "sat": "szombat"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "sun": "V",
                                        "mon": "H",
                                        "tue": "K",
                                        "wed": "Sze",
                                        "thu": "Cs",
                                        "fri": "P",
                                        "sat": "Szo"
                                    },
                                    "narrow": {
                                        "sun": "V",
                                        "mon": "H",
                                        "tue": "K",
                                        "wed": "Sz",
                                        "thu": "Cs",
                                        "fri": "P",
                                        "sat": "Sz"
                                    },
                                    "short": {
                                        "sun": "V",
                                        "mon": "H",
                                        "tue": "K",
                                        "wed": "Sze",
                                        "thu": "Cs",
                                        "fri": "P",
                                        "sat": "Szo"
                                    },
                                    "wide": {
                                        "sun": "vasárnap",
                                        "mon": "hétfő",
                                        "tue": "kedd",
                                        "wed": "szerda",
                                        "thu": "csütörtök",
                                        "fri": "péntek",
                                        "sat": "szombat"
                                    }
                                }
                            },
                            "quarters": {
                                "format": {
                                    "abbreviated": {
                                        "1": "N1",
                                        "2": "N2",
                                        "3": "N3",
                                        "4": "N4"
                                    },
                                    "narrow": {
                                        "1": "1.",
                                        "2": "2.",
                                        "3": "3.",
                                        "4": "4."
                                    },
                                    "wide": {
                                        "1": "I. negyedév",
                                        "2": "II. negyedév",
                                        "3": "III. negyedév",
                                        "4": "IV. negyedév"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "1": "N1",
                                        "2": "N2",
                                        "3": "N3",
                                        "4": "N4"
                                    },
                                    "narrow": {
                                        "1": "1.",
                                        "2": "2.",
                                        "3": "3.",
                                        "4": "4."
                                    },
                                    "wide": {
                                        "1": "1. negyedév",
                                        "2": "2. negyedév",
                                        "3": "3. negyedév",
                                        "4": "4. negyedév"
                                    }
                                }
                            },
                            "dayPeriods": {
                                "format": {
                                    "abbreviated": {
                                        "am": "de.",
                                        "pm": "du."
                                    },
                                    "narrow": {
                                        "am": "de.",
                                        "pm": "du."
                                    },
                                    "wide": {
                                        "am": "de.",
                                        "pm": "du."
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "am": "de.",
                                        "pm": "du."
                                    },
                                    "narrow": {
                                        "am": "de.",
                                        "pm": "du."
                                    },
                                    "wide": {
                                        "am": "de.",
                                        "pm": "du."
                                    }
                                }
                            },
                            "eras": {
                                "eraNames": {
                                    "0": "időszámításunk előtt",
                                    "1": "időszámításunk szerint",
                                    "0-alt-variant": "Kr. e.",
                                    "1-alt-variant": "Kr. u."
                                },
                                "eraAbbr": {
                                    "0": "i. e.",
                                    "1": "i. sz.",
                                    "0-alt-variant": "Kr. e.",
                                    "1-alt-variant": "Kr. u."
                                },
                                "eraNarrow": {
                                    "0": "ie.",
                                    "1": "isz.",
                                    "0-alt-variant": "Kr. e.",
                                    "1-alt-variant": "Kr. u."
                                }
                            },
                            "dateFormats": {
                                "full": "y. MMMM d., EEEE",
                                "long": "y. MMMM d.",
                                "medium": "y MMM d",
                                "short": "y. MM. dd."
                            },
                            "timeFormats": {
                                "full": "H:mm:ss zzzz",
                                "long": "H:mm:ss z",
                                "medium": "H:mm:ss",
                                "short": "H:mm"
                            },
                            "dateTimeFormats": {
                                "full": "{1} {0}",
                                "long": "{1} {0}",
                                "medium": "{1} {0}",
                                "short": "{1} {0}",
                                "availableFormats": {
                                    "d": "d",
                                    "Ed": "d., E",
                                    "Ehm": "E h:mm a",
                                    "EHm": "E HH:mm",
                                    "Ehms": "E h:mm:ss a",
                                    "EHms": "E HH:mm:ss",
                                    "Gy": "G y.",
                                    "GyMMM": "G y. MMM",
                                    "GyMMMd": "G y. MMM d.",
                                    "GyMMMEd": "G y. MMM d., E",
                                    "h": "a h",
                                    "H": "H",
                                    "hm": "a h:mm",
                                    "Hm": "H:mm",
                                    "hms": "a h:mm:ss",
                                    "Hms": "H:mm:ss",
                                    "M": "L",
                                    "Md": "M. d.",
                                    "MEd": "M. d., E",
                                    "MMM": "LLL",
                                    "MMMd": "MMM d.",
                                    "MMMEd": "MMM d., E",
                                    "MMMMd": "MMMM d.",
                                    "mmss": "mm:ss",
                                    "ms": "mm:ss",
                                    "y": "y.",
                                    "yM": "y. M.",
                                    "yMd": "y. MM. dd.",
                                    "yMEd": "y. MM. dd., E",
                                    "yMMM": "y. MMM",
                                    "yMMMd": "y. MMM d.",
                                    "yMMMEd": "y. MMM d., E",
                                    "yMMMM": "y. MMMM",
                                    "yQQQ": "y. QQQ",
                                    "yQQQQ": "y. QQQQ"
                                },
                                "appendItems": {
                                    "Day": "{0} ({2}: {1})",
                                    "Day-Of-Week": "{0} {1}",
                                    "Era": "{1} {0}",
                                    "Hour": "{0} ({2}: {1})",
                                    "Minute": "{0} ({2}: {1})",
                                    "Month": "{0} ({2}: {1})",
                                    "Quarter": "{0} ({2}: {1})",
                                    "Second": "{0} ({2}: {1})",
                                    "Timezone": "{0} {1}",
                                    "Week": "{0} ({2}: {1})",
                                    "Year": "{1} {0}"
                                },
                                "intervalFormats": {
                                    "intervalFormatFallback": "{0} – {1}",
                                    "d": {
                                        "d": "d–d."
                                    },
                                    "h": {
                                        "a": "a h – a h",
                                        "h": "a h–h"
                                    },
                                    "H": {
                                        "H": "H-H"
                                    },
                                    "hm": {
                                        "a": "a h:mm – a h:mm",
                                        "h": "a h:mm–h:mm",
                                        "m": "a h:mm–h:mm"
                                    },
                                    "Hm": {
                                        "H": "H:mm–H:mm",
                                        "m": "H:mm–H:mm"
                                    },
                                    "hmv": {
                                        "a": "a h:mm – a h:mm v",
                                        "h": "a h:mm–h:mm v",
                                        "m": "a h:mm–h:mm v"
                                    },
                                    "Hmv": {
                                        "H": "H:mm–H:mm v",
                                        "m": "H:mm–H:mm v"
                                    },
                                    "hv": {
                                        "a": "a h – a h v",
                                        "h": "a h–h v"
                                    },
                                    "Hv": {
                                        "H": "H–H v"
                                    },
                                    "M": {
                                        "M": "M–M."
                                    },
                                    "Md": {
                                        "d": "M. d–d.",
                                        "M": "M. d. – M. d."
                                    },
                                    "MEd": {
                                        "d": "M. dd., E – M. d., E",
                                        "M": "M. d., E – M. d., E"
                                    },
                                    "MMM": {
                                        "M": "MMM–MMM"
                                    },
                                    "MMMd": {
                                        "d": "MMM d–d.",
                                        "M": "MMM d. – MMM d."
                                    },
                                    "MMMEd": {
                                        "d": "MMM d., E – d., E",
                                        "M": "MMM d., E – MMM d., E"
                                    },
                                    "y": {
                                        "y": "y–y"
                                    },
                                    "yM": {
                                        "M": "y. MM–MM.",
                                        "y": "y. MM. – y. MM."
                                    },
                                    "yMd": {
                                        "d": "y. MM. dd–dd.",
                                        "M": "y. MM. dd. – MM. dd.",
                                        "y": "y. MM. dd. – y. MM. dd."
                                    },
                                    "yMEd": {
                                        "d": "y. MM. dd., E – dd., E",
                                        "M": "y. MM. dd., E – MM. dd., E",
                                        "y": "y. MM. dd., E – y. MM. dd., E"
                                    },
                                    "yMMM": {
                                        "M": "y. MMM–MMM",
                                        "y": "y. MMM – y. MMM"
                                    },
                                    "yMMMd": {
                                        "d": "y. MMM d–d.",
                                        "M": "y. MMM d. – MMM d.",
                                        "y": "y. MMM d. – y. MMM d."
                                    },
                                    "yMMMEd": {
                                        "d": "y. MMM d., E – d., E",
                                        "M": "y. MMM d., E – MMM d., E",
                                        "y": "y. MMM d., E – y. MMM d., E"
                                    },
                                    "yMMMM": {
                                        "M": "y. MMMM–MMMM",
                                        "y": "y. MMMM – y. MMMM"
                                    }
                                }
                            }
                        }
                    },
                    "timeZoneNames": {
                        "hourFormat": "+HH:mm;-HH:mm",
                        "gmtFormat": "GMT{0}",
                        "gmtZeroFormat": "GMT",
                        "regionFormat": "{0} idő",
                        "regionFormat-type-daylight": "{0} nyári idő",
                        "regionFormat-type-standard": "{0} zónaidő",
                        "fallbackFormat": "{1} ({0})"
                    }
                }
            },
            "it": {
                "dates": {
                    "calendars": {
                        "gregorian": {
                            "months": {
                                "format": {
                                    "abbreviated": {
                                        "1": "gen",
                                        "2": "feb",
                                        "3": "mar",
                                        "4": "apr",
                                        "5": "mag",
                                        "6": "giu",
                                        "7": "lug",
                                        "8": "ago",
                                        "9": "set",
                                        "10": "ott",
                                        "11": "nov",
                                        "12": "dic"
                                    },
                                    "narrow": {
                                        "1": "G",
                                        "2": "F",
                                        "3": "M",
                                        "4": "A",
                                        "5": "M",
                                        "6": "G",
                                        "7": "L",
                                        "8": "A",
                                        "9": "S",
                                        "10": "O",
                                        "11": "N",
                                        "12": "D"
                                    },
                                    "wide": {
                                        "1": "gennaio",
                                        "2": "febbraio",
                                        "3": "marzo",
                                        "4": "aprile",
                                        "5": "maggio",
                                        "6": "giugno",
                                        "7": "luglio",
                                        "8": "agosto",
                                        "9": "settembre",
                                        "10": "ottobre",
                                        "11": "novembre",
                                        "12": "dicembre"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "1": "gen",
                                        "2": "feb",
                                        "3": "mar",
                                        "4": "apr",
                                        "5": "mag",
                                        "6": "giu",
                                        "7": "lug",
                                        "8": "ago",
                                        "9": "set",
                                        "10": "ott",
                                        "11": "nov",
                                        "12": "dic"
                                    },
                                    "narrow": {
                                        "1": "G",
                                        "2": "F",
                                        "3": "M",
                                        "4": "A",
                                        "5": "M",
                                        "6": "G",
                                        "7": "L",
                                        "8": "A",
                                        "9": "S",
                                        "10": "O",
                                        "11": "N",
                                        "12": "D"
                                    },
                                    "wide": {
                                        "1": "Gennaio",
                                        "2": "Febbraio",
                                        "3": "Marzo",
                                        "4": "Aprile",
                                        "5": "Maggio",
                                        "6": "Giugno",
                                        "7": "Luglio",
                                        "8": "Agosto",
                                        "9": "Settembre",
                                        "10": "Ottobre",
                                        "11": "Novembre",
                                        "12": "Dicembre"
                                    }
                                }
                            },
                            "days": {
                                "format": {
                                    "abbreviated": {
                                        "sun": "dom",
                                        "mon": "lun",
                                        "tue": "mar",
                                        "wed": "mer",
                                        "thu": "gio",
                                        "fri": "ven",
                                        "sat": "sab"
                                    },
                                    "narrow": {
                                        "sun": "D",
                                        "mon": "L",
                                        "tue": "M",
                                        "wed": "M",
                                        "thu": "G",
                                        "fri": "V",
                                        "sat": "S"
                                    },
                                    "short": {
                                        "sun": "dom",
                                        "mon": "lun",
                                        "tue": "mar",
                                        "wed": "mer",
                                        "thu": "gio",
                                        "fri": "ven",
                                        "sat": "sab"
                                    },
                                    "wide": {
                                        "sun": "domenica",
                                        "mon": "lunedì",
                                        "tue": "martedì",
                                        "wed": "mercoledì",
                                        "thu": "giovedì",
                                        "fri": "venerdì",
                                        "sat": "sabato"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "sun": "dom",
                                        "mon": "lun",
                                        "tue": "mar",
                                        "wed": "mer",
                                        "thu": "gio",
                                        "fri": "ven",
                                        "sat": "sab"
                                    },
                                    "narrow": {
                                        "sun": "D",
                                        "mon": "L",
                                        "tue": "M",
                                        "wed": "M",
                                        "thu": "G",
                                        "fri": "V",
                                        "sat": "S"
                                    },
                                    "short": {
                                        "sun": "dom",
                                        "mon": "lun",
                                        "tue": "mar",
                                        "wed": "mer",
                                        "thu": "gio",
                                        "fri": "ven",
                                        "sat": "sab"
                                    },
                                    "wide": {
                                        "sun": "Domenica",
                                        "mon": "Lunedì",
                                        "tue": "Martedì",
                                        "wed": "Mercoledì",
                                        "thu": "Giovedì",
                                        "fri": "Venerdì",
                                        "sat": "Sabato"
                                    }
                                }
                            },
                            "quarters": {
                                "format": {
                                    "abbreviated": {
                                        "1": "T1",
                                        "2": "T2",
                                        "3": "T3",
                                        "4": "T4"
                                    },
                                    "narrow": {
                                        "1": "1",
                                        "2": "2",
                                        "3": "3",
                                        "4": "4"
                                    },
                                    "wide": {
                                        "1": "1º trimestre",
                                        "2": "2º trimestre",
                                        "3": "3º trimestre",
                                        "4": "4º trimestre"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "1": "T1",
                                        "2": "T2",
                                        "3": "T3",
                                        "4": "T4"
                                    },
                                    "narrow": {
                                        "1": "1",
                                        "2": "2",
                                        "3": "3",
                                        "4": "4"
                                    },
                                    "wide": {
                                        "1": "Primo trimestre",
                                        "2": "Secondo trimestre",
                                        "3": "Terzo trimestre",
                                        "4": "Quarto trimestre"
                                    }
                                }
                            },
                            "dayPeriods": {
                                "format": {
                                    "abbreviated": {
                                        "am": "AM",
                                        "pm": "PM"
                                    },
                                    "narrow": {
                                        "am": "m.",
                                        "pm": "p."
                                    },
                                    "wide": {
                                        "am": "AM",
                                        "pm": "PM"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "am": "AM",
                                        "pm": "PM"
                                    },
                                    "narrow": {
                                        "am": "m.",
                                        "pm": "p."
                                    },
                                    "wide": {
                                        "am": "AM",
                                        "pm": "PM"
                                    }
                                }
                            },
                            "eras": {
                                "eraNames": {
                                    "0": "a.C.",
                                    "1": "d.C.",
                                    "0-alt-variant": "BCE",
                                    "1-alt-variant": "CE"
                                },
                                "eraAbbr": {
                                    "0": "aC",
                                    "1": "dC",
                                    "0-alt-variant": "BCE",
                                    "1-alt-variant": "CE"
                                },
                                "eraNarrow": {
                                    "0": "aC",
                                    "1": "dC",
                                    "0-alt-variant": "BCE",
                                    "1-alt-variant": "CE"
                                }
                            },
                            "dateFormats": {
                                "full": "EEEE d MMMM y",
                                "long": "dd MMMM y",
                                "medium": "dd/MMM/y",
                                "short": "dd/MM/yy"
                            },
                            "timeFormats": {
                                "full": "HH:mm:ss zzzz",
                                "long": "HH:mm:ss z",
                                "medium": "HH:mm:ss",
                                "short": "HH:mm"
                            },
                            "dateTimeFormats": {
                                "full": "{1} {0}",
                                "long": "{1} {0}",
                                "medium": "{1} {0}",
                                "short": "{1} {0}",
                                "availableFormats": {
                                    "d": "d",
                                    "Ed": "E d",
                                    "Ehm": "E h.mm a",
                                    "EHm": "E HH.mm",
                                    "Ehms": "E h:mm:ss a",
                                    "EHms": "E HH:mm:ss",
                                    "Gy": "y G",
                                    "GyMMM": "MMM y G",
                                    "GyMMMd": "d MMM y G",
                                    "GyMMMEd": "E d MMM y G",
                                    "h": "hh a",
                                    "H": "HH",
                                    "hm": "hh:mm a",
                                    "Hm": "HH:mm",
                                    "hms": "hh:mm:ss a",
                                    "Hms": "HH:mm:ss",
                                    "M": "L",
                                    "Md": "d/M",
                                    "MEd": "E d/M",
                                    "MMM": "LLL",
                                    "MMMd": "d MMM",
                                    "MMMEd": "E d MMM",
                                    "ms": "mm:ss",
                                    "y": "y",
                                    "yM": "M/y",
                                    "yMd": "d/M/y",
                                    "yMEd": "E d/M/y",
                                    "yMMM": "MMM y",
                                    "yMMMd": "d MMM y",
                                    "yMMMEd": "E d MMM y",
                                    "yMMMM": "MMMM y",
                                    "yQQQ": "QQQ y",
                                    "yQQQQ": "QQQQ y"
                                },
                                "appendItems": {
                                    "Day": "{0} ({2}: {1})",
                                    "Day-Of-Week": "{0} {1}",
                                    "Era": "{1} {0}",
                                    "Hour": "{0} ({2}: {1})",
                                    "Minute": "{0} ({2}: {1})",
                                    "Month": "{0} ({2}: {1})",
                                    "Quarter": "{0} ({2}: {1})",
                                    "Second": "{0} ({2}: {1})",
                                    "Timezone": "{0} {1}",
                                    "Week": "{0} ({2}: {1})",
                                    "Year": "{1} {0}"
                                },
                                "intervalFormats": {
                                    "intervalFormatFallback": "{0} - {1}",
                                    "d": {
                                        "d": "d-d"
                                    },
                                    "h": {
                                        "a": "h a - h a",
                                        "h": "h-h a"
                                    },
                                    "H": {
                                        "H": "HH-HH"
                                    },
                                    "hm": {
                                        "a": "h:mm a - h:mm a",
                                        "h": "h:mm-h:mm a",
                                        "m": "h:mm-h:mm a"
                                    },
                                    "Hm": {
                                        "H": "HH:mm-HH:mm",
                                        "m": "HH:mm-HH:mm"
                                    },
                                    "hmv": {
                                        "a": "h:mm a - h:mm a v",
                                        "h": "h:mm-h:mm a v",
                                        "m": "h:mm-h:mm a v"
                                    },
                                    "Hmv": {
                                        "H": "HH:mm-HH:mm v",
                                        "m": "HH:mm-HH:mm v"
                                    },
                                    "hv": {
                                        "a": "h a - h a v",
                                        "h": "h-h a v"
                                    },
                                    "Hv": {
                                        "H": "HH-HH v"
                                    },
                                    "M": {
                                        "M": "M-M"
                                    },
                                    "Md": {
                                        "d": "dd/MM - dd/MM",
                                        "M": "dd/MM - dd/MM"
                                    },
                                    "MEd": {
                                        "d": "E dd/MM - E dd/MM",
                                        "M": "E dd/MM - E dd/MM"
                                    },
                                    "MMM": {
                                        "M": "MMM-MMM"
                                    },
                                    "MMMd": {
                                        "d": "dd-dd MMM",
                                        "M": "dd MMM - dd MMM"
                                    },
                                    "MMMEd": {
                                        "d": "E dd - E dd MMM",
                                        "M": "E dd MMM - E dd MMM"
                                    },
                                    "y": {
                                        "y": "y-y"
                                    },
                                    "yM": {
                                        "M": "MM/y - MM/y",
                                        "y": "MM/y - MM/y"
                                    },
                                    "yMd": {
                                        "d": "dd/MM/y - dd/MM/y",
                                        "M": "dd/MM/y - dd/MM/y",
                                        "y": "dd/MM/y - dd/MM/y"
                                    },
                                    "yMEd": {
                                        "d": "E dd/MM/y - E dd/MM/y",
                                        "M": "E dd/MM/y - E dd/MM/y",
                                        "y": "E dd/MM/y - E dd/MM/y"
                                    },
                                    "yMMM": {
                                        "M": "MMM-MMM y",
                                        "y": "MMM y - MMM y"
                                    },
                                    "yMMMd": {
                                        "d": "dd-dd MMM y",
                                        "M": "dd MMM - dd MMM y",
                                        "y": "dd MMM y - dd MMM y"
                                    },
                                    "yMMMEd": {
                                        "d": "E d - E d MMM y",
                                        "M": "E d MMM - E d MMM y",
                                        "y": "E d MMM y - E d MMM y"
                                    },
                                    "yMMMM": {
                                        "M": "MMMM-MMMM y",
                                        "y": "MMMM y - MMMM y"
                                    }
                                }
                            }
                        }
                    },
                    "timeZoneNames": {
                        "hourFormat": "+HH:mm;-HH:mm",
                        "gmtFormat": "GMT{0}",
                        "gmtZeroFormat": "GMT",
                        "regionFormat": "Ora {0}",
                        "regionFormat-type-daylight": "Ora legale: {0}",
                        "regionFormat-type-standard": "Ora standard: {0}",
                        "fallbackFormat": "{1} ({0})"
                    }
                }
            },
            "ja": {
                "dates": {
                    "calendars": {
                        "gregorian": {
                            "months": {
                                "format": {
                                    "abbreviated": {
                                        "1": "1月",
                                        "2": "2月",
                                        "3": "3月",
                                        "4": "4月",
                                        "5": "5月",
                                        "6": "6月",
                                        "7": "7月",
                                        "8": "8月",
                                        "9": "9月",
                                        "10": "10月",
                                        "11": "11月",
                                        "12": "12月"
                                    },
                                    "narrow": {
                                        "1": "1",
                                        "2": "2",
                                        "3": "3",
                                        "4": "4",
                                        "5": "5",
                                        "6": "6",
                                        "7": "7",
                                        "8": "8",
                                        "9": "9",
                                        "10": "10",
                                        "11": "11",
                                        "12": "12"
                                    },
                                    "wide": {
                                        "1": "1月",
                                        "2": "2月",
                                        "3": "3月",
                                        "4": "4月",
                                        "5": "5月",
                                        "6": "6月",
                                        "7": "7月",
                                        "8": "8月",
                                        "9": "9月",
                                        "10": "10月",
                                        "11": "11月",
                                        "12": "12月"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "1": "1月",
                                        "2": "2月",
                                        "3": "3月",
                                        "4": "4月",
                                        "5": "5月",
                                        "6": "6月",
                                        "7": "7月",
                                        "8": "8月",
                                        "9": "9月",
                                        "10": "10月",
                                        "11": "11月",
                                        "12": "12月"
                                    },
                                    "narrow": {
                                        "1": "1",
                                        "2": "2",
                                        "3": "3",
                                        "4": "4",
                                        "5": "5",
                                        "6": "6",
                                        "7": "7",
                                        "8": "8",
                                        "9": "9",
                                        "10": "10",
                                        "11": "11",
                                        "12": "12"
                                    },
                                    "wide": {
                                        "1": "1月",
                                        "2": "2月",
                                        "3": "3月",
                                        "4": "4月",
                                        "5": "5月",
                                        "6": "6月",
                                        "7": "7月",
                                        "8": "8月",
                                        "9": "9月",
                                        "10": "10月",
                                        "11": "11月",
                                        "12": "12月"
                                    }
                                }
                            },
                            "days": {
                                "format": {
                                    "abbreviated": {
                                        "sun": "日",
                                        "mon": "月",
                                        "tue": "火",
                                        "wed": "水",
                                        "thu": "木",
                                        "fri": "金",
                                        "sat": "土"
                                    },
                                    "narrow": {
                                        "sun": "日",
                                        "mon": "月",
                                        "tue": "火",
                                        "wed": "水",
                                        "thu": "木",
                                        "fri": "金",
                                        "sat": "土"
                                    },
                                    "short": {
                                        "sun": "日",
                                        "mon": "月",
                                        "tue": "火",
                                        "wed": "水",
                                        "thu": "木",
                                        "fri": "金",
                                        "sat": "土"
                                    },
                                    "wide": {
                                        "sun": "日曜日",
                                        "mon": "月曜日",
                                        "tue": "火曜日",
                                        "wed": "水曜日",
                                        "thu": "木曜日",
                                        "fri": "金曜日",
                                        "sat": "土曜日"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "sun": "日",
                                        "mon": "月",
                                        "tue": "火",
                                        "wed": "水",
                                        "thu": "木",
                                        "fri": "金",
                                        "sat": "土"
                                    },
                                    "narrow": {
                                        "sun": "日",
                                        "mon": "月",
                                        "tue": "火",
                                        "wed": "水",
                                        "thu": "木",
                                        "fri": "金",
                                        "sat": "土"
                                    },
                                    "short": {
                                        "sun": "日",
                                        "mon": "月",
                                        "tue": "火",
                                        "wed": "水",
                                        "thu": "木",
                                        "fri": "金",
                                        "sat": "土"
                                    },
                                    "wide": {
                                        "sun": "日曜日",
                                        "mon": "月曜日",
                                        "tue": "火曜日",
                                        "wed": "水曜日",
                                        "thu": "木曜日",
                                        "fri": "金曜日",
                                        "sat": "土曜日"
                                    }
                                }
                            },
                            "quarters": {
                                "format": {
                                    "abbreviated": {
                                        "1": "Q1",
                                        "2": "Q2",
                                        "3": "Q3",
                                        "4": "Q4"
                                    },
                                    "narrow": {
                                        "1": "1",
                                        "2": "2",
                                        "3": "3",
                                        "4": "4"
                                    },
                                    "wide": {
                                        "1": "第1四半期",
                                        "2": "第2四半期",
                                        "3": "第3四半期",
                                        "4": "第4四半期"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "1": "Q1",
                                        "2": "Q2",
                                        "3": "Q3",
                                        "4": "Q4"
                                    },
                                    "narrow": {
                                        "1": "1",
                                        "2": "2",
                                        "3": "3",
                                        "4": "4"
                                    },
                                    "wide": {
                                        "1": "第1四半期",
                                        "2": "第2四半期",
                                        "3": "第3四半期",
                                        "4": "第4四半期"
                                    }
                                }
                            },
                            "dayPeriods": {
                                "format": {
                                    "abbreviated": {
                                        "am": "午前",
                                        "noon": "正午",
                                        "pm": "午後"
                                    },
                                    "narrow": {
                                        "am": "午前",
                                        "noon": "正午",
                                        "pm": "午後"
                                    },
                                    "wide": {
                                        "am": "午前",
                                        "noon": "正午",
                                        "pm": "午後"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "am": "午前",
                                        "noon": "正午",
                                        "pm": "午後"
                                    },
                                    "narrow": {
                                        "am": "午前",
                                        "noon": "正午",
                                        "pm": "午後"
                                    },
                                    "wide": {
                                        "am": "午前",
                                        "noon": "正午",
                                        "pm": "午後"
                                    }
                                }
                            },
                            "eras": {
                                "eraNames": {
                                    "0": "紀元前",
                                    "1": "西暦",
                                    "0-alt-variant": "西暦紀元前",
                                    "1-alt-variant": "CE"
                                },
                                "eraAbbr": {
                                    "0": "紀元前",
                                    "1": "西暦",
                                    "0-alt-variant": "西暦紀元前",
                                    "1-alt-variant": "CE"
                                },
                                "eraNarrow": {
                                    "0": "BC",
                                    "1": "AD",
                                    "0-alt-variant": "BCE",
                                    "1-alt-variant": "CE"
                                }
                            },
                            "dateFormats": {
                                "full": "y年M月d日EEEE",
                                "long": "y年M月d日",
                                "medium": "y/MM/dd",
                                "short": "y/MM/dd"
                            },
                            "timeFormats": {
                                "full": "H時mm分ss秒 zzzz",
                                "long": "H:mm:ss z",
                                "medium": "H:mm:ss",
                                "short": "H:mm"
                            },
                            "dateTimeFormats": {
                                "full": "{1} {0}",
                                "long": "{1} {0}",
                                "medium": "{1} {0}",
                                "short": "{1} {0}",
                                "availableFormats": {
                                    "d": "d日",
                                    "Ed": "d日(E)",
                                    "EEEEd": "d日EEEE",
                                    "Ehm": "a K 時 mm 分 (E)",
                                    "EHm": "HH 時 mm 分 (E)",
                                    "Ehms": "a K 時 mm 分 ss 秒 (E)",
                                    "EHms": "HH 時 mm 分 ss 秒 (E)",
                                    "Gy": "Gy年",
                                    "GyMMM": "Gy年M月",
                                    "GyMMMd": "Gy年M月d日",
                                    "GyMMMEd": "Gy年M月d日(E)",
                                    "GyMMMEEEEd": "Gy年M月d日EEEE",
                                    "h": "aK時",
                                    "H": "H時",
                                    "hm": "aK:mm",
                                    "Hm": "H:mm",
                                    "hms": "aK:mm:ss",
                                    "Hms": "H:mm:ss",
                                    "M": "M月",
                                    "Md": "M/d",
                                    "MEd": "M/d(E)",
                                    "MEEEEd": "M/dEEEE",
                                    "MMM": "M月",
                                    "MMMd": "M月d日",
                                    "MMMEd": "M月d日(E)",
                                    "MMMEEEEd": "M月d日EEEE",
                                    "ms": "mm:ss",
                                    "y": "y年",
                                    "yM": "y/M",
                                    "yMd": "y/M/d",
                                    "yMEd": "y/M/d(E)",
                                    "yMEEEEd": "y/M/dEEEE",
                                    "yMM": "y/MM",
                                    "yMMM": "y年M月",
                                    "yMMMd": "y年M月d日",
                                    "yMMMEd": "y年M月d日(E)",
                                    "yMMMEEEEd": "y年M月d日EEEE",
                                    "yQQQ": "y/QQQ",
                                    "yQQQQ": "yQQQQ"
                                },
                                "appendItems": {
                                    "Day": "{0} ({2}: {1})",
                                    "Day-Of-Week": "{0} {1}",
                                    "Era": "{1} {0}",
                                    "Hour": "{0} ({2}: {1})",
                                    "Minute": "{0} ({2}: {1})",
                                    "Month": "{0} ({2}: {1})",
                                    "Quarter": "{0} ({2}: {1})",
                                    "Second": "{0} ({2}: {1})",
                                    "Timezone": "{0} {1}",
                                    "Week": "{0} ({2}: {1})",
                                    "Year": "{1} {0}"
                                },
                                "intervalFormats": {
                                    "intervalFormatFallback": "{0}～{1}",
                                    "d": {
                                        "d": "d日～d日"
                                    },
                                    "h": {
                                        "a": "aK時～aK時",
                                        "h": "aK時～K時"
                                    },
                                    "H": {
                                        "H": "H時～H時"
                                    },
                                    "hm": {
                                        "a": "aK時mm分～aK時mm分",
                                        "h": "aK時mm分～K時mm分",
                                        "m": "aK時mm分～K時mm分"
                                    },
                                    "Hm": {
                                        "H": "H時mm分～H時mm分",
                                        "m": "H時mm分～H時mm分"
                                    },
                                    "hmv": {
                                        "a": "aK時mm分～aK時mm分(v)",
                                        "h": "aK時mm分～K時mm分(v)",
                                        "m": "aK時mm分～K時mm分(v)"
                                    },
                                    "Hmv": {
                                        "H": "H時mm分～H時mm分(v)",
                                        "m": "H時mm分～H時mm分(v)"
                                    },
                                    "hv": {
                                        "a": "aK時～aK時(v)",
                                        "h": "aK時～K時(v)"
                                    },
                                    "Hv": {
                                        "H": "H時～H時(v)"
                                    },
                                    "M": {
                                        "M": "M月～M月"
                                    },
                                    "Md": {
                                        "d": "MM/dd～MM/dd",
                                        "M": "MM/dd～MM/dd"
                                    },
                                    "MEd": {
                                        "d": "MM/dd(E)～MM/dd(E)",
                                        "M": "MM/dd(E)～MM/dd(E)"
                                    },
                                    "MMM": {
                                        "M": "M月～M月"
                                    },
                                    "MMMd": {
                                        "d": "M月d日～d日",
                                        "M": "M月d日～M月d日"
                                    },
                                    "MMMEd": {
                                        "d": "M月d日(E)～d日(E)",
                                        "M": "M月d日(E)～M月d日(E)"
                                    },
                                    "MMMM": {
                                        "M": "M月～M月"
                                    },
                                    "y": {
                                        "y": "y年～y年"
                                    },
                                    "yM": {
                                        "M": "y/MM～y/MM",
                                        "y": "y/MM～y/MM"
                                    },
                                    "yMd": {
                                        "d": "y/MM/dd～y/MM/dd",
                                        "M": "y/MM/dd～y/MM/dd",
                                        "y": "y/MM/dd～y/MM/dd"
                                    },
                                    "yMEd": {
                                        "d": "y/MM/dd(E)～y/MM/dd(E)",
                                        "M": "y/MM/dd(E)～y/MM/dd(E)",
                                        "y": "y/MM/dd(E)～y/MM/dd(E)"
                                    },
                                    "yMMM": {
                                        "M": "y年M月～M月",
                                        "y": "y年M月～y年M月"
                                    },
                                    "yMMMd": {
                                        "d": "y年M月d日～d日",
                                        "M": "y年M月d日～M月d日",
                                        "y": "y年M月d日～y年M月d日"
                                    },
                                    "yMMMEd": {
                                        "d": "y年M月d日(E)～d日(E)",
                                        "M": "y年M月d日(E)～M月d日(E)",
                                        "y": "y年M月d日(E)～y年M月d日(E)"
                                    },
                                    "yMMMM": {
                                        "M": "y年M月～M月",
                                        "y": "y年M月～y年M月"
                                    }
                                }
                            }
                        }
                    },
                    "timeZoneNames": {
                        "hourFormat": "+HH:mm;-HH:mm",
                        "gmtFormat": "GMT{0}",
                        "gmtZeroFormat": "GMT",
                        "regionFormat": "{0}時間",
                        "regionFormat-type-daylight": "{0}夏時間",
                        "regionFormat-type-standard": "{0}標準時",
                        "fallbackFormat": "{1}（{0}）"
                    }
                }
            },
            "ko": {
                "dates": {
                    "calendars": {
                        "gregorian": {
                            "months": {
                                "format": {
                                    "abbreviated": {
                                        "1": "1월",
                                        "2": "2월",
                                        "3": "3월",
                                        "4": "4월",
                                        "5": "5월",
                                        "6": "6월",
                                        "7": "7월",
                                        "8": "8월",
                                        "9": "9월",
                                        "10": "10월",
                                        "11": "11월",
                                        "12": "12월"
                                    },
                                    "narrow": {
                                        "1": "1월",
                                        "2": "2월",
                                        "3": "3월",
                                        "4": "4월",
                                        "5": "5월",
                                        "6": "6월",
                                        "7": "7월",
                                        "8": "8월",
                                        "9": "9월",
                                        "10": "10월",
                                        "11": "11월",
                                        "12": "12월"
                                    },
                                    "wide": {
                                        "1": "1월",
                                        "2": "2월",
                                        "3": "3월",
                                        "4": "4월",
                                        "5": "5월",
                                        "6": "6월",
                                        "7": "7월",
                                        "8": "8월",
                                        "9": "9월",
                                        "10": "10월",
                                        "11": "11월",
                                        "12": "12월"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "1": "1월",
                                        "2": "2월",
                                        "3": "3월",
                                        "4": "4월",
                                        "5": "5월",
                                        "6": "6월",
                                        "7": "7월",
                                        "8": "8월",
                                        "9": "9월",
                                        "10": "10월",
                                        "11": "11월",
                                        "12": "12월"
                                    },
                                    "narrow": {
                                        "1": "1월",
                                        "2": "2월",
                                        "3": "3월",
                                        "4": "4월",
                                        "5": "5월",
                                        "6": "6월",
                                        "7": "7월",
                                        "8": "8월",
                                        "9": "9월",
                                        "10": "10월",
                                        "11": "11월",
                                        "12": "12월"
                                    },
                                    "wide": {
                                        "1": "1월",
                                        "2": "2월",
                                        "3": "3월",
                                        "4": "4월",
                                        "5": "5월",
                                        "6": "6월",
                                        "7": "7월",
                                        "8": "8월",
                                        "9": "9월",
                                        "10": "10월",
                                        "11": "11월",
                                        "12": "12월"
                                    }
                                }
                            },
                            "days": {
                                "format": {
                                    "abbreviated": {
                                        "sun": "일",
                                        "mon": "월",
                                        "tue": "화",
                                        "wed": "수",
                                        "thu": "목",
                                        "fri": "금",
                                        "sat": "토"
                                    },
                                    "narrow": {
                                        "sun": "일",
                                        "mon": "월",
                                        "tue": "화",
                                        "wed": "수",
                                        "thu": "목",
                                        "fri": "금",
                                        "sat": "토"
                                    },
                                    "short": {
                                        "sun": "일",
                                        "mon": "월",
                                        "tue": "화",
                                        "wed": "수",
                                        "thu": "목",
                                        "fri": "금",
                                        "sat": "토"
                                    },
                                    "wide": {
                                        "sun": "일요일",
                                        "mon": "월요일",
                                        "tue": "화요일",
                                        "wed": "수요일",
                                        "thu": "목요일",
                                        "fri": "금요일",
                                        "sat": "토요일"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "sun": "일",
                                        "mon": "월",
                                        "tue": "화",
                                        "wed": "수",
                                        "thu": "목",
                                        "fri": "금",
                                        "sat": "토"
                                    },
                                    "narrow": {
                                        "sun": "일",
                                        "mon": "월",
                                        "tue": "화",
                                        "wed": "수",
                                        "thu": "목",
                                        "fri": "금",
                                        "sat": "토"
                                    },
                                    "short": {
                                        "sun": "일",
                                        "mon": "월",
                                        "tue": "화",
                                        "wed": "수",
                                        "thu": "목",
                                        "fri": "금",
                                        "sat": "토"
                                    },
                                    "wide": {
                                        "sun": "일요일",
                                        "mon": "월요일",
                                        "tue": "화요일",
                                        "wed": "수요일",
                                        "thu": "목요일",
                                        "fri": "금요일",
                                        "sat": "토요일"
                                    }
                                }
                            },
                            "quarters": {
                                "format": {
                                    "abbreviated": {
                                        "1": "1분기",
                                        "2": "2분기",
                                        "3": "3분기",
                                        "4": "4분기"
                                    },
                                    "narrow": {
                                        "1": "1",
                                        "2": "2",
                                        "3": "3",
                                        "4": "4"
                                    },
                                    "wide": {
                                        "1": "제 1/4분기",
                                        "2": "제 2/4분기",
                                        "3": "제 3/4분기",
                                        "4": "제 4/4분기"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "1": "1분기",
                                        "2": "2분기",
                                        "3": "3분기",
                                        "4": "4분기"
                                    },
                                    "narrow": {
                                        "1": "1",
                                        "2": "2",
                                        "3": "3",
                                        "4": "4"
                                    },
                                    "wide": {
                                        "1": "제 1/4분기",
                                        "2": "제 2/4분기",
                                        "3": "제 3/4분기",
                                        "4": "제 4/4분기"
                                    }
                                }
                            },
                            "dayPeriods": {
                                "format": {
                                    "abbreviated": {
                                        "am": "오전",
                                        "pm": "오후"
                                    },
                                    "narrow": {
                                        "am": "오전",
                                        "pm": "오후"
                                    },
                                    "wide": {
                                        "am": "오전",
                                        "pm": "오후"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "am": "오전",
                                        "pm": "오후"
                                    },
                                    "narrow": {
                                        "am": "오전",
                                        "pm": "오후"
                                    },
                                    "wide": {
                                        "am": "오전",
                                        "pm": "오후"
                                    }
                                }
                            },
                            "eras": {
                                "eraNames": {
                                    "0": "서력기원전",
                                    "1": "서력기원",
                                    "0-alt-variant": "BCE",
                                    "1-alt-variant": "CE"
                                },
                                "eraAbbr": {
                                    "0": "기원전",
                                    "1": "서기",
                                    "0-alt-variant": "BCE",
                                    "1-alt-variant": "CE"
                                },
                                "eraNarrow": {
                                    "0": "기원전",
                                    "1": "서기",
                                    "0-alt-variant": "BCE",
                                    "1-alt-variant": "CE"
                                }
                            },
                            "dateFormats": {
                                "full": "y년 M월 d일 EEEE",
                                "long": "y년 M월 d일",
                                "medium": "y. M. d.",
                                "short": "yy. M. d."
                            },
                            "timeFormats": {
                                "full": "a h시 m분 s초 zzzz",
                                "long": "a h시 m분 s초 z",
                                "medium": "a h:mm:ss",
                                "short": "a h:mm"
                            },
                            "dateTimeFormats": {
                                "full": "{1} {0}",
                                "long": "{1} {0}",
                                "medium": "{1} {0}",
                                "short": "{1} {0}",
                                "availableFormats": {
                                    "d": "d일",
                                    "Ed": "d일 (E)",
                                    "EEEEd": "d일 EEEE",
                                    "Ehm": "(E) a h:mm",
                                    "EHm": "(E) HH:mm",
                                    "Ehms": "(E) a h:mm:ss",
                                    "EHms": "(E) HH:mm:ss",
                                    "Gy": "G y년",
                                    "GyMMM": "G y년 MMM",
                                    "GyMMMd": "G y년 MMM d일",
                                    "GyMMMEd": "G y년 MMM d일 (E)",
                                    "GyMMMEEEEd": "G y년 MMM d일 EEEE",
                                    "h": "a h시",
                                    "H": "H시",
                                    "HHmmss": "HH:mm:ss",
                                    "hm": "a h:mm",
                                    "Hm": "HH:mm",
                                    "hms": "a h:mm:ss",
                                    "Hms": "H시 m분 s초",
                                    "M": "M월",
                                    "Md": "M. d.",
                                    "MEd": "M. d. (E)",
                                    "MEEEEd": "M. d. EEEE",
                                    "MMM": "LLL",
                                    "MMMd": "MMM d일",
                                    "MMMEd": "MMM d일 (E)",
                                    "MMMEEEEd": "MMM d일 EEEE",
                                    "mmss": "mm:ss",
                                    "ms": "mm:ss",
                                    "y": "y년",
                                    "yM": "y. M.",
                                    "yMd": "y. M. d.",
                                    "yMEd": "y. M. d. (E)",
                                    "yMEEEEd": "y. M. d. EEEE",
                                    "yMM": "y. M.",
                                    "yMMM": "y년 MMM",
                                    "yMMMd": "y년 MMM d일",
                                    "yMMMEd": "y년 MMM d일 (E)",
                                    "yMMMEEEEd": "y년 MMM d일 EEEE",
                                    "yQQQ": "y년 QQQ",
                                    "yQQQQ": "y년 QQQQ"
                                },
                                "appendItems": {
                                    "Day": "{0} ({2}: {1})",
                                    "Day-Of-Week": "{0} {1}",
                                    "Era": "{1} {0}",
                                    "Hour": "{0} ({2}: {1})",
                                    "Minute": "{0} ({2}: {1})",
                                    "Month": "{0} ({2}: {1})",
                                    "Quarter": "{0} ({2}: {1})",
                                    "Second": "{0} ({2}: {1})",
                                    "Timezone": "{0} {1}",
                                    "Week": "{0} ({2}: {1})",
                                    "Year": "{1} {0}"
                                },
                                "intervalFormats": {
                                    "intervalFormatFallback": "{0} ~ {1}",
                                    "d": {
                                        "d": "d일 ~ d일"
                                    },
                                    "h": {
                                        "a": "a h시 ~ a h시",
                                        "h": "a h시 ~ h시"
                                    },
                                    "H": {
                                        "H": "HH ~ HH시"
                                    },
                                    "hm": {
                                        "a": "a h:mm ~ a h:mm",
                                        "h": "a h:mm~h:mm",
                                        "m": "a h:mm~h:mm"
                                    },
                                    "Hm": {
                                        "H": "HH:mm ~ HH:mm",
                                        "m": "HH:mm ~ HH:mm"
                                    },
                                    "hmv": {
                                        "a": "a h:mm ~ a h:mm v",
                                        "h": "a h:mm~h:mm v",
                                        "m": "a h:mm~h:mm v"
                                    },
                                    "Hmv": {
                                        "H": "HH:mm ~ HH:mm v",
                                        "m": "HH:mm ~ HH:mm v"
                                    },
                                    "hv": {
                                        "a": "a h시 ~ a h시(v)",
                                        "h": "a h시 ~ h시(v)"
                                    },
                                    "Hv": {
                                        "H": "HH ~ HH시 v"
                                    },
                                    "M": {
                                        "M": "M월 ~ M월"
                                    },
                                    "Md": {
                                        "d": "M. d ~ M. d",
                                        "M": "M. d ~ M. d"
                                    },
                                    "MEd": {
                                        "d": "M. d (E) ~ M. d (E)",
                                        "M": "M. d (E) ~ M. d (E)"
                                    },
                                    "MMM": {
                                        "M": "MMM ~ MMM"
                                    },
                                    "MMMd": {
                                        "d": "M월 d일 ~ d일",
                                        "M": "M월 d일 ~ M월 d일"
                                    },
                                    "MMMEd": {
                                        "d": "M월 d일 (E) ~ d일 (E)",
                                        "M": "M월 d일 (E) ~ M월 d일 (E)"
                                    },
                                    "MMMM": {
                                        "M": "LLLL-LLLL"
                                    },
                                    "y": {
                                        "y": "y년 ~ y년"
                                    },
                                    "yM": {
                                        "M": "y. M ~ y. M",
                                        "y": "y. M ~ y. M"
                                    },
                                    "yMd": {
                                        "d": "y. M. d. ~ y. M. d.",
                                        "M": "y. M. d. ~ y. M. d.",
                                        "y": "y. M. d. ~ y. M. d."
                                    },
                                    "yMEd": {
                                        "d": "y. M. d. (E) ~ y. M. d. (E)",
                                        "M": "y. M. d. (E) ~ y. M. d. (E)",
                                        "y": "y. M. d. (E) ~ y. M. d. (E)"
                                    },
                                    "yMMM": {
                                        "M": "y년 M월~M월",
                                        "y": "y년 M월 ~ y년 M월"
                                    },
                                    "yMMMd": {
                                        "d": "y년 M월 d일~d일",
                                        "M": "y년 M월 d일 ~ M월 d일",
                                        "y": "y년 M월 d일 ~ y년 M월 d일"
                                    },
                                    "yMMMEd": {
                                        "d": "y년 M월 d일 (E) ~ d일 (E)",
                                        "M": "y년 M월 d일 (E) ~ M월 d일 (E)",
                                        "y": "y년 M월 d일 (E) ~ y년 M월 d일 (E)"
                                    },
                                    "yMMMEEEEd": {
                                        "d": "y년 M월 d일 EEEE ~ d일 EEEE",
                                        "M": "y년 M월 d일 EEEE ~ M월 d일 EEEE",
                                        "y": "y년 M월 d일 EEEE ~ y년 M월 d일 EEEE"
                                    },
                                    "yMMMM": {
                                        "M": "y년 MM월 ~ MM월",
                                        "y": "y년 MM월 ~ y년 MM월"
                                    }
                                }
                            }
                        }
                    },
                    "timeZoneNames": {
                        "hourFormat": "+HH:mm;-HH:mm",
                        "gmtFormat": "GMT{0}",
                        "gmtZeroFormat": "GMT",
                        "regionFormat": "{0} 시간",
                        "regionFormat-type-daylight": "{0} 일광 절약 시간",
                        "regionFormat-type-standard": "{0} 표준시",
                        "fallbackFormat": "{1} ({0})"
                    }
                }
            },
            "nb": {
                "dates": {
                    "calendars": {
                        "gregorian": {
                            "months": {
                                "format": {
                                    "abbreviated": {
                                        "1": "jan.",
                                        "2": "feb.",
                                        "3": "mar.",
                                        "4": "apr.",
                                        "5": "mai",
                                        "6": "jun.",
                                        "7": "jul.",
                                        "8": "aug.",
                                        "9": "sep.",
                                        "10": "okt.",
                                        "11": "nov.",
                                        "12": "des."
                                    },
                                    "narrow": {
                                        "1": "J",
                                        "2": "F",
                                        "3": "M",
                                        "4": "A",
                                        "5": "M",
                                        "6": "J",
                                        "7": "J",
                                        "8": "A",
                                        "9": "S",
                                        "10": "O",
                                        "11": "N",
                                        "12": "D"
                                    },
                                    "wide": {
                                        "1": "januar",
                                        "2": "februar",
                                        "3": "mars",
                                        "4": "april",
                                        "5": "mai",
                                        "6": "juni",
                                        "7": "juli",
                                        "8": "august",
                                        "9": "september",
                                        "10": "oktober",
                                        "11": "november",
                                        "12": "desember"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "1": "jan",
                                        "2": "feb",
                                        "3": "mar",
                                        "4": "apr",
                                        "5": "mai",
                                        "6": "jun",
                                        "7": "jul",
                                        "8": "aug",
                                        "9": "sep",
                                        "10": "okt",
                                        "11": "nov",
                                        "12": "des"
                                    },
                                    "narrow": {
                                        "1": "J",
                                        "2": "F",
                                        "3": "M",
                                        "4": "A",
                                        "5": "M",
                                        "6": "J",
                                        "7": "J",
                                        "8": "A",
                                        "9": "S",
                                        "10": "O",
                                        "11": "N",
                                        "12": "D"
                                    },
                                    "wide": {
                                        "1": "januar",
                                        "2": "februar",
                                        "3": "mars",
                                        "4": "april",
                                        "5": "mai",
                                        "6": "juni",
                                        "7": "juli",
                                        "8": "august",
                                        "9": "september",
                                        "10": "oktober",
                                        "11": "november",
                                        "12": "desember"
                                    }
                                }
                            },
                            "days": {
                                "format": {
                                    "abbreviated": {
                                        "sun": "søn.",
                                        "mon": "man.",
                                        "tue": "tir.",
                                        "wed": "ons.",
                                        "thu": "tor.",
                                        "fri": "fre.",
                                        "sat": "lør."
                                    },
                                    "narrow": {
                                        "sun": "S",
                                        "mon": "M",
                                        "tue": "T",
                                        "wed": "O",
                                        "thu": "T",
                                        "fri": "F",
                                        "sat": "L"
                                    },
                                    "short": {
                                        "sun": "sø.",
                                        "mon": "ma.",
                                        "tue": "ti.",
                                        "wed": "on.",
                                        "thu": "to.",
                                        "fri": "fr.",
                                        "sat": "lø."
                                    },
                                    "wide": {
                                        "sun": "søndag",
                                        "mon": "mandag",
                                        "tue": "tirsdag",
                                        "wed": "onsdag",
                                        "thu": "torsdag",
                                        "fri": "fredag",
                                        "sat": "lørdag"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "sun": "sø.",
                                        "mon": "ma.",
                                        "tue": "ti.",
                                        "wed": "on.",
                                        "thu": "to.",
                                        "fri": "fr.",
                                        "sat": "lø."
                                    },
                                    "narrow": {
                                        "sun": "S",
                                        "mon": "M",
                                        "tue": "T",
                                        "wed": "O",
                                        "thu": "T",
                                        "fri": "F",
                                        "sat": "L"
                                    },
                                    "short": {
                                        "sun": "sø.",
                                        "mon": "ma.",
                                        "tue": "ti.",
                                        "wed": "on.",
                                        "thu": "to.",
                                        "fri": "fr.",
                                        "sat": "lø."
                                    },
                                    "wide": {
                                        "sun": "søndag",
                                        "mon": "mandag",
                                        "tue": "tirsdag",
                                        "wed": "onsdag",
                                        "thu": "torsdag",
                                        "fri": "fredag",
                                        "sat": "lørdag"
                                    }
                                }
                            },
                            "quarters": {
                                "format": {
                                    "abbreviated": {
                                        "1": "K1",
                                        "2": "K2",
                                        "3": "K3",
                                        "4": "K4"
                                    },
                                    "narrow": {
                                        "1": "1",
                                        "2": "2",
                                        "3": "3",
                                        "4": "4"
                                    },
                                    "wide": {
                                        "1": "1. kvartal",
                                        "2": "2. kvartal",
                                        "3": "3. kvartal",
                                        "4": "4. kvartal"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "1": "K1",
                                        "2": "K2",
                                        "3": "K3",
                                        "4": "K4"
                                    },
                                    "narrow": {
                                        "1": "1",
                                        "2": "2",
                                        "3": "3",
                                        "4": "4"
                                    },
                                    "wide": {
                                        "1": "1. kvartal",
                                        "2": "2. kvartal",
                                        "3": "3. kvartal",
                                        "4": "4. kvartal"
                                    }
                                }
                            },
                            "dayPeriods": {
                                "format": {
                                    "abbreviated": {
                                        "am": "a.m.",
                                        "pm": "p.m."
                                    },
                                    "narrow": {
                                        "am": "a",
                                        "pm": "p"
                                    },
                                    "wide": {
                                        "am": "a.m.",
                                        "pm": "p.m."
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "am": "a.m.",
                                        "pm": "p.m."
                                    },
                                    "narrow": {
                                        "am": "a",
                                        "pm": "p"
                                    },
                                    "wide": {
                                        "am": "AM",
                                        "pm": "PM"
                                    }
                                }
                            },
                            "eras": {
                                "eraNames": {
                                    "0": "f.Kr.",
                                    "1": "e.Kr.",
                                    "0-alt-variant": "før vår tidsregning",
                                    "1-alt-variant": "vår tidsregning"
                                },
                                "eraAbbr": {
                                    "0": "f.Kr.",
                                    "1": "e.Kr.",
                                    "0-alt-variant": "fvt.",
                                    "1-alt-variant": "vt."
                                },
                                "eraNarrow": {
                                    "0": "f.Kr.",
                                    "1": "e.Kr.",
                                    "0-alt-variant": "fvt.",
                                    "1-alt-variant": "vt"
                                }
                            },
                            "dateFormats": {
                                "full": "EEEE d. MMMM y",
                                "long": "d. MMMM y",
                                "medium": "d. MMM y",
                                "short": "dd.MM.yy"
                            },
                            "timeFormats": {
                                "full": "HH.mm.ss zzzz",
                                "long": "HH.mm.ss z",
                                "medium": "HH.mm.ss",
                                "short": "HH.mm"
                            },
                            "dateTimeFormats": {
                                "full": "{1} {0}",
                                "long": "{1} 'kl.' {0}",
                                "medium": "{1}, {0}",
                                "short": "{1}, {0}",
                                "availableFormats": {
                                    "d": "d.",
                                    "Ed": "E d.",
                                    "Ehm": "E h.mm a",
                                    "EHm": "E HH.mm",
                                    "Ehms": "E h.mm.ss a",
                                    "EHms": "E HH.mm.ss",
                                    "Gy": "y G",
                                    "GyMMM": "MMM y G",
                                    "GyMMMd": "d. MMM y G",
                                    "GyMMMEd": "E d. MMM y G",
                                    "h": "h a",
                                    "H": "HH",
                                    "hm": "h.mm a",
                                    "Hm": "HH.mm",
                                    "hms": "h.mm.ss a",
                                    "Hms": "HH.mm.ss",
                                    "M": "L.",
                                    "Md": "d.M.",
                                    "MEd": "E d.M",
                                    "MMdd": "d.M.",
                                    "MMM": "LLL",
                                    "MMMd": "d. MMM",
                                    "MMMEd": "E d. MMM",
                                    "ms": "mm.ss",
                                    "y": "y",
                                    "yM": "M.y",
                                    "yMd": "d.M.y",
                                    "yMEd": "E d.MM.y",
                                    "yMM": "MM.y",
                                    "yMMM": "MMM y",
                                    "yMMMd": "d. MMM y",
                                    "yMMMEd": "E d. MMM y",
                                    "yMMMM": "MMMM y",
                                    "yQQQ": "QQQ y",
                                    "yQQQQ": "QQQQ y"
                                },
                                "appendItems": {
                                    "Day": "{0} ({2}: {1})",
                                    "Day-Of-Week": "{0} {1}",
                                    "Era": "{1} {0}",
                                    "Hour": "{0} ({2}: {1})",
                                    "Minute": "{0} ({2}: {1})",
                                    "Month": "{0} ({2}: {1})",
                                    "Quarter": "{0} ({2}: {1})",
                                    "Second": "{0} ({2}: {1})",
                                    "Timezone": "{0} {1}",
                                    "Week": "{0} ({2}: {1})",
                                    "Year": "{1} {0}"
                                },
                                "intervalFormats": {
                                    "intervalFormatFallback": "{0}–{1}",
                                    "d": {
                                        "d": "d.–d."
                                    },
                                    "h": {
                                        "a": "H–H",
                                        "h": "H–H"
                                    },
                                    "H": {
                                        "H": "HH–HH"
                                    },
                                    "hm": {
                                        "a": "H.mm–H.mm",
                                        "h": "H.mm–H.mm",
                                        "m": "H.mm–H.mm"
                                    },
                                    "Hm": {
                                        "H": "HH.mm–HH.mm",
                                        "m": "HH.mm–HH.mm"
                                    },
                                    "hmv": {
                                        "a": "H.mm–H.mm v",
                                        "h": "H.mm–H.mm v",
                                        "m": "H.mm–H.mm v"
                                    },
                                    "Hmv": {
                                        "H": "HH.mm–HH.mm v",
                                        "m": "HH.mm–HH.mm v"
                                    },
                                    "hv": {
                                        "a": "H–H v",
                                        "h": "H–H v"
                                    },
                                    "Hv": {
                                        "H": "HH–HH v"
                                    },
                                    "M": {
                                        "M": "M.–M."
                                    },
                                    "Md": {
                                        "d": "dd.MM.–dd.MM.",
                                        "M": "dd.MM.–dd.MM."
                                    },
                                    "MEd": {
                                        "d": "E dd.MM.–E dd.MM.",
                                        "M": "E dd.MM.–E dd.MM."
                                    },
                                    "MMM": {
                                        "M": "MMM–MMM"
                                    },
                                    "MMMd": {
                                        "d": "d.–d. MMM",
                                        "M": "d. MMM–d. MMM"
                                    },
                                    "MMMEd": {
                                        "d": "E d.–E d. MMM",
                                        "M": "E d. MMM–E d. MMM"
                                    },
                                    "y": {
                                        "y": "y–y"
                                    },
                                    "yM": {
                                        "M": "MM.y–MM.y",
                                        "y": "MM.y–MM.y"
                                    },
                                    "yMd": {
                                        "d": "dd.MM.y–dd.MM.y",
                                        "M": "dd.MM.y–dd.MM.y",
                                        "y": "dd.MM.y–dd.MM.y"
                                    },
                                    "yMEd": {
                                        "d": "E dd.MM.y–E dd.MM.y",
                                        "M": "E dd.MM.y–E dd.MM.y",
                                        "y": "E dd.MM.y–E dd.MM.y"
                                    },
                                    "yMMM": {
                                        "M": "MMM–MMM y",
                                        "y": "MMM y–MMM y"
                                    },
                                    "yMMMd": {
                                        "d": "d.–d. MMM y",
                                        "M": "d. MMM–d. MMM y",
                                        "y": "d. MMM y–d. MMM y"
                                    },
                                    "yMMMEd": {
                                        "d": "E d.–E d. MMM y",
                                        "M": "E d. MMM–E d. MMM y",
                                        "y": "E d. MMM y–E d. MMM y"
                                    },
                                    "yMMMM": {
                                        "M": "MMMM–MMMM y",
                                        "y": "MMMM y–MMMM y"
                                    }
                                }
                            }
                        }
                    },
                    "timeZoneNames": {
                        "hourFormat": "+HH.mm;-HH.mm",
                        "gmtFormat": "GMT{0}",
                        "gmtZeroFormat": "GMT",
                        "regionFormat": "tidssone for {0}",
                        "regionFormat-type-daylight": "sommertid – {0}",
                        "regionFormat-type-standard": "normaltid – {0}",
                        "fallbackFormat": "{1} ({0})"
                    }
                }
            },
            "nl": {
                "dates": {
                    "calendars": {
                        "gregorian": {
                            "months": {
                                "format": {
                                    "abbreviated": {
                                        "1": "jan.",
                                        "2": "feb.",
                                        "3": "mrt.",
                                        "4": "apr.",
                                        "5": "mei",
                                        "6": "jun.",
                                        "7": "jul.",
                                        "8": "aug.",
                                        "9": "sep.",
                                        "10": "okt.",
                                        "11": "nov.",
                                        "12": "dec."
                                    },
                                    "narrow": {
                                        "1": "J",
                                        "2": "F",
                                        "3": "M",
                                        "4": "A",
                                        "5": "M",
                                        "6": "J",
                                        "7": "J",
                                        "8": "A",
                                        "9": "S",
                                        "10": "O",
                                        "11": "N",
                                        "12": "D"
                                    },
                                    "wide": {
                                        "1": "januari",
                                        "2": "februari",
                                        "3": "maart",
                                        "4": "april",
                                        "5": "mei",
                                        "6": "juni",
                                        "7": "juli",
                                        "8": "augustus",
                                        "9": "september",
                                        "10": "oktober",
                                        "11": "november",
                                        "12": "december"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "1": "jan",
                                        "2": "feb",
                                        "3": "mrt",
                                        "4": "apr",
                                        "5": "mei",
                                        "6": "jun",
                                        "7": "jul",
                                        "8": "aug",
                                        "9": "sep",
                                        "10": "okt",
                                        "11": "nov",
                                        "12": "dec"
                                    },
                                    "narrow": {
                                        "1": "J",
                                        "2": "F",
                                        "3": "M",
                                        "4": "A",
                                        "5": "M",
                                        "6": "J",
                                        "7": "J",
                                        "8": "A",
                                        "9": "S",
                                        "10": "O",
                                        "11": "N",
                                        "12": "D"
                                    },
                                    "wide": {
                                        "1": "januari",
                                        "2": "februari",
                                        "3": "maart",
                                        "4": "april",
                                        "5": "mei",
                                        "6": "juni",
                                        "7": "juli",
                                        "8": "augustus",
                                        "9": "september",
                                        "10": "oktober",
                                        "11": "november",
                                        "12": "december"
                                    }
                                }
                            },
                            "days": {
                                "format": {
                                    "abbreviated": {
                                        "sun": "zo",
                                        "mon": "ma",
                                        "tue": "di",
                                        "wed": "wo",
                                        "thu": "do",
                                        "fri": "vr",
                                        "sat": "za"
                                    },
                                    "narrow": {
                                        "sun": "Z",
                                        "mon": "M",
                                        "tue": "D",
                                        "wed": "W",
                                        "thu": "D",
                                        "fri": "V",
                                        "sat": "Z"
                                    },
                                    "short": {
                                        "sun": "zo",
                                        "mon": "ma",
                                        "tue": "di",
                                        "wed": "wo",
                                        "thu": "do",
                                        "fri": "vr",
                                        "sat": "za"
                                    },
                                    "wide": {
                                        "sun": "zondag",
                                        "mon": "maandag",
                                        "tue": "dinsdag",
                                        "wed": "woensdag",
                                        "thu": "donderdag",
                                        "fri": "vrijdag",
                                        "sat": "zaterdag"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "sun": "zo",
                                        "mon": "ma",
                                        "tue": "di",
                                        "wed": "wo",
                                        "thu": "do",
                                        "fri": "vr",
                                        "sat": "za"
                                    },
                                    "narrow": {
                                        "sun": "Z",
                                        "mon": "M",
                                        "tue": "D",
                                        "wed": "W",
                                        "thu": "D",
                                        "fri": "V",
                                        "sat": "Z"
                                    },
                                    "short": {
                                        "sun": "zo",
                                        "mon": "ma",
                                        "tue": "di",
                                        "wed": "wo",
                                        "thu": "do",
                                        "fri": "vr",
                                        "sat": "za"
                                    },
                                    "wide": {
                                        "sun": "zondag",
                                        "mon": "maandag",
                                        "tue": "dinsdag",
                                        "wed": "woensdag",
                                        "thu": "donderdag",
                                        "fri": "vrijdag",
                                        "sat": "zaterdag"
                                    }
                                }
                            },
                            "quarters": {
                                "format": {
                                    "abbreviated": {
                                        "1": "K1",
                                        "2": "K2",
                                        "3": "K3",
                                        "4": "K4"
                                    },
                                    "narrow": {
                                        "1": "1",
                                        "2": "2",
                                        "3": "3",
                                        "4": "4"
                                    },
                                    "wide": {
                                        "1": "1e kwartaal",
                                        "2": "2e kwartaal",
                                        "3": "3e kwartaal",
                                        "4": "4e kwartaal"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "1": "K1",
                                        "2": "K2",
                                        "3": "K3",
                                        "4": "K4"
                                    },
                                    "narrow": {
                                        "1": "1",
                                        "2": "2",
                                        "3": "3",
                                        "4": "4"
                                    },
                                    "wide": {
                                        "1": "1e kwartaal",
                                        "2": "2e kwartaal",
                                        "3": "3e kwartaal",
                                        "4": "4e kwartaal"
                                    }
                                }
                            },
                            "dayPeriods": {
                                "format": {
                                    "abbreviated": {
                                        "am": "AM",
                                        "noon": "12 uur 's middags",
                                        "pm": "PM"
                                    },
                                    "narrow": {
                                        "am": "AM",
                                        "noon": "n",
                                        "pm": "PM"
                                    },
                                    "wide": {
                                        "am": "AM",
                                        "noon": "12 uur 's middags",
                                        "pm": "PM"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "am": "a.m.",
                                        "noon": "12 uur 's middags",
                                        "pm": "p.m."
                                    },
                                    "narrow": {
                                        "am": "AM",
                                        "noon": "n",
                                        "pm": "PM"
                                    },
                                    "wide": {
                                        "am": "voormiddag",
                                        "noon": "12 uur 's middags",
                                        "pm": "p.m."
                                    }
                                }
                            },
                            "eras": {
                                "eraNames": {
                                    "0": "Voor Christus",
                                    "1": "na Christus",
                                    "0-alt-variant": "vóór gewone jaartelling",
                                    "1-alt-variant": "gewone jaartelling"
                                },
                                "eraAbbr": {
                                    "0": "v.Chr.",
                                    "1": "n.Chr.",
                                    "0-alt-variant": "v.g.j.",
                                    "1-alt-variant": "g.j."
                                },
                                "eraNarrow": {
                                    "0": "v.C.",
                                    "1": "n.C.",
                                    "0-alt-variant": "vgj",
                                    "1-alt-variant": "gj"
                                }
                            },
                            "dateFormats": {
                                "full": "EEEE d MMMM y",
                                "long": "d MMMM y",
                                "medium": "d MMM y",
                                "short": "dd-MM-yy"
                            },
                            "timeFormats": {
                                "full": "HH:mm:ss zzzz",
                                "long": "HH:mm:ss z",
                                "medium": "HH:mm:ss",
                                "short": "HH:mm"
                            },
                            "dateTimeFormats": {
                                "full": "{1} {0}",
                                "long": "{1} {0}",
                                "medium": "{1} {0}",
                                "short": "{1} {0}",
                                "availableFormats": {
                                    "d": "d",
                                    "Ed": "E d",
                                    "Ehm": "E h:mm a",
                                    "EHm": "E HH:mm",
                                    "Ehms": "E h:mm:ss a",
                                    "EHms": "E HH:mm:ss",
                                    "Gy": "y G",
                                    "GyMMM": "MMM y G",
                                    "GyMMMd": "d MMM y G",
                                    "GyMMMEd": "E d MMM y G",
                                    "h": "h a",
                                    "H": "HH",
                                    "hm": "h:mm a",
                                    "Hm": "HH:mm",
                                    "hms": "h:mm:ss a",
                                    "Hms": "HH:mm:ss",
                                    "M": "L",
                                    "Md": "d-M",
                                    "MEd": "E d-M",
                                    "MMM": "LLL",
                                    "MMMd": "d MMM",
                                    "MMMEd": "E d MMM",
                                    "MMMMd": "d MMMM",
                                    "ms": "mm:ss",
                                    "y": "y",
                                    "yM": "M-y",
                                    "yMd": "d-M-y",
                                    "yMEd": "E d-M-y",
                                    "yMMM": "MMM y",
                                    "yMMMd": "d MMM y",
                                    "yMMMEd": "E d MMM y",
                                    "yMMMM": "MMMM y",
                                    "yQQQ": "QQQ y",
                                    "yQQQQ": "QQQQ y"
                                },
                                "appendItems": {
                                    "Day": "{0} ({2}: {1})",
                                    "Day-Of-Week": "{0} {1}",
                                    "Era": "{1} {0}",
                                    "Hour": "{0} ({2}: {1})",
                                    "Minute": "{0} ({2}: {1})",
                                    "Month": "{0} ({2}: {1})",
                                    "Quarter": "{0} ({2}: {1})",
                                    "Second": "{0} ({2}: {1})",
                                    "Timezone": "{0} {1}",
                                    "Week": "{0} ({2}: {1})",
                                    "Year": "{1} {0}"
                                },
                                "intervalFormats": {
                                    "intervalFormatFallback": "{0} - {1}",
                                    "d": {
                                        "d": "d-d"
                                    },
                                    "h": {
                                        "a": "h a - h a",
                                        "h": "h-h a"
                                    },
                                    "H": {
                                        "H": "HH-HH"
                                    },
                                    "hm": {
                                        "a": "h:mm a - h:mm a",
                                        "h": "h:mm-h:mm a",
                                        "m": "h:mm-h:mm a"
                                    },
                                    "Hm": {
                                        "H": "HH:mm-HH:mm",
                                        "m": "HH:mm-HH:mm"
                                    },
                                    "hmv": {
                                        "a": "h:mm a - h:mm a v",
                                        "h": "h:mm-h:mm a v",
                                        "m": "h:mm-h:mm a v"
                                    },
                                    "Hmv": {
                                        "H": "HH:mm-HH:mm v",
                                        "m": "HH:mm-HH:mm v"
                                    },
                                    "hv": {
                                        "a": "h a - h a v",
                                        "h": "h-h a v"
                                    },
                                    "Hv": {
                                        "H": "HH-HH v"
                                    },
                                    "M": {
                                        "M": "M-M"
                                    },
                                    "Md": {
                                        "d": "dd-MM - dd-MM",
                                        "M": "dd-MM - dd-MM"
                                    },
                                    "MEd": {
                                        "d": "E dd-MM - E dd-MM",
                                        "M": "E dd-MM - E dd-MM"
                                    },
                                    "MMM": {
                                        "M": "MMM-MMM"
                                    },
                                    "MMMd": {
                                        "d": "d-d MMM",
                                        "M": "d MMM - d MMM"
                                    },
                                    "MMMEd": {
                                        "d": "E d - E d MMM",
                                        "M": "E d MMM - E d MMM"
                                    },
                                    "MMMM": {
                                        "M": "MMMM–MMMM"
                                    },
                                    "y": {
                                        "y": "y-y"
                                    },
                                    "yM": {
                                        "M": "MM-y - MM-y",
                                        "y": "MM-y - MM-y"
                                    },
                                    "yMd": {
                                        "d": "dd-MM-y - dd-MM-y",
                                        "M": "dd-MM-y - dd-MM-y",
                                        "y": "dd-MM-y - dd-MM-y"
                                    },
                                    "yMEd": {
                                        "d": "E dd-MM-y - E dd-MM-y",
                                        "M": "E dd-MM-y - E dd-MM-y",
                                        "y": "E dd-MM-y - E dd-MM-y"
                                    },
                                    "yMMM": {
                                        "M": "MMM-MMM y",
                                        "y": "MMM y - MMM y"
                                    },
                                    "yMMMd": {
                                        "d": "d-d MMM y",
                                        "M": "d MMM - d MMM y",
                                        "y": "d MMM y - d MMM y"
                                    },
                                    "yMMMEd": {
                                        "d": "E d - E d MMM y",
                                        "M": "E d MMM - E d MMM y",
                                        "y": "E d MMM y - E d MMM y"
                                    },
                                    "yMMMM": {
                                        "M": "MMMM-MMMM y",
                                        "y": "MMMM y - MMMM y"
                                    }
                                }
                            }
                        }
                    },
                    "timeZoneNames": {
                        "hourFormat": "+HH:mm;-HH:mm",
                        "gmtFormat": "GMT{0}",
                        "gmtZeroFormat": "GMT",
                        "regionFormat": "{0}-tijd",
                        "regionFormat-type-daylight": "Zomertijd {0}",
                        "regionFormat-type-standard": "Standaardtijd {0}",
                        "fallbackFormat": "{1} ({0})"
                    }
                }
            },
            "pl": {
                "dates": {
                    "calendars": {
                        "gregorian": {
                            "months": {
                                "format": {
                                    "abbreviated": {
                                        "1": "sty",
                                        "2": "lut",
                                        "3": "mar",
                                        "4": "kwi",
                                        "5": "maj",
                                        "6": "cze",
                                        "7": "lip",
                                        "8": "sie",
                                        "9": "wrz",
                                        "10": "paź",
                                        "11": "lis",
                                        "12": "gru"
                                    },
                                    "narrow": {
                                        "1": "s",
                                        "2": "l",
                                        "3": "m",
                                        "4": "k",
                                        "5": "m",
                                        "6": "c",
                                        "7": "l",
                                        "8": "s",
                                        "9": "w",
                                        "10": "p",
                                        "11": "l",
                                        "12": "g"
                                    },
                                    "wide": {
                                        "1": "stycznia",
                                        "2": "lutego",
                                        "3": "marca",
                                        "4": "kwietnia",
                                        "5": "maja",
                                        "6": "czerwca",
                                        "7": "lipca",
                                        "8": "sierpnia",
                                        "9": "września",
                                        "10": "października",
                                        "11": "listopada",
                                        "12": "grudnia"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "1": "sty",
                                        "2": "lut",
                                        "3": "mar",
                                        "4": "kwi",
                                        "5": "maj",
                                        "6": "cze",
                                        "7": "lip",
                                        "8": "sie",
                                        "9": "wrz",
                                        "10": "paź",
                                        "11": "lis",
                                        "12": "gru"
                                    },
                                    "narrow": {
                                        "1": "s",
                                        "2": "l",
                                        "3": "m",
                                        "4": "k",
                                        "5": "m",
                                        "6": "c",
                                        "7": "l",
                                        "8": "s",
                                        "9": "w",
                                        "10": "p",
                                        "11": "l",
                                        "12": "g"
                                    },
                                    "wide": {
                                        "1": "styczeń",
                                        "2": "luty",
                                        "3": "marzec",
                                        "4": "kwiecień",
                                        "5": "maj",
                                        "6": "czerwiec",
                                        "7": "lipiec",
                                        "8": "sierpień",
                                        "9": "wrzesień",
                                        "10": "październik",
                                        "11": "listopad",
                                        "12": "grudzień"
                                    }
                                }
                            },
                            "days": {
                                "format": {
                                    "abbreviated": {
                                        "sun": "niedz.",
                                        "mon": "pon.",
                                        "tue": "wt.",
                                        "wed": "śr.",
                                        "thu": "czw.",
                                        "fri": "pt.",
                                        "sat": "sob."
                                    },
                                    "narrow": {
                                        "sun": "N",
                                        "mon": "P",
                                        "tue": "W",
                                        "wed": "Ś",
                                        "thu": "C",
                                        "fri": "P",
                                        "sat": "S"
                                    },
                                    "short": {
                                        "sun": "niedz.",
                                        "mon": "pon.",
                                        "tue": "wt.",
                                        "wed": "śr.",
                                        "thu": "czw.",
                                        "fri": "pt.",
                                        "sat": "sob."
                                    },
                                    "wide": {
                                        "sun": "niedziela",
                                        "mon": "poniedziałek",
                                        "tue": "wtorek",
                                        "wed": "środa",
                                        "thu": "czwartek",
                                        "fri": "piątek",
                                        "sat": "sobota"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "sun": "niedz.",
                                        "mon": "pon.",
                                        "tue": "wt.",
                                        "wed": "śr.",
                                        "thu": "czw.",
                                        "fri": "pt.",
                                        "sat": "sob."
                                    },
                                    "narrow": {
                                        "sun": "N",
                                        "mon": "P",
                                        "tue": "W",
                                        "wed": "Ś",
                                        "thu": "C",
                                        "fri": "P",
                                        "sat": "S"
                                    },
                                    "short": {
                                        "sun": "niedz.",
                                        "mon": "pon.",
                                        "tue": "wt.",
                                        "wed": "śr.",
                                        "thu": "czw.",
                                        "fri": "pt.",
                                        "sat": "sob."
                                    },
                                    "wide": {
                                        "sun": "niedziela",
                                        "mon": "poniedziałek",
                                        "tue": "wtorek",
                                        "wed": "środa",
                                        "thu": "czwartek",
                                        "fri": "piątek",
                                        "sat": "sobota"
                                    }
                                }
                            },
                            "quarters": {
                                "format": {
                                    "abbreviated": {
                                        "1": "K1",
                                        "2": "K2",
                                        "3": "K3",
                                        "4": "K4"
                                    },
                                    "narrow": {
                                        "1": "1",
                                        "2": "2",
                                        "3": "3",
                                        "4": "4"
                                    },
                                    "wide": {
                                        "1": "I kwartał",
                                        "2": "II kwartał",
                                        "3": "III kwartał",
                                        "4": "IV kwartał"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "1": "1 kw.",
                                        "2": "2 kw.",
                                        "3": "3 kw.",
                                        "4": "4 kw."
                                    },
                                    "narrow": {
                                        "1": "1",
                                        "2": "2",
                                        "3": "3",
                                        "4": "4"
                                    },
                                    "wide": {
                                        "1": "I kwartał",
                                        "2": "II kwartał",
                                        "3": "III kwartał",
                                        "4": "IV kwartał"
                                    }
                                }
                            },
                            "dayPeriods": {
                                "format": {
                                    "abbreviated": {
                                        "afternoon": "po południu",
                                        "am": "AM",
                                        "earlyMorning": "nad ranem",
                                        "evening": "wieczorem",
                                        "lateMorning": "przed południem",
                                        "morning": "rano",
                                        "night": "w nocy",
                                        "noon": "w południe",
                                        "pm": "PM"
                                    },
                                    "narrow": {
                                        "afternoon": "po południu",
                                        "am": "AM",
                                        "earlyMorning": "nad ranem",
                                        "evening": "wieczorem",
                                        "lateMorning": "przed południem",
                                        "morning": "rano",
                                        "night": "w nocy",
                                        "noon": "w południe",
                                        "pm": "PM"
                                    },
                                    "wide": {
                                        "afternoon": "po południu",
                                        "am": "AM",
                                        "earlyMorning": "nad ranem",
                                        "evening": "wieczorem",
                                        "lateMorning": "przed południem",
                                        "morning": "rano",
                                        "night": "w nocy",
                                        "noon": "w południe",
                                        "pm": "PM"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "afternoon": "po południu",
                                        "am": "AM",
                                        "earlyMorning": "nad ranem",
                                        "evening": "wieczorem",
                                        "lateMorning": "przed południem",
                                        "morning": "rano",
                                        "night": "w nocy",
                                        "noon": "w południe",
                                        "pm": "PM"
                                    },
                                    "narrow": {
                                        "afternoon": "po południu",
                                        "am": "AM",
                                        "earlyMorning": "nad ranem",
                                        "evening": "wieczorem",
                                        "lateMorning": "przed południem",
                                        "morning": "rano",
                                        "night": "w nocy",
                                        "noon": "w południe",
                                        "pm": "PM"
                                    },
                                    "wide": {
                                        "afternoon": "po południu",
                                        "am": "AM",
                                        "earlyMorning": "nad ranem",
                                        "evening": "wieczorem",
                                        "lateMorning": "przed południem",
                                        "morning": "rano",
                                        "night": "w nocy",
                                        "noon": "w południe",
                                        "pm": "PM"
                                    }
                                }
                            },
                            "eras": {
                                "eraNames": {
                                    "0": "p.n.e.",
                                    "1": "n.e.",
                                    "0-alt-variant": "BCE",
                                    "1-alt-variant": "CE"
                                },
                                "eraAbbr": {
                                    "0": "p.n.e.",
                                    "1": "n.e.",
                                    "0-alt-variant": "BCE",
                                    "1-alt-variant": "CE"
                                },
                                "eraNarrow": {
                                    "0": "p.n.e.",
                                    "1": "n.e.",
                                    "0-alt-variant": "BCE",
                                    "1-alt-variant": "CE"
                                }
                            },
                            "dateFormats": {
                                "full": "EEEE, d MMMM y",
                                "long": "d MMMM y",
                                "medium": "d MMM y",
                                "short": "dd.MM.y"
                            },
                            "timeFormats": {
                                "full": "HH:mm:ss zzzz",
                                "long": "HH:mm:ss z",
                                "medium": "HH:mm:ss",
                                "short": "HH:mm"
                            },
                            "dateTimeFormats": {
                                "full": "{1} {0}",
                                "long": "{1} {0}",
                                "medium": "{1}, {0}",
                                "short": "{1}, {0}",
                                "availableFormats": {
                                    "d": "d",
                                    "Ed": "E, d",
                                    "Ehm": "E, h:mm a",
                                    "EHm": "E, HH:mm",
                                    "Ehms": "E, h:mm:ss a",
                                    "EHms": "E, HH:mm:ss",
                                    "Gy": "y G",
                                    "GyMMM": "MMM y G",
                                    "GyMMMd": "d MMM y G",
                                    "GyMMMEd": "E, d MMM y G",
                                    "h": "h a",
                                    "H": "HH",
                                    "hm": "h:mm a",
                                    "Hm": "HH:mm",
                                    "hms": "h:mm:ss a",
                                    "Hms": "HH:mm:ss",
                                    "M": "L",
                                    "Md": "d.MM",
                                    "MEd": "E, d.MM",
                                    "MMdd": "d.MM",
                                    "MMM": "LLL",
                                    "MMMd": "d MMM",
                                    "MMMEd": "E, d MMM",
                                    "MMMMd": "d MMMM",
                                    "ms": "mm:ss",
                                    "y": "y",
                                    "yM": "MM.y",
                                    "yMd": "d.MM.y",
                                    "yMEd": "E, d.MM.y",
                                    "yMM": "MM.y",
                                    "yMMM": "LLL y",
                                    "yMMMd": "d MMM y",
                                    "yMMMEd": "E, d MMM y",
                                    "yMMMM": "LLLL y",
                                    "yQQQ": "QQQ y",
                                    "yQQQQ": "QQQQ y"
                                },
                                "appendItems": {
                                    "Day": "{0} ({2}: {1})",
                                    "Day-Of-Week": "{0} {1}",
                                    "Era": "{1} {0}",
                                    "Hour": "{0} ({2}: {1})",
                                    "Minute": "{0} ({2}: {1})",
                                    "Month": "{0} ({2}: {1})",
                                    "Quarter": "{0} ({2}: {1})",
                                    "Second": "{0} ({2}: {1})",
                                    "Timezone": "{0} {1}",
                                    "Week": "{0} ({2}: {1})",
                                    "Year": "{1} {0}"
                                },
                                "intervalFormats": {
                                    "intervalFormatFallback": "{0} – {1}",
                                    "d": {
                                        "d": "d–d"
                                    },
                                    "h": {
                                        "a": "h a – h a",
                                        "h": "h–h a"
                                    },
                                    "H": {
                                        "H": "HH–HH"
                                    },
                                    "hm": {
                                        "a": "h:mm a – h:mm a",
                                        "h": "h:mm–h:mm a",
                                        "m": "h:mm–h:mm a"
                                    },
                                    "Hm": {
                                        "H": "HH:mm–HH:mm",
                                        "m": "HH:mm–HH:mm"
                                    },
                                    "hmv": {
                                        "a": "h:mm a – h:mm a v",
                                        "h": "h:mm–h:mm a v",
                                        "m": "h:mm-h:mm a v"
                                    },
                                    "Hmv": {
                                        "H": "HH:mm–HH:mm v",
                                        "m": "HH:mm–HH:mm v"
                                    },
                                    "hv": {
                                        "a": "h a – h a v",
                                        "h": "h–h a v"
                                    },
                                    "Hv": {
                                        "H": "HH–HH v"
                                    },
                                    "M": {
                                        "M": "MM-MM"
                                    },
                                    "Md": {
                                        "d": "dd.MM–dd.MM",
                                        "M": "dd.MM–dd.MM"
                                    },
                                    "MEd": {
                                        "d": "E, dd.MM – E, dd.MM",
                                        "M": "E, dd.MM – E, dd.MM"
                                    },
                                    "MMM": {
                                        "M": "LLL–LLL"
                                    },
                                    "MMMd": {
                                        "d": "d-d MMM",
                                        "M": "d MMM - d MMM"
                                    },
                                    "MMMEd": {
                                        "d": "E, d MMM – E, d MMM",
                                        "M": "E, d MMM - E, d MMM"
                                    },
                                    "y": {
                                        "y": "y–y"
                                    },
                                    "yM": {
                                        "M": "MM.y - MM.y",
                                        "y": "MM.y - MM.y"
                                    },
                                    "yMd": {
                                        "d": "dd-dd.MM.y",
                                        "M": "dd.MM-dd.MM.y",
                                        "y": "dd.MM.y-dd.MM.y"
                                    },
                                    "yMEd": {
                                        "d": "E, dd.MM.y - E, dd.MM.y",
                                        "M": "E, dd.MM.y - E, dd.MM.y",
                                        "y": "E, dd.MM.y - E, dd.MM.y"
                                    },
                                    "yMMM": {
                                        "M": "LLL-LLL y",
                                        "y": "LLL y - LLL y"
                                    },
                                    "yMMMd": {
                                        "d": "d-d MMM y",
                                        "M": "d MMM - d MMM y",
                                        "y": "d MMM y - d MMM y"
                                    },
                                    "yMMMEd": {
                                        "d": "E, d - E, d MMM y",
                                        "M": "E, d MMM - E, d MMM y",
                                        "y": "E, d MMM y - E, d MMM y"
                                    },
                                    "yMMMM": {
                                        "M": "LLLL-LLLL y",
                                        "y": "LLLL y - LLLL y"
                                    }
                                }
                            }
                        }
                    },
                    "timeZoneNames": {
                        "hourFormat": "+HH:mm;-HH:mm",
                        "gmtFormat": "GMT{0}",
                        "gmtZeroFormat": "GMT",
                        "regionFormat": "Czas: {0}",
                        "regionFormat-type-daylight": "{0} (czas letni)",
                        "regionFormat-type-standard": "{0} (czas standardowy)",
                        "fallbackFormat": "{1} ({0})"
                    }
                }
            },
            "pt": {
                "dates": {
                    "calendars": {
                        "gregorian": {
                            "months": {
                                "format": {
                                    "abbreviated": {
                                        "1": "jan",
                                        "2": "fev",
                                        "3": "mar",
                                        "4": "abr",
                                        "5": "mai",
                                        "6": "jun",
                                        "7": "jul",
                                        "8": "ago",
                                        "9": "set",
                                        "10": "out",
                                        "11": "nov",
                                        "12": "dez"
                                    },
                                    "narrow": {
                                        "1": "J",
                                        "2": "F",
                                        "3": "M",
                                        "4": "A",
                                        "5": "M",
                                        "6": "J",
                                        "7": "J",
                                        "8": "A",
                                        "9": "S",
                                        "10": "O",
                                        "11": "N",
                                        "12": "D"
                                    },
                                    "wide": {
                                        "1": "janeiro",
                                        "2": "fevereiro",
                                        "3": "março",
                                        "4": "abril",
                                        "5": "maio",
                                        "6": "junho",
                                        "7": "julho",
                                        "8": "agosto",
                                        "9": "setembro",
                                        "10": "outubro",
                                        "11": "novembro",
                                        "12": "dezembro"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "1": "jan",
                                        "2": "fev",
                                        "3": "mar",
                                        "4": "abr",
                                        "5": "mai",
                                        "6": "jun",
                                        "7": "jul",
                                        "8": "ago",
                                        "9": "set",
                                        "10": "out",
                                        "11": "nov",
                                        "12": "dez"
                                    },
                                    "narrow": {
                                        "1": "J",
                                        "2": "F",
                                        "3": "M",
                                        "4": "A",
                                        "5": "M",
                                        "6": "J",
                                        "7": "J",
                                        "8": "A",
                                        "9": "S",
                                        "10": "O",
                                        "11": "N",
                                        "12": "D"
                                    },
                                    "wide": {
                                        "1": "janeiro",
                                        "2": "fevereiro",
                                        "3": "março",
                                        "4": "abril",
                                        "5": "maio",
                                        "6": "junho",
                                        "7": "julho",
                                        "8": "agosto",
                                        "9": "setembro",
                                        "10": "outubro",
                                        "11": "novembro",
                                        "12": "dezembro"
                                    }
                                }
                            },
                            "days": {
                                "format": {
                                    "abbreviated": {
                                        "sun": "dom",
                                        "mon": "seg",
                                        "tue": "ter",
                                        "wed": "qua",
                                        "thu": "qui",
                                        "fri": "sex",
                                        "sat": "sáb"
                                    },
                                    "narrow": {
                                        "sun": "D",
                                        "mon": "S",
                                        "tue": "T",
                                        "wed": "Q",
                                        "thu": "Q",
                                        "fri": "S",
                                        "sat": "S"
                                    },
                                    "short": {
                                        "sun": "dom",
                                        "mon": "seg",
                                        "tue": "ter",
                                        "wed": "qua",
                                        "thu": "qui",
                                        "fri": "sex",
                                        "sat": "sáb"
                                    },
                                    "wide": {
                                        "sun": "domingo",
                                        "mon": "segunda-feira",
                                        "tue": "terça-feira",
                                        "wed": "quarta-feira",
                                        "thu": "quinta-feira",
                                        "fri": "sexta-feira",
                                        "sat": "sábado"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "sun": "dom",
                                        "mon": "seg",
                                        "tue": "ter",
                                        "wed": "qua",
                                        "thu": "qui",
                                        "fri": "sex",
                                        "sat": "sáb"
                                    },
                                    "narrow": {
                                        "sun": "D",
                                        "mon": "S",
                                        "tue": "T",
                                        "wed": "Q",
                                        "thu": "Q",
                                        "fri": "S",
                                        "sat": "S"
                                    },
                                    "short": {
                                        "sun": "dom",
                                        "mon": "seg",
                                        "tue": "ter",
                                        "wed": "qua",
                                        "thu": "qui",
                                        "fri": "sex",
                                        "sat": "sáb"
                                    },
                                    "wide": {
                                        "sun": "domingo",
                                        "mon": "segunda-feira",
                                        "tue": "terça-feira",
                                        "wed": "quarta-feira",
                                        "thu": "quinta-feira",
                                        "fri": "sexta-feira",
                                        "sat": "sábado"
                                    }
                                }
                            },
                            "quarters": {
                                "format": {
                                    "abbreviated": {
                                        "1": "T1",
                                        "2": "T2",
                                        "3": "T3",
                                        "4": "T4"
                                    },
                                    "narrow": {
                                        "1": "1",
                                        "2": "2",
                                        "3": "3",
                                        "4": "4"
                                    },
                                    "wide": {
                                        "1": "1º trimestre",
                                        "2": "2º trimestre",
                                        "3": "3º trimestre",
                                        "4": "4º trimestre"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "1": "T1",
                                        "2": "T2",
                                        "3": "T3",
                                        "4": "T4"
                                    },
                                    "narrow": {
                                        "1": "1",
                                        "2": "2",
                                        "3": "3",
                                        "4": "4"
                                    },
                                    "wide": {
                                        "1": "1º trimestre",
                                        "2": "2º trimestre",
                                        "3": "3º trimestre",
                                        "4": "4º trimestre"
                                    }
                                }
                            },
                            "dayPeriods": {
                                "format": {
                                    "abbreviated": {
                                        "afternoon": "tarde",
                                        "am": "AM",
                                        "morning": "manhã",
                                        "night": "noite",
                                        "noon": "meio-dia",
                                        "pm": "PM"
                                    },
                                    "narrow": {
                                        "afternoon": "tarde",
                                        "am": "a",
                                        "morning": "manhã",
                                        "night": "noite",
                                        "noon": "meio-dia",
                                        "pm": "p"
                                    },
                                    "wide": {
                                        "afternoon": "tarde",
                                        "am": "AM",
                                        "morning": "manhã",
                                        "night": "noite",
                                        "noon": "meio-dia",
                                        "pm": "PM"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "afternoon": "tarde",
                                        "am": "AM",
                                        "morning": "manhã",
                                        "night": "noite",
                                        "noon": "meia-noite",
                                        "pm": "PM"
                                    },
                                    "narrow": {
                                        "afternoon": "tarde",
                                        "am": "a",
                                        "morning": "manhã",
                                        "night": "noite",
                                        "noon": "meio-dia",
                                        "pm": "p"
                                    },
                                    "wide": {
                                        "afternoon": "tarde",
                                        "am": "AM",
                                        "morning": "manhã",
                                        "night": "noite",
                                        "noon": "meio-dia",
                                        "pm": "PM"
                                    }
                                }
                            },
                            "eras": {
                                "eraNames": {
                                    "0": "Antes de Cristo",
                                    "1": "Ano do Senhor",
                                    "0-alt-variant": "BCE",
                                    "1-alt-variant": "CE"
                                },
                                "eraAbbr": {
                                    "0": "a.C.",
                                    "1": "d.C.",
                                    "0-alt-variant": "BCE",
                                    "1-alt-variant": "CE"
                                },
                                "eraNarrow": {
                                    "0": "a.C.",
                                    "1": "d.C.",
                                    "0-alt-variant": "BCE",
                                    "1-alt-variant": "CE"
                                }
                            },
                            "dateFormats": {
                                "full": "EEEE, d 'de' MMMM 'de' y",
                                "long": "d 'de' MMMM 'de' y",
                                "medium": "dd/MM/y",
                                "short": "dd/MM/yy"
                            },
                            "timeFormats": {
                                "full": "HH:mm:ss zzzz",
                                "long": "HH:mm:ss z",
                                "medium": "HH:mm:ss",
                                "short": "HH:mm"
                            },
                            "dateTimeFormats": {
                                "full": "{1} {0}",
                                "long": "{1} {0}",
                                "medium": "{1} {0}",
                                "short": "{1} {0}",
                                "availableFormats": {
                                    "d": "d",
                                    "Ed": "E, d",
                                    "Ehm": "E, h:mm a",
                                    "EHm": "E, HH:mm",
                                    "Ehms": "E, h:mm:ss a",
                                    "EHms": "E, HH:mm:ss",
                                    "Gy": "y G",
                                    "GyMMM": "MMM 'de' y G",
                                    "GyMMMd": "d 'de' MMM 'de' y G",
                                    "GyMMMEd": "E, d 'de' MMM 'de' y G",
                                    "h": "h a",
                                    "H": "HH",
                                    "HHmm": "HH:mm",
                                    "HHmmss": "HH:mm:ss",
                                    "hm": "h:mm a",
                                    "Hm": "HH:mm",
                                    "hms": "h:mm:ss a",
                                    "Hms": "HH:mm:ss",
                                    "M": "L",
                                    "Md": "d/M",
                                    "MEd": "E, dd/MM",
                                    "MMdd": "dd/MM",
                                    "MMM": "LLL",
                                    "MMMd": "d 'de' MMM",
                                    "MMMEd": "E, d 'de' MMM",
                                    "ms": "mm:ss",
                                    "y": "y",
                                    "yM": "MM/y",
                                    "yMd": "dd/MM/y",
                                    "yMEd": "E, dd/MM/y",
                                    "yMM": "MM/y",
                                    "yMMM": "MMM 'de' y",
                                    "yMMMd": "d 'de' MMM 'de' y",
                                    "yMMMEd": "E, d 'de' MMM 'de' y",
                                    "yQQQ": "y QQQ",
                                    "yQQQQ": "y QQQQ"
                                },
                                "appendItems": {
                                    "Day": "{0} ({2}: {1})",
                                    "Day-Of-Week": "{0} {1}",
                                    "Era": "{1} {0}",
                                    "Hour": "{0} ({2}: {1})",
                                    "Minute": "{0} ({2}: {1})",
                                    "Month": "{0} ({2}: {1})",
                                    "Quarter": "{0} ({2}: {1})",
                                    "Second": "{0} ({2}: {1})",
                                    "Timezone": "{0} {1}",
                                    "Week": "{0} ({2}: {1})",
                                    "Year": "{1} {0}"
                                },
                                "intervalFormats": {
                                    "intervalFormatFallback": "{0} - {1}",
                                    "d": {
                                        "d": "d-d"
                                    },
                                    "h": {
                                        "a": "h'h' a - h'h' a",
                                        "h": "h'h' - h'h' a"
                                    },
                                    "H": {
                                        "H": "HH'h' - HH'h'"
                                    },
                                    "hm": {
                                        "a": "h:mm a – h:mm a",
                                        "h": "h:mm–h:mm a",
                                        "m": "h:mm–h:mm a"
                                    },
                                    "Hm": {
                                        "H": "HH:mm–HH:mm",
                                        "m": "HH:mm–HH:mm"
                                    },
                                    "hmv": {
                                        "a": "h:mm a – h:mm a v",
                                        "h": "h:mm–h:mm a v",
                                        "m": "h:mm–h:mm a v"
                                    },
                                    "Hmv": {
                                        "H": "HH:mm–HH:mm v",
                                        "m": "HH:mm–HH:mm v"
                                    },
                                    "hv": {
                                        "a": "h a - h a v",
                                        "h": "h - h a v"
                                    },
                                    "Hv": {
                                        "H": "HH - HH v"
                                    },
                                    "M": {
                                        "M": "M-M"
                                    },
                                    "Md": {
                                        "d": "dd/MM - dd/MM",
                                        "M": "dd/MM - dd/MM"
                                    },
                                    "MEd": {
                                        "d": "E, dd/MM - E, dd/MM",
                                        "M": "E, dd/MM - E, dd/MM"
                                    },
                                    "MMM": {
                                        "M": "MMM - MMM"
                                    },
                                    "MMMd": {
                                        "d": "d-d 'de' MMM",
                                        "M": "d 'de' MMM - d 'de' MMM"
                                    },
                                    "MMMEd": {
                                        "d": "E, d - E, d 'de' MMM",
                                        "M": "E, d 'de' MMM - E, d 'de' MMM"
                                    },
                                    "y": {
                                        "y": "y - y"
                                    },
                                    "yM": {
                                        "M": "MM/y - MM/y",
                                        "y": "MM/y - MM/y"
                                    },
                                    "yMd": {
                                        "d": "dd/MM/y - dd/MM/y",
                                        "M": "dd/MM/y - dd/MM/y",
                                        "y": "dd/MM/y - dd/MM/y"
                                    },
                                    "yMEd": {
                                        "d": "E, dd/MM/y - E, dd/MM/y",
                                        "M": "E, dd/MM/y - E, dd/MM/y",
                                        "y": "E, dd/MM/y - E, dd/MM/y"
                                    },
                                    "yMMM": {
                                        "M": "MMM-MMM 'de' y",
                                        "y": "MMM 'de' y - MMM 'de' y"
                                    },
                                    "yMMMd": {
                                        "d": "d-d 'de' MMM 'de' y",
                                        "M": "d 'de' MMM - d 'de' MMM 'de' y",
                                        "y": "d 'de' MMM 'de' y - d 'de' MMM 'de' y"
                                    },
                                    "yMMMEd": {
                                        "d": "E, d - E, d 'de' MMM 'de' y",
                                        "M": "E, d 'de' MMM - E, d 'de' MMM 'de' y",
                                        "y": "E, d 'de' MMM 'de' y - E, d 'de' MMM 'de' y"
                                    },
                                    "yMMMM": {
                                        "M": "MMMM - MMMM 'de' y",
                                        "y": "MMMM 'de' y - MMMM 'de' y"
                                    }
                                }
                            }
                        }
                    },
                    "timeZoneNames": {
                        "hourFormat": "+HH:mm;-HH:mm",
                        "gmtFormat": "GMT{0}",
                        "gmtZeroFormat": "GMT",
                        "regionFormat": "Horário {0}",
                        "regionFormat-type-daylight": "{0} (+1)",
                        "regionFormat-type-standard": "{0} (+0)",
                        "fallbackFormat": "{1} ({0})"
                    }
                }
            },
            "pt-PT": {
                "dates": {
                    "calendars": {
                        "gregorian": {
                            "months": {
                                "format": {
                                    "abbreviated": {
                                        "1": "Jan",
                                        "2": "Fev",
                                        "3": "Mar",
                                        "4": "Abr",
                                        "5": "Mai",
                                        "6": "Jun",
                                        "7": "Jul",
                                        "8": "Ago",
                                        "9": "Set",
                                        "10": "Out",
                                        "11": "Nov",
                                        "12": "Dez"
                                    },
                                    "narrow": {
                                        "1": "J",
                                        "2": "F",
                                        "3": "M",
                                        "4": "A",
                                        "5": "M",
                                        "6": "J",
                                        "7": "J",
                                        "8": "A",
                                        "9": "S",
                                        "10": "O",
                                        "11": "N",
                                        "12": "D"
                                    },
                                    "wide": {
                                        "1": "Janeiro",
                                        "2": "Fevereiro",
                                        "3": "Março",
                                        "4": "Abril",
                                        "5": "Maio",
                                        "6": "Junho",
                                        "7": "Julho",
                                        "8": "Agosto",
                                        "9": "Setembro",
                                        "10": "Outubro",
                                        "11": "Novembro",
                                        "12": "Dezembro"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "1": "Jan",
                                        "2": "Fev",
                                        "3": "Mar",
                                        "4": "Abr",
                                        "5": "Mai",
                                        "6": "Jun",
                                        "7": "Jul",
                                        "8": "Ago",
                                        "9": "Set",
                                        "10": "Out",
                                        "11": "Nov",
                                        "12": "Dez"
                                    },
                                    "narrow": {
                                        "1": "J",
                                        "2": "F",
                                        "3": "M",
                                        "4": "A",
                                        "5": "M",
                                        "6": "J",
                                        "7": "J",
                                        "8": "A",
                                        "9": "S",
                                        "10": "O",
                                        "11": "N",
                                        "12": "D"
                                    },
                                    "wide": {
                                        "1": "Janeiro",
                                        "2": "Fevereiro",
                                        "3": "Março",
                                        "4": "Abril",
                                        "5": "Maio",
                                        "6": "Junho",
                                        "7": "Julho",
                                        "8": "Agosto",
                                        "9": "Setembro",
                                        "10": "Outubro",
                                        "11": "Novembro",
                                        "12": "Dezembro"
                                    }
                                }
                            },
                            "days": {
                                "format": {
                                    "abbreviated": {
                                        "sun": "dom",
                                        "mon": "seg",
                                        "tue": "ter",
                                        "wed": "qua",
                                        "thu": "qui",
                                        "fri": "sex",
                                        "sat": "sáb"
                                    },
                                    "narrow": {
                                        "sun": "D",
                                        "mon": "S",
                                        "tue": "T",
                                        "wed": "Q",
                                        "thu": "Q",
                                        "fri": "S",
                                        "sat": "S"
                                    },
                                    "short": {
                                        "sun": "do",
                                        "mon": "sg",
                                        "tue": "te",
                                        "wed": "qu",
                                        "thu": "qi",
                                        "fri": "sx",
                                        "sat": "sb"
                                    },
                                    "wide": {
                                        "sun": "domingo",
                                        "mon": "segunda-feira",
                                        "tue": "terça-feira",
                                        "wed": "quarta-feira",
                                        "thu": "quinta-feira",
                                        "fri": "sexta-feira",
                                        "sat": "sábado"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "sun": "dom",
                                        "mon": "seg",
                                        "tue": "ter",
                                        "wed": "qua",
                                        "thu": "qui",
                                        "fri": "sex",
                                        "sat": "sáb"
                                    },
                                    "narrow": {
                                        "sun": "D",
                                        "mon": "S",
                                        "tue": "T",
                                        "wed": "Q",
                                        "thu": "Q",
                                        "fri": "S",
                                        "sat": "S"
                                    },
                                    "short": {
                                        "sun": "do",
                                        "mon": "sg",
                                        "tue": "te",
                                        "wed": "qu",
                                        "thu": "qi",
                                        "fri": "sx",
                                        "sat": "sb"
                                    },
                                    "wide": {
                                        "sun": "domingo",
                                        "mon": "segunda-feira",
                                        "tue": "terça-feira",
                                        "wed": "quarta-feira",
                                        "thu": "quinta-feira",
                                        "fri": "sexta-feira",
                                        "sat": "sábado"
                                    }
                                }
                            },
                            "quarters": {
                                "format": {
                                    "abbreviated": {
                                        "1": "T1",
                                        "2": "T2",
                                        "3": "T3",
                                        "4": "T4"
                                    },
                                    "narrow": {
                                        "1": "1",
                                        "2": "2",
                                        "3": "3",
                                        "4": "4"
                                    },
                                    "wide": {
                                        "1": "1.º trimestre",
                                        "2": "2.º trimestre",
                                        "3": "3.º trimestre",
                                        "4": "4.º trimestre"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "1": "T1",
                                        "2": "T2",
                                        "3": "T3",
                                        "4": "T4"
                                    },
                                    "narrow": {
                                        "1": "1",
                                        "2": "2",
                                        "3": "3",
                                        "4": "4"
                                    },
                                    "wide": {
                                        "1": "1.º trimestre",
                                        "2": "2.º trimestre",
                                        "3": "3.º trimestre",
                                        "4": "4.º trimestre"
                                    }
                                }
                            },
                            "dayPeriods": {
                                "format": {
                                    "abbreviated": {
                                        "afternoon": "tarde",
                                        "am": "a.m.",
                                        "morning": "manhã",
                                        "night": "noite",
                                        "noon": "meio-dia",
                                        "pm": "p.m."
                                    },
                                    "narrow": {
                                        "afternoon": "tarde",
                                        "am": "a.m.",
                                        "morning": "manhã",
                                        "night": "noite",
                                        "noon": "meio-dia",
                                        "pm": "p.m."
                                    },
                                    "wide": {
                                        "afternoon": "tarde",
                                        "am": "da manhã",
                                        "morning": "manhã",
                                        "night": "noite",
                                        "noon": "meio-dia",
                                        "pm": "da tarde"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "afternoon": "tarde",
                                        "am": "a.m.",
                                        "morning": "manhã",
                                        "night": "noite",
                                        "noon": "meia-noite",
                                        "pm": "p.m."
                                    },
                                    "narrow": {
                                        "afternoon": "tarde",
                                        "am": "a.m.",
                                        "morning": "manhã",
                                        "night": "noite",
                                        "noon": "meio-dia",
                                        "pm": "p.m."
                                    },
                                    "wide": {
                                        "afternoon": "tarde",
                                        "am": "a.m.",
                                        "morning": "manhã",
                                        "night": "noite",
                                        "noon": "meio-dia",
                                        "pm": "p.m."
                                    }
                                }
                            },
                            "eras": {
                                "eraNames": {
                                    "0": "Antes de Cristo",
                                    "1": "Ano do Senhor",
                                    "0-alt-variant": "a.E.C.",
                                    "1-alt-variant": "E.C."
                                },
                                "eraAbbr": {
                                    "0": "a.C.",
                                    "1": "d.C.",
                                    "0-alt-variant": "a.E.C.",
                                    "1-alt-variant": "E.C."
                                },
                                "eraNarrow": {
                                    "0": "a.C.",
                                    "1": "d.C.",
                                    "0-alt-variant": "a.E.C.",
                                    "1-alt-variant": "E.C."
                                }
                            },
                            "dateFormats": {
                                "full": "EEEE, d 'de' MMMM 'de' y",
                                "long": "d 'de' MMMM 'de' y",
                                "medium": "dd/MM/y",
                                "short": "dd/MM/yy"
                            },
                            "timeFormats": {
                                "full": "HH:mm:ss zzzz",
                                "long": "HH:mm:ss z",
                                "medium": "HH:mm:ss",
                                "short": "HH:mm"
                            },
                            "dateTimeFormats": {
                                "full": "{1} 'às' {0}",
                                "long": "{1} 'às' {0}",
                                "medium": "{1}, {0}",
                                "short": "{1}, {0}",
                                "availableFormats": {
                                    "d": "d",
                                    "Ed": "E, d",
                                    "Ehm": "E, h:mm a",
                                    "EHm": "E, HH:mm",
                                    "Ehms": "E, h:mm:ss a",
                                    "EHms": "E, HH:mm:ss",
                                    "Gy": "y G",
                                    "GyMMM": "MMM 'de' y G",
                                    "GyMMMd": "d 'de' MMM 'de' y G",
                                    "GyMMMEd": "E, d 'de' MMM 'de' y G",
                                    "h": "h a",
                                    "H": "HH",
                                    "HHmm": "HH:mm",
                                    "HHmmss": "HH:mm:ss",
                                    "hm": "h:mm a",
                                    "Hm": "HH:mm",
                                    "hms": "h:mm:ss a",
                                    "Hms": "HH:mm:ss",
                                    "M": "L",
                                    "Md": "d/M",
                                    "MEd": "E, dd/MM",
                                    "MMdd": "dd/MM",
                                    "MMM": "LLL",
                                    "MMMd": "d/MM",
                                    "MMMEd": "E, d/MM",
                                    "MMMMd": "d 'de' MMMM",
                                    "MMMMEd": "E, d 'de' MMMM",
                                    "ms": "mm:ss",
                                    "y": "y",
                                    "yM": "MM/y",
                                    "yMd": "dd/MM/y",
                                    "yMEd": "E, dd/MM/y",
                                    "yMM": "MM/y",
                                    "yMMM": "MM/y",
                                    "yMMMd": "d/MM/y",
                                    "yMMMEd": "E, d/MM/y",
                                    "yMMMEEEEd": "EEEE, d/MM/y",
                                    "yMMMM": "MMMM 'de' y",
                                    "yMMMMd": "d 'de' MMMM 'de' y",
                                    "yMMMMEd": "E, d 'de' MMMM 'de' y",
                                    "yQQQ": "QQQQ 'de' y",
                                    "yQQQQ": "QQQQ 'de' y"
                                },
                                "appendItems": {
                                    "Day": "{0} ({2}: {1})",
                                    "Day-Of-Week": "{0} {1}",
                                    "Era": "{1} {0}",
                                    "Hour": "{0} ({2}: {1})",
                                    "Minute": "{0} ({2}: {1})",
                                    "Month": "{0} ({2}: {1})",
                                    "Quarter": "{0} ({2}: {1})",
                                    "Second": "{0} ({2}: {1})",
                                    "Timezone": "{0} {1}",
                                    "Week": "{0} ({2}: {1})",
                                    "Year": "{1} {0}"
                                },
                                "intervalFormats": {
                                    "intervalFormatFallback": "{0} - {1}",
                                    "d": {
                                        "d": "d–d"
                                    },
                                    "h": {
                                        "a": "h a - h a",
                                        "h": "h-h a"
                                    },
                                    "H": {
                                        "H": "HH–HH"
                                    },
                                    "hm": {
                                        "a": "h:mm a - h:mm a",
                                        "h": "h:mm - h:mm a",
                                        "m": "h:mm - h:mm a"
                                    },
                                    "Hm": {
                                        "H": "HH:mm - HH:mm",
                                        "m": "HH:mm - HH:mm"
                                    },
                                    "hmv": {
                                        "a": "h:mm a – h:mm a v",
                                        "h": "h:mm - h:mm a v",
                                        "m": "h:mm - h:mm a v"
                                    },
                                    "Hmv": {
                                        "H": "HH:mm - HH:mm v",
                                        "m": "HH:mm - HH:mm v"
                                    },
                                    "hv": {
                                        "a": "h a - h a v",
                                        "h": "h - h a v"
                                    },
                                    "Hv": {
                                        "H": "HH - HH v"
                                    },
                                    "M": {
                                        "M": "M-M"
                                    },
                                    "Md": {
                                        "d": "dd/MM - dd/MM",
                                        "M": "dd/MM - dd/MM"
                                    },
                                    "MEd": {
                                        "d": "E, dd/MM - E, dd/MM",
                                        "M": "E, dd/MM - E, dd/MM"
                                    },
                                    "MMM": {
                                        "M": "MMM-MMM"
                                    },
                                    "MMMd": {
                                        "d": "d-d 'de' MMM",
                                        "M": "d 'de' MMM - d 'de' MMM"
                                    },
                                    "MMMEd": {
                                        "d": "E, d 'de' MMM - E, d 'de' MMM",
                                        "M": "E, d 'de' MMM - E, d 'de' MMM"
                                    },
                                    "y": {
                                        "y": "y-y"
                                    },
                                    "yM": {
                                        "M": "MM/y - MM/y",
                                        "y": "MM/y - MM/y"
                                    },
                                    "yMd": {
                                        "d": "dd/MM/y - dd/MM/y",
                                        "M": "dd/MM/y - dd/MM/y",
                                        "y": "dd/MM/y - dd/MM/y"
                                    },
                                    "yMEd": {
                                        "d": "E, dd/MM/y - E, dd/MM/y",
                                        "M": "E, dd/MM/y - E, dd/MM/y",
                                        "y": "E, dd/MM/y - E, dd/MM/y"
                                    },
                                    "yMMM": {
                                        "M": "MMM-MMM 'de' y",
                                        "y": "MMM 'de' y - MMM 'de' y"
                                    },
                                    "yMMMd": {
                                        "d": "d-d 'de' MMM 'de' y",
                                        "M": "d 'de' MMM - d 'de' MMM 'de' y",
                                        "y": "d 'de' MMM 'de' y - d 'de' MMM 'de' y"
                                    },
                                    "yMMMEd": {
                                        "d": "E, d 'de' MMM - E, d 'de' MMM 'de' y",
                                        "M": "E, d 'de' MMM - E, d 'de' MMM 'de' y",
                                        "y": "E, d 'de' MMM 'de' y - E, d 'de' MMM 'de' y"
                                    },
                                    "yMMMM": {
                                        "M": "MMMM - MMMM 'de' y",
                                        "y": "MMMM 'de' y - MMMM 'de' y"
                                    }
                                }
                            }
                        }
                    },
                    "timeZoneNames": {
                        "hourFormat": "+HH:mm;-HH:mm",
                        "gmtFormat": "GMT{0}",
                        "gmtZeroFormat": "GMT",
                        "regionFormat": "Hora de {0}",
                        "regionFormat-type-daylight": "Hora de Verão de {0}",
                        "regionFormat-type-standard": "Hora Padrão de {0}",
                        "fallbackFormat": "{1} ({0})"
                    }
                }
            },
            "ro": {
                "dates": {
                    "calendars": {
                        "gregorian": {
                            "months": {
                                "format": {
                                    "abbreviated": {
                                        "1": "ian.",
                                        "2": "feb.",
                                        "3": "mar.",
                                        "4": "apr.",
                                        "5": "mai",
                                        "6": "iun.",
                                        "7": "iul.",
                                        "8": "aug.",
                                        "9": "sept.",
                                        "10": "oct.",
                                        "11": "nov.",
                                        "12": "dec."
                                    },
                                    "narrow": {
                                        "1": "I",
                                        "2": "F",
                                        "3": "M",
                                        "4": "A",
                                        "5": "M",
                                        "6": "I",
                                        "7": "I",
                                        "8": "A",
                                        "9": "S",
                                        "10": "O",
                                        "11": "N",
                                        "12": "D"
                                    },
                                    "wide": {
                                        "1": "ianuarie",
                                        "2": "februarie",
                                        "3": "martie",
                                        "4": "aprilie",
                                        "5": "mai",
                                        "6": "iunie",
                                        "7": "iulie",
                                        "8": "august",
                                        "9": "septembrie",
                                        "10": "octombrie",
                                        "11": "noiembrie",
                                        "12": "decembrie"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "1": "ian.",
                                        "2": "feb.",
                                        "3": "mar.",
                                        "4": "apr.",
                                        "5": "mai",
                                        "6": "iun.",
                                        "7": "iul.",
                                        "8": "aug.",
                                        "9": "sept.",
                                        "10": "oct.",
                                        "11": "nov.",
                                        "12": "dec."
                                    },
                                    "narrow": {
                                        "1": "I",
                                        "2": "F",
                                        "3": "M",
                                        "4": "A",
                                        "5": "M",
                                        "6": "I",
                                        "7": "I",
                                        "8": "A",
                                        "9": "S",
                                        "10": "O",
                                        "11": "N",
                                        "12": "D"
                                    },
                                    "wide": {
                                        "1": "ianuarie",
                                        "2": "februarie",
                                        "3": "martie",
                                        "4": "aprilie",
                                        "5": "mai",
                                        "6": "iunie",
                                        "7": "iulie",
                                        "8": "august",
                                        "9": "septembrie",
                                        "10": "octombrie",
                                        "11": "noiembrie",
                                        "12": "decembrie"
                                    }
                                }
                            },
                            "days": {
                                "format": {
                                    "abbreviated": {
                                        "sun": "Dum",
                                        "mon": "Lun",
                                        "tue": "Mar",
                                        "wed": "Mie",
                                        "thu": "Joi",
                                        "fri": "Vin",
                                        "sat": "Sâm"
                                    },
                                    "narrow": {
                                        "sun": "D",
                                        "mon": "L",
                                        "tue": "M",
                                        "wed": "M",
                                        "thu": "J",
                                        "fri": "V",
                                        "sat": "S"
                                    },
                                    "short": {
                                        "sun": "Du",
                                        "mon": "Lu",
                                        "tue": "Ma",
                                        "wed": "Mi",
                                        "thu": "Jo",
                                        "fri": "Vi",
                                        "sat": "Sâ"
                                    },
                                    "wide": {
                                        "sun": "duminică",
                                        "mon": "luni",
                                        "tue": "marți",
                                        "wed": "miercuri",
                                        "thu": "joi",
                                        "fri": "vineri",
                                        "sat": "sâmbătă"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "sun": "Dum",
                                        "mon": "Lun",
                                        "tue": "Mar",
                                        "wed": "Mie",
                                        "thu": "Joi",
                                        "fri": "Vin",
                                        "sat": "Sâm"
                                    },
                                    "narrow": {
                                        "sun": "D",
                                        "mon": "L",
                                        "tue": "M",
                                        "wed": "M",
                                        "thu": "J",
                                        "fri": "V",
                                        "sat": "S"
                                    },
                                    "short": {
                                        "sun": "Du",
                                        "mon": "Lu",
                                        "tue": "Ma",
                                        "wed": "Mi",
                                        "thu": "Jo",
                                        "fri": "Vi",
                                        "sat": "Sâ"
                                    },
                                    "wide": {
                                        "sun": "duminică",
                                        "mon": "luni",
                                        "tue": "marți",
                                        "wed": "miercuri",
                                        "thu": "joi",
                                        "fri": "vineri",
                                        "sat": "sâmbătă"
                                    }
                                }
                            },
                            "quarters": {
                                "format": {
                                    "abbreviated": {
                                        "1": "trim. I",
                                        "2": "trim. II",
                                        "3": "trim. III",
                                        "4": "trim. IV"
                                    },
                                    "narrow": {
                                        "1": "1",
                                        "2": "2",
                                        "3": "3",
                                        "4": "4"
                                    },
                                    "wide": {
                                        "1": "trimestrul I",
                                        "2": "trimestrul al II-lea",
                                        "3": "trimestrul al III-lea",
                                        "4": "trimestrul al IV-lea"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "1": "T1",
                                        "2": "T2",
                                        "3": "T3",
                                        "4": "T4"
                                    },
                                    "narrow": {
                                        "1": "1",
                                        "2": "2",
                                        "3": "3",
                                        "4": "4"
                                    },
                                    "wide": {
                                        "1": "trimestrul I",
                                        "2": "trimestrul al II-lea",
                                        "3": "trimestrul al III-lea",
                                        "4": "trimestrul al IV-lea"
                                    }
                                }
                            },
                            "dayPeriods": {
                                "format": {
                                    "abbreviated": {
                                        "am": "a.m.",
                                        "pm": "p.m."
                                    },
                                    "narrow": {
                                        "am": "a.m.",
                                        "pm": "p.m."
                                    },
                                    "wide": {
                                        "am": "a.m.",
                                        "pm": "p.m."
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "am": "a.m.",
                                        "pm": "p.m."
                                    },
                                    "narrow": {
                                        "am": "a.m.",
                                        "pm": "p.m."
                                    },
                                    "wide": {
                                        "am": "a.m.",
                                        "pm": "p.m."
                                    }
                                }
                            },
                            "eras": {
                                "eraNames": {
                                    "0": "înainte de Hristos",
                                    "1": "după Hristos",
                                    "0-alt-variant": "î.e.n",
                                    "1-alt-variant": "e.n."
                                },
                                "eraAbbr": {
                                    "0": "î.Hr.",
                                    "1": "d.Hr.",
                                    "0-alt-variant": "î.e.n",
                                    "1-alt-variant": "e.n."
                                },
                                "eraNarrow": {
                                    "0": "î.Hr.",
                                    "1": "d.Hr.",
                                    "0-alt-variant": "î.e.n",
                                    "1-alt-variant": "e.n."
                                }
                            },
                            "dateFormats": {
                                "full": "EEEE, d MMMM y",
                                "long": "d MMMM y",
                                "medium": "d MMM y",
                                "short": "dd.MM.y"
                            },
                            "timeFormats": {
                                "full": "HH:mm:ss zzzz",
                                "long": "HH:mm:ss z",
                                "medium": "HH:mm:ss",
                                "short": "HH:mm"
                            },
                            "dateTimeFormats": {
                                "full": "{1}, {0}",
                                "long": "{1}, {0}",
                                "medium": "{1}, {0}",
                                "short": "{1}, {0}",
                                "availableFormats": {
                                    "d": "d",
                                    "Ed": "E d",
                                    "Ehm": "E h:mm a",
                                    "EHm": "E HH:mm",
                                    "Ehms": "E h:mm:ss a",
                                    "EHms": "E HH:mm:ss",
                                    "Gy": "y G",
                                    "GyMMM": "MMM y G",
                                    "GyMMMd": "d MMM y G",
                                    "GyMMMEd": "E, d MMM y G",
                                    "h": "h a",
                                    "H": "HH",
                                    "hm": "h:mm a",
                                    "Hm": "HH:mm",
                                    "hms": "h:mm:ss a",
                                    "Hms": "HH:mm:ss",
                                    "M": "L",
                                    "Md": "dd.MM",
                                    "MEd": "E, dd.MM",
                                    "MMdd": "dd.MM",
                                    "MMM": "LLL",
                                    "MMMd": "d MMM",
                                    "MMMEd": "E, d MMM",
                                    "MMMMd": "d MMMM",
                                    "MMMMEd": "E, d MMMM",
                                    "ms": "mm:ss",
                                    "y": "y",
                                    "yM": "MM.y",
                                    "yMd": "dd.MM.y",
                                    "yMEd": "E, dd.MM.y",
                                    "yMM": "MM.y",
                                    "yMMM": "MMM y",
                                    "yMMMd": "d MMM y",
                                    "yMMMEd": "E, d MMM y",
                                    "yMMMM": "MMMM y",
                                    "yQQQ": "QQQ y",
                                    "yQQQQ": "QQQQ y"
                                },
                                "appendItems": {
                                    "Day": "{0} ({2}: {1})",
                                    "Day-Of-Week": "{0} {1}",
                                    "Era": "{1} {0}",
                                    "Hour": "{0} ({2}: {1})",
                                    "Minute": "{0} ({2}: {1})",
                                    "Month": "{0} ({2}: {1})",
                                    "Quarter": "{0} ({2}: {1})",
                                    "Second": "{0} ({2}: {1})",
                                    "Timezone": "{0} {1}",
                                    "Week": "{0} ({2}: {1})",
                                    "Year": "{1} {0}"
                                },
                                "intervalFormats": {
                                    "intervalFormatFallback": "{0} - {1}",
                                    "d": {
                                        "d": "d-d"
                                    },
                                    "h": {
                                        "a": "h a - h a",
                                        "h": "h-h a"
                                    },
                                    "H": {
                                        "H": "HH-HH"
                                    },
                                    "hm": {
                                        "a": "h:mm a - h:mm a",
                                        "h": "h:mm-h:mm a",
                                        "m": "h:mm-h:mm a"
                                    },
                                    "Hm": {
                                        "H": "HH:mm-HH:mm",
                                        "m": "HH:mm-HH:mm"
                                    },
                                    "hmv": {
                                        "a": "h:mm a - h:mm a v",
                                        "h": "h:mm-h:mm a v",
                                        "m": "h:mm-h:mm a v"
                                    },
                                    "Hmv": {
                                        "H": "HH:mm-HH:mm v",
                                        "m": "HH:mm-HH:mm v"
                                    },
                                    "hv": {
                                        "a": "h a - h a v",
                                        "h": "h-h a v"
                                    },
                                    "Hv": {
                                        "H": "HH-HH v"
                                    },
                                    "M": {
                                        "M": "M-M"
                                    },
                                    "Md": {
                                        "d": "dd.MM - dd.MM",
                                        "M": "dd.MM - dd.MM"
                                    },
                                    "MEd": {
                                        "d": "E, dd.MM - E, dd.MM",
                                        "M": "E, dd.MM - E, dd.MM"
                                    },
                                    "MMM": {
                                        "M": "MMM-MMM"
                                    },
                                    "MMMd": {
                                        "d": "d-d MMM",
                                        "M": "d MMM - d MMM"
                                    },
                                    "MMMEd": {
                                        "d": "E, d MMM - E, d MMM",
                                        "M": "E, d MMM - E, d MMM"
                                    },
                                    "y": {
                                        "y": "y-y"
                                    },
                                    "yM": {
                                        "M": "MM.y - MM.y",
                                        "y": "MM.y - MM.y"
                                    },
                                    "yMd": {
                                        "d": "dd.MM.y - dd.MM.y",
                                        "M": "dd.MM.y - dd.MM.y",
                                        "y": "dd.MM.y - dd.MM.y"
                                    },
                                    "yMEd": {
                                        "d": "E, dd.MM.y - E, dd.MM.y",
                                        "M": "E, dd.MM.y - E, dd.MM.y",
                                        "y": "E, dd.MM.y - E, dd.MM.y"
                                    },
                                    "yMMM": {
                                        "M": "MMM-MMM y",
                                        "y": "MMM y - MMM y"
                                    },
                                    "yMMMd": {
                                        "d": "d-d MMM y",
                                        "M": "d MMM - d MMM y",
                                        "y": "d MMM y - d MMM y"
                                    },
                                    "yMMMEd": {
                                        "d": "E, d MMM - E, d MMM y",
                                        "M": "E, d MMM - E, d MMM y",
                                        "y": "E, d MMM y - E, d MMM y"
                                    },
                                    "yMMMM": {
                                        "M": "MMMM - MMMM y",
                                        "y": "MMMM y – MMMM y"
                                    }
                                }
                            }
                        }
                    },
                    "timeZoneNames": {
                        "hourFormat": "+HH:mm;-HH:mm",
                        "gmtFormat": "GMT{0}",
                        "gmtZeroFormat": "GMT",
                        "regionFormat": "Ora din {0}",
                        "regionFormat-type-daylight": "Ora de vară din {0}",
                        "regionFormat-type-standard": "Ora standard din {0}",
                        "fallbackFormat": "{1} ({0})"
                    }
                }
            },
            "root": {
                "dates": {
                    "calendars": {
                        "gregorian": {
                            "months": {
                                "format": {
                                    "abbreviated": {
                                        "1": "M01",
                                        "2": "M02",
                                        "3": "M03",
                                        "4": "M04",
                                        "5": "M05",
                                        "6": "M06",
                                        "7": "M07",
                                        "8": "M08",
                                        "9": "M09",
                                        "10": "M10",
                                        "11": "M11",
                                        "12": "M12"
                                    },
                                    "narrow": {
                                        "1": "1",
                                        "2": "2",
                                        "3": "3",
                                        "4": "4",
                                        "5": "5",
                                        "6": "6",
                                        "7": "7",
                                        "8": "8",
                                        "9": "9",
                                        "10": "10",
                                        "11": "11",
                                        "12": "12"
                                    },
                                    "wide": {
                                        "1": "M01",
                                        "2": "M02",
                                        "3": "M03",
                                        "4": "M04",
                                        "5": "M05",
                                        "6": "M06",
                                        "7": "M07",
                                        "8": "M08",
                                        "9": "M09",
                                        "10": "M10",
                                        "11": "M11",
                                        "12": "M12"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "1": "M01",
                                        "2": "M02",
                                        "3": "M03",
                                        "4": "M04",
                                        "5": "M05",
                                        "6": "M06",
                                        "7": "M07",
                                        "8": "M08",
                                        "9": "M09",
                                        "10": "M10",
                                        "11": "M11",
                                        "12": "M12"
                                    },
                                    "narrow": {
                                        "1": "1",
                                        "2": "2",
                                        "3": "3",
                                        "4": "4",
                                        "5": "5",
                                        "6": "6",
                                        "7": "7",
                                        "8": "8",
                                        "9": "9",
                                        "10": "10",
                                        "11": "11",
                                        "12": "12"
                                    },
                                    "wide": {
                                        "1": "M01",
                                        "2": "M02",
                                        "3": "M03",
                                        "4": "M04",
                                        "5": "M05",
                                        "6": "M06",
                                        "7": "M07",
                                        "8": "M08",
                                        "9": "M09",
                                        "10": "M10",
                                        "11": "M11",
                                        "12": "M12"
                                    }
                                }
                            },
                            "days": {
                                "format": {
                                    "abbreviated": {
                                        "sun": "Sun",
                                        "mon": "Mon",
                                        "tue": "Tue",
                                        "wed": "Wed",
                                        "thu": "Thu",
                                        "fri": "Fri",
                                        "sat": "Sat"
                                    },
                                    "narrow": {
                                        "sun": "S",
                                        "mon": "M",
                                        "tue": "T",
                                        "wed": "W",
                                        "thu": "T",
                                        "fri": "F",
                                        "sat": "S"
                                    },
                                    "short": {
                                        "sun": "Sun",
                                        "mon": "Mon",
                                        "tue": "Tue",
                                        "wed": "Wed",
                                        "thu": "Thu",
                                        "fri": "Fri",
                                        "sat": "Sat"
                                    },
                                    "wide": {
                                        "sun": "Sun",
                                        "mon": "Mon",
                                        "tue": "Tue",
                                        "wed": "Wed",
                                        "thu": "Thu",
                                        "fri": "Fri",
                                        "sat": "Sat"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "sun": "Sun",
                                        "mon": "Mon",
                                        "tue": "Tue",
                                        "wed": "Wed",
                                        "thu": "Thu",
                                        "fri": "Fri",
                                        "sat": "Sat"
                                    },
                                    "narrow": {
                                        "sun": "S",
                                        "mon": "M",
                                        "tue": "T",
                                        "wed": "W",
                                        "thu": "T",
                                        "fri": "F",
                                        "sat": "S"
                                    },
                                    "short": {
                                        "sun": "Sun",
                                        "mon": "Mon",
                                        "tue": "Tue",
                                        "wed": "Wed",
                                        "thu": "Thu",
                                        "fri": "Fri",
                                        "sat": "Sat"
                                    },
                                    "wide": {
                                        "sun": "Sun",
                                        "mon": "Mon",
                                        "tue": "Tue",
                                        "wed": "Wed",
                                        "thu": "Thu",
                                        "fri": "Fri",
                                        "sat": "Sat"
                                    }
                                }
                            },
                            "quarters": {
                                "format": {
                                    "abbreviated": {
                                        "1": "Q1",
                                        "2": "Q2",
                                        "3": "Q3",
                                        "4": "Q4"
                                    },
                                    "narrow": {
                                        "1": "1",
                                        "2": "2",
                                        "3": "3",
                                        "4": "4"
                                    },
                                    "wide": {
                                        "1": "Q1",
                                        "2": "Q2",
                                        "3": "Q3",
                                        "4": "Q4"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "1": "Q1",
                                        "2": "Q2",
                                        "3": "Q3",
                                        "4": "Q4"
                                    },
                                    "narrow": {
                                        "1": "1",
                                        "2": "2",
                                        "3": "3",
                                        "4": "4"
                                    },
                                    "wide": {
                                        "1": "Q1",
                                        "2": "Q2",
                                        "3": "Q3",
                                        "4": "Q4"
                                    }
                                }
                            },
                            "dayPeriods": {
                                "format": {
                                    "abbreviated": {
                                        "am": "AM",
                                        "pm": "PM"
                                    },
                                    "narrow": {
                                        "am": "AM",
                                        "pm": "PM"
                                    },
                                    "wide": {
                                        "am": "AM",
                                        "pm": "PM"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "am": "AM",
                                        "pm": "PM"
                                    },
                                    "narrow": {
                                        "am": "AM",
                                        "pm": "PM"
                                    },
                                    "wide": {
                                        "am": "AM",
                                        "pm": "PM"
                                    }
                                }
                            },
                            "eras": {
                                "eraNames": {
                                    "0": "BCE",
                                    "1": "CE",
                                    "0-alt-variant": "BCE",
                                    "1-alt-variant": "CE"
                                },
                                "eraAbbr": {
                                    "0": "BCE",
                                    "1": "CE",
                                    "0-alt-variant": "BCE",
                                    "1-alt-variant": "CE"
                                },
                                "eraNarrow": {
                                    "0": "BCE",
                                    "1": "CE",
                                    "0-alt-variant": "BCE",
                                    "1-alt-variant": "CE"
                                }
                            },
                            "dateFormats": {
                                "full": "y MMMM d, EEEE",
                                "long": "y MMMM d",
                                "medium": "y MMM d",
                                "short": "y-MM-dd"
                            },
                            "timeFormats": {
                                "full": "HH:mm:ss zzzz",
                                "long": "HH:mm:ss z",
                                "medium": "HH:mm:ss",
                                "short": "HH:mm"
                            },
                            "dateTimeFormats": {
                                "full": "{1} {0}",
                                "long": "{1} {0}",
                                "medium": "{1} {0}",
                                "short": "{1} {0}",
                                "availableFormats": {
                                    "d": "d",
                                    "Ed": "d, E",
                                    "Ehm": "E h:mm a",
                                    "EHm": "E HH:mm",
                                    "Ehms": "E h:mm:ss a",
                                    "EHms": "E HH:mm:ss",
                                    "Gy": "G y",
                                    "GyMMM": "G y MMM",
                                    "GyMMMd": "G y MMM d",
                                    "GyMMMEd": "G y MMM d, E",
                                    "h": "h a",
                                    "H": "HH",
                                    "hm": "h:mm a",
                                    "Hm": "HH:mm",
                                    "hms": "h:mm:ss a",
                                    "Hms": "HH:mm:ss",
                                    "M": "L",
                                    "Md": "MM-dd",
                                    "MEd": "MM-dd, E",
                                    "MMM": "LLL",
                                    "MMMd": "MMM d",
                                    "MMMEd": "MMM d, E",
                                    "ms": "mm:ss",
                                    "y": "y",
                                    "yM": "y-MM",
                                    "yMd": "y-MM-dd",
                                    "yMEd": "y-MM-dd, E",
                                    "yMMM": "y MMM",
                                    "yMMMd": "y MMM d",
                                    "yMMMEd": "y MMM d, E",
                                    "yQQQ": "y QQQ",
                                    "yQQQQ": "y QQQQ"
                                },
                                "appendItems": {
                                    "Day": "{0} ({2}: {1})",
                                    "Day-Of-Week": "{0} {1}",
                                    "Era": "{1} {0}",
                                    "Hour": "{0} ({2}: {1})",
                                    "Minute": "{0} ({2}: {1})",
                                    "Month": "{0} ({2}: {1})",
                                    "Quarter": "{0} ({2}: {1})",
                                    "Second": "{0} ({2}: {1})",
                                    "Timezone": "{0} {1}",
                                    "Week": "{0} ({2}: {1})",
                                    "Year": "{1} {0}"
                                },
                                "intervalFormats": {
                                    "intervalFormatFallback": "{0} – {1}",
                                    "d": {
                                        "d": "d–d"
                                    },
                                    "h": {
                                        "a": "h a – h a",
                                        "h": "h–h a"
                                    },
                                    "H": {
                                        "H": "HH–HH"
                                    },
                                    "hm": {
                                        "a": "h:mm a – h:mm a",
                                        "h": "h:mm–h:mm a",
                                        "m": "h:mm–h:mm a"
                                    },
                                    "Hm": {
                                        "H": "HH:mm–HH:mm",
                                        "m": "HH:mm–HH:mm"
                                    },
                                    "hmv": {
                                        "a": "h:mm a – h:mm a v",
                                        "h": "h:mm–h:mm a v",
                                        "m": "h:mm–h:mm a v"
                                    },
                                    "Hmv": {
                                        "H": "HH:mm–HH:mm v",
                                        "m": "HH:mm–HH:mm v"
                                    },
                                    "hv": {
                                        "a": "h a – h a v",
                                        "h": "h–h a v"
                                    },
                                    "Hv": {
                                        "H": "HH–HH v"
                                    },
                                    "M": {
                                        "M": "MM–MM"
                                    },
                                    "Md": {
                                        "d": "MM-dd – MM-dd",
                                        "M": "MM-dd – MM-dd"
                                    },
                                    "MEd": {
                                        "d": "MM-dd, E – MM-dd, E",
                                        "M": "MM-dd, E – MM-dd, E"
                                    },
                                    "MMM": {
                                        "M": "LLL–LLL"
                                    },
                                    "MMMd": {
                                        "d": "MMM d–d",
                                        "M": "MMM d – MMM d"
                                    },
                                    "MMMEd": {
                                        "d": "MMM d, E – MMM d, E",
                                        "M": "MMM d, E – MMM d, E"
                                    },
                                    "y": {
                                        "y": "y–y"
                                    },
                                    "yM": {
                                        "M": "y-MM – y-MM",
                                        "y": "y-MM – y-MM"
                                    },
                                    "yMd": {
                                        "d": "y-MM-dd – y-MM-dd",
                                        "M": "y-MM-dd – y-MM-dd",
                                        "y": "y-MM-dd – y-MM-dd"
                                    },
                                    "yMEd": {
                                        "d": "y-MM-dd, E – y-MM-dd, E",
                                        "M": "y-MM-dd, E – y-MM-dd, E",
                                        "y": "y-MM-dd, E – y-MM-dd, E"
                                    },
                                    "yMMM": {
                                        "M": "y MMM–MMM",
                                        "y": "y MMM – y MMM"
                                    },
                                    "yMMMd": {
                                        "d": "y MMM d–d",
                                        "M": "y MMM d – MMM d",
                                        "y": "y MMM d – y MMM d"
                                    },
                                    "yMMMEd": {
                                        "d": "y MMM d, E – MMM d, E",
                                        "M": "y MMM d, E – MMM d, E",
                                        "y": "y MMM d, E – y MMM d, E"
                                    },
                                    "yMMMM": {
                                        "M": "y MMMM–MMMM",
                                        "y": "y MMMM – y MMMM"
                                    }
                                }
                            }
                        }
                    },
                    "timeZoneNames": {
                        "hourFormat": "+HH:mm;-HH:mm",
                        "gmtFormat": "GMT{0}",
                        "gmtZeroFormat": "GMT",
                        "regionFormat": "{0}",
                        "regionFormat-type-daylight": "{0} (+1)",
                        "regionFormat-type-standard": "{0} (+0)",
                        "fallbackFormat": "{1} ({0})"
                    }
                }
            },
            "ru": {
                "dates": {
                    "calendars": {
                        "gregorian": {
                            "months": {
                                "format": {
                                    "abbreviated": {
                                        "1": "янв.",
                                        "2": "февр.",
                                        "3": "марта",
                                        "4": "апр.",
                                        "5": "мая",
                                        "6": "июня",
                                        "7": "июля",
                                        "8": "авг.",
                                        "9": "сент.",
                                        "10": "окт.",
                                        "11": "нояб.",
                                        "12": "дек."
                                    },
                                    "narrow": {
                                        "1": "Я",
                                        "2": "Ф",
                                        "3": "М",
                                        "4": "А",
                                        "5": "М",
                                        "6": "И",
                                        "7": "И",
                                        "8": "А",
                                        "9": "С",
                                        "10": "О",
                                        "11": "Н",
                                        "12": "Д"
                                    },
                                    "wide": {
                                        "1": "января",
                                        "2": "февраля",
                                        "3": "марта",
                                        "4": "апреля",
                                        "5": "мая",
                                        "6": "июня",
                                        "7": "июля",
                                        "8": "августа",
                                        "9": "сентября",
                                        "10": "октября",
                                        "11": "ноября",
                                        "12": "декабря"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "1": "Янв.",
                                        "2": "Февр.",
                                        "3": "Март",
                                        "4": "Апр.",
                                        "5": "Май",
                                        "6": "Июнь",
                                        "7": "Июль",
                                        "8": "Авг.",
                                        "9": "Сент.",
                                        "10": "Окт.",
                                        "11": "Нояб.",
                                        "12": "Дек."
                                    },
                                    "narrow": {
                                        "1": "Я",
                                        "2": "Ф",
                                        "3": "М",
                                        "4": "А",
                                        "5": "М",
                                        "6": "И",
                                        "7": "И",
                                        "8": "А",
                                        "9": "С",
                                        "10": "О",
                                        "11": "Н",
                                        "12": "Д"
                                    },
                                    "wide": {
                                        "1": "Январь",
                                        "2": "Февраль",
                                        "3": "Март",
                                        "4": "Апрель",
                                        "5": "Май",
                                        "6": "Июнь",
                                        "7": "Июль",
                                        "8": "Август",
                                        "9": "Сентябрь",
                                        "10": "Октябрь",
                                        "11": "Ноябрь",
                                        "12": "Декабрь"
                                    }
                                }
                            },
                            "days": {
                                "format": {
                                    "abbreviated": {
                                        "sun": "вс",
                                        "mon": "пн",
                                        "tue": "вт",
                                        "wed": "ср",
                                        "thu": "чт",
                                        "fri": "пт",
                                        "sat": "сб"
                                    },
                                    "narrow": {
                                        "sun": "вс",
                                        "mon": "пн",
                                        "tue": "вт",
                                        "wed": "ср",
                                        "thu": "чт",
                                        "fri": "пт",
                                        "sat": "сб"
                                    },
                                    "short": {
                                        "sun": "вс",
                                        "mon": "пн",
                                        "tue": "вт",
                                        "wed": "ср",
                                        "thu": "чт",
                                        "fri": "пт",
                                        "sat": "сб"
                                    },
                                    "wide": {
                                        "sun": "воскресенье",
                                        "mon": "понедельник",
                                        "tue": "вторник",
                                        "wed": "среда",
                                        "thu": "четверг",
                                        "fri": "пятница",
                                        "sat": "суббота"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "sun": "Вс",
                                        "mon": "Пн",
                                        "tue": "Вт",
                                        "wed": "Ср",
                                        "thu": "Чт",
                                        "fri": "Пт",
                                        "sat": "Сб"
                                    },
                                    "narrow": {
                                        "sun": "В",
                                        "mon": "П",
                                        "tue": "В",
                                        "wed": "С",
                                        "thu": "Ч",
                                        "fri": "П",
                                        "sat": "С"
                                    },
                                    "short": {
                                        "sun": "вс",
                                        "mon": "пн",
                                        "tue": "вт",
                                        "wed": "ср",
                                        "thu": "чт",
                                        "fri": "пт",
                                        "sat": "сб"
                                    },
                                    "wide": {
                                        "sun": "Воскресенье",
                                        "mon": "Понедельник",
                                        "tue": "Вторник",
                                        "wed": "Среда",
                                        "thu": "Четверг",
                                        "fri": "Пятница",
                                        "sat": "Суббота"
                                    }
                                }
                            },
                            "quarters": {
                                "format": {
                                    "abbreviated": {
                                        "1": "1-й кв.",
                                        "2": "2-й кв.",
                                        "3": "3-й кв.",
                                        "4": "4-й кв."
                                    },
                                    "narrow": {
                                        "1": "1",
                                        "2": "2",
                                        "3": "3",
                                        "4": "4"
                                    },
                                    "wide": {
                                        "1": "1-й квартал",
                                        "2": "2-й квартал",
                                        "3": "3-й квартал",
                                        "4": "4-й квартал"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "1": "1-й кв.",
                                        "2": "2-й кв.",
                                        "3": "3-й кв.",
                                        "4": "4-й кв."
                                    },
                                    "narrow": {
                                        "1": "1",
                                        "2": "2",
                                        "3": "3",
                                        "4": "4"
                                    },
                                    "wide": {
                                        "1": "1-й квартал",
                                        "2": "2-й квартал",
                                        "3": "3-й квартал",
                                        "4": "4-й квартал"
                                    }
                                }
                            },
                            "dayPeriods": {
                                "format": {
                                    "abbreviated": {
                                        "am": "до полудня",
                                        "pm": "после полудня"
                                    },
                                    "narrow": {
                                        "am": "дп",
                                        "pm": "пп"
                                    },
                                    "wide": {
                                        "am": "до полудня",
                                        "pm": "после полудня"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "am": "до полудня",
                                        "pm": "после полудня"
                                    },
                                    "narrow": {
                                        "am": "дп",
                                        "pm": "пп"
                                    },
                                    "wide": {
                                        "am": "до полудня",
                                        "pm": "после полудня"
                                    }
                                }
                            },
                            "eras": {
                                "eraNames": {
                                    "0": "до н.э.",
                                    "1": "н.э.",
                                    "0-alt-variant": "BCE",
                                    "1-alt-variant": "н.э."
                                },
                                "eraAbbr": {
                                    "0": "до н. э.",
                                    "1": "н. э.",
                                    "0-alt-variant": "BCE",
                                    "1-alt-variant": "н.э."
                                },
                                "eraNarrow": {
                                    "0": "до н.э.",
                                    "1": "н.э.",
                                    "0-alt-variant": "BCE",
                                    "1-alt-variant": "н.э."
                                }
                            },
                            "dateFormats": {
                                "full": "EEEE, d MMMM y 'г'.",
                                "long": "d MMMM y 'г'.",
                                "medium": "dd MMM y 'г'.",
                                "short": "dd.MM.yy"
                            },
                            "timeFormats": {
                                "full": "H:mm:ss zzzz",
                                "long": "H:mm:ss z",
                                "medium": "H:mm:ss",
                                "short": "H:mm"
                            },
                            "dateTimeFormats": {
                                "full": "{1}, {0}",
                                "long": "{1}, {0}",
                                "medium": "{1}, {0}",
                                "short": "{1}, {0}",
                                "availableFormats": {
                                    "d": "d",
                                    "E": "ccc",
                                    "Ed": "ccc, d",
                                    "Ehm": "E h:mm a",
                                    "EHm": "E HH:mm",
                                    "Ehms": "E h:mm:ss a",
                                    "EHms": "E HH:mm:ss",
                                    "Gy": "y G",
                                    "GyMMM": "LLL y G",
                                    "GyMMMd": "d MMM y 'г'. G",
                                    "GyMMMEd": "E, d MMM y G",
                                    "h": "h a",
                                    "H": "H",
                                    "hm": "h:mm a",
                                    "Hm": "H:mm",
                                    "hms": "h:mm:ss a",
                                    "Hms": "H:mm:ss",
                                    "M": "L",
                                    "Md": "dd.MM",
                                    "MEd": "E, dd.MM",
                                    "MMdd": "dd.MM",
                                    "MMM": "LLL",
                                    "MMMd": "d MMM",
                                    "MMMEd": "ccc, d MMM",
                                    "ms": "mm:ss",
                                    "y": "y",
                                    "yLLLL": "LLLL y",
                                    "yM": "MM.y",
                                    "yMd": "dd.MM.y",
                                    "yMEd": "ccc, d.MM.y 'г'.",
                                    "yMM": "MM.y",
                                    "yMMM": "LLL y",
                                    "yMMMd": "d MMM y 'г'.",
                                    "yMMMEd": "E, d MMM y",
                                    "yMMMM": "LLLL y",
                                    "yQQQ": "QQQ y 'г'.",
                                    "yQQQQ": "QQQQ y 'г'."
                                },
                                "appendItems": {
                                    "Day": "{0} ({2}: {1})",
                                    "Day-Of-Week": "{0} {1}",
                                    "Era": "{1} {0}",
                                    "Hour": "{0} ({2}: {1})",
                                    "Minute": "{0} ({2}: {1})",
                                    "Month": "{0} ({2}: {1})",
                                    "Quarter": "{0} ({2}: {1})",
                                    "Second": "{0} ({2}: {1})",
                                    "Timezone": "{0} {1}",
                                    "Week": "{0} ({2}: {1})",
                                    "Year": "{1} {0}"
                                },
                                "intervalFormats": {
                                    "intervalFormatFallback": "{0} - {1}",
                                    "d": {
                                        "d": "d-d"
                                    },
                                    "h": {
                                        "a": "h a - h a",
                                        "h": "h-h a"
                                    },
                                    "H": {
                                        "H": "H-H"
                                    },
                                    "hm": {
                                        "a": "h:mm a - h:mm a",
                                        "h": "h:mm-h:mm a",
                                        "m": "h:mm-h:mm a"
                                    },
                                    "Hm": {
                                        "H": "H:mm-H:mm",
                                        "m": "H:mm-H:mm"
                                    },
                                    "hmv": {
                                        "a": "h:mm a - h:mm a v",
                                        "h": "h:mm-h:mm a v",
                                        "m": "h:mm-h:mm a v"
                                    },
                                    "Hmv": {
                                        "H": "H:mm-H:mm v",
                                        "m": "H:mm-H:mm v"
                                    },
                                    "hv": {
                                        "a": "h a - h a v",
                                        "h": "h-h a v"
                                    },
                                    "Hv": {
                                        "H": "H-H v"
                                    },
                                    "M": {
                                        "M": "M-M"
                                    },
                                    "Md": {
                                        "d": "dd.MM - dd.MM",
                                        "M": "dd.MM - dd.MM"
                                    },
                                    "MEd": {
                                        "d": "E, dd.MM - E, dd.MM",
                                        "M": "E, dd.MM - E, dd.MM"
                                    },
                                    "MMM": {
                                        "M": "LLL-MMM"
                                    },
                                    "MMMd": {
                                        "d": "d-d MMM",
                                        "M": "d MMM - d MMM"
                                    },
                                    "MMMEd": {
                                        "d": "ccc, d - E, d MMM",
                                        "M": "ccc, d MMM - ccc, d MMM"
                                    },
                                    "MMMM": {
                                        "M": "LLLL-LLLL"
                                    },
                                    "y": {
                                        "y": "y-y"
                                    },
                                    "yM": {
                                        "M": "MM.y - MM.y",
                                        "y": "MM.y - MM.y"
                                    },
                                    "yMd": {
                                        "d": "dd.MM.y - dd.MM.y",
                                        "M": "dd.MM.y - dd.MM.y",
                                        "y": "dd.MM.y - dd.MM.y"
                                    },
                                    "yMEd": {
                                        "d": "ccc, dd.MM.y - ccc, dd.MM.y",
                                        "M": "ccc, dd.MM.y - ccc, dd.MM.y",
                                        "y": "ccc, dd.MM.y - ccc, dd.MM.y"
                                    },
                                    "yMMM": {
                                        "M": "LLL-LLL y 'г'.",
                                        "y": "LLL y - LLL y 'г'."
                                    },
                                    "yMMMd": {
                                        "d": "d-d MMM y 'г'.",
                                        "M": "d MMM - d MMM y 'г'.",
                                        "y": "d MMM y - d MMM y 'г'."
                                    },
                                    "yMMMEd": {
                                        "d": "ccc, d - ccc, d MMM y 'г'.",
                                        "M": "ccc, d MMM - ccc, d MMM y 'г'.",
                                        "y": "ccc, d MMM y - ccc, d MMM y 'г'."
                                    },
                                    "yMMMM": {
                                        "M": "LLLL-LLLL y 'г'.",
                                        "y": "LLLL y - LLLL y 'г'."
                                    }
                                }
                            }
                        }
                    },
                    "timeZoneNames": {
                        "hourFormat": "+HH:mm;-HH:mm",
                        "gmtFormat": "GMT{0}",
                        "gmtZeroFormat": "GMT",
                        "regionFormat": "{0} время",
                        "regionFormat-type-daylight": "{0} (+1)",
                        "regionFormat-type-standard": "{0} (+0)",
                        "fallbackFormat": "{1} ({0})"
                    }
                }
            },
            "sk": {
                "dates": {
                    "calendars": {
                        "gregorian": {
                            "months": {
                                "format": {
                                    "abbreviated": {
                                        "1": "jan",
                                        "2": "feb",
                                        "3": "mar",
                                        "4": "apr",
                                        "5": "máj",
                                        "6": "jún",
                                        "7": "júl",
                                        "8": "aug",
                                        "9": "sep",
                                        "10": "okt",
                                        "11": "nov",
                                        "12": "dec"
                                    },
                                    "narrow": {
                                        "1": "j",
                                        "2": "f",
                                        "3": "m",
                                        "4": "a",
                                        "5": "m",
                                        "6": "j",
                                        "7": "j",
                                        "8": "a",
                                        "9": "s",
                                        "10": "o",
                                        "11": "n",
                                        "12": "d"
                                    },
                                    "wide": {
                                        "1": "januára",
                                        "2": "februára",
                                        "3": "marca",
                                        "4": "apríla",
                                        "5": "mája",
                                        "6": "júna",
                                        "7": "júla",
                                        "8": "augusta",
                                        "9": "septembra",
                                        "10": "októbra",
                                        "11": "novembra",
                                        "12": "decembra"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "1": "jan",
                                        "2": "feb",
                                        "3": "mar",
                                        "4": "apr",
                                        "5": "máj",
                                        "6": "jún",
                                        "7": "júl",
                                        "8": "aug",
                                        "9": "sep",
                                        "10": "okt",
                                        "11": "nov",
                                        "12": "dec"
                                    },
                                    "narrow": {
                                        "1": "j",
                                        "2": "f",
                                        "3": "m",
                                        "4": "a",
                                        "5": "m",
                                        "6": "j",
                                        "7": "j",
                                        "8": "a",
                                        "9": "s",
                                        "10": "o",
                                        "11": "n",
                                        "12": "d"
                                    },
                                    "wide": {
                                        "1": "január",
                                        "2": "február",
                                        "3": "marec",
                                        "4": "apríl",
                                        "5": "máj",
                                        "6": "jún",
                                        "7": "júl",
                                        "8": "august",
                                        "9": "september",
                                        "10": "október",
                                        "11": "november",
                                        "12": "december"
                                    }
                                }
                            },
                            "days": {
                                "format": {
                                    "abbreviated": {
                                        "sun": "ne",
                                        "mon": "po",
                                        "tue": "ut",
                                        "wed": "st",
                                        "thu": "št",
                                        "fri": "pi",
                                        "sat": "so"
                                    },
                                    "narrow": {
                                        "sun": "N",
                                        "mon": "P",
                                        "tue": "U",
                                        "wed": "S",
                                        "thu": "Š",
                                        "fri": "P",
                                        "sat": "S"
                                    },
                                    "short": {
                                        "sun": "Ne",
                                        "mon": "Po",
                                        "tue": "Ut",
                                        "wed": "St",
                                        "thu": "Št",
                                        "fri": "Pi",
                                        "sat": "So"
                                    },
                                    "wide": {
                                        "sun": "nedeľa",
                                        "mon": "pondelok",
                                        "tue": "utorok",
                                        "wed": "streda",
                                        "thu": "štvrtok",
                                        "fri": "piatok",
                                        "sat": "sobota"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "sun": "ne",
                                        "mon": "po",
                                        "tue": "ut",
                                        "wed": "st",
                                        "thu": "št",
                                        "fri": "pi",
                                        "sat": "so"
                                    },
                                    "narrow": {
                                        "sun": "N",
                                        "mon": "P",
                                        "tue": "U",
                                        "wed": "S",
                                        "thu": "Š",
                                        "fri": "P",
                                        "sat": "S"
                                    },
                                    "short": {
                                        "sun": "Ne",
                                        "mon": "Po",
                                        "tue": "Ut",
                                        "wed": "St",
                                        "thu": "Št",
                                        "fri": "Pi",
                                        "sat": "So"
                                    },
                                    "wide": {
                                        "sun": "nedeľa",
                                        "mon": "pondelok",
                                        "tue": "utorok",
                                        "wed": "streda",
                                        "thu": "štvrtok",
                                        "fri": "piatok",
                                        "sat": "sobota"
                                    }
                                }
                            },
                            "quarters": {
                                "format": {
                                    "abbreviated": {
                                        "1": "Q1",
                                        "2": "Q2",
                                        "3": "Q3",
                                        "4": "Q4"
                                    },
                                    "narrow": {
                                        "1": "1",
                                        "2": "2",
                                        "3": "3",
                                        "4": "4"
                                    },
                                    "wide": {
                                        "1": "1. štvrťrok",
                                        "2": "2. štvrťrok",
                                        "3": "3. štvrťrok",
                                        "4": "4. štvrťrok"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "1": "1Q",
                                        "2": "2Q",
                                        "3": "3Q",
                                        "4": "4Q"
                                    },
                                    "narrow": {
                                        "1": "1",
                                        "2": "2",
                                        "3": "3",
                                        "4": "4"
                                    },
                                    "wide": {
                                        "1": "1. štvrťrok",
                                        "2": "2. štvrťrok",
                                        "3": "3. štvrťrok",
                                        "4": "4. štvrťrok"
                                    }
                                }
                            },
                            "dayPeriods": {
                                "format": {
                                    "abbreviated": {
                                        "am": "AM",
                                        "pm": "PM"
                                    },
                                    "narrow": {
                                        "am": "AM",
                                        "pm": "PM"
                                    },
                                    "wide": {
                                        "am": "AM",
                                        "pm": "PM"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "am": "AM",
                                        "pm": "PM"
                                    },
                                    "narrow": {
                                        "am": "AM",
                                        "pm": "PM"
                                    },
                                    "wide": {
                                        "am": "AM",
                                        "pm": "PM"
                                    }
                                }
                            },
                            "eras": {
                                "eraNames": {
                                    "0": "pred n.l.",
                                    "1": "n.l.",
                                    "0-alt-variant": "BCE",
                                    "1-alt-variant": "CE"
                                },
                                "eraAbbr": {
                                    "0": "pred n.l.",
                                    "1": "n.l.",
                                    "0-alt-variant": "BCE",
                                    "1-alt-variant": "CE"
                                },
                                "eraNarrow": {
                                    "0": "pred n.l.",
                                    "1": "n.l.",
                                    "0-alt-variant": "BCE",
                                    "1-alt-variant": "CE"
                                }
                            },
                            "dateFormats": {
                                "full": "EEEE, d. MMMM y",
                                "long": "d. MMMM y",
                                "medium": "d.M.y",
                                "short": "d.M.y"
                            },
                            "timeFormats": {
                                "full": "H:mm:ss zzzz",
                                "long": "H:mm:ss z",
                                "medium": "H:mm:ss",
                                "short": "H:mm"
                            },
                            "dateTimeFormats": {
                                "full": "{1} {0}",
                                "long": "{1} {0}",
                                "medium": "{1} {0}",
                                "short": "{1} {0}",
                                "availableFormats": {
                                    "d": "d.",
                                    "Ed": "E d.",
                                    "Ehm": "E h:mm",
                                    "EHm": "E HH:mm",
                                    "Ehms": "E h:mm:ss",
                                    "EHms": "E HH:mm:ss",
                                    "Gy": "y G",
                                    "GyMMM": "LLL y G",
                                    "GyMMMd": "d.M.y G",
                                    "GyMMMEd": "E, d. MMM y G",
                                    "GyMMMMd": "d. MMMM y G",
                                    "h": "h a",
                                    "H": "H",
                                    "hm": "h:mm a",
                                    "Hm": "H:mm",
                                    "hms": "h:mm:ss a",
                                    "Hms": "H:mm:ss",
                                    "M": "L.",
                                    "Md": "d.M.",
                                    "MEd": "E, d.M.",
                                    "MMM": "LLL",
                                    "MMMd": "d. MMM.",
                                    "MMMEd": "E, d. MMM.",
                                    "MMMMd": "d. MMMM",
                                    "MMMMEd": "E, d. MMMM",
                                    "mmss": "mm:ss",
                                    "ms": "mm:ss",
                                    "y": "y",
                                    "yM": "M.y",
                                    "yMd": "d.M.y",
                                    "yMEd": "E d. M. y",
                                    "yMMM": "LLL y",
                                    "yMMMd": "d.M.y",
                                    "yMMMEd": "E, d. MMM y",
                                    "yMMMM": "LLLL y",
                                    "yMMMMd": "d. MMMM y",
                                    "yQQQ": "QQQ y",
                                    "yQQQQ": "QQQQ y"
                                },
                                "appendItems": {
                                    "Day": "{0} ({2}: {1})",
                                    "Day-Of-Week": "{0} {1}",
                                    "Era": "{1} {0}",
                                    "Hour": "{0} ({2}: {1})",
                                    "Minute": "{0} ({2}: {1})",
                                    "Month": "{0} ({2}: {1})",
                                    "Quarter": "{0} ({2}: {1})",
                                    "Second": "{0} ({2}: {1})",
                                    "Timezone": "{0} {1}",
                                    "Week": "{0} ({2}: {1})",
                                    "Year": "{1} {0}"
                                },
                                "intervalFormats": {
                                    "intervalFormatFallback": "{0} – {1}",
                                    "d": {
                                        "d": "d. – d."
                                    },
                                    "h": {
                                        "a": "h a – h a",
                                        "h": "h – h a"
                                    },
                                    "H": {
                                        "H": "HH – HH"
                                    },
                                    "hm": {
                                        "a": "h:mm a - h:mm a",
                                        "h": "h:mm - h:mm a",
                                        "m": "h:mm - h:mm a"
                                    },
                                    "Hm": {
                                        "H": "H:mm – H:mm",
                                        "m": "H:mm – H:mm"
                                    },
                                    "hmv": {
                                        "a": "h:mm a - h:mm a v",
                                        "h": "h:mm - h:mm a v",
                                        "m": "h:mm - h:mm a v"
                                    },
                                    "Hmv": {
                                        "H": "H:mm – H:mm v",
                                        "m": "H:mm – H:mm v"
                                    },
                                    "hv": {
                                        "a": "h a - h a v",
                                        "h": "h – h a v"
                                    },
                                    "Hv": {
                                        "H": "HH – HH v"
                                    },
                                    "M": {
                                        "M": "M. – M."
                                    },
                                    "Md": {
                                        "d": "d.M. - d.M.",
                                        "M": "d.M. - d.M."
                                    },
                                    "MEd": {
                                        "d": "E, d.M. - E, d.M.",
                                        "M": "E, d.M. - E, d.M."
                                    },
                                    "MMM": {
                                        "M": "LLL – LLL"
                                    },
                                    "MMMd": {
                                        "d": "d. - d. MMM",
                                        "M": "d. MMM - d. MMM"
                                    },
                                    "MMMEd": {
                                        "d": "E, d. - E, d. MMM",
                                        "M": "E, d. MMM - E, d. MMM"
                                    },
                                    "MMMM": {
                                        "M": "LLLL-LLLL"
                                    },
                                    "y": {
                                        "y": "y - y"
                                    },
                                    "yM": {
                                        "M": "M.y - M.y",
                                        "y": "M.y - M.y"
                                    },
                                    "yMd": {
                                        "d": "d.M.y - d.M.y",
                                        "M": "d.M.y - d.M.y",
                                        "y": "d.M.y - d.M.y"
                                    },
                                    "yMEd": {
                                        "d": "E, d.M.y - E, d.M.y",
                                        "M": "E, d.M.y - E, d.M.y",
                                        "y": "E, d.M.y - E, d.M.y"
                                    },
                                    "yMMM": {
                                        "M": "LLL - LLL y",
                                        "y": "LLL y - LLL y"
                                    },
                                    "yMMMd": {
                                        "d": "d. - d. MMM y",
                                        "M": "d. MMM - d. MMM y",
                                        "y": "d. MMM y - d. MMM y"
                                    },
                                    "yMMMEd": {
                                        "d": "E, d. - E, d. MMM y",
                                        "M": "E, d. MMM - E, d. MMM y",
                                        "y": "E, d. MMM y - E, d. MMM y"
                                    },
                                    "yMMMM": {
                                        "M": "LLLL - LLLL y",
                                        "y": "LLLL y - LLLL y"
                                    }
                                }
                            }
                        }
                    },
                    "timeZoneNames": {
                        "hourFormat": "+HH:mm;-HH:mm",
                        "gmtFormat": "GMT{0}",
                        "gmtZeroFormat": "GMT",
                        "regionFormat": "Časové pásmo {0}",
                        "regionFormat-type-daylight": "{0} (+1)",
                        "regionFormat-type-standard": "{0} (+0)",
                        "fallbackFormat": "{1} ({0})"
                    }
                }
            },
            "sl": {
                "dates": {
                    "calendars": {
                        "gregorian": {
                            "months": {
                                "format": {
                                    "abbreviated": {
                                        "1": "jan.",
                                        "2": "feb.",
                                        "3": "mar.",
                                        "4": "apr.",
                                        "5": "maj",
                                        "6": "jun.",
                                        "7": "jul.",
                                        "8": "avg.",
                                        "9": "sep.",
                                        "10": "okt.",
                                        "11": "nov.",
                                        "12": "dec."
                                    },
                                    "narrow": {
                                        "1": "j",
                                        "2": "f",
                                        "3": "m",
                                        "4": "a",
                                        "5": "m",
                                        "6": "j",
                                        "7": "j",
                                        "8": "a",
                                        "9": "s",
                                        "10": "o",
                                        "11": "n",
                                        "12": "d"
                                    },
                                    "wide": {
                                        "1": "januar",
                                        "2": "februar",
                                        "3": "marec",
                                        "4": "april",
                                        "5": "maj",
                                        "6": "junij",
                                        "7": "julij",
                                        "8": "avgust",
                                        "9": "september",
                                        "10": "oktober",
                                        "11": "november",
                                        "12": "december"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "1": "jan",
                                        "2": "feb",
                                        "3": "mar",
                                        "4": "apr",
                                        "5": "maj",
                                        "6": "jun",
                                        "7": "jul",
                                        "8": "avg",
                                        "9": "sep",
                                        "10": "okt",
                                        "11": "nov",
                                        "12": "dec"
                                    },
                                    "narrow": {
                                        "1": "j",
                                        "2": "f",
                                        "3": "m",
                                        "4": "a",
                                        "5": "m",
                                        "6": "j",
                                        "7": "j",
                                        "8": "a",
                                        "9": "s",
                                        "10": "o",
                                        "11": "n",
                                        "12": "d"
                                    },
                                    "wide": {
                                        "1": "januar",
                                        "2": "februar",
                                        "3": "marec",
                                        "4": "april",
                                        "5": "maj",
                                        "6": "junij",
                                        "7": "julij",
                                        "8": "avgust",
                                        "9": "september",
                                        "10": "oktober",
                                        "11": "november",
                                        "12": "december"
                                    }
                                }
                            },
                            "days": {
                                "format": {
                                    "abbreviated": {
                                        "sun": "ned.",
                                        "mon": "pon.",
                                        "tue": "tor.",
                                        "wed": "sre.",
                                        "thu": "čet.",
                                        "fri": "pet.",
                                        "sat": "sob."
                                    },
                                    "narrow": {
                                        "sun": "n",
                                        "mon": "p",
                                        "tue": "t",
                                        "wed": "s",
                                        "thu": "č",
                                        "fri": "p",
                                        "sat": "s"
                                    },
                                    "short": {
                                        "sun": "ned.",
                                        "mon": "pon.",
                                        "tue": "tor.",
                                        "wed": "sre.",
                                        "thu": "čet.",
                                        "fri": "pet.",
                                        "sat": "sob."
                                    },
                                    "wide": {
                                        "sun": "nedelja",
                                        "mon": "ponedeljek",
                                        "tue": "torek",
                                        "wed": "sreda",
                                        "thu": "četrtek",
                                        "fri": "petek",
                                        "sat": "sobota"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "sun": "ned",
                                        "mon": "pon",
                                        "tue": "tor",
                                        "wed": "sre",
                                        "thu": "čet",
                                        "fri": "pet",
                                        "sat": "sob"
                                    },
                                    "narrow": {
                                        "sun": "n",
                                        "mon": "p",
                                        "tue": "t",
                                        "wed": "s",
                                        "thu": "č",
                                        "fri": "p",
                                        "sat": "s"
                                    },
                                    "short": {
                                        "sun": "ned.",
                                        "mon": "pon.",
                                        "tue": "tor.",
                                        "wed": "sre.",
                                        "thu": "čet.",
                                        "fri": "pet.",
                                        "sat": "sob."
                                    },
                                    "wide": {
                                        "sun": "nedelja",
                                        "mon": "ponedeljek",
                                        "tue": "torek",
                                        "wed": "sreda",
                                        "thu": "četrtek",
                                        "fri": "petek",
                                        "sat": "sobota"
                                    }
                                }
                            },
                            "quarters": {
                                "format": {
                                    "abbreviated": {
                                        "1": "Q1",
                                        "2": "Q2",
                                        "3": "Q3",
                                        "4": "Q4"
                                    },
                                    "narrow": {
                                        "1": "1",
                                        "2": "2",
                                        "3": "3",
                                        "4": "4"
                                    },
                                    "wide": {
                                        "1": "1. četrtletje",
                                        "2": "2. četrtletje",
                                        "3": "3. četrtletje",
                                        "4": "4. četrtletje"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "1": "Q1",
                                        "2": "Q2",
                                        "3": "Q3",
                                        "4": "Q4"
                                    },
                                    "narrow": {
                                        "1": "1",
                                        "2": "2",
                                        "3": "3",
                                        "4": "4"
                                    },
                                    "wide": {
                                        "1": "1. četrtletje",
                                        "2": "2. četrtletje",
                                        "3": "3. četrtletje",
                                        "4": "4. četrtletje"
                                    }
                                }
                            },
                            "dayPeriods": {
                                "format": {
                                    "abbreviated": {
                                        "am": "dop.",
                                        "pm": "pop."
                                    },
                                    "narrow": {
                                        "am": "dop.",
                                        "pm": "pop."
                                    },
                                    "wide": {
                                        "am": "dop.",
                                        "pm": "pop."
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "am": "dop.",
                                        "pm": "pop."
                                    },
                                    "narrow": {
                                        "am": "dop.",
                                        "pm": "pop."
                                    },
                                    "wide": {
                                        "am": "dop.",
                                        "pm": "pop."
                                    }
                                }
                            },
                            "eras": {
                                "eraNames": {
                                    "0": "pred našim štetjem",
                                    "1": "naše štetje",
                                    "0-alt-variant": "BCE",
                                    "1-alt-variant": "po n. št."
                                },
                                "eraAbbr": {
                                    "0": "pr. n. št.",
                                    "1": "po Kr.",
                                    "0-alt-variant": "BCE",
                                    "1-alt-variant": "po n. št."
                                },
                                "eraNarrow": {
                                    "0": "pr. n. št.",
                                    "1": "po Kr.",
                                    "0-alt-variant": "BCE",
                                    "1-alt-variant": "po n. št."
                                }
                            },
                            "dateFormats": {
                                "full": "EEEE, dd. MMMM y",
                                "long": "dd. MMMM y",
                                "medium": "d. MMM y",
                                "short": "d. MM. yy"
                            },
                            "timeFormats": {
                                "full": "HH:mm:ss zzzz",
                                "long": "HH:mm:ss z",
                                "medium": "HH:mm:ss",
                                "short": "HH:mm"
                            },
                            "dateTimeFormats": {
                                "full": "{1} {0}",
                                "long": "{1} {0}",
                                "medium": "{1} {0}",
                                "short": "{1} {0}",
                                "availableFormats": {
                                    "d": "d",
                                    "Ed": "E, d.",
                                    "Ehm": "E h.mm a",
                                    "EHm": "E HH.mm",
                                    "Ehms": "E h.mm.ss a",
                                    "EHms": "E HH.mm.ss",
                                    "Gy": "y G",
                                    "GyM": "M/y G",
                                    "GyMMM": "MMM y G",
                                    "GyMMMd": "d. MMM y G",
                                    "GyMMMEd": "E, d. MMM y G",
                                    "h": "h a",
                                    "H": "HH",
                                    "hm": "h:mm a",
                                    "Hm": "HH:mm",
                                    "hms": "h:mm:ss a",
                                    "Hms": "HH:mm:ss",
                                    "M": "L",
                                    "Md": "d. M.",
                                    "MEd": "E, d. MM.",
                                    "MMM": "LLL",
                                    "MMMd": "d. MMM",
                                    "MMMEd": "E, d. MMM",
                                    "ms": "mm:ss",
                                    "y": "y",
                                    "yM": "M/y",
                                    "yMd": "d. M. y",
                                    "yMEd": "E, d. M. y",
                                    "yMMM": "MMM y",
                                    "yMMMd": "d. MMM y",
                                    "yMMMEd": "E, d. MMM y",
                                    "yMMMM": "MMMM y",
                                    "yQQQ": "QQQ y",
                                    "yQQQQ": "QQQQ y"
                                },
                                "appendItems": {
                                    "Day": "{0} ({2}: {1})",
                                    "Day-Of-Week": "{0} {1}",
                                    "Era": "{1} {0}",
                                    "Hour": "{0} ({2}: {1})",
                                    "Minute": "{0} ({2}: {1})",
                                    "Month": "{0} ({2}: {1})",
                                    "Quarter": "{0} ({2}: {1})",
                                    "Second": "{0} ({2}: {1})",
                                    "Timezone": "{0} {1}",
                                    "Week": "{0} ({2}: {1})",
                                    "Year": "{1} {0}"
                                },
                                "intervalFormats": {
                                    "intervalFormatFallback": "{0} – {1}",
                                    "d": {
                                        "d": "d.–d."
                                    },
                                    "h": {
                                        "a": "h a – h a",
                                        "h": "h–h a"
                                    },
                                    "H": {
                                        "H": "HH–HH"
                                    },
                                    "hm": {
                                        "a": "h:mm a – h:mm a",
                                        "h": "h:mm–h:mm a",
                                        "m": "h:mm–h:mm a"
                                    },
                                    "Hm": {
                                        "H": "HH.mm–HH.mm",
                                        "m": "HH.mm–HH.mm"
                                    },
                                    "hmv": {
                                        "a": "h:mm a – h:mm a v",
                                        "h": "h:mm–h:mm a v",
                                        "m": "h:mm–h:mm a v"
                                    },
                                    "Hmv": {
                                        "H": "HH.mm–HH.mm v",
                                        "m": "HH.mm–HH.mm v"
                                    },
                                    "hv": {
                                        "a": "h a – h a v",
                                        "h": "h–h a v"
                                    },
                                    "Hv": {
                                        "H": "HH–HH v"
                                    },
                                    "M": {
                                        "M": "M.–M."
                                    },
                                    "Md": {
                                        "d": "d. – d. M.",
                                        "M": "d. M. – d. M."
                                    },
                                    "MEd": {
                                        "d": "E, d. – E, d. M.",
                                        "M": "E, d. M. – E, d. M."
                                    },
                                    "MMM": {
                                        "M": "MMM–MMM"
                                    },
                                    "MMMd": {
                                        "d": "d.–d. MMM",
                                        "M": "d. MMM – d. MMM"
                                    },
                                    "MMMEd": {
                                        "d": "E, d. – E, d. MMM",
                                        "M": "E, d. MMM – E, d. MMM"
                                    },
                                    "y": {
                                        "y": "y–y"
                                    },
                                    "yM": {
                                        "M": "M.–M. y",
                                        "y": "M. y – M. y"
                                    },
                                    "yMd": {
                                        "d": "d. M. y – d. M. y",
                                        "M": "d. M. – d. M. y",
                                        "y": "d. M. y – d. M. y"
                                    },
                                    "yMEd": {
                                        "d": "E, d. – E, d. M. y",
                                        "M": "E, d. M. – E, d. M. y",
                                        "y": "E, d. M. y – E, d. M. y"
                                    },
                                    "yMMM": {
                                        "M": "MMM – MMM y",
                                        "y": "MMM y – MMM y"
                                    },
                                    "yMMMd": {
                                        "d": "d.–d. MMM y",
                                        "M": "d. MMM – d. MMM y",
                                        "y": "d. MMM y – d. MMM y"
                                    },
                                    "yMMMEd": {
                                        "d": "E, d. MMM – E, d. MMM y",
                                        "M": "E, d. MMM – E, d. MMM y",
                                        "y": "E, d. MMM y – E, d. MMM y"
                                    },
                                    "yMMMM": {
                                        "M": "MMMM–MMMM y",
                                        "y": "MMMM y – MMMM y"
                                    }
                                }
                            }
                        }
                    },
                    "timeZoneNames": {
                        "hourFormat": "+HH:mm;-HH:mm",
                        "gmtFormat": "GMT{0}",
                        "gmtZeroFormat": "GMT",
                        "regionFormat": "{0} čas",
                        "regionFormat-type-daylight": "{0} (+1)",
                        "regionFormat-type-standard": "{0} (+0)",
                        "fallbackFormat": "{1} ({0})"
                    }
                }
            },
            "sr": {
                "dates": {
                    "calendars": {
                        "gregorian": {
                            "months": {
                                "format": {
                                    "abbreviated": {
                                        "1": "јан",
                                        "2": "феб",
                                        "3": "мар",
                                        "4": "апр",
                                        "5": "мај",
                                        "6": "јун",
                                        "7": "јул",
                                        "8": "авг",
                                        "9": "сеп",
                                        "10": "окт",
                                        "11": "нов",
                                        "12": "дец"
                                    },
                                    "narrow": {
                                        "1": "ј",
                                        "2": "ф",
                                        "3": "м",
                                        "4": "а",
                                        "5": "м",
                                        "6": "ј",
                                        "7": "ј",
                                        "8": "а",
                                        "9": "с",
                                        "10": "о",
                                        "11": "н",
                                        "12": "д"
                                    },
                                    "wide": {
                                        "1": "јануар",
                                        "2": "фебруар",
                                        "3": "март",
                                        "4": "април",
                                        "5": "мај",
                                        "6": "јун",
                                        "7": "јул",
                                        "8": "август",
                                        "9": "септембар",
                                        "10": "октобар",
                                        "11": "новембар",
                                        "12": "децембар"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "1": "јан",
                                        "2": "феб",
                                        "3": "мар",
                                        "4": "апр",
                                        "5": "мај",
                                        "6": "јун",
                                        "7": "јул",
                                        "8": "авг",
                                        "9": "сеп",
                                        "10": "окт",
                                        "11": "нов",
                                        "12": "дец"
                                    },
                                    "narrow": {
                                        "1": "ј",
                                        "2": "ф",
                                        "3": "м",
                                        "4": "а",
                                        "5": "м",
                                        "6": "ј",
                                        "7": "ј",
                                        "8": "а",
                                        "9": "с",
                                        "10": "о",
                                        "11": "н",
                                        "12": "д"
                                    },
                                    "wide": {
                                        "1": "јануар",
                                        "2": "фебруар",
                                        "3": "март",
                                        "4": "април",
                                        "5": "мај",
                                        "6": "јун",
                                        "7": "јул",
                                        "8": "август",
                                        "9": "септембар",
                                        "10": "октобар",
                                        "11": "новембар",
                                        "12": "децембар"
                                    }
                                }
                            },
                            "days": {
                                "format": {
                                    "abbreviated": {
                                        "sun": "нед",
                                        "mon": "пон",
                                        "tue": "уто",
                                        "wed": "сре",
                                        "thu": "чет",
                                        "fri": "пет",
                                        "sat": "суб"
                                    },
                                    "narrow": {
                                        "sun": "н",
                                        "mon": "п",
                                        "tue": "у",
                                        "wed": "с",
                                        "thu": "ч",
                                        "fri": "п",
                                        "sat": "с"
                                    },
                                    "short": {
                                        "sun": "нед",
                                        "mon": "пон",
                                        "tue": "уто",
                                        "wed": "сре",
                                        "thu": "чет",
                                        "fri": "пет",
                                        "sat": "суб"
                                    },
                                    "wide": {
                                        "sun": "недеља",
                                        "mon": "понедељак",
                                        "tue": "уторак",
                                        "wed": "среда",
                                        "thu": "четвртак",
                                        "fri": "петак",
                                        "sat": "субота"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "sun": "нед",
                                        "mon": "пон",
                                        "tue": "уто",
                                        "wed": "сре",
                                        "thu": "чет",
                                        "fri": "пет",
                                        "sat": "суб"
                                    },
                                    "narrow": {
                                        "sun": "н",
                                        "mon": "п",
                                        "tue": "у",
                                        "wed": "с",
                                        "thu": "ч",
                                        "fri": "п",
                                        "sat": "с"
                                    },
                                    "short": {
                                        "sun": "не",
                                        "mon": "по",
                                        "tue": "ут",
                                        "wed": "ср",
                                        "thu": "че",
                                        "fri": "пе",
                                        "sat": "су"
                                    },
                                    "wide": {
                                        "sun": "недеља",
                                        "mon": "понедељак",
                                        "tue": "уторак",
                                        "wed": "среда",
                                        "thu": "четвртак",
                                        "fri": "петак",
                                        "sat": "субота"
                                    }
                                }
                            },
                            "quarters": {
                                "format": {
                                    "abbreviated": {
                                        "1": "К1",
                                        "2": "К2",
                                        "3": "К3",
                                        "4": "К4"
                                    },
                                    "narrow": {
                                        "1": "1.",
                                        "2": "2.",
                                        "3": "3.",
                                        "4": "4."
                                    },
                                    "wide": {
                                        "1": "Прво тромесечје",
                                        "2": "Друго тромесечје",
                                        "3": "Треће тромесечје",
                                        "4": "Четврто тромесечје"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "1": "К1",
                                        "2": "К2",
                                        "3": "К3",
                                        "4": "К4"
                                    },
                                    "narrow": {
                                        "1": "1.",
                                        "2": "2.",
                                        "3": "3.",
                                        "4": "4."
                                    },
                                    "wide": {
                                        "1": "Прво тромесечје",
                                        "2": "Друго тромесечје",
                                        "3": "Треће тромесечје",
                                        "4": "Четврто тромесечје"
                                    }
                                }
                            },
                            "dayPeriods": {
                                "format": {
                                    "abbreviated": {
                                        "am": "пре подне",
                                        "pm": "поподне"
                                    },
                                    "narrow": {
                                        "am": "пре подне",
                                        "pm": "поподне"
                                    },
                                    "wide": {
                                        "am": "пре подне",
                                        "pm": "поподне"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "am": "пре подне",
                                        "pm": "поподне"
                                    },
                                    "narrow": {
                                        "am": "пре подне",
                                        "pm": "поподне"
                                    },
                                    "wide": {
                                        "am": "пре подне",
                                        "pm": "поподне"
                                    }
                                }
                            },
                            "eras": {
                                "eraNames": {
                                    "0": "Пре нове ере",
                                    "1": "Нове ере",
                                    "0-alt-variant": "BCE",
                                    "1-alt-variant": "CE"
                                },
                                "eraAbbr": {
                                    "0": "п. н. е.",
                                    "1": "н. е.",
                                    "0-alt-variant": "BCE",
                                    "1-alt-variant": "CE"
                                },
                                "eraNarrow": {
                                    "0": "п.н.е.",
                                    "1": "н.е.",
                                    "0-alt-variant": "BCE",
                                    "1-alt-variant": "CE"
                                }
                            },
                            "dateFormats": {
                                "full": "EEEE, dd. MMMM y.",
                                "long": "dd. MMMM y.",
                                "medium": "dd.MM.y.",
                                "short": "d.M.yy."
                            },
                            "timeFormats": {
                                "full": "HH.mm.ss zzzz",
                                "long": "HH.mm.ss z",
                                "medium": "HH.mm.ss",
                                "short": "HH.mm"
                            },
                            "dateTimeFormats": {
                                "full": "{1} {0}",
                                "long": "{1} {0}",
                                "medium": "{1} {0}",
                                "short": "{1} {0}",
                                "availableFormats": {
                                    "d": "d",
                                    "Ed": "E d.",
                                    "Ehm": "E, h:mm a",
                                    "EHm": "E, HH:mm",
                                    "Ehms": "E, h:mm:ss a",
                                    "EHms": "E, HH:mm:ss",
                                    "Gy": "y. G",
                                    "GyMMM": "MMM y. G",
                                    "GyMMMd": "d. MMM y. G",
                                    "GyMMMEd": "E, d. MMM y. G",
                                    "h": "hh a",
                                    "H": "HH",
                                    "hm": "hh.mm a",
                                    "Hm": "HH.mm",
                                    "hms": "hh.mm.ss a",
                                    "Hms": "HH.mm.ss",
                                    "M": "L",
                                    "Md": "d/M",
                                    "MEd": "E, M-d",
                                    "MMdd": "MM-dd",
                                    "MMM": "LLL",
                                    "MMMd": "d. MMM",
                                    "MMMdd": "dd.MMM",
                                    "MMMEd": "E d. MMM",
                                    "MMMMd": "d. MMMM",
                                    "MMMMdd": "dd. MMMM",
                                    "MMMMEd": "E d. MMMM",
                                    "ms": "mm.ss",
                                    "y": "y.",
                                    "yM": "y-M",
                                    "yMd": "d. M. y.",
                                    "yMEd": "E, d. M. y.",
                                    "yMM": "MM.y",
                                    "yMMdd": "dd.MM.y",
                                    "yMMM": "MMM y.",
                                    "yMMMd": "d. MMM y.",
                                    "yMMMEd": "E, d. MMM y.",
                                    "yMMMM": "MMMM y.",
                                    "yQQQ": "QQQ. y",
                                    "yQQQQ": "QQQQ. y"
                                },
                                "appendItems": {
                                    "Day": "{0} ({2}: {1})",
                                    "Day-Of-Week": "{0} {1}",
                                    "Era": "{1} {0}",
                                    "Hour": "{0} ({2}: {1})",
                                    "Minute": "{0} ({2}: {1})",
                                    "Month": "{0} ({2}: {1})",
                                    "Quarter": "{0} ({2}: {1})",
                                    "Second": "{0} ({2}: {1})",
                                    "Timezone": "{0} {1}",
                                    "Week": "{0} ({2}: {1})",
                                    "Year": "{1} {0}"
                                },
                                "intervalFormats": {
                                    "intervalFormatFallback": "{0} - {1}",
                                    "d": {
                                        "d": "d-d"
                                    },
                                    "h": {
                                        "a": "h a - h a",
                                        "h": "h-h a"
                                    },
                                    "H": {
                                        "H": "HH-HH"
                                    },
                                    "hm": {
                                        "a": "h.mm a - h.mm a",
                                        "h": "h.mm-h.mm a",
                                        "m": "h.mm-h.mm a"
                                    },
                                    "Hm": {
                                        "H": "HH.mm-HH.mm",
                                        "m": "HH.mm-HH.mm"
                                    },
                                    "hmv": {
                                        "a": "h.mm a - h.mm a v",
                                        "h": "h.mm-h.mm a v",
                                        "m": "h.mm-h.mm a v"
                                    },
                                    "Hmv": {
                                        "H": "HH.mm-HH.mm v",
                                        "m": "HH.mm-HH.mm v"
                                    },
                                    "hv": {
                                        "a": "h a - h a v",
                                        "h": "h-h a v"
                                    },
                                    "Hv": {
                                        "H": "HH-HH v"
                                    },
                                    "M": {
                                        "M": "M-M"
                                    },
                                    "Md": {
                                        "d": "d.M - d.M",
                                        "M": "d.M - d.M"
                                    },
                                    "MEd": {
                                        "d": "E, d.M - E, d.M",
                                        "M": "E, d.M - E, d.M"
                                    },
                                    "MMM": {
                                        "M": "MMM-MMM"
                                    },
                                    "MMMd": {
                                        "d": "dd.-dd. MMM",
                                        "M": "dd. MMM - dd. MMM"
                                    },
                                    "MMMEd": {
                                        "d": "E, dd. - E, dd. MMM",
                                        "M": "E, dd. MMM - E, dd. MMM"
                                    },
                                    "y": {
                                        "y": "y-y"
                                    },
                                    "yM": {
                                        "M": "y M - M",
                                        "y": "y M - M"
                                    },
                                    "yMd": {
                                        "d": "d.M.y. - d.M.y.",
                                        "M": "d.M.y. - d.M.y.",
                                        "y": "d.M.y. - d.M.y."
                                    },
                                    "yMEd": {
                                        "d": "E, d.M.y. - E, d.M.y.",
                                        "M": "E, d.M.y. - E, d.M.y.",
                                        "y": "E, d.M.y. - E, d.M.y."
                                    },
                                    "yMMM": {
                                        "M": "MMM-MMM y.",
                                        "y": "MMM y. - MMM y."
                                    },
                                    "yMMMd": {
                                        "d": "dd.-dd. MMM y.",
                                        "M": "dd. MMM - dd. MMM y.",
                                        "y": "dd. MMM y. - dd. MMM y."
                                    },
                                    "yMMMEd": {
                                        "d": "E, dd. - E, dd. MMM y.",
                                        "M": "E, dd. MMM - E, dd. MMM y.",
                                        "y": "E, dd. MMM y. - E, dd. MMM y."
                                    },
                                    "yMMMM": {
                                        "M": "y-MM – MM",
                                        "y": "y-MM – y-MM"
                                    }
                                }
                            }
                        }
                    },
                    "timeZoneNames": {
                        "hourFormat": "+HHmm;-HHmm",
                        "gmtFormat": "GMT{0}",
                        "gmtZeroFormat": "GMT",
                        "regionFormat": "Време у земљи: {0}",
                        "regionFormat-type-daylight": "{0}, летње време",
                        "regionFormat-type-standard": "{0}, стандардно време",
                        "fallbackFormat": "{1} ({0})"
                    }
                }
            },
            "sv": {
                "dates": {
                    "calendars": {
                        "gregorian": {
                            "months": {
                                "format": {
                                    "abbreviated": {
                                        "1": "jan",
                                        "2": "feb",
                                        "3": "mar",
                                        "4": "apr",
                                        "5": "maj",
                                        "6": "jun",
                                        "7": "jul",
                                        "8": "aug",
                                        "9": "sep",
                                        "10": "okt",
                                        "11": "nov",
                                        "12": "dec"
                                    },
                                    "narrow": {
                                        "1": "J",
                                        "2": "F",
                                        "3": "M",
                                        "4": "A",
                                        "5": "M",
                                        "6": "J",
                                        "7": "J",
                                        "8": "A",
                                        "9": "S",
                                        "10": "O",
                                        "11": "N",
                                        "12": "D"
                                    },
                                    "wide": {
                                        "1": "januari",
                                        "2": "februari",
                                        "3": "mars",
                                        "4": "april",
                                        "5": "maj",
                                        "6": "juni",
                                        "7": "juli",
                                        "8": "augusti",
                                        "9": "september",
                                        "10": "oktober",
                                        "11": "november",
                                        "12": "december"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "1": "Jan",
                                        "2": "Feb",
                                        "3": "Mar",
                                        "4": "Apr",
                                        "5": "Maj",
                                        "6": "Jun",
                                        "7": "Jul",
                                        "8": "Aug",
                                        "9": "Sep",
                                        "10": "Okt",
                                        "11": "Nov",
                                        "12": "Dec"
                                    },
                                    "narrow": {
                                        "1": "J",
                                        "2": "F",
                                        "3": "M",
                                        "4": "A",
                                        "5": "M",
                                        "6": "J",
                                        "7": "J",
                                        "8": "A",
                                        "9": "S",
                                        "10": "O",
                                        "11": "N",
                                        "12": "D"
                                    },
                                    "wide": {
                                        "1": "Januari",
                                        "2": "Februari",
                                        "3": "Mars",
                                        "4": "April",
                                        "5": "Maj",
                                        "6": "Juni",
                                        "7": "Juli",
                                        "8": "Augusti",
                                        "9": "September",
                                        "10": "Oktober",
                                        "11": "November",
                                        "12": "December"
                                    }
                                }
                            },
                            "days": {
                                "format": {
                                    "abbreviated": {
                                        "sun": "sön",
                                        "mon": "mån",
                                        "tue": "tis",
                                        "wed": "ons",
                                        "thu": "tors",
                                        "fri": "fre",
                                        "sat": "lör"
                                    },
                                    "narrow": {
                                        "sun": "S",
                                        "mon": "M",
                                        "tue": "T",
                                        "wed": "O",
                                        "thu": "T",
                                        "fri": "F",
                                        "sat": "L"
                                    },
                                    "short": {
                                        "sun": "sö",
                                        "mon": "må",
                                        "tue": "ti",
                                        "wed": "on",
                                        "thu": "to",
                                        "fri": "fr",
                                        "sat": "lö"
                                    },
                                    "wide": {
                                        "sun": "söndag",
                                        "mon": "måndag",
                                        "tue": "tisdag",
                                        "wed": "onsdag",
                                        "thu": "torsdag",
                                        "fri": "fredag",
                                        "sat": "lördag"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "sun": "Sön",
                                        "mon": "Mån",
                                        "tue": "Tis",
                                        "wed": "Ons",
                                        "thu": "Tor",
                                        "fri": "Fre",
                                        "sat": "Lör"
                                    },
                                    "narrow": {
                                        "sun": "S",
                                        "mon": "M",
                                        "tue": "T",
                                        "wed": "O",
                                        "thu": "T",
                                        "fri": "F",
                                        "sat": "L"
                                    },
                                    "short": {
                                        "sun": "Sö",
                                        "mon": "Må",
                                        "tue": "Ti",
                                        "wed": "On",
                                        "thu": "To",
                                        "fri": "Fr",
                                        "sat": "Lö"
                                    },
                                    "wide": {
                                        "sun": "Söndag",
                                        "mon": "Måndag",
                                        "tue": "Tisdag",
                                        "wed": "Onsdag",
                                        "thu": "Torsdag",
                                        "fri": "Fredag",
                                        "sat": "Lördag"
                                    }
                                }
                            },
                            "quarters": {
                                "format": {
                                    "abbreviated": {
                                        "1": "K1",
                                        "2": "K2",
                                        "3": "K3",
                                        "4": "K4"
                                    },
                                    "narrow": {
                                        "1": "1",
                                        "2": "2",
                                        "3": "3",
                                        "4": "4"
                                    },
                                    "wide": {
                                        "1": "1:a kvartalet",
                                        "2": "2:a kvartalet",
                                        "3": "3:e kvartalet",
                                        "4": "4:e kvartalet"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "1": "K1",
                                        "2": "K2",
                                        "3": "K3",
                                        "4": "K4"
                                    },
                                    "narrow": {
                                        "1": "1",
                                        "2": "2",
                                        "3": "3",
                                        "4": "4"
                                    },
                                    "wide": {
                                        "1": "1:a kvartalet",
                                        "2": "2:a kvartalet",
                                        "3": "3:e kvartalet",
                                        "4": "4:e kvartalet"
                                    }
                                }
                            },
                            "dayPeriods": {
                                "format": {
                                    "abbreviated": {
                                        "am": "FM",
                                        "pm": "EM"
                                    },
                                    "narrow": {
                                        "am": "f",
                                        "pm": "e"
                                    },
                                    "wide": {
                                        "am": "fm",
                                        "pm": "em"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "am": "fm",
                                        "pm": "em"
                                    },
                                    "narrow": {
                                        "am": "f.m.",
                                        "pm": "e.m."
                                    },
                                    "wide": {
                                        "am": "förmiddag",
                                        "pm": "eftermiddag"
                                    }
                                }
                            },
                            "eras": {
                                "eraNames": {
                                    "0": "före Kristus",
                                    "1": "efter Kristus",
                                    "0-alt-variant": "före västerländsk tideräkning",
                                    "1-alt-variant": "västerländsk tideräkning"
                                },
                                "eraAbbr": {
                                    "0": "f.Kr.",
                                    "1": "e.Kr.",
                                    "0-alt-variant": "f.v.t.",
                                    "1-alt-variant": "v.t."
                                },
                                "eraNarrow": {
                                    "0": "f.Kr.",
                                    "1": "e.Kr.",
                                    "0-alt-variant": "fvt",
                                    "1-alt-variant": "vt"
                                }
                            },
                            "dateFormats": {
                                "full": "EEEE'en' 'den' d:'e' MMMM y",
                                "long": "d MMMM y",
                                "medium": "d MMM y",
                                "short": "y-MM-dd"
                            },
                            "timeFormats": {
                                "full": "'kl'. HH:mm:ss zzzz",
                                "long": "HH:mm:ss z",
                                "medium": "HH:mm:ss",
                                "short": "HH:mm"
                            },
                            "dateTimeFormats": {
                                "full": "{1} {0}",
                                "long": "{1} {0}",
                                "medium": "{1} {0}",
                                "short": "{1} {0}",
                                "availableFormats": {
                                    "d": "d",
                                    "Ed": "E d",
                                    "Ehm": "E h:mm a",
                                    "EHm": "E HH:mm",
                                    "Ehms": "E h:mm:ss a",
                                    "EHms": "E HH:mm:ss",
                                    "Gy": "y G",
                                    "GyMMM": "MMM y G",
                                    "GyMMMd": "d MMM y G",
                                    "GyMMMEd": "E d MMM y G",
                                    "h": "h a",
                                    "H": "HH",
                                    "hm": "h:mm a",
                                    "Hm": "HH:mm",
                                    "hms": "h:mm:ss a",
                                    "Hms": "HH:mm:ss",
                                    "M": "L",
                                    "Md": "d/M",
                                    "MEd": "E d/M",
                                    "MMd": "d/M",
                                    "MMdd": "dd/MM",
                                    "MMM": "LLL",
                                    "MMMd": "d MMM",
                                    "MMMEd": "E d MMM",
                                    "MMMMd": "d:'e' MMMM",
                                    "MMMMEd": "E d:'e' MMMM",
                                    "ms": "mm:ss",
                                    "y": "y",
                                    "yM": "y-MM",
                                    "yMd": "y-MM-dd",
                                    "yMEd": "E, y-MM-dd",
                                    "yMM": "y-MM",
                                    "yMMM": "MMM y",
                                    "yMMMd": "d MMM y",
                                    "yMMMEd": "E d MMM y",
                                    "yQQQ": "y QQQ",
                                    "yQQQQ": "y QQQQ"
                                },
                                "appendItems": {
                                    "Day": "{0} ({2}: {1})",
                                    "Day-Of-Week": "{0} {1}",
                                    "Era": "{1} {0}",
                                    "Hour": "{0} ({2}: {1})",
                                    "Minute": "{0} ({2}: {1})",
                                    "Month": "{0} ({2}: {1})",
                                    "Quarter": "{0} ({2}: {1})",
                                    "Second": "{0} ({2}: {1})",
                                    "Timezone": "{0} {1}",
                                    "Week": "{0} ({2}: {1})",
                                    "Year": "{1} {0}"
                                },
                                "intervalFormats": {
                                    "intervalFormatFallback": "{0} – {1}",
                                    "d": {
                                        "d": "d–d"
                                    },
                                    "h": {
                                        "a": "h a – h a",
                                        "h": "h–h a"
                                    },
                                    "H": {
                                        "H": "HH–HH"
                                    },
                                    "hm": {
                                        "a": "h:mm a – h:mm a",
                                        "h": "h:mm–h:mm a",
                                        "m": "h:mm–h:mm a"
                                    },
                                    "Hm": {
                                        "H": "HH:mm–HH:mm",
                                        "m": "HH:mm–HH:mm"
                                    },
                                    "hmv": {
                                        "a": "h:mm a – h:mm a v",
                                        "h": "h:mm–h:mm a v",
                                        "m": "h:mm–h:mm a v"
                                    },
                                    "Hmv": {
                                        "H": "HH:mm–HH:mm v",
                                        "m": "HH:mm–HH:mm v"
                                    },
                                    "hv": {
                                        "a": "h a – h a v",
                                        "h": "h–h a v"
                                    },
                                    "Hv": {
                                        "H": "HH–HH v"
                                    },
                                    "M": {
                                        "M": "M–M"
                                    },
                                    "Md": {
                                        "d": "d–d/M",
                                        "M": "d/M – d/M"
                                    },
                                    "MEd": {
                                        "d": "E d/M – E d/M",
                                        "M": "E d/M – E d/M"
                                    },
                                    "MMM": {
                                        "M": "MMM–MMM"
                                    },
                                    "MMMd": {
                                        "d": "d–d MMM",
                                        "M": "d MMM – d MMM"
                                    },
                                    "MMMEd": {
                                        "d": "E d – E d MMM",
                                        "M": "E d MMM – E d MMM"
                                    },
                                    "y": {
                                        "y": "y–y"
                                    },
                                    "yM": {
                                        "M": "y-MM – MM",
                                        "y": "y-MM – y-MM"
                                    },
                                    "yMd": {
                                        "d": "y-MM-dd – dd",
                                        "M": "y-MM-dd – MM-dd",
                                        "y": "y-MM-dd – y-MM-dd"
                                    },
                                    "yMEd": {
                                        "d": "E, y-MM-dd – E, y-MM-dd",
                                        "M": "E, y-MM-dd – E, y-MM-dd",
                                        "y": "E, y-MM-dd – E, y-MM-dd"
                                    },
                                    "yMMM": {
                                        "M": "MMM–MMM y",
                                        "y": "MMM y – MMM y"
                                    },
                                    "yMMMd": {
                                        "d": "d–d MMM y",
                                        "M": "d MMM–d MMM y",
                                        "y": "d MMM y–d MMM y"
                                    },
                                    "yMMMEd": {
                                        "d": "E dd MMM–E dd MMM y",
                                        "M": "E dd MMM–E dd MMM y",
                                        "y": "E dd MMM y–E dd MMM y"
                                    },
                                    "yMMMM": {
                                        "M": "MMMM–MMMM y",
                                        "y": "MMMM y – MMMM y"
                                    }
                                }
                            }
                        }
                    },
                    "timeZoneNames": {
                        "hourFormat": "+HH:mm;−HH:mm",
                        "gmtFormat": "GMT{0}",
                        "gmtZeroFormat": "GMT",
                        "regionFormat": "{0}tid",
                        "regionFormat-type-daylight": "{0} (sommartid)",
                        "regionFormat-type-standard": "{0} (normaltid)",
                        "fallbackFormat": "{1} ({0})"
                    }
                }
            },
            "th": {
                "dates": {
                    "calendars": {
                        "gregorian": {
                            "months": {
                                "format": {
                                    "abbreviated": {
                                        "1": "ม.ค.",
                                        "2": "ก.พ.",
                                        "3": "มี.ค.",
                                        "4": "เม.ย.",
                                        "5": "พ.ค.",
                                        "6": "มิ.ย.",
                                        "7": "ก.ค.",
                                        "8": "ส.ค.",
                                        "9": "ก.ย.",
                                        "10": "ต.ค.",
                                        "11": "พ.ย.",
                                        "12": "ธ.ค."
                                    },
                                    "narrow": {
                                        "1": "ม.ค.",
                                        "2": "ก.พ.",
                                        "3": "มี.ค.",
                                        "4": "เม.ย.",
                                        "5": "พ.ค.",
                                        "6": "มิ.ย.",
                                        "7": "ก.ค.",
                                        "8": "ส.ค.",
                                        "9": "ก.ย.",
                                        "10": "ต.ค.",
                                        "11": "พ.ย.",
                                        "12": "ธ.ค."
                                    },
                                    "wide": {
                                        "1": "มกราคม",
                                        "2": "กุมภาพันธ์",
                                        "3": "มีนาคม",
                                        "4": "เมษายน",
                                        "5": "พฤษภาคม",
                                        "6": "มิถุนายน",
                                        "7": "กรกฎาคม",
                                        "8": "สิงหาคม",
                                        "9": "กันยายน",
                                        "10": "ตุลาคม",
                                        "11": "พฤศจิกายน",
                                        "12": "ธันวาคม"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "1": "ม.ค.",
                                        "2": "ก.พ.",
                                        "3": "มี.ค.",
                                        "4": "เม.ย.",
                                        "5": "พ.ค.",
                                        "6": "มิ.ย.",
                                        "7": "ก.ค.",
                                        "8": "ส.ค.",
                                        "9": "ก.ย.",
                                        "10": "ต.ค.",
                                        "11": "พ.ย.",
                                        "12": "ธ.ค."
                                    },
                                    "narrow": {
                                        "1": "ม.ค.",
                                        "2": "ก.พ.",
                                        "3": "มี.ค.",
                                        "4": "เม.ย.",
                                        "5": "พ.ค.",
                                        "6": "มิ.ย.",
                                        "7": "ก.ค.",
                                        "8": "ส.ค.",
                                        "9": "ก.ย.",
                                        "10": "ต.ค.",
                                        "11": "พ.ย.",
                                        "12": "ธ.ค."
                                    },
                                    "wide": {
                                        "1": "มกราคม",
                                        "2": "กุมภาพันธ์",
                                        "3": "มีนาคม",
                                        "4": "เมษายน",
                                        "5": "พฤษภาคม",
                                        "6": "มิถุนายน",
                                        "7": "กรกฎาคม",
                                        "8": "สิงหาคม",
                                        "9": "กันยายน",
                                        "10": "ตุลาคม",
                                        "11": "พฤศจิกายน",
                                        "12": "ธันวาคม"
                                    }
                                }
                            },
                            "days": {
                                "format": {
                                    "abbreviated": {
                                        "sun": "อา.",
                                        "mon": "จ.",
                                        "tue": "อ.",
                                        "wed": "พ.",
                                        "thu": "พฤ.",
                                        "fri": "ศ.",
                                        "sat": "ส."
                                    },
                                    "narrow": {
                                        "sun": "อา",
                                        "mon": "จ",
                                        "tue": "อ",
                                        "wed": "พ",
                                        "thu": "พฤ",
                                        "fri": "ศ",
                                        "sat": "ส"
                                    },
                                    "short": {
                                        "sun": "อา.",
                                        "mon": "จ.",
                                        "tue": "อ.",
                                        "wed": "พ.",
                                        "thu": "พฤ.",
                                        "fri": "ศ.",
                                        "sat": "ส."
                                    },
                                    "wide": {
                                        "sun": "วันอาทิตย์",
                                        "mon": "วันจันทร์",
                                        "tue": "วันอังคาร",
                                        "wed": "วันพุธ",
                                        "thu": "วันพฤหัสบดี",
                                        "fri": "วันศุกร์",
                                        "sat": "วันเสาร์"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "sun": "อา.",
                                        "mon": "จ.",
                                        "tue": "อ.",
                                        "wed": "พ.",
                                        "thu": "พฤ.",
                                        "fri": "ศ.",
                                        "sat": "ส."
                                    },
                                    "narrow": {
                                        "sun": "อา",
                                        "mon": "จ",
                                        "tue": "อ",
                                        "wed": "พ",
                                        "thu": "พฤ",
                                        "fri": "ศ",
                                        "sat": "ส"
                                    },
                                    "short": {
                                        "sun": "อา.",
                                        "mon": "จ.",
                                        "tue": "อ.",
                                        "wed": "พ.",
                                        "thu": "พฤ.",
                                        "fri": "ศ.",
                                        "sat": "ส."
                                    },
                                    "wide": {
                                        "sun": "วันอาทิตย์",
                                        "mon": "วันจันทร์",
                                        "tue": "วันอังคาร",
                                        "wed": "วันพุธ",
                                        "thu": "วันพฤหัสบดี",
                                        "fri": "วันศุกร์",
                                        "sat": "วันเสาร์"
                                    }
                                }
                            },
                            "quarters": {
                                "format": {
                                    "abbreviated": {
                                        "1": "ไตรมาส 1",
                                        "2": "ไตรมาส 2",
                                        "3": "ไตรมาส 3",
                                        "4": "ไตรมาส 4"
                                    },
                                    "narrow": {
                                        "1": "1",
                                        "2": "2",
                                        "3": "3",
                                        "4": "4"
                                    },
                                    "wide": {
                                        "1": "ไตรมาส 1",
                                        "2": "ไตรมาส 2",
                                        "3": "ไตรมาส 3",
                                        "4": "ไตรมาส 4"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "1": "ไตรมาส 1",
                                        "2": "ไตรมาส 2",
                                        "3": "ไตรมาส 3",
                                        "4": "ไตรมาส 4"
                                    },
                                    "narrow": {
                                        "1": "1",
                                        "2": "2",
                                        "3": "3",
                                        "4": "4"
                                    },
                                    "wide": {
                                        "1": "ไตรมาส 1",
                                        "2": "ไตรมาส 2",
                                        "3": "ไตรมาส 3",
                                        "4": "ไตรมาส 4"
                                    }
                                }
                            },
                            "dayPeriods": {
                                "format": {
                                    "abbreviated": {
                                        "am": "ก่อนเที่ยง",
                                        "pm": "หลังเที่ยง"
                                    },
                                    "narrow": {
                                        "am": "ก่อนเที่ยง",
                                        "pm": "หลังเที่ยง"
                                    },
                                    "wide": {
                                        "am": "ก่อนเที่ยง",
                                        "pm": "หลังเที่ยง"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "am": "ก่อนเที่ยง",
                                        "pm": "หลังเที่ยง"
                                    },
                                    "narrow": {
                                        "am": "ก่อนเที่ยง",
                                        "pm": "หลังเที่ยง"
                                    },
                                    "wide": {
                                        "am": "ก่อนเที่ยง",
                                        "pm": "หลังเที่ยง"
                                    }
                                }
                            },
                            "eras": {
                                "eraNames": {
                                    "0": "ปีก่อนคริสต์ศักราช",
                                    "1": "คริสต์ศักราช",
                                    "0-alt-variant": "ก่อนสามัญศักราช",
                                    "1-alt-variant": "สามัญศักราช"
                                },
                                "eraAbbr": {
                                    "0": "ปีก่อน ค.ศ.",
                                    "1": "ค.ศ.",
                                    "0-alt-variant": "ก.ส.ศ.",
                                    "1-alt-variant": "ส.ศ."
                                },
                                "eraNarrow": {
                                    "0": "ก่อน ค.ศ.",
                                    "1": "ค.ศ.",
                                    "0-alt-variant": "ก.ส.ศ.",
                                    "1-alt-variant": "ส.ศ."
                                }
                            },
                            "dateFormats": {
                                "full": "EEEEที่ d MMMM G y",
                                "long": "d MMMM y",
                                "medium": "d MMM y",
                                "short": "d/M/yy"
                            },
                            "timeFormats": {
                                "full": "H นาฬิกา mm นาที ss วินาที zzzz",
                                "long": "H นาฬิกา mm นาที ss วินาที z",
                                "medium": "HH:mm:ss",
                                "short": "HH:mm"
                            },
                            "dateTimeFormats": {
                                "full": "{1} {0}",
                                "long": "{1} {0}",
                                "medium": "{1} {0}",
                                "short": "{1} {0}",
                                "availableFormats": {
                                    "d": "d",
                                    "Ed": "E d",
                                    "Ehm": "E h:mm a",
                                    "EHm": "E HH:mm",
                                    "Ehms": "E h:mm:ss a",
                                    "EHms": "E HH:mm:ss",
                                    "Gy": "G y",
                                    "GyMMM": "MMM G y",
                                    "GyMMMd": "d MMM G y",
                                    "GyMMMEd": "E d MMM G y",
                                    "h": "h a",
                                    "H": "HH",
                                    "hm": "h:mm a",
                                    "Hm": "HH:mm",
                                    "hms": "h:mm:ss a",
                                    "Hms": "HH:mm:ss",
                                    "M": "L",
                                    "Md": "d/M",
                                    "MEd": "E d/M",
                                    "MMM": "LLL",
                                    "MMMd": "d MMM",
                                    "MMMEd": "E d MMM",
                                    "MMMMd": "d MMMM",
                                    "MMMMEd": "E d MMMM",
                                    "mmss": "mm:ss",
                                    "ms": "mm:ss",
                                    "y": "y",
                                    "yM": "M/y",
                                    "yMd": "d/M/y",
                                    "yMEd": "E d/M/y",
                                    "yMMM": "MMM y",
                                    "yMMMd": "d MMM y",
                                    "yMMMEd": "E d MMM y",
                                    "yMMMM": "MMMM y",
                                    "yQQQ": "QQQ y",
                                    "yQQQQ": "QQQQ y"
                                },
                                "appendItems": {
                                    "Day": "{0} ({2}: {1})",
                                    "Day-Of-Week": "{0} {1}",
                                    "Era": "{1} {0}",
                                    "Hour": "{0} ({2}: {1})",
                                    "Minute": "{0} ({2}: {1})",
                                    "Month": "{0} ({2}: {1})",
                                    "Quarter": "{0} ({2}: {1})",
                                    "Second": "{0} ({2}: {1})",
                                    "Timezone": "{0} {1}",
                                    "Week": "{0} ({2}: {1})",
                                    "Year": "{1} {0}"
                                },
                                "intervalFormats": {
                                    "intervalFormatFallback": "{0} – {1}",
                                    "d": {
                                        "d": "d-d"
                                    },
                                    "h": {
                                        "a": "h a - h a",
                                        "h": "h-h a"
                                    },
                                    "H": {
                                        "H": "HH–HH"
                                    },
                                    "hm": {
                                        "a": "h:mm a - h:mm a",
                                        "h": "h:mm-h:mm a",
                                        "m": "h:mm-h:mm a"
                                    },
                                    "Hm": {
                                        "H": "HH:mm-HH:mm",
                                        "m": "HH:mm-HH:mm"
                                    },
                                    "hmv": {
                                        "a": "h:mm a - h:mm a v",
                                        "h": "h:mm-h:mm a v",
                                        "m": "h:mm-h:mm a v"
                                    },
                                    "Hmv": {
                                        "H": "H:mm-H:mm v",
                                        "m": "H:mm-H:mm v"
                                    },
                                    "hv": {
                                        "a": "h a - h a v",
                                        "h": "h-h a v"
                                    },
                                    "Hv": {
                                        "H": "HH–HH v"
                                    },
                                    "M": {
                                        "M": "M-M"
                                    },
                                    "Md": {
                                        "d": "d/M - d/M",
                                        "M": "d/M - d/M"
                                    },
                                    "MEd": {
                                        "d": "E d - E d/M",
                                        "M": "E d - E d/M"
                                    },
                                    "MMM": {
                                        "M": "LLL-LLL"
                                    },
                                    "MMMd": {
                                        "d": "d - d MMM",
                                        "M": "d MMM - d MMM"
                                    },
                                    "MMMEd": {
                                        "d": "E d - E d MMM",
                                        "M": "E d MMM - E d MMM"
                                    },
                                    "y": {
                                        "y": "y-y"
                                    },
                                    "yM": {
                                        "M": "M/y - M/y",
                                        "y": "M/y - M/y"
                                    },
                                    "yMd": {
                                        "d": "d-d/M/y",
                                        "M": "d/M/y - d/M/y",
                                        "y": "d/M/y - d/M/y"
                                    },
                                    "yMEd": {
                                        "d": "E d - E d/M/y",
                                        "M": "E d/M/y - E d/M/y",
                                        "y": "E d/M/y - E d/M/y"
                                    },
                                    "yMMM": {
                                        "M": "MMM–MMM y",
                                        "y": "MMM y - MMM y"
                                    },
                                    "yMMMd": {
                                        "d": "d-d MMM y",
                                        "M": "d MMM - d MMM y",
                                        "y": "d MMM y - d MMM y"
                                    },
                                    "yMMMEd": {
                                        "d": "E d - E d MMM y",
                                        "M": "E d MMM - E d MMM y",
                                        "y": "E d MMM y - E d MMM y"
                                    },
                                    "yMMMM": {
                                        "M": "MMMM–MMMM y",
                                        "y": "MMMM y - MMMM y"
                                    }
                                }
                            }
                        }
                    },
                    "timeZoneNames": {
                        "hourFormat": "+HH:mm;-HH:mm",
                        "gmtFormat": "GMT{0}",
                        "gmtZeroFormat": "GMT",
                        "regionFormat": "เวลา{0}",
                        "regionFormat-type-daylight": "เวลาออมแสง{0}",
                        "regionFormat-type-standard": "เวลามาตรฐาน{0}",
                        "fallbackFormat": "{1} ({0})"
                    }
                }
            },
            "tr": {
                "dates": {
                    "calendars": {
                        "gregorian": {
                            "months": {
                                "format": {
                                    "abbreviated": {
                                        "1": "Oca",
                                        "2": "Şub",
                                        "3": "Mar",
                                        "4": "Nis",
                                        "5": "May",
                                        "6": "Haz",
                                        "7": "Tem",
                                        "8": "Ağu",
                                        "9": "Eyl",
                                        "10": "Eki",
                                        "11": "Kas",
                                        "12": "Ara"
                                    },
                                    "narrow": {
                                        "1": "O",
                                        "2": "Ş",
                                        "3": "M",
                                        "4": "N",
                                        "5": "M",
                                        "6": "H",
                                        "7": "T",
                                        "8": "A",
                                        "9": "E",
                                        "10": "E",
                                        "11": "K",
                                        "12": "A"
                                    },
                                    "wide": {
                                        "1": "Ocak",
                                        "2": "Şubat",
                                        "3": "Mart",
                                        "4": "Nisan",
                                        "5": "Mayıs",
                                        "6": "Haziran",
                                        "7": "Temmuz",
                                        "8": "Ağustos",
                                        "9": "Eylül",
                                        "10": "Ekim",
                                        "11": "Kasım",
                                        "12": "Aralık"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "1": "Oca",
                                        "2": "Şub",
                                        "3": "Mar",
                                        "4": "Nis",
                                        "5": "May",
                                        "6": "Haz",
                                        "7": "Tem",
                                        "8": "Ağu",
                                        "9": "Eyl",
                                        "10": "Eki",
                                        "11": "Kas",
                                        "12": "Ara"
                                    },
                                    "narrow": {
                                        "1": "O",
                                        "2": "Ş",
                                        "3": "M",
                                        "4": "N",
                                        "5": "M",
                                        "6": "H",
                                        "7": "T",
                                        "8": "A",
                                        "9": "E",
                                        "10": "E",
                                        "11": "K",
                                        "12": "A"
                                    },
                                    "wide": {
                                        "1": "Ocak",
                                        "2": "Şubat",
                                        "3": "Mart",
                                        "4": "Nisan",
                                        "5": "Mayıs",
                                        "6": "Haziran",
                                        "7": "Temmuz",
                                        "8": "Ağustos",
                                        "9": "Eylül",
                                        "10": "Ekim",
                                        "11": "Kasım",
                                        "12": "Aralık"
                                    }
                                }
                            },
                            "days": {
                                "format": {
                                    "abbreviated": {
                                        "sun": "Paz",
                                        "mon": "Pzt",
                                        "tue": "Sal",
                                        "wed": "Çar",
                                        "thu": "Per",
                                        "fri": "Cum",
                                        "sat": "Cmt"
                                    },
                                    "narrow": {
                                        "sun": "P",
                                        "mon": "P",
                                        "tue": "S",
                                        "wed": "Ç",
                                        "thu": "P",
                                        "fri": "C",
                                        "sat": "C"
                                    },
                                    "short": {
                                        "sun": "Pa",
                                        "mon": "Pt",
                                        "tue": "Sa",
                                        "wed": "Ça",
                                        "thu": "Pe",
                                        "fri": "Cu",
                                        "sat": "Ct"
                                    },
                                    "wide": {
                                        "sun": "Pazar",
                                        "mon": "Pazartesi",
                                        "tue": "Salı",
                                        "wed": "Çarşamba",
                                        "thu": "Perşembe",
                                        "fri": "Cuma",
                                        "sat": "Cumartesi"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "sun": "Paz",
                                        "mon": "Pzt",
                                        "tue": "Sal",
                                        "wed": "Çar",
                                        "thu": "Per",
                                        "fri": "Cum",
                                        "sat": "Cmt"
                                    },
                                    "narrow": {
                                        "sun": "P",
                                        "mon": "P",
                                        "tue": "S",
                                        "wed": "Ç",
                                        "thu": "P",
                                        "fri": "C",
                                        "sat": "C"
                                    },
                                    "short": {
                                        "sun": "Pa",
                                        "mon": "Pt",
                                        "tue": "Sa",
                                        "wed": "Ça",
                                        "thu": "Pe",
                                        "fri": "Cu",
                                        "sat": "Ct"
                                    },
                                    "wide": {
                                        "sun": "Pazar",
                                        "mon": "Pazartesi",
                                        "tue": "Salı",
                                        "wed": "Çarşamba",
                                        "thu": "Perşembe",
                                        "fri": "Cuma",
                                        "sat": "Cumartesi"
                                    }
                                }
                            },
                            "quarters": {
                                "format": {
                                    "abbreviated": {
                                        "1": "Ç1",
                                        "2": "Ç2",
                                        "3": "Ç3",
                                        "4": "Ç4"
                                    },
                                    "narrow": {
                                        "1": "1.",
                                        "2": "2.",
                                        "3": "3.",
                                        "4": "4."
                                    },
                                    "wide": {
                                        "1": "1. çeyrek",
                                        "2": "2. çeyrek",
                                        "3": "3. çeyrek",
                                        "4": "4. çeyrek"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "1": "Ç1",
                                        "2": "Ç2",
                                        "3": "Ç3",
                                        "4": "Ç4"
                                    },
                                    "narrow": {
                                        "1": "1.",
                                        "2": "2.",
                                        "3": "3.",
                                        "4": "4."
                                    },
                                    "wide": {
                                        "1": "1. çeyrek",
                                        "2": "2. çeyrek",
                                        "3": "3. çeyrek",
                                        "4": "4. çeyrek"
                                    }
                                }
                            },
                            "dayPeriods": {
                                "format": {
                                    "abbreviated": {
                                        "am": "ÖÖ",
                                        "pm": "ÖS"
                                    },
                                    "narrow": {
                                        "am": "ÖÖ",
                                        "pm": "ÖS"
                                    },
                                    "wide": {
                                        "am": "ÖÖ",
                                        "pm": "ÖS"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "am": "ÖÖ",
                                        "pm": "ÖS"
                                    },
                                    "narrow": {
                                        "am": "ÖÖ",
                                        "pm": "ÖS"
                                    },
                                    "wide": {
                                        "am": "ÖÖ",
                                        "pm": "ÖS"
                                    }
                                }
                            },
                            "eras": {
                                "eraNames": {
                                    "0": "Milattan Önce",
                                    "1": "Milattan Sonra",
                                    "0-alt-variant": "İÖ",
                                    "1-alt-variant": "İS"
                                },
                                "eraAbbr": {
                                    "0": "MÖ",
                                    "1": "MS",
                                    "0-alt-variant": "İÖ",
                                    "1-alt-variant": "İS"
                                },
                                "eraNarrow": {
                                    "0": "MÖ",
                                    "1": "MS",
                                    "0-alt-variant": "İÖ",
                                    "1-alt-variant": "İS"
                                }
                            },
                            "dateFormats": {
                                "full": "d MMMM y EEEE",
                                "long": "d MMMM y",
                                "medium": "d MMM y",
                                "short": "d.MM.y"
                            },
                            "timeFormats": {
                                "full": "HH:mm:ss zzzz",
                                "long": "HH:mm:ss z",
                                "medium": "HH:mm:ss",
                                "short": "HH:mm"
                            },
                            "dateTimeFormats": {
                                "full": "{1} {0}",
                                "long": "{1} {0}",
                                "medium": "{1} {0}",
                                "short": "{1} {0}",
                                "availableFormats": {
                                    "d": "d",
                                    "Ed": "d E",
                                    "Ehm": "E a h:mm",
                                    "EHm": "E HH:mm",
                                    "Ehms": "E a h:mm:ss",
                                    "EHms": "E HH:mm:ss",
                                    "Gy": "G y",
                                    "GyMMM": "G MMM y",
                                    "GyMMMd": "G dd MMM y",
                                    "GyMMMEd": "G d MMM y E",
                                    "h": "a h",
                                    "H": "HH",
                                    "hm": "a h:mm",
                                    "Hm": "HH:mm",
                                    "hms": "a h:mm:ss",
                                    "Hms": "HH:mm:ss",
                                    "M": "L",
                                    "Md": "dd/MM",
                                    "MEd": "dd/MM E",
                                    "MMM": "LLL",
                                    "MMMd": "d MMM",
                                    "MMMEd": "d MMMM E",
                                    "MMMMd": "dd MMMM",
                                    "MMMMEd": "dd MMMM E",
                                    "mmss": "mm:ss",
                                    "ms": "mm:ss",
                                    "y": "y",
                                    "yM": "MM/y",
                                    "yMd": "dd.MM.y",
                                    "yMEd": "dd.MM.y E",
                                    "yMM": "MM.y",
                                    "yMMM": "MMM y",
                                    "yMMMd": "dd MMM y",
                                    "yMMMEd": "d MMM y E",
                                    "yMMMM": "MMMM y",
                                    "yQQQ": "y/QQQ",
                                    "yQQQQ": "y/QQQQ"
                                },
                                "appendItems": {
                                    "Day": "{0} ({2}: {1})",
                                    "Day-Of-Week": "{0} {1}",
                                    "Era": "{1} {0}",
                                    "Hour": "{0} ({2}: {1})",
                                    "Minute": "{0} ({2}: {1})",
                                    "Month": "{0} ({2}: {1})",
                                    "Quarter": "{0} ({2}: {1})",
                                    "Second": "{0} ({2}: {1})",
                                    "Timezone": "{0} {1}",
                                    "Week": "{0} ({2}: {1})",
                                    "Year": "{1} {0}"
                                },
                                "intervalFormats": {
                                    "intervalFormatFallback": "{0} – {1}",
                                    "d": {
                                        "d": "d–d"
                                    },
                                    "h": {
                                        "a": "a h – a h",
                                        "h": "a h–h"
                                    },
                                    "H": {
                                        "H": "HH–HH"
                                    },
                                    "hm": {
                                        "a": "a h:mm – a h:mm",
                                        "h": "a h:mm–h:mm",
                                        "m": "a h:mm–h:mm"
                                    },
                                    "Hm": {
                                        "H": "HH:mm–HH:mm",
                                        "m": "HH:mm–HH:mm"
                                    },
                                    "hmv": {
                                        "a": "a h:mm – a h:mm v",
                                        "h": "a h:mm–h:mm v",
                                        "m": "a h:mm–h:mm v"
                                    },
                                    "Hmv": {
                                        "H": "HH:mm–HH:mm v",
                                        "m": "HH:mm–HH:mm v"
                                    },
                                    "hv": {
                                        "a": "a h – a h v",
                                        "h": "a h–h v"
                                    },
                                    "Hv": {
                                        "H": "HH–HH v"
                                    },
                                    "M": {
                                        "M": "MM–MM"
                                    },
                                    "Md": {
                                        "d": "dd/MM – dd/MM",
                                        "M": "dd/MM – dd/MM"
                                    },
                                    "MEd": {
                                        "d": "dd/MM E – dd/MM E",
                                        "M": "dd/MM E – dd/MM E"
                                    },
                                    "MMM": {
                                        "M": "MMM–MMM"
                                    },
                                    "MMMd": {
                                        "d": "d – d MMM",
                                        "M": "d MMM – d MMM"
                                    },
                                    "MMMEd": {
                                        "d": "d MMM E – d MMM E",
                                        "M": "d MMM E – d MMM E"
                                    },
                                    "y": {
                                        "y": "y–y"
                                    },
                                    "yM": {
                                        "M": "MM/y – MM/y",
                                        "y": "MM/y – MM/y"
                                    },
                                    "yMd": {
                                        "d": "dd.MM.y – dd.MM.y",
                                        "M": "dd.MM.y – dd.MM.y",
                                        "y": "dd.MM.y – dd.MM.y"
                                    },
                                    "yMEd": {
                                        "d": "dd.MM.y E – dd.MM.y E",
                                        "M": "dd.MM.y E – dd.MM.y E",
                                        "y": "dd.MM.y E – dd.MM.y E"
                                    },
                                    "yMMM": {
                                        "M": "MMM–MMM y",
                                        "y": "MMM y – MMM y"
                                    },
                                    "yMMMd": {
                                        "d": "d–d MMM y",
                                        "M": "d MMM – d MMM y",
                                        "y": "d MMM y – d MMM y"
                                    },
                                    "yMMMEd": {
                                        "d": "d MMM y E – d MMM y E",
                                        "M": "d MMM y E – d MMM y E",
                                        "y": "d MMM y E – d MMM y E"
                                    },
                                    "yMMMM": {
                                        "M": "MMMM – MMMM y",
                                        "y": "MMMM y – MMMM y"
                                    }
                                }
                            }
                        }
                    },
                    "timeZoneNames": {
                        "hourFormat": "+HH:mm;-HH:mm",
                        "gmtFormat": "GMT{0}",
                        "gmtZeroFormat": "GMT",
                        "regionFormat": "{0} Saati",
                        "regionFormat-type-daylight": "{0} Yaz Saati",
                        "regionFormat-type-standard": "{0} Standart Saati",
                        "fallbackFormat": "{1} ({0})"
                    }
                }
            },
            "uk": {
                "dates": {
                    "calendars": {
                        "gregorian": {
                            "months": {
                                "format": {
                                    "abbreviated": {
                                        "1": "січ.",
                                        "2": "лют.",
                                        "3": "бер.",
                                        "4": "квіт.",
                                        "5": "трав.",
                                        "6": "черв.",
                                        "7": "лип.",
                                        "8": "серп.",
                                        "9": "вер.",
                                        "10": "жовт.",
                                        "11": "лист.",
                                        "12": "груд."
                                    },
                                    "narrow": {
                                        "1": "С",
                                        "2": "Л",
                                        "3": "Б",
                                        "4": "К",
                                        "5": "Т",
                                        "6": "Ч",
                                        "7": "Л",
                                        "8": "С",
                                        "9": "В",
                                        "10": "Ж",
                                        "11": "Л",
                                        "12": "Г"
                                    },
                                    "wide": {
                                        "1": "січня",
                                        "2": "лютого",
                                        "3": "березня",
                                        "4": "квітня",
                                        "5": "травня",
                                        "6": "червня",
                                        "7": "липня",
                                        "8": "серпня",
                                        "9": "вересня",
                                        "10": "жовтня",
                                        "11": "листопада",
                                        "12": "грудня"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "1": "Січ",
                                        "2": "Лют",
                                        "3": "Бер",
                                        "4": "Кві",
                                        "5": "Тра",
                                        "6": "Чер",
                                        "7": "Лип",
                                        "8": "Сер",
                                        "9": "Вер",
                                        "10": "Жов",
                                        "11": "Лис",
                                        "12": "Гру"
                                    },
                                    "narrow": {
                                        "1": "С",
                                        "2": "Л",
                                        "3": "Б",
                                        "4": "К",
                                        "5": "Т",
                                        "6": "Ч",
                                        "7": "Л",
                                        "8": "С",
                                        "9": "В",
                                        "10": "Ж",
                                        "11": "Л",
                                        "12": "Г"
                                    },
                                    "wide": {
                                        "1": "Січень",
                                        "2": "Лютий",
                                        "3": "Березень",
                                        "4": "Квітень",
                                        "5": "Травень",
                                        "6": "Червень",
                                        "7": "Липень",
                                        "8": "Серпень",
                                        "9": "Вересень",
                                        "10": "Жовтень",
                                        "11": "Листопад",
                                        "12": "Грудень"
                                    }
                                }
                            },
                            "days": {
                                "format": {
                                    "abbreviated": {
                                        "sun": "Нд",
                                        "mon": "Пн",
                                        "tue": "Вт",
                                        "wed": "Ср",
                                        "thu": "Чт",
                                        "fri": "Пт",
                                        "sat": "Сб"
                                    },
                                    "narrow": {
                                        "sun": "Н",
                                        "mon": "П",
                                        "tue": "В",
                                        "wed": "С",
                                        "thu": "Ч",
                                        "fri": "П",
                                        "sat": "С"
                                    },
                                    "short": {
                                        "sun": "Нд",
                                        "mon": "Пн",
                                        "tue": "Вт",
                                        "wed": "Ср",
                                        "thu": "Чт",
                                        "fri": "Пт",
                                        "sat": "Сб"
                                    },
                                    "wide": {
                                        "sun": "неділя",
                                        "mon": "понеділок",
                                        "tue": "вівторок",
                                        "wed": "середа",
                                        "thu": "четвер",
                                        "fri": "пʼятниця",
                                        "sat": "субота"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "sun": "Нд",
                                        "mon": "Пн",
                                        "tue": "Вт",
                                        "wed": "Ср",
                                        "thu": "Чт",
                                        "fri": "Пт",
                                        "sat": "Сб"
                                    },
                                    "narrow": {
                                        "sun": "Н",
                                        "mon": "П",
                                        "tue": "В",
                                        "wed": "С",
                                        "thu": "Ч",
                                        "fri": "П",
                                        "sat": "С"
                                    },
                                    "short": {
                                        "sun": "Нд",
                                        "mon": "Пн",
                                        "tue": "Вт",
                                        "wed": "Ср",
                                        "thu": "Чт",
                                        "fri": "Пт",
                                        "sat": "Сб"
                                    },
                                    "wide": {
                                        "sun": "Неділя",
                                        "mon": "Понеділок",
                                        "tue": "Вівторок",
                                        "wed": "Середа",
                                        "thu": "Четвер",
                                        "fri": "Пʼятниця",
                                        "sat": "Субота"
                                    }
                                }
                            },
                            "quarters": {
                                "format": {
                                    "abbreviated": {
                                        "1": "I кв.",
                                        "2": "II кв.",
                                        "3": "III кв.",
                                        "4": "IV кв."
                                    },
                                    "narrow": {
                                        "1": "1",
                                        "2": "2",
                                        "3": "3",
                                        "4": "4"
                                    },
                                    "wide": {
                                        "1": "I квартал",
                                        "2": "II квартал",
                                        "3": "III квартал",
                                        "4": "IV квартал"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "1": "1-й кв.",
                                        "2": "2-й кв.",
                                        "3": "3-й кв.",
                                        "4": "4-й кв."
                                    },
                                    "narrow": {
                                        "1": "1",
                                        "2": "2",
                                        "3": "3",
                                        "4": "4"
                                    },
                                    "wide": {
                                        "1": "1-й квартал",
                                        "2": "2-й квартал",
                                        "3": "3-й квартал",
                                        "4": "4-й квартал"
                                    }
                                }
                            },
                            "dayPeriods": {
                                "format": {
                                    "abbreviated": {
                                        "afternoon": "дня",
                                        "am": "дп",
                                        "evening": "вечора",
                                        "morning": "ранку",
                                        "night": "ночі",
                                        "pm": "пп"
                                    },
                                    "narrow": {
                                        "afternoon": "дня",
                                        "am": "дп",
                                        "evening": "вечора",
                                        "morning": "ранку",
                                        "night": "ночі",
                                        "pm": "пп"
                                    },
                                    "wide": {
                                        "afternoon": "дня",
                                        "am": "дп",
                                        "evening": "вечора",
                                        "morning": "ранку",
                                        "night": "ночі",
                                        "pm": "пп"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "afternoon": "дня",
                                        "am": "дп",
                                        "evening": "вечора",
                                        "morning": "ранку",
                                        "night": "ночі",
                                        "pm": "пп"
                                    },
                                    "narrow": {
                                        "afternoon": "дня",
                                        "am": "дп",
                                        "evening": "вечора",
                                        "morning": "ранку",
                                        "night": "ночі",
                                        "pm": "пп"
                                    },
                                    "wide": {
                                        "afternoon": "дня",
                                        "am": "дп",
                                        "evening": "вечора",
                                        "morning": "ранку",
                                        "night": "ночі",
                                        "pm": "пп"
                                    }
                                }
                            },
                            "eras": {
                                "eraNames": {
                                    "0": "до нашої ери",
                                    "1": "нашої ери",
                                    "0-alt-variant": "BCE",
                                    "1-alt-variant": "CE"
                                },
                                "eraAbbr": {
                                    "0": "до н.е.",
                                    "1": "н.е.",
                                    "0-alt-variant": "BCE",
                                    "1-alt-variant": "CE"
                                },
                                "eraNarrow": {
                                    "0": "до н.е.",
                                    "1": "н.е.",
                                    "0-alt-variant": "BCE",
                                    "1-alt-variant": "CE"
                                }
                            },
                            "dateFormats": {
                                "full": "EEEE, d MMMM y 'р'.",
                                "long": "d MMMM y 'р'.",
                                "medium": "d MMM y",
                                "short": "dd.MM.yy"
                            },
                            "timeFormats": {
                                "full": "HH:mm:ss zzzz",
                                "long": "HH:mm:ss z",
                                "medium": "HH:mm:ss",
                                "short": "HH:mm"
                            },
                            "dateTimeFormats": {
                                "full": "{1} {0}",
                                "long": "{1} {0}",
                                "medium": "{1} {0}",
                                "short": "{1} {0}",
                                "availableFormats": {
                                    "d": "d",
                                    "Ed": "E, d",
                                    "Ehm": "E h:mm a",
                                    "EHm": "E HH:mm",
                                    "Ehms": "E h:mm:ss a",
                                    "EHms": "E HH:mm:ss",
                                    "Gy": "y G",
                                    "GyMMM": "LLL y G",
                                    "GyMMMd": "d MMM y G",
                                    "GyMMMEd": "E, d MMM y G",
                                    "h": "h a",
                                    "H": "HH",
                                    "HHmm": "HH:mm",
                                    "HHmmss": "HH:mm:ss",
                                    "hm": "h:mm a",
                                    "Hm": "HH:mm",
                                    "hms": "h:mm:ss a",
                                    "Hms": "HH:mm:ss",
                                    "M": "L",
                                    "Md": "dd.MM",
                                    "MEd": "E, dd.MM",
                                    "MMM": "LLL",
                                    "MMMd": "d MMM",
                                    "MMMEd": "E, d MMM",
                                    "MMMMd": "d MMMM",
                                    "MMMMEd": "E, d MMMM",
                                    "ms": "mm:ss",
                                    "y": "y",
                                    "yM": "MM.y",
                                    "yMd": "dd.MM.y",
                                    "yMEd": "E, dd.MM.y",
                                    "yMMM": "LLL y",
                                    "yMMMd": "d MMM y",
                                    "yMMMEd": "E, d MMM y",
                                    "yMMMM": "LLLL y",
                                    "yQQQ": "QQQ y",
                                    "yQQQQ": "QQQQ y 'р'."
                                },
                                "appendItems": {
                                    "Day": "{0} ({2}: {1})",
                                    "Day-Of-Week": "{0} {1}",
                                    "Era": "{1} {0}",
                                    "Hour": "{0} ({2}: {1})",
                                    "Minute": "{0} ({2}: {1})",
                                    "Month": "{0} ({2}: {1})",
                                    "Quarter": "{0} ({2}: {1})",
                                    "Second": "{0} ({2}: {1})",
                                    "Timezone": "{0} {1}",
                                    "Week": "{0} ({2}: {1})",
                                    "Year": "{1} {0}"
                                },
                                "intervalFormats": {
                                    "intervalFormatFallback": "{0} – {1}",
                                    "d": {
                                        "d": "d–d"
                                    },
                                    "h": {
                                        "a": "h a – h a",
                                        "h": "h–h a"
                                    },
                                    "H": {
                                        "H": "HH–HH"
                                    },
                                    "hm": {
                                        "a": "h:mm a – h:mm a",
                                        "h": "h:mm–h:mm a",
                                        "m": "h:mm–h:mm a"
                                    },
                                    "Hm": {
                                        "H": "HH:mm–HH:mm",
                                        "m": "HH:mm–HH:mm"
                                    },
                                    "hmv": {
                                        "a": "h:mm a – h:mm a v",
                                        "h": "h:mm–h:mm a v",
                                        "m": "h:mm–h:mm a v"
                                    },
                                    "Hmv": {
                                        "H": "HH:mm–HH:mm v",
                                        "m": "HH:mm–HH:mm v"
                                    },
                                    "hv": {
                                        "a": "h a – h a v",
                                        "h": "h–h a v"
                                    },
                                    "Hv": {
                                        "H": "HH–HH v"
                                    },
                                    "M": {
                                        "M": "M–M"
                                    },
                                    "Md": {
                                        "d": "dd.MM – dd.MM",
                                        "M": "dd.MM – dd.MM"
                                    },
                                    "MEd": {
                                        "d": "E, dd.MM – E, dd.MM",
                                        "M": "E, dd.MM – E, dd.MM"
                                    },
                                    "MMM": {
                                        "M": "LLL–LLL"
                                    },
                                    "MMMd": {
                                        "d": "d–d MMM",
                                        "M": "d MMM – d MMM"
                                    },
                                    "MMMEd": {
                                        "d": "E, d – E, d MMM",
                                        "M": "E, d MMM – E, d MMM"
                                    },
                                    "y": {
                                        "y": "y–y"
                                    },
                                    "yM": {
                                        "M": "MM.y – MM.y",
                                        "y": "MM.y – MM.y"
                                    },
                                    "yMd": {
                                        "d": "dd.MM.y – dd.MM.y",
                                        "M": "dd.MM.y – dd.MM.y",
                                        "y": "dd.MM.y – dd.MM.y"
                                    },
                                    "yMEd": {
                                        "d": "E, dd.MM.y – E, dd.MM.y",
                                        "M": "E, dd.MM.y – E, dd.MM.y",
                                        "y": "E, dd.MM.y – E, dd.MM.y"
                                    },
                                    "yMMM": {
                                        "M": "LLL–LLL y",
                                        "y": "LLL y – LLL y"
                                    },
                                    "yMMMd": {
                                        "d": "d–d MMM y",
                                        "M": "d MMM – d MMM y",
                                        "y": "d MMM y – d MMM y"
                                    },
                                    "yMMMEd": {
                                        "d": "E, d – E, d MMM y",
                                        "M": "E, d MMM – E, d MMM y",
                                        "y": "E, d MMM y – E, d MMM y"
                                    },
                                    "yMMMM": {
                                        "M": "LLLL – LLLL y",
                                        "y": "LLLL y – LLLL y"
                                    }
                                }
                            }
                        }
                    },
                    "timeZoneNames": {
                        "hourFormat": "+HH:mm;-HH:mm",
                        "gmtFormat": "GMT{0}",
                        "gmtZeroFormat": "GMT",
                        "regionFormat": "Час: {0}",
                        "regionFormat-type-daylight": "Час: {0}, літній",
                        "regionFormat-type-standard": "Час: {0}, стандартний",
                        "fallbackFormat": "{1} ({0})"
                    }
                }
            },
            "vi": {
                "dates": {
                    "calendars": {
                        "gregorian": {
                            "months": {
                                "format": {
                                    "abbreviated": {
                                        "1": "thg 1",
                                        "2": "thg 2",
                                        "3": "thg 3",
                                        "4": "thg 4",
                                        "5": "thg 5",
                                        "6": "thg 6",
                                        "7": "thg 7",
                                        "8": "thg 8",
                                        "9": "thg 9",
                                        "10": "thg 10",
                                        "11": "thg 11",
                                        "12": "thg 12"
                                    },
                                    "narrow": {
                                        "1": "1",
                                        "2": "2",
                                        "3": "3",
                                        "4": "4",
                                        "5": "5",
                                        "6": "6",
                                        "7": "7",
                                        "8": "8",
                                        "9": "9",
                                        "10": "10",
                                        "11": "11",
                                        "12": "12"
                                    },
                                    "wide": {
                                        "1": "tháng 1",
                                        "2": "tháng 2",
                                        "3": "tháng 3",
                                        "4": "tháng 4",
                                        "5": "tháng 5",
                                        "6": "tháng 6",
                                        "7": "tháng 7",
                                        "8": "tháng 8",
                                        "9": "tháng 9",
                                        "10": "tháng 10",
                                        "11": "tháng 11",
                                        "12": "tháng 12"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "1": "Thg 1",
                                        "2": "Thg 2",
                                        "3": "Thg 3",
                                        "4": "Thg 4",
                                        "5": "Thg 5",
                                        "6": "Thg 6",
                                        "7": "Thg 7",
                                        "8": "Thg 8",
                                        "9": "Thg 9",
                                        "10": "Thg 10",
                                        "11": "Thg 11",
                                        "12": "Thg 12"
                                    },
                                    "narrow": {
                                        "1": "1",
                                        "2": "2",
                                        "3": "3",
                                        "4": "4",
                                        "5": "5",
                                        "6": "6",
                                        "7": "7",
                                        "8": "8",
                                        "9": "9",
                                        "10": "10",
                                        "11": "11",
                                        "12": "12"
                                    },
                                    "wide": {
                                        "1": "Tháng 1",
                                        "2": "Tháng 2",
                                        "3": "Tháng 3",
                                        "4": "Tháng 4",
                                        "5": "Tháng 5",
                                        "6": "Tháng 6",
                                        "7": "Tháng 7",
                                        "8": "Tháng 8",
                                        "9": "Tháng 9",
                                        "10": "Tháng 10",
                                        "11": "Tháng 11",
                                        "12": "Tháng 12"
                                    }
                                }
                            },
                            "days": {
                                "format": {
                                    "abbreviated": {
                                        "sun": "CN",
                                        "mon": "Th 2",
                                        "tue": "Th 3",
                                        "wed": "Th 4",
                                        "thu": "Th 5",
                                        "fri": "Th 6",
                                        "sat": "Th 7"
                                    },
                                    "narrow": {
                                        "sun": "CN",
                                        "mon": "T2",
                                        "tue": "T3",
                                        "wed": "T4",
                                        "thu": "T5",
                                        "fri": "T6",
                                        "sat": "T7"
                                    },
                                    "short": {
                                        "sun": "CN",
                                        "mon": "T2",
                                        "tue": "T3",
                                        "wed": "T4",
                                        "thu": "T5",
                                        "fri": "T6",
                                        "sat": "T7"
                                    },
                                    "wide": {
                                        "sun": "Chủ Nhật",
                                        "mon": "Thứ Hai",
                                        "tue": "Thứ Ba",
                                        "wed": "Thứ Tư",
                                        "thu": "Thứ Năm",
                                        "fri": "Thứ Sáu",
                                        "sat": "Thứ Bảy"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "sun": "CN",
                                        "mon": "Th 2",
                                        "tue": "Th 3",
                                        "wed": "Th 4",
                                        "thu": "Th 5",
                                        "fri": "Th 6",
                                        "sat": "Th 7"
                                    },
                                    "narrow": {
                                        "sun": "CN",
                                        "mon": "T2",
                                        "tue": "T3",
                                        "wed": "T4",
                                        "thu": "T5",
                                        "fri": "T6",
                                        "sat": "T7"
                                    },
                                    "short": {
                                        "sun": "CN",
                                        "mon": "T2",
                                        "tue": "T3",
                                        "wed": "T4",
                                        "thu": "T5",
                                        "fri": "T6",
                                        "sat": "T7"
                                    },
                                    "wide": {
                                        "sun": "Chủ Nhật",
                                        "mon": "Thứ Hai",
                                        "tue": "Thứ Ba",
                                        "wed": "Thứ Tư",
                                        "thu": "Thứ Năm",
                                        "fri": "Thứ Sáu",
                                        "sat": "Thứ Bảy"
                                    }
                                }
                            },
                            "quarters": {
                                "format": {
                                    "abbreviated": {
                                        "1": "Q1",
                                        "2": "Q2",
                                        "3": "Q3",
                                        "4": "Q4"
                                    },
                                    "narrow": {
                                        "1": "1",
                                        "2": "2",
                                        "3": "3",
                                        "4": "4"
                                    },
                                    "wide": {
                                        "1": "Quý 1",
                                        "2": "Quý 2",
                                        "3": "Quý 3",
                                        "4": "Quý 4"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "1": "Q1",
                                        "2": "Q2",
                                        "3": "Q3",
                                        "4": "Q4"
                                    },
                                    "narrow": {
                                        "1": "1",
                                        "2": "2",
                                        "3": "3",
                                        "4": "4"
                                    },
                                    "wide": {
                                        "1": "Quý 1",
                                        "2": "Quý 2",
                                        "3": "Quý 3",
                                        "4": "Quý 4"
                                    }
                                }
                            },
                            "dayPeriods": {
                                "format": {
                                    "abbreviated": {
                                        "am": "SA",
                                        "pm": "CH"
                                    },
                                    "narrow": {
                                        "am": "SA",
                                        "pm": "CH"
                                    },
                                    "wide": {
                                        "am": "SA",
                                        "pm": "CH"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "am": "SA",
                                        "pm": "CH"
                                    },
                                    "narrow": {
                                        "am": "SA",
                                        "pm": "CH"
                                    },
                                    "wide": {
                                        "am": "SA",
                                        "pm": "CH"
                                    }
                                }
                            },
                            "eras": {
                                "eraNames": {
                                    "0": "tr. CN",
                                    "1": "sau CN",
                                    "0-alt-variant": "BCE",
                                    "1-alt-variant": "CE"
                                },
                                "eraAbbr": {
                                    "0": "tr. CN",
                                    "1": "sau CN",
                                    "0-alt-variant": "BCE",
                                    "1-alt-variant": "CE"
                                },
                                "eraNarrow": {
                                    "0": "tr. CN",
                                    "1": "sau CN",
                                    "0-alt-variant": "BCE",
                                    "1-alt-variant": "CE"
                                }
                            },
                            "dateFormats": {
                                "full": "EEEE, 'ngày' dd MMMM 'năm' y",
                                "long": "'Ngày' dd 'tháng' MM 'năm' y",
                                "medium": "dd-MM-y",
                                "short": "dd/MM/y"
                            },
                            "timeFormats": {
                                "full": "HH:mm:ss zzzz",
                                "long": "HH:mm:ss z",
                                "medium": "HH:mm:ss",
                                "short": "HH:mm"
                            },
                            "dateTimeFormats": {
                                "full": "{0} {1}",
                                "long": "{0} {1}",
                                "medium": "{0} {1}",
                                "short": "{0} {1}",
                                "availableFormats": {
                                    "d": "d",
                                    "Ed": "E, dd",
                                    "Ehm": "E h:mm a",
                                    "EHm": "E HH:mm",
                                    "Ehms": "E h:mm:ss a",
                                    "EHms": "E HH:mm:ss",
                                    "Gy": "'Năm' y G",
                                    "GyMMM": "MMM y G",
                                    "GyMMMd": "dd MMM, y G",
                                    "GyMMMEd": "E, dd MMM y G",
                                    "h": "h a",
                                    "H": "HH",
                                    "hm": "h:mm a",
                                    "Hm": "H:mm",
                                    "hms": "h:mm:ss a",
                                    "Hms": "H:mm:ss",
                                    "M": "L",
                                    "Md": "dd-M",
                                    "MEd": "E, dd-M",
                                    "MMdd": "dd-MM",
                                    "MMM": "LLL",
                                    "MMMd": "dd MMM",
                                    "MMMEd": "E, dd MMM",
                                    "MMMMd": "dd MMMM",
                                    "MMMMEd": "E, dd MMMM",
                                    "mmss": "mm:ss",
                                    "ms": "mm:ss",
                                    "y": "'Năm' y",
                                    "yM": "M/y",
                                    "yMd": "d/M/y",
                                    "yMEd": "E, dd-M-y",
                                    "yMM": "MM-y",
                                    "yMMM": "MMM y",
                                    "yMMMd": "dd MMM, y",
                                    "yMMMEd": "E, dd MMM y",
                                    "yMMMM": "MMMM y",
                                    "yQQQ": "QQQ y",
                                    "yQQQQ": "QQQQ y"
                                },
                                "appendItems": {
                                    "Day": "{0} ({2}: {1})",
                                    "Day-Of-Week": "{0} {1}",
                                    "Era": "{1} {0}",
                                    "Hour": "{0} ({2}: {1})",
                                    "Minute": "{0} ({2}: {1})",
                                    "Month": "{0} ({2}: {1})",
                                    "Quarter": "{0} ({2}: {1})",
                                    "Second": "{0} ({2}: {1})",
                                    "Timezone": "{0} {1}",
                                    "Week": "{0} ({2}: {1})",
                                    "Year": "{1} {0}"
                                },
                                "intervalFormats": {
                                    "intervalFormatFallback": "{0} - {1}",
                                    "d": {
                                        "d": "'Ngày' dd-dd"
                                    },
                                    "h": {
                                        "a": "h'h' a - h'h' a",
                                        "h": "h'h' - h'h' a"
                                    },
                                    "H": {
                                        "H": "HH'h' - HH'h'"
                                    },
                                    "hm": {
                                        "a": "h:mm a – h:mm a",
                                        "h": "h:mm-h:mm a",
                                        "m": "h:mm-h:mm a"
                                    },
                                    "Hm": {
                                        "H": "HH:mm-HH:mm",
                                        "m": "HH:mm-HH:mm"
                                    },
                                    "hmv": {
                                        "a": "h:mm a – h:mm a v",
                                        "h": "h:mm-h:mm a v",
                                        "m": "h:mm-h:mm a v"
                                    },
                                    "Hmv": {
                                        "H": "HH:mm-HH:mm v",
                                        "m": "HH:mm-HH:mm v"
                                    },
                                    "hv": {
                                        "a": "h'h' a - h'h' a v",
                                        "h": "h'h'-h'h' a v"
                                    },
                                    "Hv": {
                                        "H": "HH'h'-HH'h' v"
                                    },
                                    "M": {
                                        "M": "'Tháng' M - 'Tháng' M"
                                    },
                                    "Md": {
                                        "d": "dd/MM - dd/MM",
                                        "M": "dd/MM - dd/MM"
                                    },
                                    "MEd": {
                                        "d": "EEEE, dd/MM - EEEE, dd/MM",
                                        "M": "EEEE, dd/MM - EEEE, dd/MM"
                                    },
                                    "MMM": {
                                        "M": "MMM-MMM"
                                    },
                                    "MMMd": {
                                        "d": "'Ngày' dd 'tháng' M - 'Ngày' dd 'tháng' M",
                                        "M": "'Ngày' dd 'tháng' M - 'Ngày' dd 'tháng' M"
                                    },
                                    "MMMEd": {
                                        "d": "EEEE, 'ngày' dd - EEEE, 'ngày' dd 'tháng' M",
                                        "M": "EEEE, 'ngày' dd 'tháng' M - EEEE, 'ngày' dd 'tháng' M"
                                    },
                                    "y": {
                                        "y": "y-y"
                                    },
                                    "yM": {
                                        "M": "MM/y - MM/y",
                                        "y": "MM/y - MM/y"
                                    },
                                    "yMd": {
                                        "d": "dd/MM/y - dd/MM/y",
                                        "M": "dd/MM/y - dd/MM/y",
                                        "y": "dd/MM/y - dd/MM/y"
                                    },
                                    "yMEd": {
                                        "d": "EEEE, dd/MM/y - EEEE, dd/MM/y",
                                        "M": "EEEE, dd/MM/y - EEEE, dd/MM/y",
                                        "y": "EEEE, dd/MM/y - EEEE, dd/MM/y"
                                    },
                                    "yMMM": {
                                        "M": "'Tháng' M - 'Tháng' M 'năm' y",
                                        "y": "'Tháng' M 'năm' y - 'Tháng' M 'năm' y"
                                    },
                                    "yMMMd": {
                                        "d": "'Ngày' dd 'tháng' M - 'Ngày' dd 'tháng' M 'năm' y",
                                        "M": "'Ngày' dd 'tháng' M - 'Ngày' dd 'tháng' M 'năm' y",
                                        "y": "'Ngày' dd 'tháng' M 'năm' y - 'Ngày' dd 'tháng' M 'năm' y"
                                    },
                                    "yMMMEd": {
                                        "d": "EEEE, 'ngày' dd MMM - EEEE, 'ngày' dd MMM 'năm' y",
                                        "M": "E, dd 'tháng' M - E, dd 'tháng' M, y",
                                        "y": "E, dd 'tháng' M, y - E, dd 'tháng' M, y"
                                    },
                                    "yMMMM": {
                                        "M": "MMMM-MMMM y",
                                        "y": "MMMM y – MMMM y"
                                    }
                                }
                            }
                        }
                    },
                    "timeZoneNames": {
                        "hourFormat": "+HH:mm;-HH:mm",
                        "gmtFormat": "GMT{0}",
                        "gmtZeroFormat": "GMT",
                        "regionFormat": "Giờ {0}",
                        "regionFormat-type-daylight": "Giờ ban ngày {0}",
                        "regionFormat-type-standard": "Giờ chuẩn {0}",
                        "fallbackFormat": "{1} ({0})"
                    }
                }
            },
            "zh": {
                "dates": {
                    "calendars": {
                        "gregorian": {
                            "months": {
                                "format": {
                                    "abbreviated": {
                                        "1": "1月",
                                        "2": "2月",
                                        "3": "3月",
                                        "4": "4月",
                                        "5": "5月",
                                        "6": "6月",
                                        "7": "7月",
                                        "8": "8月",
                                        "9": "9月",
                                        "10": "10月",
                                        "11": "11月",
                                        "12": "12月"
                                    },
                                    "narrow": {
                                        "1": "1",
                                        "2": "2",
                                        "3": "3",
                                        "4": "4",
                                        "5": "5",
                                        "6": "6",
                                        "7": "7",
                                        "8": "8",
                                        "9": "9",
                                        "10": "10",
                                        "11": "11",
                                        "12": "12"
                                    },
                                    "wide": {
                                        "1": "一月",
                                        "2": "二月",
                                        "3": "三月",
                                        "4": "四月",
                                        "5": "五月",
                                        "6": "六月",
                                        "7": "七月",
                                        "8": "八月",
                                        "9": "九月",
                                        "10": "十月",
                                        "11": "十一月",
                                        "12": "十二月"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "1": "1月",
                                        "2": "2月",
                                        "3": "3月",
                                        "4": "4月",
                                        "5": "5月",
                                        "6": "6月",
                                        "7": "7月",
                                        "8": "8月",
                                        "9": "9月",
                                        "10": "10月",
                                        "11": "11月",
                                        "12": "12月"
                                    },
                                    "narrow": {
                                        "1": "1",
                                        "2": "2",
                                        "3": "3",
                                        "4": "4",
                                        "5": "5",
                                        "6": "6",
                                        "7": "7",
                                        "8": "8",
                                        "9": "9",
                                        "10": "10",
                                        "11": "11",
                                        "12": "12"
                                    },
                                    "wide": {
                                        "1": "一月",
                                        "2": "二月",
                                        "3": "三月",
                                        "4": "四月",
                                        "5": "五月",
                                        "6": "六月",
                                        "7": "七月",
                                        "8": "八月",
                                        "9": "九月",
                                        "10": "十月",
                                        "11": "十一月",
                                        "12": "十二月"
                                    }
                                }
                            },
                            "days": {
                                "format": {
                                    "abbreviated": {
                                        "sun": "周日",
                                        "mon": "周一",
                                        "tue": "周二",
                                        "wed": "周三",
                                        "thu": "周四",
                                        "fri": "周五",
                                        "sat": "周六"
                                    },
                                    "narrow": {
                                        "sun": "日",
                                        "mon": "一",
                                        "tue": "二",
                                        "wed": "三",
                                        "thu": "四",
                                        "fri": "五",
                                        "sat": "六"
                                    },
                                    "short": {
                                        "sun": "周日",
                                        "mon": "周一",
                                        "tue": "周二",
                                        "wed": "周三",
                                        "thu": "周四",
                                        "fri": "周五",
                                        "sat": "周六"
                                    },
                                    "wide": {
                                        "sun": "星期日",
                                        "mon": "星期一",
                                        "tue": "星期二",
                                        "wed": "星期三",
                                        "thu": "星期四",
                                        "fri": "星期五",
                                        "sat": "星期六"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "sun": "周日",
                                        "mon": "周一",
                                        "tue": "周二",
                                        "wed": "周三",
                                        "thu": "周四",
                                        "fri": "周五",
                                        "sat": "周六"
                                    },
                                    "narrow": {
                                        "sun": "日",
                                        "mon": "一",
                                        "tue": "二",
                                        "wed": "三",
                                        "thu": "四",
                                        "fri": "五",
                                        "sat": "六"
                                    },
                                    "short": {
                                        "sun": "周日",
                                        "mon": "周一",
                                        "tue": "周二",
                                        "wed": "周三",
                                        "thu": "周四",
                                        "fri": "周五",
                                        "sat": "周六"
                                    },
                                    "wide": {
                                        "sun": "星期日",
                                        "mon": "星期一",
                                        "tue": "星期二",
                                        "wed": "星期三",
                                        "thu": "星期四",
                                        "fri": "星期五",
                                        "sat": "星期六"
                                    }
                                }
                            },
                            "quarters": {
                                "format": {
                                    "abbreviated": {
                                        "1": "1季度",
                                        "2": "2季度",
                                        "3": "3季度",
                                        "4": "4季度"
                                    },
                                    "narrow": {
                                        "1": "1",
                                        "2": "2",
                                        "3": "3",
                                        "4": "4"
                                    },
                                    "wide": {
                                        "1": "第一季度",
                                        "2": "第二季度",
                                        "3": "第三季度",
                                        "4": "第四季度"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "1": "1季度",
                                        "2": "2季度",
                                        "3": "3季度",
                                        "4": "4季度"
                                    },
                                    "narrow": {
                                        "1": "1",
                                        "2": "2",
                                        "3": "3",
                                        "4": "4"
                                    },
                                    "wide": {
                                        "1": "第一季度",
                                        "2": "第二季度",
                                        "3": "第三季度",
                                        "4": "第四季度"
                                    }
                                }
                            },
                            "dayPeriods": {
                                "format": {
                                    "abbreviated": {
                                        "afternoon": "下午",
                                        "am": "上午",
                                        "earlyMorning": "清晨",
                                        "midDay": "中午",
                                        "morning": "上午",
                                        "night": "晚上",
                                        "noon": "中午",
                                        "pm": "下午",
                                        "weeHours": "凌晨"
                                    },
                                    "narrow": {
                                        "afternoon": "下午",
                                        "am": "上午",
                                        "earlyMorning": "清晨",
                                        "midDay": "中午",
                                        "morning": "上午",
                                        "night": "晚上",
                                        "noon": "中午",
                                        "pm": "下午",
                                        "weeHours": "凌晨"
                                    },
                                    "wide": {
                                        "afternoon": "下午",
                                        "am": "上午",
                                        "earlyMorning": "清晨",
                                        "midDay": "中午",
                                        "morning": "上午",
                                        "night": "晚上",
                                        "noon": "中午",
                                        "pm": "下午",
                                        "weeHours": "凌晨"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "afternoon": "下午",
                                        "am": "上午",
                                        "earlyMorning": "清晨",
                                        "midDay": "中午",
                                        "morning": "上午",
                                        "night": "晚上",
                                        "noon": "中午",
                                        "pm": "下午",
                                        "weeHours": "凌晨"
                                    },
                                    "narrow": {
                                        "afternoon": "下午",
                                        "am": "上午",
                                        "earlyMorning": "清晨",
                                        "midDay": "中午",
                                        "morning": "上午",
                                        "night": "晚上",
                                        "noon": "中午",
                                        "pm": "下午",
                                        "weeHours": "凌晨"
                                    },
                                    "wide": {
                                        "afternoon": "下午",
                                        "am": "上午",
                                        "earlyMorning": "清晨",
                                        "midDay": "中午",
                                        "morning": "上午",
                                        "night": "晚上",
                                        "noon": "中午",
                                        "pm": "下午",
                                        "weeHours": "凌晨"
                                    }
                                }
                            },
                            "eras": {
                                "eraNames": {
                                    "0": "公元前",
                                    "1": "公元",
                                    "0-alt-variant": "BCE",
                                    "1-alt-variant": "CE"
                                },
                                "eraAbbr": {
                                    "0": "公元前",
                                    "1": "公元",
                                    "0-alt-variant": "BCE",
                                    "1-alt-variant": "CE"
                                },
                                "eraNarrow": {
                                    "0": "公元前",
                                    "1": "公元",
                                    "0-alt-variant": "BCE",
                                    "1-alt-variant": "CE"
                                }
                            },
                            "dateFormats": {
                                "full": "y年M月d日EEEE",
                                "long": "y年M月d日",
                                "medium": "y年M月d日",
                                "short": "yy/M/d"
                            },
                            "timeFormats": {
                                "full": "zzzzah:mm:ss",
                                "long": "zah:mm:ss",
                                "medium": "ah:mm:ss",
                                "short": "ah:mm"
                            },
                            "dateTimeFormats": {
                                "full": "{1} {0}",
                                "long": "{1} {0}",
                                "medium": "{1} {0}",
                                "short": "{1} {0}",
                                "availableFormats": {
                                    "d": "d日",
                                    "Ed": "d日E",
                                    "Ehm": "Eah:mm",
                                    "EHm": "EHH:mm",
                                    "Ehms": "Eah:mm:ss",
                                    "EHms": "EHH:mm:ss",
                                    "Gy": "Gy年",
                                    "GyMMM": "Gy年M月",
                                    "GyMMMd": "Gy年M月d日",
                                    "GyMMMEd": "Gy年M月d日E",
                                    "h": "ah时",
                                    "H": "H时",
                                    "hm": "ah:mm",
                                    "Hm": "HH:mm",
                                    "hms": "ah:mm:ss",
                                    "Hms": "HH:mm:ss",
                                    "M": "M月",
                                    "Md": "M/d",
                                    "MEd": "M/dE",
                                    "MMdd": "MM/dd",
                                    "MMM": "LLL",
                                    "MMMd": "M月d日",
                                    "MMMEd": "M月d日E",
                                    "MMMMdd": "M月dd日",
                                    "ms": "mm:ss",
                                    "y": "y年",
                                    "yM": "y/M",
                                    "yMd": "y/M/d",
                                    "yMEd": "y/M/dE",
                                    "yMM": "y年M月",
                                    "yMMM": "y年M月",
                                    "yMMMd": "y年M月d日",
                                    "yMMMEd": "y年M月d日E",
                                    "yMMMM": "y年M月",
                                    "yQQQ": "y年第Q季度",
                                    "yQQQQ": "y年第Q季度"
                                },
                                "appendItems": {
                                    "Day": "{0} ({2}: {1})",
                                    "Day-Of-Week": "{0} {1}",
                                    "Era": "{1} {0}",
                                    "Hour": "{0} ({2}: {1})",
                                    "Minute": "{0} ({2}: {1})",
                                    "Month": "{0} ({2}: {1})",
                                    "Quarter": "{0} ({2}: {1})",
                                    "Second": "{0} ({2}: {1})",
                                    "Timezone": "{1}{0}",
                                    "Week": "{0} ({2}: {1})",
                                    "Year": "{1} {0}"
                                },
                                "intervalFormats": {
                                    "intervalFormatFallback": "{0} – {1}",
                                    "d": {
                                        "d": "d–d日"
                                    },
                                    "h": {
                                        "a": "ah时至ah时",
                                        "h": "ah时至h时"
                                    },
                                    "H": {
                                        "H": "HH–HH"
                                    },
                                    "hm": {
                                        "a": "ah:mm至ah:mm",
                                        "h": "ah:mm至h:mm",
                                        "m": "ah:mm至h:mm"
                                    },
                                    "Hm": {
                                        "H": "HH:mm–HH:mm",
                                        "m": "HH:mm–HH:mm"
                                    },
                                    "hmv": {
                                        "a": "vah:mm至ah:mm",
                                        "h": "vah:mm至h:mm",
                                        "m": "vah:mm至h:mm"
                                    },
                                    "Hmv": {
                                        "H": "v HH:mm–HH:mm",
                                        "m": "v HH:mm–HH:mm"
                                    },
                                    "hv": {
                                        "a": "vah时至ah时",
                                        "h": "vah时至h时"
                                    },
                                    "Hv": {
                                        "H": "v HH–HH"
                                    },
                                    "M": {
                                        "M": "M–M月"
                                    },
                                    "Md": {
                                        "d": "M/d – M/d",
                                        "M": "M/d – M/d"
                                    },
                                    "MEd": {
                                        "d": "M/dE至M/dE",
                                        "M": "M/dE至M/dE"
                                    },
                                    "MMM": {
                                        "M": "LLL至LLL"
                                    },
                                    "MMMd": {
                                        "d": "M月d日至d日",
                                        "M": "M月d日至M月d日"
                                    },
                                    "MMMEd": {
                                        "d": "M月d日E至d日E",
                                        "M": "M月d日E至M月d日E"
                                    },
                                    "y": {
                                        "y": "y–y年"
                                    },
                                    "yM": {
                                        "M": "y年M月至M月",
                                        "y": "y年M月至y年M月"
                                    },
                                    "yMd": {
                                        "d": "y/M/d – y/M/d",
                                        "M": "y/M/d – y/M/d",
                                        "y": "y/M/d – y/M/d"
                                    },
                                    "yMEd": {
                                        "d": "y/M/dE至y/M/dE",
                                        "M": "y/M/dE至y/M/dE",
                                        "y": "y/M/dE至y/M/dE"
                                    },
                                    "yMMM": {
                                        "M": "y年M月至M月",
                                        "y": "y年M月至y年M月"
                                    },
                                    "yMMMd": {
                                        "d": "y年M月d日至d日",
                                        "M": "y年M月d日至M月d日",
                                        "y": "y年M月d日至y年M月d日"
                                    },
                                    "yMMMEd": {
                                        "d": "y年M月d日E至d日E",
                                        "M": "y年M月d日E至M月d日E",
                                        "y": "y年M月d日E至y年M月d日E"
                                    },
                                    "yMMMM": {
                                        "M": "y年M月至M月",
                                        "y": "y年M月至y年M月"
                                    }
                                }
                            }
                        }
                    },
                    "timeZoneNames": {
                        "hourFormat": "+HH:mm;-HH:mm",
                        "gmtFormat": "GMT{0}",
                        "gmtZeroFormat": "GMT",
                        "regionFormat": "{0}时间",
                        "regionFormat-type-daylight": "{0}夏令时间",
                        "regionFormat-type-standard": "{0}标准时间",
                        "fallbackFormat": "{1}（{0}）"
                    }
                }
            },
            "zh-Hant": {
                "dates": {
                    "calendars": {
                        "gregorian": {
                            "months": {
                                "format": {
                                    "abbreviated": {
                                        "1": "1月",
                                        "2": "2月",
                                        "3": "3月",
                                        "4": "4月",
                                        "5": "5月",
                                        "6": "6月",
                                        "7": "7月",
                                        "8": "8月",
                                        "9": "9月",
                                        "10": "10月",
                                        "11": "11月",
                                        "12": "12月"
                                    },
                                    "narrow": {
                                        "1": "1",
                                        "2": "2",
                                        "3": "3",
                                        "4": "4",
                                        "5": "5",
                                        "6": "6",
                                        "7": "7",
                                        "8": "8",
                                        "9": "9",
                                        "10": "10",
                                        "11": "11",
                                        "12": "12"
                                    },
                                    "wide": {
                                        "1": "1月",
                                        "2": "2月",
                                        "3": "3月",
                                        "4": "4月",
                                        "5": "5月",
                                        "6": "6月",
                                        "7": "7月",
                                        "8": "8月",
                                        "9": "9月",
                                        "10": "10月",
                                        "11": "11月",
                                        "12": "12月"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "1": "1月",
                                        "2": "2月",
                                        "3": "3月",
                                        "4": "4月",
                                        "5": "5月",
                                        "6": "6月",
                                        "7": "7月",
                                        "8": "8月",
                                        "9": "9月",
                                        "10": "10月",
                                        "11": "11月",
                                        "12": "12月"
                                    },
                                    "narrow": {
                                        "1": "1",
                                        "2": "2",
                                        "3": "3",
                                        "4": "4",
                                        "5": "5",
                                        "6": "6",
                                        "7": "7",
                                        "8": "8",
                                        "9": "9",
                                        "10": "10",
                                        "11": "11",
                                        "12": "12"
                                    },
                                    "wide": {
                                        "1": "1月",
                                        "2": "2月",
                                        "3": "3月",
                                        "4": "4月",
                                        "5": "5月",
                                        "6": "6月",
                                        "7": "7月",
                                        "8": "8月",
                                        "9": "9月",
                                        "10": "10月",
                                        "11": "11月",
                                        "12": "12月"
                                    }
                                }
                            },
                            "days": {
                                "format": {
                                    "abbreviated": {
                                        "sun": "週日",
                                        "mon": "週一",
                                        "tue": "週二",
                                        "wed": "週三",
                                        "thu": "週四",
                                        "fri": "週五",
                                        "sat": "週六"
                                    },
                                    "narrow": {
                                        "sun": "日",
                                        "mon": "一",
                                        "tue": "二",
                                        "wed": "三",
                                        "thu": "四",
                                        "fri": "五",
                                        "sat": "六"
                                    },
                                    "short": {
                                        "sun": "日",
                                        "mon": "一",
                                        "tue": "二",
                                        "wed": "三",
                                        "thu": "四",
                                        "fri": "五",
                                        "sat": "六"
                                    },
                                    "wide": {
                                        "sun": "星期日",
                                        "mon": "星期一",
                                        "tue": "星期二",
                                        "wed": "星期三",
                                        "thu": "星期四",
                                        "fri": "星期五",
                                        "sat": "星期六"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "sun": "週日",
                                        "mon": "週一",
                                        "tue": "週二",
                                        "wed": "週三",
                                        "thu": "週四",
                                        "fri": "週五",
                                        "sat": "週六"
                                    },
                                    "narrow": {
                                        "sun": "日",
                                        "mon": "一",
                                        "tue": "二",
                                        "wed": "三",
                                        "thu": "四",
                                        "fri": "五",
                                        "sat": "六"
                                    },
                                    "short": {
                                        "sun": "日",
                                        "mon": "一",
                                        "tue": "二",
                                        "wed": "三",
                                        "thu": "四",
                                        "fri": "五",
                                        "sat": "六"
                                    },
                                    "wide": {
                                        "sun": "星期日",
                                        "mon": "星期一",
                                        "tue": "星期二",
                                        "wed": "星期三",
                                        "thu": "星期四",
                                        "fri": "星期五",
                                        "sat": "星期六"
                                    }
                                }
                            },
                            "quarters": {
                                "format": {
                                    "abbreviated": {
                                        "1": "1季",
                                        "2": "2季",
                                        "3": "3季",
                                        "4": "4季"
                                    },
                                    "narrow": {
                                        "1": "1",
                                        "2": "2",
                                        "3": "3",
                                        "4": "4"
                                    },
                                    "wide": {
                                        "1": "第1季",
                                        "2": "第2季",
                                        "3": "第3季",
                                        "4": "第4季"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "1": "1季",
                                        "2": "2季",
                                        "3": "3季",
                                        "4": "4季"
                                    },
                                    "narrow": {
                                        "1": "1",
                                        "2": "2",
                                        "3": "3",
                                        "4": "4"
                                    },
                                    "wide": {
                                        "1": "第1季",
                                        "2": "第2季",
                                        "3": "第3季",
                                        "4": "第4季"
                                    }
                                }
                            },
                            "dayPeriods": {
                                "format": {
                                    "abbreviated": {
                                        "afternoon": "下午",
                                        "am": "上午",
                                        "earlyMorning": "清晨",
                                        "midDay": "中午",
                                        "morning": "上午",
                                        "night": "晚上",
                                        "noon": "中午",
                                        "pm": "下午",
                                        "weeHours": "凌晨"
                                    },
                                    "narrow": {
                                        "afternoon": "下午",
                                        "am": "上午",
                                        "earlyMorning": "清晨",
                                        "midDay": "中午",
                                        "morning": "上午",
                                        "night": "晚上",
                                        "noon": "中午",
                                        "pm": "下午",
                                        "weeHours": "凌晨"
                                    },
                                    "wide": {
                                        "afternoon": "下午",
                                        "am": "上午",
                                        "earlyMorning": "清晨",
                                        "midDay": "中午",
                                        "morning": "上午",
                                        "night": "晚上",
                                        "noon": "中午",
                                        "pm": "下午",
                                        "weeHours": "凌晨"
                                    }
                                },
                                "stand-alone": {
                                    "abbreviated": {
                                        "afternoon": "下午",
                                        "am": "上午",
                                        "earlyMorning": "清晨",
                                        "midDay": "中午",
                                        "morning": "上午",
                                        "night": "晚上",
                                        "noon": "中午",
                                        "pm": "下午",
                                        "weeHours": "凌晨"
                                    },
                                    "narrow": {
                                        "afternoon": "下午",
                                        "am": "上午",
                                        "earlyMorning": "清晨",
                                        "midDay": "中午",
                                        "morning": "上午",
                                        "night": "晚上",
                                        "noon": "中午",
                                        "pm": "下午",
                                        "weeHours": "凌晨"
                                    },
                                    "wide": {
                                        "afternoon": "下午",
                                        "am": "上午",
                                        "earlyMorning": "清晨",
                                        "midDay": "中午",
                                        "morning": "上午",
                                        "night": "晚上",
                                        "noon": "中午",
                                        "pm": "下午",
                                        "weeHours": "凌晨"
                                    }
                                }
                            },
                            "eras": {
                                "eraNames": {
                                    "0": "西元前",
                                    "1": "西元",
                                    "0-alt-variant": "公元前",
                                    "1-alt-variant": "公元"
                                },
                                "eraAbbr": {
                                    "0": "西元前",
                                    "1": "西元",
                                    "0-alt-variant": "公元前",
                                    "1-alt-variant": "公元"
                                },
                                "eraNarrow": {
                                    "0": "西元前",
                                    "1": "西元",
                                    "0-alt-variant": "公元前",
                                    "1-alt-variant": "公元"
                                }
                            },
                            "dateFormats": {
                                "full": "y年M月d日EEEE",
                                "long": "y年M月d日",
                                "medium": "y年M月d日",
                                "short": "y/M/d"
                            },
                            "timeFormats": {
                                "full": "zzzzah時mm分ss秒",
                                "long": "zah時mm分ss秒",
                                "medium": "ah:mm:ss",
                                "short": "ah:mm"
                            },
                            "dateTimeFormats": {
                                "full": "{1}{0}",
                                "long": "{1} {0}",
                                "medium": "{1} {0}",
                                "short": "{1} {0}",
                                "availableFormats": {
                                    "d": "d日",
                                    "Ed": "d日（E）",
                                    "Ehm": "E a h:mm",
                                    "EHm": "E HH:mm",
                                    "Ehms": "E a h:mm:ss",
                                    "EHms": "E HH:mm:ss",
                                    "Gy": "G y 年",
                                    "GyMMM": "G y 年 M 月",
                                    "GyMMMd": "G y 年 M 月 d 日",
                                    "GyMMMEd": "G y 年 M 月 d 日E",
                                    "h": "ah時",
                                    "H": "H時",
                                    "hm": "ah:mm",
                                    "Hm": "HH:mm",
                                    "hms": "ah:mm:ss",
                                    "Hms": "HH:mm:ss",
                                    "M": "M月",
                                    "Md": "M/d",
                                    "MEd": "M/d（E）",
                                    "MMdd": "MM/dd",
                                    "MMM": "LLL",
                                    "MMMd": "M月d日",
                                    "MMMEd": "M月d日E",
                                    "MMMMdd": "M月dd日",
                                    "ms": "mm:ss",
                                    "y": "y年",
                                    "yM": "y/M",
                                    "yMd": "y/M/d",
                                    "yMEd": "y/M/d（E）",
                                    "yMM": "y-MM",
                                    "yMMM": "y年M月",
                                    "yMMMd": "y年M月d日",
                                    "yMMMEd": "y年M月d日E",
                                    "yMMMM": "y年M月",
                                    "yQQQ": "y年QQQ",
                                    "yQQQQ": "y年QQQQ"
                                },
                                "appendItems": {
                                    "Day": "{0} ({2}: {1})",
                                    "Day-Of-Week": "{0} {1}",
                                    "Era": "{1} {0}",
                                    "Hour": "{0} ({2}: {1})",
                                    "Minute": "{0} ({2}: {1})",
                                    "Month": "{0} ({2}: {1})",
                                    "Quarter": "{0} ({2}: {1})",
                                    "Second": "{0} ({2}: {1})",
                                    "Timezone": "{0} {1}",
                                    "Week": "{0} ({2}: {1})",
                                    "Year": "{1} {0}"
                                },
                                "intervalFormats": {
                                    "intervalFormatFallback": "{0}至{1}",
                                    "d": {
                                        "d": "d日至d日"
                                    },
                                    "h": {
                                        "a": "ah時至ah時",
                                        "h": "ah時至h時"
                                    },
                                    "H": {
                                        "H": "HH–HH"
                                    },
                                    "hm": {
                                        "a": "ah:mm至ah:mm",
                                        "h": "ah:mm至h:mm",
                                        "m": "ah:mm至h:mm"
                                    },
                                    "Hm": {
                                        "H": "HH:mm–HH:mm",
                                        "m": "HH:mm至HH:mm"
                                    },
                                    "hmv": {
                                        "a": "a h:mm 至a h:mm [v]",
                                        "h": "a h:mm 至 h:mm [v]",
                                        "m": "a h:mm 至 h:mm [v]"
                                    },
                                    "Hmv": {
                                        "H": "HH:mm–HH:mm [v]",
                                        "m": "HH:mm–HH:mm [v]"
                                    },
                                    "hv": {
                                        "a": "a h 時至a h 時 [v]",
                                        "h": "a h 時至 h 時 [v]"
                                    },
                                    "Hv": {
                                        "H": "HH–HH [v]"
                                    },
                                    "M": {
                                        "M": "M月至M月"
                                    },
                                    "Md": {
                                        "d": "M/d至M/d",
                                        "M": "M/d至M/d"
                                    },
                                    "MEd": {
                                        "d": "M/dE至M/dE",
                                        "M": "M/dE至M/dE"
                                    },
                                    "MMM": {
                                        "M": "LLL至LLL"
                                    },
                                    "MMMd": {
                                        "d": "M月d日至d日",
                                        "M": "M月d日至M月d日"
                                    },
                                    "MMMEd": {
                                        "d": "M月d日E至d日E",
                                        "M": "M月d日E至M月d日E"
                                    },
                                    "MMMM": {
                                        "M": "LLLL至 LLLL"
                                    },
                                    "y": {
                                        "y": "y至y"
                                    },
                                    "yM": {
                                        "M": "y/M至y/M",
                                        "y": "y/M至y/M"
                                    },
                                    "yMd": {
                                        "d": "y/M/d至y/M/d",
                                        "M": "y/M/d至y/M/d",
                                        "y": "y/M/d至y/M/d"
                                    },
                                    "yMEd": {
                                        "d": "y/M/dE至y/M/dE",
                                        "M": "y/M/dE至y/M/dE",
                                        "y": "y/M/dE至y/M/dE"
                                    },
                                    "yMMM": {
                                        "M": "y年M月至M月",
                                        "y": "y年M月至y年M月"
                                    },
                                    "yMMMd": {
                                        "d": "y年M月d日至d日",
                                        "M": "y年M月d日至M月d日",
                                        "y": "y年M月d日至y年M月d日"
                                    },
                                    "yMMMEd": {
                                        "d": "y年M月d日E至d日E",
                                        "M": "y年M月d日E至M月d日E",
                                        "y": "y年M月d日E至y年M月d日E"
                                    },
                                    "yMMMM": {
                                        "M": "y年M月至M月",
                                        "y": "y年M月至y年M月"
                                    }
                                }
                            }
                        }
                    },
                    "timeZoneNames": {
                        "hourFormat": "+HH:mm;-HH:mm",
                        "gmtFormat": "GMT{0}",
                        "gmtZeroFormat": "GMT",
                        "regionFormat": "{0}時間",
                        "regionFormat-type-daylight": "{0} (+1)",
                        "regionFormat-type-standard": "{0} (+0)",
                        "fallbackFormat": "{1}（{0}）"
                    }
                }
            }
        });

        AstroDate.locale('en_GB');

        return AstroDate;
    }

    /*
     *
     * UMD
     *
     */

    if (!isTypeObject(globalThis)) {
        throw new TypeError('Invalid global context');
    }

    function addBigNumberModule(module, define) {
        if (!isUndefined(module) || !isUndefined(define)) {
            throw new Error();
        }

        /*jslint eqeq: true, plusplus: true, sub: true, white: true, newcap: true, vars: true, ass: true, bitwise: true */
        /*jshint unused: false, expr: true, asi: true, eqnull: true, laxbreak: true, validthis: true, noempty: false, -W017, -W018, -W032, -W041, -W084, -W116, -W120 */
        /* bignumber.js v1.3.0 https://github.com/MikeMcl/bignumber.js/LICENCE */
        ;
        (function (global) {
            'use strict';

            /*
      bignumber.js v1.3.0
      A JavaScript library for arbitrary-precision arithmetic.
      https://github.com/MikeMcl/bignumber.js
      Copyright (c) 2012 Michael Mclaughlin <M8ch88l@gmail.com>
      MIT Expat Licence
    */

            /*********************************** DEFAULTS ************************************/

            /*
             * The default values below must be integers within the stated ranges (inclusive).
             * Most of these values can be changed during run-time using BigNumber.config().
             */

            /*
             * The limit on the value of DECIMAL_PLACES, TO_EXP_NEG, TO_EXP_POS, MIN_EXP,
             * MAX_EXP, and the argument to toFixed, toPrecision and toExponential, beyond
             * which an exception is thrown (if ERRORS is true).
             */
            var MAX = 1E9, // 0 to 1e+9

                // Limit of magnitude of exponent argument to toPower.
                MAX_POWER = 1E6, // 1 to 1e+6

                // The maximum number of decimal places for operations involving division.
                DECIMAL_PLACES = 20, // 0 to MAX

                /*
                 * The rounding mode used when rounding to the above decimal places, and when
                 * using toFixed, toPrecision and toExponential, and round (default value).
                 * UP         0 Away from zero.
                 * DOWN       1 Towards zero.
                 * CEIL       2 Towards +Infinity.
                 * FLOOR      3 Towards -Infinity.
                 * HALF_UP    4 Towards nearest neighbour. If equidistant, up.
                 * HALF_DOWN  5 Towards nearest neighbour. If equidistant, down.
                 * HALF_EVEN  6 Towards nearest neighbour. If equidistant, towards even neighbour.
                 * HALF_CEIL  7 Towards nearest neighbour. If equidistant, towards +Infinity.
                 * HALF_FLOOR 8 Towards nearest neighbour. If equidistant, towards -Infinity.
                 */
                ROUNDING_MODE = 4, // 0 to 8

                // EXPONENTIAL_AT : [TO_EXP_NEG , TO_EXP_POS]

                // The exponent value at and beneath which toString returns exponential notation.
                // Number type: -7
                TO_EXP_NEG = -7, // 0 to -MAX

                // The exponent value at and above which toString returns exponential notation.
                // Number type: 21
                TO_EXP_POS = 21, // 0 to MAX

                // RANGE : [MIN_EXP, MAX_EXP]

                // The minimum exponent value, beneath which underflow to zero occurs.
                // Number type: -324  (5e-324)
                MIN_EXP = -MAX, // -1 to -MAX

                // The maximum exponent value, above which overflow to Infinity occurs.
                // Number type:  308  (1.7976931348623157e+308)
                MAX_EXP = MAX, // 1 to MAX

                // Whether BigNumber Errors are ever thrown.
                // CHANGE parseInt to parseFloat if changing ERRORS to false.
                ERRORS = true, // true or false
                parse = parseInt, // parseInt or parseFloat

                /***********************************************************************************/

                P = BigNumber.prototype,
                DIGITS = '0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ$_',
                outOfRange,
                id = 0,
                isValid = /^-?(\d+(\.\d*)?|\.\d+)(e[+-]?\d+)?$/i,
                trim = String.prototype.trim || function () {
                    return this.replace(/^\s+|\s+$/g, '')
                },
                ONE = BigNumber(1);


            // CONSTRUCTOR


            /*
             * The exported function.
             * Create and return a new instance of a BigNumber object.
             *
             * n {number|string|BigNumber} A numeric value.
             * [b] {number} The base of n. Integer, 2 to 64 inclusive.
             */
            function BigNumber(n, b) {
                var e, i, isNum, digits, valid, orig,
                    x = this;

                // Enable constructor usage without new.
                if (!(x instanceof BigNumber)) {
                    return new BigNumber(n, b)
                }

                // Duplicate.
                if (n instanceof BigNumber) {
                    id = 0;

                    // e is undefined.
                    if (b !== e) {
                        n += ''
                    } else {
                        x['s'] = n['s'];
                        x['e'] = n['e'];
                        x['c'] = (n = n['c']) ? n.slice() : n;
                        return
                    }
                }

                // If number, check if minus zero.
                if (typeof n != 'string') {
                    n = (isNum = typeof n == 'number' ||
                        Object.prototype.toString.call(n) == '[object Number]') &&
                        n === 0 && 1 / n < 0 ? '-0' : n + ''
                }

                orig = n;

                if (b === e && isValid.test(n)) {

                    // Determine sign.
                    x['s'] = n.charAt(0) == '-' ? (n = n.slice(1), -1) : 1

                    // Either n is not a valid BigNumber or a base has been specified.
                } else {

                    // Enable exponential notation to be used with base 10 argument.
                    // Ensure return value is rounded to DECIMAL_PLACES as with other bases.
                    if (b == 10) {

                        return setMode(n, DECIMAL_PLACES, ROUNDING_MODE)
                    }

                    n = trim.call(n).replace(/^\+(?!-)/, '');

                    x['s'] = n.charAt(0) == '-' ? (n = n.replace(/^-(?!-)/, ''), -1) : 1;

                    if (b != null) {

                        if ((b == (b | 0) || !ERRORS) && !(outOfRange = !(b >= 2 && b < 65))) {

                            digits = '[' + DIGITS.slice(0, b = b | 0) + ']+';

                            // Before non-decimal number validity test and base conversion
                            // remove the `.` from e.g. '1.', and replace e.g. '.1' with '0.1'.
                            n = n.replace(/\.$/, '').replace(/^\./, '0.');

                            // Any number in exponential form will fail due to the e+/-.
                            if (valid = new RegExp(
                                '^' + digits + '(?:\\.' + digits + ')?$', b < 37 ? 'i' : '').test(n)) {

                                if (isNum) {

                                    if (n.replace(/^0\.0*|\./, '').length > 15) {

                                        // 'new BigNumber() number type has more than 15 significant digits: {n}'
                                        ifExceptionsThrow(orig, 0)
                                    }

                                    // Prevent later check for length on converted number.
                                    isNum = !isNum
                                }
                                n = convert(n, 10, b, x['s'])

                            } else if (n != 'Infinity' && n != 'NaN') {

                                // 'new BigNumber() not a base {b} number: {n}'
                                ifExceptionsThrow(orig, 1, b);
                                n = 'NaN'
                            }
                        } else {

                            // 'new BigNumber() base not an integer: {b}'
                            // 'new BigNumber() base out of range: {b}'
                            ifExceptionsThrow(b, 2);

                            // Ignore base.
                            valid = isValid.test(n)
                        }
                    } else {
                        valid = isValid.test(n)
                    }

                    if (!valid) {

                        // Infinity/NaN
                        x['c'] = x['e'] = null;

                        // NaN
                        if (n != 'Infinity') {

                            // No exception on NaN.
                            if (n != 'NaN') {

                                // 'new BigNumber() not a number: {n}'
                                ifExceptionsThrow(orig, 3)
                            }
                            x['s'] = null
                        }
                        id = 0;

                        return
                    }
                }

                // Decimal point?
                if ((e = n.indexOf('.')) > -1) {
                    n = n.replace('.', '')
                }

                // Exponential form?
                if ((i = n.search(/e/i)) > 0) {

                    // Determine exponent.
                    if (e < 0) {
                        e = i
                    }
                    e += +n.slice(i + 1);
                    n = n.substring(0, i)

                } else if (e < 0) {

                    // Integer.
                    e = n.length
                }

                // Determine leading zeros.
                for (i = 0; n.charAt(i) == '0'; i++) {}

                b = n.length;

                // Disallow numbers with over 15 significant digits if number type.
                if (isNum && b > 15 && n.slice(i).length > 15) {

                    // 'new BigNumber() number type has more than 15 significant digits: {n}'
                    ifExceptionsThrow(orig, 0)
                }
                id = 0;

                // Overflow?
                if ((e -= i + 1) > MAX_EXP) {

                    // Infinity.
                    x['c'] = x['e'] = null

                    // Zero or underflow?
                } else if (i == b || e < MIN_EXP) {

                    // Zero.
                    x['c'] = [x['e'] = 0]
                } else {

                    // Determine trailing zeros.
                    for (; n.charAt(--b) == '0';) {}

                    x['e'] = e;
                    x['c'] = [];

                    // Convert string to array of digits (without leading and trailing zeros).
                    for (e = 0; i <= b; x['c'][e++] = +n.charAt(i++)) {}
                }
            }


            // CONSTRUCTOR PROPERTIES/METHODS


            BigNumber['ROUND_UP'] = 0;
            BigNumber['ROUND_DOWN'] = 1;
            BigNumber['ROUND_CEIL'] = 2;
            BigNumber['ROUND_FLOOR'] = 3;
            BigNumber['ROUND_HALF_UP'] = 4;
            BigNumber['ROUND_HALF_DOWN'] = 5;
            BigNumber['ROUND_HALF_EVEN'] = 6;
            BigNumber['ROUND_HALF_CEIL'] = 7;
            BigNumber['ROUND_HALF_FLOOR'] = 8;


            /*
             * Configure infrequently-changing library-wide settings.
             *
             * Accept an object or an argument list, with one or many of the following
             * properties or parameters respectively:
             * [ DECIMAL_PLACES [, ROUNDING_MODE [, EXPONENTIAL_AT [, RANGE [, ERRORS ]]]]]
             *
             * E.g.
             * BigNumber.config(20, 4) is equivalent to
             * BigNumber.config({ DECIMAL_PLACES : 20, ROUNDING_MODE : 4 })
             * Ignore properties/parameters set to null or undefined.
             *
             * Return an object with the properties current values.
             */
            BigNumber['config'] = function () {
                var v, p,
                    i = 0,
                    r = {},
                    a = arguments,
                    o = a[0],
                    c = 'config',
                    inRange = function (n, lo, hi) {
                        return !((outOfRange = n < lo || n > hi) ||
                            parse(n) != n && n !== 0)
                    },
                    has = o && typeof o == 'object' ? function () {
                        if (o.hasOwnProperty(p)) return (v = o[p]) != null
                    } : function () {
                        if (a.length > i) return (v = a[i++]) != null
                    };

                // [DECIMAL_PLACES] {number} Integer, 0 to MAX inclusive.
                if (has(p = 'DECIMAL_PLACES')) {

                    if (inRange(v, 0, MAX)) {
                        DECIMAL_PLACES = v | 0
                    } else {

                        // 'config() DECIMAL_PLACES not an integer: {v}'
                        // 'config() DECIMAL_PLACES out of range: {v}'
                        ifExceptionsThrow(v, p, c)
                    }
                }
                r[p] = DECIMAL_PLACES;

                // [ROUNDING_MODE] {number} Integer, 0 to 8 inclusive.
                if (has(p = 'ROUNDING_MODE')) {

                    if (inRange(v, 0, 8)) {
                        ROUNDING_MODE = v | 0
                    } else {

                        // 'config() ROUNDING_MODE not an integer: {v}'
                        // 'config() ROUNDING_MODE out of range: {v}'
                        ifExceptionsThrow(v, p, c)
                    }
                }
                r[p] = ROUNDING_MODE;

                /*
                 * [EXPONENTIAL_AT] {number|number[]} Integer, -MAX to MAX inclusive or
                 * [ integer -MAX to 0 inclusive, 0 to MAX inclusive ].
                 */
                if (has(p = 'EXPONENTIAL_AT')) {

                    if (inRange(v, -MAX, MAX)) {
                        TO_EXP_NEG = -(TO_EXP_POS = ~~ (v < 0 ? -v : +v))
                    } else if (!outOfRange && v && inRange(v[0], -MAX, 0) &&
                        inRange(v[1], 0, MAX)) {
                        TO_EXP_NEG = ~~v[0], TO_EXP_POS = ~~v[1]
                    } else {

                        // 'config() EXPONENTIAL_AT not an integer or not [integer, integer]: {v}'
                        // 'config() EXPONENTIAL_AT out of range or not [negative, positive: {v}'
                        ifExceptionsThrow(v, p, c, 1)
                    }
                }
                r[p] = [TO_EXP_NEG, TO_EXP_POS];

                /*
                 * [RANGE][ {number|number[]} Non-zero integer, -MAX to MAX inclusive or
                 * [ integer -MAX to -1 inclusive, integer 1 to MAX inclusive ].
                 */
                if (has(p = 'RANGE')) {

                    if (inRange(v, -MAX, MAX) && ~~v) {
                        MIN_EXP = -(MAX_EXP = ~~ (v < 0 ? -v : +v))
                    } else if (!outOfRange && v && inRange(v[0], -MAX, -1) &&
                        inRange(v[1], 1, MAX)) {
                        MIN_EXP = ~~v[0], MAX_EXP = ~~v[1]
                    } else {

                        // 'config() RANGE not a non-zero integer or not [integer, integer]: {v}'
                        // 'config() RANGE out of range or not [negative, positive: {v}'
                        ifExceptionsThrow(v, p, c, 1, 1)
                    }
                }
                r[p] = [MIN_EXP, MAX_EXP];

                // [ERRORS] {boolean|number} true, false, 1 or 0.
                if (has(p = 'ERRORS')) {

                    if (v === !! v || v === 1 || v === 0) {
                        parse = (outOfRange = id = 0, ERRORS = !! v) ? parseInt : parseFloat
                    } else {

                        // 'config() ERRORS not a boolean or binary digit: {v}'
                        ifExceptionsThrow(v, p, c, 0, 0, 1)
                    }
                }
                r[p] = ERRORS;

                return r
            };


            // PRIVATE FUNCTIONS


            // Assemble error messages. Throw BigNumber Errors.
            function ifExceptionsThrow(arg, i, j, isArray, isRange, isErrors) {

                if (ERRORS) {
                    var error,
                        method = ['new BigNumber', 'cmp', 'div', 'eq', 'gt', 'gte', 'lt',
                            'lte', 'minus', 'mod', 'plus', 'times', 'toFr'
                        ][id ? id < 0 ? -id : id : 1 / id < 0 ? 1 : 0] + '()',
                        message = outOfRange ? ' out of range' : ' not a' +
                            (isRange ? ' non-zero' : 'n') + ' integer';

                    message = ([
                            method + ' number type has more than 15 significant digits',
                            method + ' not a base ' + j + ' number',
                            method + ' base' + message,
                            method + ' not a number'
                        ][i] ||
                        j + '() ' + i + (isErrors ? ' not a boolean or binary digit' : message + (isArray ? ' or not [' + (outOfRange ? ' negative, positive' : ' integer, integer') + ' ]' : ''))) + ': ' + arg;

                    outOfRange = id = 0;
                    error = new Error(message);
                    error['name'] = 'BigNumber Error';

                    throw error
                }
            }


            /*
             * Convert a numeric string of baseIn to a numeric string of baseOut.
             */
            function convert(nStr, baseOut, baseIn, sign) {
                var e, dvs, dvd, nArr, fracArr, fracBN;

                // Convert string of base bIn to an array of numbers of baseOut.
                // Eg. strToArr('255', 10) where baseOut is 16, returns [15, 15].
                // Eg. strToArr('ff', 16)  where baseOut is 10, returns [2, 5, 5].
                function strToArr(str, bIn) {
                    var j,
                        i = 0,
                        strL = str.length,
                        arrL,
                        arr = [0];

                    for (bIn = bIn || baseIn; i < strL; i++) {

                        for (arrL = arr.length, j = 0; j < arrL; arr[j] *= bIn, j++) {}

                        for (arr[0] += DIGITS.indexOf(str.charAt(i)), j = 0; j < arr.length; j++) {

                            if (arr[j] > baseOut - 1) {

                                if (arr[j + 1] == null) {
                                    arr[j + 1] = 0
                                }
                                arr[j + 1] += arr[j] / baseOut ^ 0;
                                arr[j] %= baseOut
                            }
                        }
                    }

                    return arr.reverse()
                }

                // Convert array to string.
                // E.g. arrToStr( [9, 10, 11] ) becomes '9ab' (in bases above 11).
                function arrToStr(arr) {
                    var i = 0,
                        arrL = arr.length,
                        str = '';

                    for (; i < arrL; str += DIGITS.charAt(arr[i++])) {}

                    return str
                }

                if (baseIn < 37) {
                    nStr = nStr.toLowerCase()
                }

                /*
                 * If non-integer convert integer part and fraction part separately.
                 * Convert the fraction part as if it is an integer than use division to
                 * reduce it down again to a value less than one.
                 */
                if ((e = nStr.indexOf('.')) > -1) {

                    /*
                     * Calculate the power to which to raise the base to get the number
                     * to divide the fraction part by after it has been converted as an
                     * integer to the required base.
                     */
                    e = nStr.length - e - 1;

                    // Use toFixed to avoid possible exponential notation.
                    dvs = strToArr(new BigNumber(baseIn)['pow'](e)['toF'](), 10);

                    nArr = nStr.split('.');

                    // Convert the base of the fraction part (as integer).
                    dvd = strToArr(nArr[1]);

                    // Convert the base of the integer part.
                    nArr = strToArr(nArr[0]);

                    // Result will be a BigNumber with a value less than 1.
                    fracBN = divide(dvd, dvs, dvd.length - dvs.length, sign, baseOut,
                        // Is least significant digit of integer part an odd number?
                        nArr[nArr.length - 1] & 1);

                    fracArr = fracBN['c'];

                    // e can be <= 0  ( if e == 0, fracArr is [0] or [1] ).
                    if (e = fracBN['e']) {

                        // Append zeros according to the exponent of the result.
                        for (; ++e; fracArr.unshift(0)) {}

                        // Append the fraction part to the converted integer part.
                        nStr = arrToStr(nArr) + '.' + arrToStr(fracArr)

                        // fracArr is [1].
                        // Fraction digits rounded up, so increment last digit of integer part.
                    } else if (fracArr[0]) {

                        if (nArr[e = nArr.length - 1] < baseOut - 1) {
                            ++nArr[e];
                            nStr = arrToStr(nArr)
                        } else {
                            nStr = new BigNumber(arrToStr(nArr),
                                baseOut)['plus'](ONE)['toS'](baseOut)
                        }

                        // fracArr is [0]. No fraction digits.
                    } else {
                        nStr = arrToStr(nArr)
                    }
                } else {

                    // Simple integer. Convert base.
                    nStr = arrToStr(strToArr(nStr))
                }

                return nStr
            }


            // Perform division in the specified base. Called by div and convert.
            function divide(dvd, dvs, exp, s, base, isOdd) {
                var dvsL, dvsT, next, cmp, remI,
                    dvsZ = dvs.slice(),
                    dvdI = dvsL = dvs.length,
                    dvdL = dvd.length,
                    rem = dvd.slice(0, dvsL),
                    remL = rem.length,
                    quo = new BigNumber(ONE),
                    qc = quo['c'] = [],
                    qi = 0,
                    dig = DECIMAL_PLACES + (quo['e'] = exp) + 1;

                quo['s'] = s;
                s = dig < 0 ? 0 : dig;

                // Add zeros to make remainder as long as divisor.
                for (; remL++ < dvsL; rem.push(0)) {}

                // Create version of divisor with leading zero.
                dvsZ.unshift(0);

                do {

                    // 'next' is how many times the divisor goes into the current remainder.
                    for (next = 0; next < base; next++) {

                        // Compare divisor and remainder.
                        if (dvsL != (remL = rem.length)) {
                            cmp = dvsL > remL ? 1 : -1
                        } else {
                            for (remI = -1, cmp = 0; ++remI < dvsL;) {

                                if (dvs[remI] != rem[remI]) {
                                    cmp = dvs[remI] > rem[remI] ? 1 : -1;
                                    break
                                }
                            }
                        }

                        // Subtract divisor from remainder (if divisor < remainder).
                        if (cmp < 0) {

                            // Remainder cannot be more than one digit longer than divisor.
                            // Equalise lengths using divisor with extra leading zero?
                            for (dvsT = remL == dvsL ? dvs : dvsZ; remL;) {

                                if (rem[--remL] < dvsT[remL]) {

                                    for (remI = remL; remI && !rem[--remI]; rem[remI] = base - 1) {}
                                    --rem[remI];
                                    rem[remL] += base
                                }
                                rem[remL] -= dvsT[remL]
                            }
                            for (; !rem[0]; rem.shift()) {}
                        } else {
                            break
                        }
                    }

                    // Add the 'next' digit to the result array.
                    qc[qi++] = cmp ? next : ++next;

                    // Update the remainder.
                    rem[0] && cmp ? (rem[remL] = dvd[dvdI] || 0) : (rem = [dvd[dvdI]])

                } while ((dvdI++ < dvdL || rem[0] != null) && s--);

                // Leading zero? Do not remove if result is simply zero (qi == 1).
                if (!qc[0] && qi != 1) {

                    // There can't be more than one zero.
                    --quo['e'];
                    qc.shift()
                }

                // Round?
                if (qi > dig) {
                    rnd(quo, DECIMAL_PLACES, base, isOdd, rem[0] != null)
                }

                // Overflow?
                if (quo['e'] > MAX_EXP) {

                    // Infinity.
                    quo['c'] = quo['e'] = null

                    // Underflow?
                } else if (quo['e'] < MIN_EXP) {

                    // Zero.
                    quo['c'] = [quo['e'] = 0]
                }

                return quo
            }


            /*
             * Return a string representing the value of BigNumber n in normal or
             * exponential notation rounded to the specified decimal places or
             * significant digits.
             * Called by toString, toExponential (exp 1), toFixed, and toPrecision (exp 2).
             * d is the index (with the value in normal notation) of the digit that may be
             * rounded up.
             */
            function format(n, d, exp) {

                // Initially, i is the number of decimal places required.
                var i = d - (n = new BigNumber(n))['e'],
                    c = n['c'];

                // +-Infinity or NaN?
                if (!c) {
                    return n['toS']()
                }

                // Round?
                if (c.length > ++d) {
                    rnd(n, i, 10)
                }

                // Recalculate d if toFixed as n['e'] may have changed if value rounded up.
                i = c[0] == 0 ? i + 1 : exp ? d : n['e'] + i + 1;

                // Append zeros?
                for (; c.length < i; c.push(0)) {}
                i = n['e'];

                /*
                 * toPrecision returns exponential notation if the number of significant
                 * digits specified is less than the number of digits necessary to
                 * represent the integer part of the value in normal notation.
                 */
                return exp == 1 || exp == 2 && (--d < i || i <= TO_EXP_NEG)

                // Exponential notation.
                ? (n['s'] < 0 && c[0] ? '-' : '') + (c.length > 1 ? (c.splice(1, 0, '.'), c.join('')) : c[0]) + (i < 0 ? 'e' : 'e+') + i

                // Normal notation.
                : n['toS']()
            }


            // Round if necessary.
            // Called by divide, format, setMode and sqrt.
            function rnd(x, dp, base, isOdd, r) {
                var xc = x['c'],
                    isNeg = x['s'] < 0,
                    half = base / 2,
                    i = x['e'] + dp + 1,

                    // 'next' is the digit after the digit that may be rounded up.
                    next = xc[i],

                    /*
                     * 'more' is whether there are digits after 'next'.
                     * E.g.
                     * 0.005 (e = -3) to be rounded to 0 decimal places (dp = 0) gives i = -2
                     * The 'next' digit is zero, and there ARE 'more' digits after it.
                     * 0.5 (e = -1) dp = 0 gives i = 0
                     * The 'next' digit is 5 and there are no 'more' digits after it.
                     */
                    more = r || i < 0 || xc[i + 1] != null;

                r = ROUNDING_MODE < 4 ? (next != null || more) &&
                    (ROUNDING_MODE == 0 ||
                    ROUNDING_MODE == 2 && !isNeg ||
                    ROUNDING_MODE == 3 && isNeg) : next > half || next == half &&
                    (ROUNDING_MODE == 4 || more ||

                    /*
                     * isOdd is used in base conversion and refers to the least significant
                     * digit of the integer part of the value to be converted. The fraction
                     * part is rounded by this method separately from the integer part.
                     */
                    ROUNDING_MODE == 6 && (xc[i - 1] & 1 || !dp && isOdd) ||
                    ROUNDING_MODE == 7 && !isNeg ||
                    ROUNDING_MODE == 8 && isNeg);

                if (i < 1 || !xc[0]) {
                    xc.length = 0;
                    xc.push(0);

                    if (r) {

                        // 1, 0.1, 0.01, 0.001, 0.0001 etc.
                        xc[0] = 1;
                        x['e'] = -dp
                    } else {

                        // Zero.
                        x['e'] = 0
                    }

                    return x
                }

                // Remove any digits after the required decimal places.
                xc.length = i--;

                // Round up?
                if (r) {

                    // Rounding up may mean the previous digit has to be rounded up and so on.
                    for (--base; ++xc[i] > base;) {
                        xc[i] = 0;

                        if (!i--) {
                            ++x['e'];
                            xc.unshift(1)
                        }
                    }
                }

                // Remove trailing zeros.
                for (i = xc.length; !xc[--i]; xc.pop()) {}

                return x
            }


            // Round after setting the appropriate rounding mode.
            // Handles ceil, floor and round.
            function setMode(x, dp, rm) {
                var r = ROUNDING_MODE;

                ROUNDING_MODE = rm;
                x = new BigNumber(x);
                x['c'] && rnd(x, dp, 10);
                ROUNDING_MODE = r;

                return x
            }


            // PROTOTYPE/INSTANCE METHODS


            /*
             * Return a new BigNumber whose value is the absolute value of this BigNumber.
             */
            P['abs'] = P['absoluteValue'] = function () {
                var x = new BigNumber(this);

                if (x['s'] < 0) {
                    x['s'] = 1
                }

                return x
            };


            /*
             * Return a new BigNumber whose value is the value of this BigNumber
             * rounded to a whole number in the direction of Infinity.
             */
            P['ceil'] = function () {
                return setMode(this, 0, 2)
            };


            /*
             * Return
             * 1 if the value of this BigNumber is greater than the value of BigNumber(y, b),
             * -1 if the value of this BigNumber is less than the value of BigNumber(y, b),
             * 0 if they have the same value,
             * or null if the value of either is NaN.
             */
            P['comparedTo'] = P['cmp'] = function (y, b) {
                var a,
                    x = this,
                    xc = x['c'],
                    yc = (id = -id, y = new BigNumber(y, b))['c'],
                    i = x['s'],
                    j = y['s'],
                    k = x['e'],
                    l = y['e'];

                // Either NaN?
                if (!i || !j) {
                    return null
                }

                a = xc && !xc[0], b = yc && !yc[0];

                // Either zero?
                if (a || b) {
                    return a ? b ? 0 : -j : i
                }

                // Signs differ?
                if (i != j) {
                    return i
                }

                // Either Infinity?
                if (a = i < 0, b = k == l, !xc || !yc) {
                    return b ? 0 : !xc ^ a ? 1 : -1
                }

                // Compare exponents.
                if (!b) {
                    return k > l ^ a ? 1 : -1
                }

                // Compare digit by digit.
                for (i = -1,
                    j = (k = xc.length) < (l = yc.length) ? k : l;
                    ++i < j;) {

                    if (xc[i] != yc[i]) {
                        return xc[i] > yc[i] ^ a ? 1 : -1
                    }
                }
                // Compare lengths.
                return k == l ? 0 : k > l ^ a ? 1 : -1
            };


            /*
             *  n / 0 = I
             *  n / N = N
             *  n / I = 0
             *  0 / n = 0
             *  0 / 0 = N
             *  0 / N = N
             *  0 / I = 0
             *  N / n = N
             *  N / 0 = N
             *  N / N = N
             *  N / I = N
             *  I / n = I
             *  I / 0 = I
             *  I / N = N
             *  I / I = N
             *
             * Return a new BigNumber whose value is the value of this BigNumber
             * divided by the value of BigNumber(y, b), rounded according to
             * DECIMAL_PLACES and ROUNDING_MODE.
             */
            P['dividedBy'] = P['div'] = function (y, b) {
                var xc = this['c'],
                    xe = this['e'],
                    xs = this['s'],
                    yc = (id = 2, y = new BigNumber(y, b))['c'],
                    ye = y['e'],
                    ys = y['s'],
                    s = xs == ys ? 1 : -1;

                // Either NaN/Infinity/0?
                return !xe && (!xc || !xc[0]) || !ye && (!yc || !yc[0])

                // Either NaN?
                ? new BigNumber(!xs || !ys ||

                    // Both 0 or both Infinity?
                    (xc ? yc && xc[0] == yc[0] : !yc)

                    // Return NaN.
                    ? NaN

                    // x is 0 or y is Infinity?
                    : xc && xc[0] == 0 || !yc

                    // Return +-0.
                    ? s * 0

                    // y is 0. Return +-Infinity.
                    : s / 0)

                : divide(xc, yc, xe - ye, s, 10)
            };


            /*
             * Return true if the value of this BigNumber is equal to the value of
             * BigNumber(n, b), otherwise returns false.
             */
            P['equals'] = P['eq'] = function (n, b) {
                id = 3;
                return this['cmp'](n, b) === 0
            };


            /*
             * Return a new BigNumber whose value is the value of this BigNumber
             * rounded to a whole number in the direction of -Infinity.
             */
            P['floor'] = function () {
                return setMode(this, 0, 3)
            };


            /*
             * Return true if the value of this BigNumber is greater than the value of
             * BigNumber(n, b), otherwise returns false.
             */
            P['greaterThan'] = P['gt'] = function (n, b) {
                id = 4;
                return this['cmp'](n, b) > 0
            };


            /*
             * Return true if the value of this BigNumber is greater than or equal to
             * the value of BigNumber(n, b), otherwise returns false.
             */
            P['greaterThanOrEqualTo'] = P['gte'] = function (n, b) {
                id = 5;
                return (b = this['cmp'](n, b)) == 1 || b === 0
            };


            /*
             * Return true if the value of this BigNumber is a finite number, otherwise
             * returns false.
             */
            P['isFinite'] = P['isF'] = function () {
                return !!this['c']
            };


            /*
             * Return true if the value of this BigNumber is NaN, otherwise returns
             * false.
             */
            P['isNaN'] = function () {
                return !this['s']
            };


            /*
             * Return true if the value of this BigNumber is negative, otherwise
             * returns false.
             */
            P['isNegative'] = P['isNeg'] = function () {
                return this['s'] < 0
            };


            /*
             * Return true if the value of this BigNumber is 0 or -0, otherwise returns
             * false.
             */
            P['isZero'] = P['isZ'] = function () {
                return !!this['c'] && this['c'][0] == 0
            };


            /*
             * Return true if the value of this BigNumber is less than the value of
             * BigNumber(n, b), otherwise returns false.
             */
            P['lessThan'] = P['lt'] = function (n, b) {
                id = 6;
                return this['cmp'](n, b) < 0
            };


            /*
             * Return true if the value of this BigNumber is less than or equal to the
             * value of BigNumber(n, b), otherwise returns false.
             */
            P['lessThanOrEqualTo'] = P['lte'] = function (n, b) {
                id = 7;
                return (b = this['cmp'](n, b)) == -1 || b === 0
            };


            /*
             *  n - 0 = n
             *  n - N = N
             *  n - I = -I
             *  0 - n = -n
             *  0 - 0 = 0
             *  0 - N = N
             *  0 - I = -I
             *  N - n = N
             *  N - 0 = N
             *  N - N = N
             *  N - I = N
             *  I - n = I
             *  I - 0 = I
             *  I - N = N
             *  I - I = N
             *
             * Return a new BigNumber whose value is the value of this BigNumber minus
             * the value of BigNumber(y, b).
             */
            P['minus'] = function (y, b) {
                var d, i, j, xLTy,
                    x = this,
                    a = x['s'];

                b = (id = 8, y = new BigNumber(y, b))['s'];

                // Either NaN?
                if (!a || !b) {
                    return new BigNumber(NaN)
                }

                // Signs differ?
                if (a != b) {
                    return y['s'] = -b, x['plus'](y)
                }

                var xc = x['c'],
                    xe = x['e'],
                    yc = y['c'],
                    ye = y['e'];

                if (!xe || !ye) {

                    // Either Infinity?
                    if (!xc || !yc) {
                        return xc ? (y['s'] = -b, y) : new BigNumber(yc ? x : NaN)
                    }

                    // Either zero?
                    if (!xc[0] || !yc[0]) {

                        // y is non-zero?
                        return yc[0] ? (y['s'] = -b, y)

                        // x is non-zero?
                        : new BigNumber(xc[0] ? x

                            // Both are zero.
                            // IEEE 754 (2008) 6.3: n - n = -0 when rounding to -Infinity
                            : ROUNDING_MODE == 3 ? -0 : 0)
                    }
                }

                // Determine which is the bigger number.
                // Prepend zeros to equalise exponents.
                if (xc = xc.slice(), a = xe - ye) {
                    d = (xLTy = a < 0) ? (a = -a, xc) : (ye = xe, yc);

                    for (d.reverse(), b = a; b--; d.push(0)) {}
                    d.reverse()
                } else {

                    // Exponents equal. Check digit by digit.
                    j = ((xLTy = xc.length < yc.length) ? xc : yc).length;

                    for (a = b = 0; b < j; b++) {

                        if (xc[b] != yc[b]) {
                            xLTy = xc[b] < yc[b];
                            break
                        }
                    }
                }

                // x < y? Point xc to the array of the bigger number.
                if (xLTy) {
                    d = xc, xc = yc, yc = d;
                    y['s'] = -y['s']
                }

                /*
                 * Append zeros to xc if shorter. No need to add zeros to yc if shorter
                 * as subtraction only needs to start at yc.length.
                 */
                if ((b = -((j = xc.length) - yc.length)) > 0) {

                    for (; b--; xc[j++] = 0) {}
                }

                // Subtract yc from xc.
                for (b = yc.length; b > a;) {

                    if (xc[--b] < yc[b]) {

                        for (i = b; i && !xc[--i]; xc[i] = 9) {}
                        --xc[i];
                        xc[b] += 10
                    }
                    xc[b] -= yc[b]
                }

                // Remove trailing zeros.
                for (; xc[--j] == 0; xc.pop()) {}

                // Remove leading zeros and adjust exponent accordingly.
                for (; xc[0] == 0; xc.shift(), --ye) {}

                /*
                 * No need to check for Infinity as +x - +y != Infinity && -x - -y != Infinity
                 * when neither x or y are Infinity.
                 */

                // Underflow?
                if (ye < MIN_EXP || !xc[0]) {

                    /*
                     * Following IEEE 754 (2008) 6.3,
                     * n - n = +0  but  n - n = -0 when rounding towards -Infinity.
                     */
                    if (!xc[0]) {
                        y['s'] = ROUNDING_MODE == 3 ? -1 : 1
                    }

                    // Result is zero.
                    xc = [ye = 0]
                }

                return y['c'] = xc, y['e'] = ye, y
            };


            /*
             *   n % 0 =  N
             *   n % N =  N
             *   0 % n =  0
             *  -0 % n = -0
             *   0 % 0 =  N
             *   0 % N =  N
             *   N % n =  N
             *   N % 0 =  N
             *   N % N =  N
             *
             * Return a new BigNumber whose value is the value of this BigNumber modulo
             * the value of BigNumber(y, b).
             */
            P['modulo'] = P['mod'] = function (y, b) {
                var x = this,
                    xc = x['c'],
                    yc = (id = 9, y = new BigNumber(y, b))['c'],
                    i = x['s'],
                    j = y['s'];

                // Is x or y NaN, or y zero?
                b = !i || !j || yc && !yc[0];

                if (b || xc && !xc[0]) {
                    return new BigNumber(b ? NaN : x)
                }

                x['s'] = y['s'] = 1;
                b = y['cmp'](x) == 1;
                x['s'] = i, y['s'] = j;

                return b ? new BigNumber(x) : (i = DECIMAL_PLACES, j = ROUNDING_MODE,
                    DECIMAL_PLACES = 0, ROUNDING_MODE = 1,
                    x = x['div'](y),
                    DECIMAL_PLACES = i, ROUNDING_MODE = j,
                    this['minus'](x['times'](y)))
            };


            /*
             * Return a new BigNumber whose value is the value of this BigNumber
             * negated, i.e. multiplied by -1.
             */
            P['negated'] = P['neg'] = function () {
                var x = new BigNumber(this);

                return x['s'] = -x['s'] || null, x
            };


            /*
             *  n + 0 = n
             *  n + N = N
             *  n + I = I
             *  0 + n = n
             *  0 + 0 = 0
             *  0 + N = N
             *  0 + I = I
             *  N + n = N
             *  N + 0 = N
             *  N + N = N
             *  N + I = N
             *  I + n = I
             *  I + 0 = I
             *  I + N = N
             *  I + I = I
             *
             * Return a new BigNumber whose value is the value of this BigNumber plus
             * the value of BigNumber(y, b).
             */
            P['plus'] = function (y, b) {
                var d,
                    x = this,
                    a = x['s'];

                b = (id = 10, y = new BigNumber(y, b))['s'];

                // Either NaN?
                if (!a || !b) {
                    return new BigNumber(NaN)
                }

                // Signs differ?
                if (a != b) {
                    return y['s'] = -b, x['minus'](y)
                }

                var xe = x['e'],
                    xc = x['c'],
                    ye = y['e'],
                    yc = y['c'];

                if (!xe || !ye) {

                    // Either Infinity?
                    if (!xc || !yc) {

                        // Return +-Infinity.
                        return new BigNumber(a / 0)
                    }

                    // Either zero?
                    if (!xc[0] || !yc[0]) {

                        // y is non-zero?
                        return yc[0] ? y

                        // x is non-zero?
                        : new BigNumber(xc[0] ? x

                            // Both are zero. Return zero.
                            : a * 0)
                    }
                }

                // Prepend zeros to equalise exponents.
                // Note: Faster to use reverse then do unshifts.
                if (xc = xc.slice(), a = xe - ye) {
                    d = a > 0 ? (ye = xe, yc) : (a = -a, xc);

                    for (d.reverse(); a--; d.push(0)) {}
                    d.reverse()
                }

                // Point xc to the longer array.
                if (xc.length - yc.length < 0) {
                    d = yc, yc = xc, xc = d
                }

                /*
                 * Only start adding at yc.length - 1 as the
                 * further digits of xc can be left as they are.
                 */
                for (a = yc.length, b = 0; a; b = (xc[--a] = xc[a] + yc[a] + b) / 10 ^ 0, xc[a] %= 10) {}

                // No need to check for zero, as +x + +y != 0 && -x + -y != 0

                if (b) {
                    xc.unshift(b);

                    // Overflow? (MAX_EXP + 1 possible)
                    if (++ye > MAX_EXP) {

                        // Infinity.
                        xc = ye = null
                    }
                }

                // Remove trailing zeros.
                for (a = xc.length; xc[--a] == 0; xc.pop()) {}

                return y['c'] = xc, y['e'] = ye, y
            };


            /*
             * Return a BigNumber whose value is the value of this BigNumber raised to
             * the power e. If e is negative round according to DECIMAL_PLACES and
             * ROUNDING_MODE.
             *
             * e {number} Integer, -MAX_POWER to MAX_POWER inclusive.
             */
            P['toPower'] = P['pow'] = function (e) {

                // e to integer, avoiding NaN or Infinity becoming 0.
                var i = e * 0 == 0 ? e | 0 : e,
                    x = new BigNumber(this),
                    y = new BigNumber(ONE);

                // Use Math.pow?
                // Pass +-Infinity for out of range exponents.
                if ((((outOfRange = e < -MAX_POWER || e > MAX_POWER) &&
                            (i = e * 1 / 0)) ||

                        /*
                         * Any exponent that fails the parse becomes NaN.
                         *
                         * Include 'e !== 0' because on Opera -0 == parseFloat(-0) is false,
                         * despite -0 === parseFloat(-0) && -0 == parseFloat('-0') is true.
                         */
                        parse(e) != e && e !== 0 && !(i = NaN)) &&

                    // 'pow() exponent not an integer: {e}'
                    // 'pow() exponent out of range: {e}'
                    !ifExceptionsThrow(e, 'exponent', 'pow') ||

                    // Pass zero to Math.pow, as any value to the power zero is 1.
                    !i) {

                    // i is +-Infinity, NaN or 0.
                    return new BigNumber(Math.pow(x['toS'](), i))
                }

                for (i = i < 0 ? -i : i;;) {

                    if (i & 1) {
                        y = y['times'](x)
                    }
                    i >>= 1;

                    if (!i) {
                        break
                    }
                    x = x['times'](x)
                }

                return e < 0 ? ONE['div'](y) : y
            };


            /*
             * Return a new BigNumber whose value is the value of this BigNumber
             * rounded to a maximum of dp decimal places using rounding mode rm, or to
             * 0 and ROUNDING_MODE respectively if omitted.
             *
             * [dp] {number} Integer, 0 to MAX inclusive.
             * [rm] {number} Integer, 0 to 8 inclusive.
             */
            P['round'] = function (dp, rm) {

                dp = dp == null || (((outOfRange = dp < 0 || dp > MAX) ||
                        parse(dp) != dp) &&

                    // 'round() decimal places out of range: {dp}'
                    // 'round() decimal places not an integer: {dp}'
                    !ifExceptionsThrow(dp, 'decimal places', 'round')) ? 0 : dp | 0;

                rm = rm == null || (((outOfRange = rm < 0 || rm > 8) ||

                        // Include '&& rm !== 0' because with Opera -0 == parseFloat(-0) is false.
                        parse(rm) != rm && rm !== 0) &&

                    // 'round() mode not an integer: {rm}'
                    // 'round() mode out of range: {rm}'
                    !ifExceptionsThrow(rm, 'mode', 'round')) ? ROUNDING_MODE : rm | 0;

                return setMode(this, dp, rm)
            };


            /*
             *  sqrt(-n) =  N
             *  sqrt( N) =  N
             *  sqrt(-I) =  N
             *  sqrt( I) =  I
             *  sqrt( 0) =  0
             *  sqrt(-0) = -0
             *
             * Return a new BigNumber whose value is the square root of the value of
             * this BigNumber, rounded according to DECIMAL_PLACES and ROUNDING_MODE.
             */
            P['squareRoot'] = P['sqrt'] = function () {
                var i, n, r, re, t,
                    x = this,
                    c = x['c'],
                    s = x['s'],
                    e = x['e'],
                    dp = DECIMAL_PLACES,
                    rm = ROUNDING_MODE,
                    half = new BigNumber('0.5');

                // Negative/NaN/Infinity/zero?
                if (s !== 1 || !c || !c[0]) {

                    return new BigNumber(!s || s < 0 && (!c || c[0]) ? NaN : c ? x : 1 / 0)
                }

                // Initial estimate.
                s = Math.sqrt(x['toS']());
                ROUNDING_MODE = 1;

                /*
          Math.sqrt underflow/overflow?
          Pass x to Math.sqrt as integer, then adjust the exponent of the result.
         */
                if (s == 0 || s == 1 / 0) {
                    n = c.join('');

                    if (!(n.length + e & 1)) {
                        n += '0'
                    }
                    r = new BigNumber(Math.sqrt(n) + '');

                    // r may still not be finite.
                    if (!r['c']) {
                        r['c'] = [1]
                    }
                    r['e'] = (((e + 1) / 2) | 0) - (e < 0 || e & 1)
                } else {
                    r = new BigNumber(n = s.toString())
                }
                re = r['e'];
                s = re + (DECIMAL_PLACES += 4);

                if (s < 3) {
                    s = 0
                }
                e = s;

                // Newton-Raphson iteration.
                for (;;) {
                    t = r;
                    r = half['times'](t['plus'](x['div'](t)));

                    if (t['c'].slice(0, s).join('') === r['c'].slice(0, s).join('')) {
                        c = r['c'];

                        /*
                  The exponent of r may here be one less than the final result
                  exponent (re), e.g 0.0009999 (e-4) --> 0.001 (e-3), so adjust
                  s so the rounding digits are indexed correctly.
                 */
                        s = s - (n && r['e'] < re);

                        /*
                  The 4th rounding digit may be in error by -1 so if the 4 rounding
                  digits are 9999 or 4999 (i.e. approaching a rounding boundary)
                  continue the iteration.
                 */
                        if (c[s] == 9 && c[s - 1] == 9 && c[s - 2] == 9 &&
                            (c[s - 3] == 9 || n && c[s - 3] == 4)) {

                            /*
                      If 9999 on first run through, check to see if rounding up
                      gives the exact result as the nines may infinitely repeat.
                     */
                            if (n && c[s - 3] == 9) {
                                t = r['round'](dp, 0);

                                if (t['times'](t)['eq'](x)) {
                                    ROUNDING_MODE = rm;
                                    DECIMAL_PLACES = dp;

                                    return t
                                }
                            }
                            DECIMAL_PLACES += 4;
                            s += 4;
                            n = ''
                        } else {

                            /*
                      If the rounding digits are null, 0000 or 5000, check for an
                      exact result. If not, then there are further digits so
                      increment the 1st rounding digit to ensure correct rounding.
                     */
                            if (!c[e] && !c[e - 1] && !c[e - 2] &&
                                (!c[e - 3] || c[e - 3] == 5)) {

                                // Truncate to the first rounding digit.
                                if (c.length > e - 2) {
                                    c.length = e - 2
                                }

                                if (!r['times'](r)['eq'](x)) {

                                    while (c.length < e - 3) {
                                        c.push(0)
                                    }
                                    c[e - 3]++
                                }
                            }
                            ROUNDING_MODE = rm;
                            rnd(r, DECIMAL_PLACES = dp, 10);

                            return r
                        }
                    }
                }
            };


            /*
             *  n * 0 = 0
             *  n * N = N
             *  n * I = I
             *  0 * n = 0
             *  0 * 0 = 0
             *  0 * N = N
             *  0 * I = N
             *  N * n = N
             *  N * 0 = N
             *  N * N = N
             *  N * I = N
             *  I * n = I
             *  I * 0 = N
             *  I * N = N
             *  I * I = I
             *
             * Return a new BigNumber whose value is the value of this BigNumber times
             * the value of BigNumber(y, b).
             */
            P['times'] = function (y, b) {
                var c,
                    x = this,
                    xc = x['c'],
                    yc = (id = 11, y = new BigNumber(y, b))['c'],
                    i = x['e'],
                    j = y['e'],
                    a = x['s'];

                y['s'] = a == (b = y['s']) ? 1 : -1;

                // Either NaN/Infinity/0?
                if (!i && (!xc || !xc[0]) || !j && (!yc || !yc[0])) {

                    // Either NaN?
                    return new BigNumber(!a || !b ||

                        // x is 0 and y is Infinity  or  y is 0 and x is Infinity?
                        xc && !xc[0] && !yc || yc && !yc[0] && !xc

                        // Return NaN.
                        ? NaN

                        // Either Infinity?
                        : !xc || !yc

                        // Return +-Infinity.
                        ? y['s'] / 0

                        // x or y is 0. Return +-0.
                        : y['s'] * 0)
                }
                y['e'] = i + j;

                if ((a = xc.length) < (b = yc.length)) {
                    c = xc, xc = yc, yc = c, j = a, a = b, b = j
                }

                for (j = a + b, c = []; j--; c.push(0)) {}

                // Multiply!
                for (i = b - 1; i > -1; i--) {

                    for (b = 0, j = a + i; j > i; b = c[j] + yc[i] * xc[j - i - 1] + b,
                        c[j--] = b % 10 | 0,
                        b = b / 10 | 0) {}

                    if (b) {
                        c[j] = (c[j] + b) % 10
                    }
                }

                b && ++y['e'];

                // Remove any leading zero.
                !c[0] && c.shift();

                // Remove trailing zeros.
                for (j = c.length; !c[--j]; c.pop()) {}

                // No zero check needed as only x * 0 == 0 etc.

                // Overflow?
                y['c'] = y['e'] > MAX_EXP

                // Infinity.
                ? (y['e'] = null)

                // Underflow?
                : y['e'] < MIN_EXP

                // Zero.
                ? [y['e'] = 0]

                // Neither.
                : c;

                return y
            };


            /*
             * Return a string representing the value of this BigNumber in exponential
             * notation to dp fixed decimal places and rounded using ROUNDING_MODE if
             * necessary.
             *
             * [dp] {number} Integer, 0 to MAX inclusive.
             */
            P['toExponential'] = P['toE'] = function (dp) {

                return format(this, (dp == null || ((outOfRange = dp < 0 || dp > MAX) ||

                        /*
                         * Include '&& dp !== 0' because with Opera -0 == parseFloat(-0) is
                         * false, despite -0 == parseFloat('-0') && 0 == -0 being true.
                         */
                        parse(dp) != dp && dp !== 0) &&

                    // 'toE() decimal places not an integer: {dp}'
                    // 'toE() decimal places out of range: {dp}'
                    !ifExceptionsThrow(dp, 'decimal places', 'toE')) && this['c'] ? this['c'].length - 1 : dp | 0, 1)
            };


            /*
             * Return a string representing the value of this BigNumber in normal
             * notation to dp fixed decimal places and rounded using ROUNDING_MODE if
             * necessary.
             *
             * Note: as with JavaScript's number type, (-0).toFixed(0) is '0',
             * but e.g. (-0.00001).toFixed(0) is '-0'.
             *
             * [dp] {number} Integer, 0 to MAX inclusive.
             */
            P['toFixed'] = P['toF'] = function (dp) {
                var n, str, d,
                    x = this;

                if (!(dp == null || ((outOfRange = dp < 0 || dp > MAX) ||
                        parse(dp) != dp && dp !== 0) &&

                    // 'toF() decimal places not an integer: {dp}'
                    // 'toF() decimal places out of range: {dp}'
                    !ifExceptionsThrow(dp, 'decimal places', 'toF'))) {
                    d = x['e'] + (dp | 0)
                }

                n = TO_EXP_NEG, dp = TO_EXP_POS;
                TO_EXP_NEG = -(TO_EXP_POS = 1 / 0);

                // Note: str is initially undefined.
                if (d == str) {
                    str = x['toS']()
                } else {
                    str = format(x, d);

                    // (-0).toFixed() is '0', but (-0.1).toFixed() is '-0'.
                    // (-0).toFixed(1) is '0.0', but (-0.01).toFixed(1) is '-0.0'.
                    if (x['s'] < 0 && x['c']) {

                        // As e.g. -0 toFixed(3), will wrongly be returned as -0.000 from toString.
                        if (!x['c'][0]) {
                            str = str.replace(/^-/, '')

                            // As e.g. -0.5 if rounded to -0 will cause toString to omit the minus sign.
                        } else if (str.indexOf('-') < 0) {
                            str = '-' + str
                        }
                    }
                }
                TO_EXP_NEG = n, TO_EXP_POS = dp;

                return str
            };


            /*
             * Return a string array representing the value of this BigNumber as a
             * simple fraction with an integer numerator and an integer denominator.
             * The denominator will be a positive non-zero value less than or equal to
             * the specified maximum denominator. If a maximum denominator is not
             * specified, the denominator will be the lowest value necessary to
             * represent the number exactly.
             *
             * [maxD] {number|string|BigNumber} Integer >= 1 and < Infinity.
             */
            P['toFraction'] = P['toFr'] = function (maxD) {
                var q, frac, n0, d0, d2, n, e,
                    n1 = d0 = new BigNumber(ONE),
                    d1 = n0 = new BigNumber('0'),
                    x = this,
                    xc = x['c'],
                    exp = MAX_EXP,
                    dp = DECIMAL_PLACES,
                    rm = ROUNDING_MODE,
                    d = new BigNumber(ONE);

                // NaN, Infinity.
                if (!xc) {
                    return x['toS']()
                }

                e = d['e'] = xc.length - x['e'] - 1;

                // If max denominator is undefined or null...
                if (maxD == null ||

                    // or NaN...
                    (!(id = 12, n = new BigNumber(maxD))['s'] ||

                        // or less than 1, or Infinity...
                        (outOfRange = n['cmp'](n1) < 0 || !n['c']) ||

                        // or not an integer...
                        (ERRORS && n['e'] < n['c'].length - 1)) &&

                    // 'toFr() max denominator not an integer: {maxD}'
                    // 'toFr() max denominator out of range: {maxD}'
                    !ifExceptionsThrow(maxD, 'max denominator', 'toFr') ||

                    // or greater than the maxD needed to specify the value exactly...
                    (maxD = n)['cmp'](d) > 0) {

                    // d is e.g. 10, 100, 1000, 10000... , n1 is 1.
                    maxD = e > 0 ? d : n1
                }

                MAX_EXP = 1 / 0;
                n = new BigNumber(xc.join(''));

                for (DECIMAL_PLACES = 0, ROUNDING_MODE = 1;;) {
                    q = n['div'](d);
                    d2 = d0['plus'](q['times'](d1));

                    if (d2['cmp'](maxD) == 1) {
                        break
                    }

                    d0 = d1, d1 = d2;

                    n1 = n0['plus'](q['times'](d2 = n1));
                    n0 = d2;

                    d = n['minus'](q['times'](d2 = d));
                    n = d2
                }

                d2 = maxD['minus'](d0)['div'](d1);
                n0 = n0['plus'](d2['times'](n1));
                d0 = d0['plus'](d2['times'](d1));

                n0['s'] = n1['s'] = x['s'];

                DECIMAL_PLACES = e * 2;
                ROUNDING_MODE = rm;

                // Determine which fraction is closer to x, n0 / d0 or n1 / d1?
                frac = n1['div'](d1)['minus'](x)['abs']()['cmp'](
                    n0['div'](d0)['minus'](x)['abs']()) < 1 ? [n1['toS'](), d1['toS']()] : [n0['toS'](), d0['toS']()];

                return MAX_EXP = exp, DECIMAL_PLACES = dp, frac
            };


            /*
             * Return a string representing the value of this BigNumber to sd significant
             * digits and rounded using ROUNDING_MODE if necessary.
             * If sd is less than the number of digits necessary to represent the integer
             * part of the value in normal notation, then use exponential notation.
             *
             * sd {number} Integer, 1 to MAX inclusive.
             */
            P['toPrecision'] = P['toP'] = function (sd) {

                /*
                 * ERRORS true: Throw if sd not undefined, null or an integer in range.
                 * ERRORS false: Ignore sd if not a number or not in range.
                 * Truncate non-integers.
                 */
                return sd == null || (((outOfRange = sd < 1 || sd > MAX) ||
                        parse(sd) != sd) &&

                    // 'toP() precision not an integer: {sd}'
                    // 'toP() precision out of range: {sd}'
                    !ifExceptionsThrow(sd, 'precision', 'toP')) ? this['toS']() : format(this, --sd | 0, 2)
            };


            /*
             * Return a string representing the value of this BigNumber in base b, or
             * base 10 if b is omitted. If a base is specified, including base 10,
             * round according to DECIMAL_PLACES and ROUNDING_MODE.
             * If a base is not specified, and this BigNumber has a positive exponent
             * that is equal to or greater than TO_EXP_POS, or a negative exponent equal
             * to or less than TO_EXP_NEG, return exponential notation.
             *
             * [b] {number} Integer, 2 to 64 inclusive.
             */
            P['toString'] = P['toS'] = function (b) {
                var u, str, strL,
                    x = this,
                    xe = x['e'];

                // Infinity or NaN?
                if (xe === null) {
                    str = x['s'] ? 'Infinity' : 'NaN'

                    // Exponential format?
                } else if (b === u && (xe <= TO_EXP_NEG || xe >= TO_EXP_POS)) {
                    return format(x, x['c'].length - 1, 1)
                } else {
                    str = x['c'].join('');

                    // Negative exponent?
                    if (xe < 0) {

                        // Prepend zeros.
                        for (; ++xe; str = '0' + str) {}
                        str = '0.' + str

                        // Positive exponent?
                    } else if (strL = str.length, xe > 0) {

                        if (++xe > strL) {

                            // Append zeros.
                            for (xe -= strL; xe--; str += '0') {}
                        } else if (xe < strL) {
                            str = str.slice(0, xe) + '.' + str.slice(xe)
                        }

                        // Exponent zero.
                    } else {
                        if (u = str.charAt(0), strL > 1) {
                            str = u + '.' + str.slice(1)

                            // Avoid '-0'
                        } else if (u == '0') {
                            return u
                        }
                    }

                    if (b != null) {

                        if (!(outOfRange = !(b >= 2 && b < 65)) &&
                            (b == (b | 0) || !ERRORS)) {
                            str = convert(str, b | 0, 10, x['s']);

                            // Avoid '-0'
                            if (str == '0') {
                                return str
                            }
                        } else {

                            // 'toS() base not an integer: {b}'
                            // 'toS() base out of range: {b}'
                            ifExceptionsThrow(b, 'base', 'toS')
                        }
                    }

                }

                return x['s'] < 0 ? '-' + str : str
            };


            /*
             * Return as toString, but do not accept a base argument.
             */
            P['valueOf'] = function () {
                return this['toS']()
            };


            // Add aliases for BigDecimal methods.
            //P['add'] = P['plus'];
            //P['subtract'] = P['minus'];
            //P['multiply'] = P['times'];
            //P['divide'] = P['div'];
            //P['remainder'] = P['mod'];
            //P['compareTo'] = P['cmp'];
            //P['negate'] = P['neg'];


            // EXPORT


            // Node and other CommonJS-like environments that support module.exports.
            if (typeof module !== 'undefined' && module.exports) {
                module.exports = BigNumber

                //AMD.
            } else if (typeof define == 'function' && define.amd) {
                define(function () {
                    return BigNumber
                })

                //Browser.
            } else {
                global['BigNumber'] = BigNumber
            }

        })(this);



        return this.BigNumber;
    }

    Definition = defineAstroDate(addBigNumberModule.call({}));
    /*global module, define */
    if (typeof module === 'object' && !isNull(module) && isTypeObject(module.exports)) {
        module.exports = Definition;
    } else if (typeof define === 'function' && isTypeObject(define.amd)) {
        define(function () {
            return Definition;
        });
    } else {
        globalThis.AstroDate = Definition;
    }

    tempSafariNFE = null;
}(this));
